@@ -31,7 +31,7 @@
 //////////////////////////////////////////////////////////////////////
 
 
-extern int Tau_Global_numCounters;
+extern "C" int Tau_Global_numCounters;
 #define TAU_STORAGE(type, variable) type variable[TAU_MAX_THREADS]
 #define TAU_MULTSTORAGE(type, variable) type variable[TAU_MAX_THREADS][TAU_MAX_COUNTERS]
 
@@ -43,6 +43,23 @@ extern int Tau_Global_numCounters;
 #include "Profile/RenciSTFF.h"
 #endif //RENCI_STFF
 
+// For EBS Sampling Profiles with custom allocator support
+#ifndef TAU_WINDOWS
+#include <sys/types.h>
+#include <unistd.h>
+#include <map>
+
+#include <Profile/TauPathHash.h>
+#include "Profile/TauSampling.h"
+
+#ifdef TAU_SS_ALLOC_SUPPORT
+#include <Profile/TauSsAllocator.h>
+#define SS_ALLOCATOR tau_ss_allocator
+#else
+#define SS_ALLOCATOR std::allocator
+#endif //TAU_SS_ALLOC_SUPPORT
+#endif //TAU_WINDOWS
+using namespace std;
 class TauUserEvent; 
 
 class FunctionInfo
@@ -131,8 +148,30 @@ public:
   char *Type;
   char *GroupName;
   char *AllGroups;
-  long FunctionId;
+  x_uint64 FunctionId;
+  string *FullName;
 
+  /* For EBS Sampling Profiles */
+  // *CWL* - these need to be per-thread structures, just like the
+  //         the data values above.
+  //         They will also potentially need per-counter information
+  //         eventually.
+  //  map<unsigned long, unsigned int> *pcHistogram;
+#ifndef TAU_WINDOWS
+  TauPathHashTable<TauPathAccumulator> *pathHistogram[TAU_MAX_THREADS];
+
+  // For CallSite discovery
+  bool isCallSite;
+  bool callSiteResolved;
+  unsigned long callSiteKeyId;
+  FunctionInfo *firstSpecializedFunction;
+  char *ShortenedName;
+  void SetShortName(string& str) { ShortenedName = strdup(str.c_str()); }
+  const char* GetShortName() const { return ShortenedName; }
+
+  /* EBS Sampling Profiles */
+  void addPcSample(unsigned long *pc, int tid, double interval[TAU_MAX_COUNTERS]);
+#endif // TAU_WINDOWS
 
   inline double *getDumpExclusiveValues(int tid) {
     return dumpExclusiveValues[tid];
@@ -147,6 +186,7 @@ public:
   const char* GetName() const { return Name; }
   void SetType(string& str) { Type = strdup(str.c_str()); }
   const char* GetType() const { return Type; }
+
   const char* GetPrimaryGroup() const { return GroupName; }
   const char* GetAllGroups() const { return AllGroups; }
   void SetPrimaryGroupName(const char *newname) { 
@@ -158,7 +198,10 @@ public:
     AllGroups = strdup(newname.c_str()); /* to make it to the profile */
   }
 
-  long GetFunctionId() ;
+  string *GetFullName(); /* created on demand, cached */
+
+
+  x_uint64 GetFunctionId() ;
   long GetCalls(int tid) { return NumCalls[tid]; }
   void SetCalls(int tid, long calls) { NumCalls[tid] = calls; }
   long GetSubrs(int tid) { return NumSubrs[tid]; }
@@ -201,7 +244,7 @@ public:
   inline void AddInclTimeForCounter(double value, int tid, int counter) { InclTime[tid][counter] += value; }
   inline void AddExclTimeForCounter(double value, int tid, int counter) { ExclTime[tid][counter] += value; }
   inline double GetInclTimeForCounter(int tid, int counter) { return InclTime[tid][counter]; }
-  inline double GetExclTimeForCounter(int tid, int counter) { return InclTime[tid][counter]; }
+  inline double GetExclTimeForCounter(int tid, int counter) { return ExclTime[tid][counter]; }
 
   TauGroup_t GetProfileGroup(int tid = RtsLayer::myThread()) const {return MyProfileGroup_[tid]; }
   void SetProfileGroup(TauGroup_t gr, int tid = RtsLayer::myThread()) {MyProfileGroup_[tid] = gr; }
@@ -270,6 +313,6 @@ void tauCreateFI(void **ptr, const string& name, const string& type,
 #endif /* _FUNCTIONINFO_H_ */
 /***************************************************************************
  * $RCSfile: FunctionInfo.h,v $   $Author: amorris $
- * $Revision: 1.55 $   $Date: 2009/04/11 00:17:56 $
- * POOMA_VERSION_ID: $Id: FunctionInfo.h,v 1.55 2009/04/11 00:17:56 amorris Exp $ 
+ * $Revision: 1.57 $   $Date: 2010/03/19 00:21:13 $
+ * POOMA_VERSION_ID: $Id: FunctionInfo.h,v 1.57 2010/03/19 00:21:13 amorris Exp $ 
  ***************************************************************************/
