@@ -48,8 +48,10 @@ pid_t tau_fork (void);
 #define pthread_exit(arg) \
         tau_pthread_exit(arg)
 
+#ifdef TAU_PTHREAD_BARRIER_AVAILABLE
 #define pthread_barrier_wait(barrier) \
   tau_track_pthread_barrier_wait(barrier)
+#endif /* TAU_PTHREAD_BARRIER_AVAILABLE */
 
 #ifdef __cplusplus
 extern "C" {
@@ -140,6 +142,10 @@ int tau_track_pthread_barrier_wait(pthread_barrier_t *barrier);
 #include <Profile/TauMapping.h>
 #include <Profile/TauSampling.h>
 
+#ifndef TAU_WINDOWS
+#include <sys/types.h>
+#endif
+
 #if defined(TAUKTAU)
 class KtauProfiler;
 #ifdef TAUKTAU_MERGE
@@ -175,6 +181,7 @@ public:
   bool AddInclCallPathFlag; 
   FunctionInfo *ThisFunction;
   FunctionInfo *CallPathFunction;
+  FunctionInfo *CallSiteFunction;
 
   Profiler() {};
   ~Profiler() {};
@@ -185,17 +192,15 @@ public:
 
   void CallPathStart(int tid);
   void CallPathStop(double* totaltime, int tid);
-  
+
 #ifdef TAU_PROFILEPARAM
   FunctionInfo *ProfileParamFunction; 
   bool 	       AddInclProfileParamFlag; 
   void ProfileParamStop(double* totaltime, int tid);
 #endif /* TAU_PROFILEPARAM */
   
-  
   double StartTime[TAU_MAX_COUNTERS];
 
-
   /* Compensate for instrumentation overhead based on total number of 
      child calls executed under the given timer */
   long NumChildren;
@@ -220,19 +225,23 @@ public:
   bool RecordEvent; /* true when an MPI call is in the callpath */
 #endif /* TAU_MPITRACE */
 
-
-#ifdef TAU_EXP_SAMPLING
+  /* For EBS sampling */
   int needToRecordStop;
   void *address[TAU_SAMP_NUM_ADDRESSES];
-#endif /* TAU_EXP_SAMPLING */
 
+  // Callsite discovery
+  unsigned long callsites[TAU_SAMP_NUM_ADDRESSES+1];
+  unsigned long callsiteKeyId;
+  long *path;
+  void CallSiteStart(int tid);
+  void CallSiteAddPath(long *comparison, int tid);
+  void CallSiteStop(double *totalTime, int tid);
 };
 }
 #ifdef TAU_LIBRARY_SOURCE
 using tau::Profiler;
 #endif /* TAU_LIBRARY_SOURCE */
 
-
 extern "C" tau::Profiler *TauInternal_CurrentProfiler(int tid);
 extern "C" tau::Profiler *TauInternal_ParentProfiler(int tid);
 
@@ -244,11 +253,6 @@ int TauProfiler_writeData(int tid, const char *prefix = "profile", bool incremen
 		       const char **inFuncs = NULL, int numFuncs = 0);
 void TauProfiler_PurgeData(int tid = RtsLayer::myThread());
 
-int TauProfiler_Snapshot(const char *name, bool finalize = false,
-		      int tid = RtsLayer::myThread()); 
-
-
-
 void TauProfiler_theFunctionList(const char ***inPtr, int *numOfFunctions,
 				 bool addName = false, const char *inString = NULL);
 void TauProfiler_dumpFunctionNames();
@@ -288,7 +292,7 @@ void TauProfiler_AddProfileParamData(long key, const char *keyname);
 
 #endif /* PROFILER_H */
 /***************************************************************************
- * $RCSfile: Profiler.h,v $   $Author: sameer $
- * $Revision: 1.118 $   $Date: 2010/03/02 21:20:07 $
- * POOMA_VERSION_ID: $Id: Profiler.h,v 1.118 2010/03/02 21:20:07 sameer Exp $ 
+ * $RCSfile: Profiler.h,v $   $Author: amorris $
+ * $Revision: 1.120 $   $Date: 2010/03/18 17:31:12 $
+ * POOMA_VERSION_ID: $Id: Profiler.h,v 1.120 2010/03/18 17:31:12 amorris Exp $ 
  ***************************************************************************/
