@@ -31,6 +31,9 @@
 
 typedef std::map<std::string, TauGroup_t, std::less<string> > ProfileMap_t;
 
+
+double TauWindowsUsecD(void);
+
 class RtsLayer {
   // Layer for Profiler to interact with the Runtime System
 public:
@@ -38,6 +41,11 @@ public:
   RtsLayer () { }  // defaults
   ~RtsLayer () { } 
 
+	static int createThread(void);
+	static void destroyThread(int id);
+	static void recycleThread(int id);
+
+
   static TauGroup_t & TheProfileMask(void);
   static bool& TheEnableInstrumentation(void);
   static bool& TheShutdown(void);
@@ -92,9 +100,15 @@ public:
   // Return the number of the 'current' thread. 0..TAU_MAX_THREADS-1
   static int myThread(void);
 
+  static int threadId(void);
+  
   static int getPid();
   static int getTid();
 
+#ifdef KTAU_NG
+  static int getLinuxKernelTid();
+#endif /* KTAU_NG */
+
   static int RegisterThread();
 	
   static void RegisterFork(int nodeid, enum TauFork_t opcode);
@@ -106,6 +120,7 @@ public:
   static void LockEnv(void);
   static void UnLockEnv(void);
 
+  static int getTotalThreads();
 
 
 private:
@@ -113,15 +128,24 @@ private:
   static void threadLockDB(void);
   static void threadUnLockDB(void);
 
+  static void threadLockEnv(void);
+  static void threadUnLockEnv(void);
+
   static int lockDBcount[TAU_MAX_THREADS];
+  static int lockEnvCount[TAU_MAX_THREADS];
 
   static bool initLocks();
+  static bool initEnvLocks();
+  //  static int *numThreads();
 
-}; 
+};
+
+extern "C" int Tau_RtsLayer_getTid();
+extern "C" int Tau_RtsLayer_createThread();
 
 #endif /* _RTSLAYER_H_  */
 /***************************************************************************
  * $RCSfile: RtsLayer.h,v $   $Author: amorris $
- * $Revision: 1.33 $   $Date: 2009/05/14 20:49:26 $
- * POOMA_VERSION_ID: $Id: RtsLayer.h,v 1.33 2009/05/14 20:49:26 amorris Exp $ 
+ * $Revision: 1.34 $   $Date: 2010/04/08 23:07:41 $
+ * POOMA_VERSION_ID: $Id: RtsLayer.h,v 1.34 2010/04/08 23:07:41 amorris Exp $ 
  ***************************************************************************/
