@@ -16,7 +16,9 @@
 #ifndef _TAU_API_H_
 #define _TAU_API_H_
 
+
 #ifdef TAU_ENABLED
+#include <Profile/tau_types.h>
 
 #if (defined(TAU_WINDOWS))
 #pragma warning( disable : 4786 )
@@ -105,7 +107,6 @@ extern "C" {
 
 #define TAU_SET_USER_CLOCK_THREAD(value, tid)   Tau_set_user_clock_thread(value, tid);
 #define TAU_SET_USER_CLOCK(value)               Tau_set_user_clock(value);
-
 #define TAU_PROFILE_INIT(argc, argv)		Tau_init(argc, argv);
 #define TAU_INIT(argc, argv)			Tau_init_ref(argc, argv);
 #define TAU_PROFILE_STMT(stmt) stmt;
@@ -126,6 +127,7 @@ extern "C" {
 
 /* DB Access */
 #define TAU_DB_DUMP()                           Tau_dump();
+#define TAU_DB_MERGED_DUMP()                    Tau_mergeProfiles();
 #define TAU_DB_DUMP_PREFIX(prefix)              Tau_dump_prefix(prefix);
 #define TAU_DB_DUMP_PREFIX_TASK(prefix, task)   Tau_dump_prefix_task(prefix, task);
 #define TAU_DB_DUMP_INCR()                      Tau_dump_incr();
@@ -150,11 +152,15 @@ extern "C" {
 /* Atomic Events */
 #define TAU_REGISTER_EVENT(event, name)	static void *event = 0; \
                                  if (event == 0) event = Tau_get_userevent(name);
-				
+#define TAU_PROFILER_REGISTER_EVENT(e, msg) TauUserEvent* e () { \
+	static TauUserEvent u(msg); return &u; } 
+ 
 #define TAU_REGISTER_CONTEXT_EVENT(event, name)	static void *event = 0; \
                                  if (event == 0) Tau_get_context_userevent(&event, name);  
 #define TAU_EVENT(event, data)			Tau_userevent(event, data);
+#define TAU_EVENT_THREAD(event, data, tid)				Tau_userevent_thread(event, data, tid)
 #define TAU_CONTEXT_EVENT(event, data)		Tau_context_userevent(event, data);
+#define TAU_CONTEXT_EVENT_THREAD(event, data, tid) Tau_context_userevent_thread(event, data, tid);
 #define TAU_EVENT_SET_NAME(event, name)	Tau_set_event_name(event, name); 	
 #define TAU_REPORT_STATISTICS()		Tau_report_statistics();
 #define TAU_REPORT_THREAD_STATISTICS()  Tau_report_thread_statistics();
@@ -211,10 +217,19 @@ extern "C" {
 
 #define TAU_GLOBAL_PHASE_EXTERNAL(timer)  extern void * TauGlobalPhase##timer(void)
 
+/* *CWL* - temporary monitoring interface. These functions must be implemented
+   by the monitoring framework. The functions should be implemented in a way
+   that does nothing should TAU_MONITORING be unset.
+*/
+#define TAU_ONLINE_DUMP()                       Tau_mon_onlineDump()
 
 #define TAU_PROFILE_SNAPSHOT(name)              Tau_profile_snapshot(name);
 #define TAU_PROFILE_SNAPSHOT_1L(name, expr)     Tau_profile_snapshot_1l(name, expr);
 #define TAU_METADATA(name, value)               Tau_metadata(name, value);
+#define TAU_METADATA_ITERATION(name,iteration,value) {char meta_buf[1024]; \
+        sprintf(meta_buf,"%s_|_%d",name,iteration); \
+        TAU_METADATA(meta_buf,value);}
+
 #define TAU_CONTEXT_METADATA(name, value)       Tau_context_metadata(name, value);
 #define TAU_PHASE_METADATA(name, value)         Tau_phase_metadata(name, value);
 
@@ -235,6 +250,11 @@ extern "C" {
 #define TAU_TRACE_RECVMSG(type, source, length) \
         Tau_trace_recvmsg(type, source, length);
 
+#define TAU_TRACE_SENDMSG_REMOTE(type, destination, length, remoteid) \
+        Tau_trace_sendmsg_remote(type, destination, length, remoteid);
+#define TAU_TRACE_RECVMSG_REMOTE(type, source, length, remoteid) \
+        Tau_trace_recvmsg_remote(type, source, length, remoteid);
+
 
 
 
@@ -269,6 +289,7 @@ extern "C" {
 #define TAU_SCATTER_DATA(data)                  Tau_scatter_data(data) 
 #define TAU_GATHER_DATA(data)  	                Tau_gather_data(data)
 #define TAU_ALLREDUCE_DATA(data)  	        Tau_allreduce_data(data)
+#define TAU_WAIT_DATA(data)  	        	Tau_wait_data(data)
 #define TAU_ALLGATHER_DATA(data)  	        Tau_allgather_data(data)
 #define TAU_REDUCESCATTER_DATA(data)  	        Tau_reducescatter_data(data)
 #define TAU_SCAN_DATA(data)  		        Tau_scan_data(data)
@@ -299,8 +320,6 @@ void Tau_stop(const char *name);
 int Tau_stop_current_timer();
 char * Tau_phase_enable(const char *group);
 
-void Tau_profile_snapshot(char *name);
-void Tau_profile_snapshot_1l(char *name, int number);
 void Tau_dynamic_start(char *name, int isPhase); 
 void Tau_dynamic_stop(char *name, int isPhase); 
 void Tau_static_phase_start(char *name);
@@ -316,6 +335,8 @@ void Tau_get_exclusive_values(void *handle, double* values, int tid);
 void Tau_set_exclusive_values(void *handle, double* values, int tid);
 void Tau_get_counter_info(const char ***counterlist, int *numcounters);
 int TAUDECL Tau_get_tid(void);
+int TAUDECL Tau_create_tid(void);
+int TAUDECL Tau_get_node(void);
 int  Tau_create_task(void);
 void Tau_destructor_trigger();
 
@@ -331,6 +352,19 @@ TauGroup_t Tau_profile_get_group(void *ptr);
 
 
 
+int Tau_global_get_insideTAU();
+int Tau_global_get_insideTAU_tid(int tid);
+int Tau_global_incr_insideTAU();
+int Tau_global_decr_insideTAU();
+int Tau_global_incr_insideTAU_tid(int tid);
+int Tau_global_decr_insideTAU_tid(int tid);
+int Tau_global_getLightsOut();
+void Tau_global_setLightsOut();
+
+long Tau_convert_ptr_to_long(void *ptr);
+unsigned long Tau_convert_ptr_to_unsigned_long(void *ptr);
+
+
 /* Runtime "context" access */
 void *Tau_query_current_event();
 const char *Tau_query_event_name(void *event);
@@ -369,6 +403,7 @@ void TAUDECL Tau_scatter_data(int data);
 void TAUDECL Tau_gather_data(int data);
 void TAUDECL Tau_allreduce_data(int data);
 void TAUDECL Tau_allgather_data(int data);
+void TAUDECL Tau_wait_data(int data);
 void TAUDECL Tau_reducescatter_data(int data);
 void TAUDECL Tau_scan_data(int data);
 void TAUDECL Tau_set_node(int node);
@@ -376,12 +411,17 @@ void TAUDECL Tau_start_timer(void *profiler, int phase, int tid);
 int TAUDECL Tau_stop_timer(void *profiler, int tid); 
 void TAUDECL Tau_trace_sendmsg(int type, int destination, int length);
 void TAUDECL Tau_trace_recvmsg(int type, int source, int length);
+void TAUDECL Tau_trace_recvmsg_remote(int type, int source, int length, int remoteid);
+void TAUDECL Tau_trace_sendmsg_remote(int type, int destination, int length, int remoteid);
 void TAUDECL Tau_create_top_level_timer_if_necessary(void);
 void TAUDECL Tau_stop_top_level_timer_if_necessary(void);
-void TAUDECL Tau_metadata(char *name, char *value);
+void TAUDECL Tau_metadata(char *name, const char *value);
 void TAUDECL Tau_phase_metadata(char *name, char *value);
 void TAUDECL Tau_context_metadata(char *name, char *value);
 
+void TAUDECL Tau_Bg_hwp_counters_start(int *error); 
+void TAUDECL Tau_Bg_hwp_counters_stop(int* numCounters, x_uint64 counters[], int* mode, int *error); 
+void TAUDECL Tau_Bg_hwp_counters_output(int* numCounters, x_uint64 counters[], int* mode, int* error);
 
 void Tau_set_user_clock(double value);
 void Tau_set_user_clock_thread(double value, int tid);
@@ -392,6 +432,7 @@ void Tau_set_context(int context);
 void Tau_set_thread(int thread);
 void Tau_callstack(void);
 int Tau_dump(void);
+int Tau_mergeProfiles();
 int Tau_dump_incr(void);
 void Tau_purge(void);
 void Tau_theFunctionList(const char ***functionList, int *num);
@@ -409,7 +450,9 @@ void Tau_register_fork(int nodeid, enum TauFork_t opcode);
 void* TAUDECL Tau_get_userevent(char *name);
 void Tau_get_context_userevent(void **ptr, char *name);
 void Tau_userevent(void *event, double data);
+void Tau_userevent_thread(void *event, double data, int tid);
 void Tau_context_userevent(void *event, double data);
+void Tau_context_userevent_thread(void *event, double data, int tid);
 void Tau_set_event_name(void *event, char * name);
 void Tau_report_statistics(void);
 void Tau_report_thread_statistics(void);
@@ -429,8 +472,9 @@ void Tau_disable_instrumentation(void);
 void Tau_global_stop(void);
 char * Tau_phase_enable_once(const char *group, void **ptr);
 
-void Tau_profile_snapshot(char *name);
-void Tau_profile_snapshot_1l(char *name, int number);
+void Tau_profile_snapshot(const char *name);
+void Tau_profile_snapshot_1l(const char *name, int number);
+void Tau_collate_onlineDump();
 
 void Tau_dynamic_start(char *name, int isPhase); 
 void Tau_dynamic_stop(char *name, int isPhase); 
@@ -453,6 +497,10 @@ void Tau_track_memory_headroom_here(void);
 void Tau_profile_param1l(long data, const char *dataname);
 
 
+void Tau_global_addWriteHook(void (*hook)(void));
+void Tau_global_callWriteHooks();
+
+
 #ifdef __cplusplus
 /* Include the C++ API header */
 #include <Profile/TauCppAPI.h>
@@ -461,7 +509,7 @@ void Tau_profile_param1l(long data, const char *dataname);
 #define TAU_PROFILE(name, type, group) 
 #define TAU_DYNAMIC_PROFILE(name, type, group) 
 #define TYPE_STRING(profileString, str)
-#define CT(obj)
+#define TAU_CT(obj)
 #endif /* __cplusplus */ 
 
 
@@ -501,7 +549,7 @@ void Tau_profile_param1l(long data, const char *dataname);
 
 #endif /* _TAU_API_H_ */
 /***************************************************************************
- * $RCSfile: TauAPI.h,v $   $Author: scottb $
- * $Revision: 1.105 $   $Date: 2010/02/12 22:52:17 $
- * POOMA_VERSION_ID: $Id: TauAPI.h,v 1.105 2010/02/12 22:52:17 scottb Exp $ 
+ * $RCSfile: TauAPI.h,v $   $Author: cheelee $
+ * $Revision: 1.116 $   $Date: 2010/06/08 01:09:52 $
+ * POOMA_VERSION_ID: $Id: TauAPI.h,v 1.116 2010/06/08 01:09:52 cheelee Exp $ 
  ***************************************************************************/
