@@ -18,7 +18,7 @@
 //////////////////////////////////////////////////////////////////////
 
 #include "Profile/Profiler.h"
-
+#include <sstream>
 
 #ifdef TAU_DOT_H_LESS_HEADERS
 #include <iostream>
@@ -46,12 +46,13 @@ using namespace std;
 #endif /* TAU_EPILOG */
 #endif /* TAU_VAMPIRTRACE */
 
-#ifdef TAU_SILC
-#include <Profile/TauSilc.h>
+#ifdef TAU_SCOREP
+#include <Profile/TauSCOREP.h>
 #endif
 
 #include <Profile/TauTrace.h>
 #include <Profile/TauInit.h>
+#include <Profile/TauUtil.h>
 
 //////////////////////////////////////////////////////////////////////
 // The purpose of this subclass of vector is to give us a chance to execute
@@ -80,7 +81,7 @@ vector<FunctionInfo*>& TheFunctionDB(void)
   static int flag = 1;
   if (flag) {
     flag = 0;
-    InitializeTAU();
+    Tau_init_initializeTAU();
   }
 
   return FunctionDB;
@@ -115,28 +116,7 @@ int& TheUsingCompInst()
   return UsingCompInst;
 }
 
-#ifdef TAU_VAMPIRTRACE
-//////////////////////////////////////////////////////////////////////
-// Initialize VampirTrace Tracing package
-//////////////////////////////////////////////////////////////////////
-int TauInitVampirTrace(void)
-{
-  DEBUGPROFMSG("Calling vt_open"<<endl;);
-  vt_open();
-  return 1;
-}
-#endif /* TAU_VAMPIRTRACE */
 
-#ifdef TAU_EPILOG 
-//////////////////////////////////////////////////////////////////////
-// Initialize EPILOG Tracing package
-//////////////////////////////////////////////////////////////////////
-int TauInitEpilog(void) {
-  DEBUGPROFMSG("Calling esd_open"<<endl;);
-  esd_open();
-  return 1;
-}
-#endif /* TAU_EPILOG */
 
 //////////////////////////////////////////////////////////////////////
 // Member Function Definitions For class FunctionInfo
@@ -167,17 +147,22 @@ void FunctionInfo::FunctionInfoInit(TauGroup_t ProfileGroup,
   static int flag = 1;
   if (flag) {
     flag = 0;
-    InitializeTAU();
+    Tau_init_initializeTAU();
   }
 
+  Tau_global_incr_insideTAU_tid(tid);
+
   //Need to keep track of all the groups this function is a member of.
   AllGroups = strip_tau_group(ProfileGroupName);
+
+  RtsLayer::LockDB();
+  // Use LockDB to avoid a possible race condition.
+
   GroupName = strdup(RtsLayer::PrimaryGroup(AllGroups).c_str());
 
   // Since FunctionInfo constructor is called once for each function (static)
   // we know that it couldn't be already on the call stack.
-  RtsLayer::LockDB();
-  // Use LockDB to avoid a possible race condition.
+
   
   //Add function name to the name list.
   TauProfiler_theFunctionList(NULL, NULL, true, (const char *)GetName());
@@ -205,36 +190,71 @@ void FunctionInfo::FunctionInfoInit(TauGroup_t ProfileGroup,
   TheFunctionDB().push_back(this);
   FunctionId = RtsLayer::GenerateUniqueId();
 
+  // Initialize EBS structures. These will be created as and when necessary.
+  //  pcHistogram = NULL;
+  // *CWL* - this is an attempt to minimize the scenario where a sample
+  //         requires the use of an actual malloc
+  //         while in the middle of some other malloc call.
+#ifndef TAU_WINDOWS
+  for (int i=0; i<TAU_MAX_THREADS; i++) {
+    pathHistogram[i] = NULL;
+    // create structure only if EBS is required.
+    if (TauEnv_get_ebs_enabled()) {
+
+      // Necessary for signal-reentrancy to ensure the mmap memory manager
+      //   is ready at this point.
+      Tau_MemMgr_initIfNecessary(); 
+
+      // Thread-safe, all (const char *) parameters. This check removes
+      //   the need to create and allocate memory for EBS post-processed
+      //   objects.
+      if (strstr(ProfileGroupName, "TAU_SAMPLE") == NULL) {
+	pathHistogram[i] = new TauPathHashTable<TauPathAccumulator>(i);
+      }
+    }
+  }
+
+  // Initialization of CallSite discovery structures.
+  isCallSite = false;
+  callSiteResolved = false;
+  //  callSiteKeyId = 0; // Any value works.
+  firstSpecializedFunction = NULL;
+
+#endif // TAU_WINDOWS
+
 #ifdef TAU_VAMPIRTRACE
-  static int tau_vt_init=TauInitVampirTrace();
   string tau_vt_name(string(Name)+" "+string(Type));
   FunctionId = TAU_VT_DEF_REGION(tau_vt_name.c_str(), VT_NO_ID, VT_NO_LNO,
 			     VT_NO_LNO, GroupName, VT_FUNCTION);
   DEBUGPROFMSG("vt_def_region: "<<tau_vt_name<<": returns "<<FunctionId<<endl;);
 #else /* TAU_VAMPIRTRACE */
 #ifdef TAU_EPILOG
-  static int tau_elg_init=TauInitEpilog();
   string tau_elg_name(string(Name)+" "+string(Type));
   FunctionId = esd_def_region(tau_elg_name.c_str(), ELG_NO_ID, ELG_NO_LNO,
 			      ELG_NO_LNO, GroupName, ELG_FUNCTION);
   DEBUGPROFMSG("elg_def_region: "<<tau_elg_name<<": returns "<<FunctionId<<endl;);
 #else
-#ifdef TAU_SILC
-  static int tau_silc_init=0;
-  if (tau_silc_init == 0) {
-    SILC_InitMeasurement();
-    tau_silc_init = 1;
-  }
+#ifdef TAU_SCOREP
   string tau_silc_name(string(Name)+" "+string(Type));
-  FunctionId =  SILC_DefineRegion( tau_silc_name.c_str(),
-				   SILC_INVALID_SOURCE_FILE,
-				   SILC_INVALID_LINE_NO,
-				   SILC_INVALID_LINE_NO,
-				   SILC_ADAPTER_COMPILER,
-				   SILC_REGION_FUNCTION
+if (strstr(ProfileGroupName, "TAU_PHASE") != NULL) {
+  FunctionId =  SCOREP_Tau_DefineRegion( tau_silc_name.c_str(),
+				   SCOREP_TAU_INVALID_SOURCE_FILE,
+				   SCOREP_TAU_INVALID_LINE_NO,
+				   SCOREP_TAU_INVALID_LINE_NO,
+				   SCOREP_TAU_ADAPTER_COMPILER,
+                                   SCOREP_TAU_REGION_PHASE
 				   );
 
-#endif /* TAU_SILC */
+}else{
+  FunctionId =  SCOREP_Tau_DefineRegion( tau_silc_name.c_str(),
+				   SCOREP_TAU_INVALID_SOURCE_FILE,
+				   SCOREP_TAU_INVALID_LINE_NO,
+				   SCOREP_TAU_INVALID_LINE_NO,
+				   SCOREP_TAU_ADAPTER_COMPILER,
+				   SCOREP_TAU_REGION_FUNCTION
+				   );
+}
+#endif /* TAU_SCOREP */
 #endif /* TAU_EPILOG */
 #endif /* TAU_VAMPIRTRACE */
   TauTraceSetFlushEvents(1);
@@ -262,6 +282,7 @@ void FunctionInfo::FunctionInfoInit(TauGroup_t ProfileGroup,
   }
 #endif //RENCI_STFF
   
+  Tau_global_decr_insideTAU_tid(tid);
   return;
 }
 
@@ -273,6 +294,7 @@ FunctionInfo::FunctionInfo(const char *name, const char *type,
 	       << " Mask = " << RtsLayer::TheProfileMask() <<endl;);
   Name = strdup(name);
   Type = strdup(type);
+  FullName = NULL;
   
   FunctionInfoInit(ProfileGroup, ProfileGroupName, InitData, tid);
 }
@@ -284,6 +306,7 @@ FunctionInfo::FunctionInfo(const char *name, const string& type,
 			   int tid) {
   Name = strdup(name);
   Type = strdup(type.c_str());
+  FullName = NULL;
   
   FunctionInfoInit(ProfileGroup, ProfileGroupName, InitData, tid);
 }
@@ -295,6 +318,7 @@ FunctionInfo::FunctionInfo(const string& name, const char * type,
 	int tid) {
   Name = strdup(name.c_str());
   Type = strdup(type);
+  FullName = NULL;
   
   FunctionInfoInit(ProfileGroup, ProfileGroupName, InitData, tid);
 }
@@ -307,6 +331,7 @@ FunctionInfo::FunctionInfo(const string& name, const string& type,
   
   Name = strdup(name.c_str());
   Type = strdup(type.c_str());
+  FullName = NULL;
   
   FunctionInfoInit(ProfileGroup, ProfileGroupName, InitData, tid);
 }
@@ -364,7 +389,7 @@ void FunctionInfo::getExclusiveValues(int tid, double *values) {
 
 
 //////////////////////////////////////////////////////////////////////
-long FunctionInfo::GetFunctionId(void) {
+x_uint64 FunctionInfo::GetFunctionId(void) {
   // To avoid data races, we use a lock if the id has not been created
   if (FunctionId == 0) {
 #ifdef DEBUG_PROF
@@ -481,8 +506,65 @@ void tauCreateFI(void **ptr, const string& name, const string& type,
 #endif
   }
 }
+
+
+string *FunctionInfo::GetFullName() {
+
+  if (FullName == NULL) {
+    ostringstream ostr;
+    if (strlen(GetType()) > 0 && strcmp(GetType()," ") != 0) {
+      ostr << GetName() << " " << GetType() << ":GROUP:" << GetAllGroups();
+    } else {
+      ostr << GetName() << ":GROUP:" << GetAllGroups();
+    }
+    FullName = new string;
+
+    string tmpstr = ostr.str();
+    char *tmp = strdup(tmpstr.c_str());
+    tmp = Tau_util_removeRuns(tmp);
+    *FullName = tmp;
+
+  }
+  return FullName;
+}
+
+/* EBS Sampling Profiles */
+
+#ifndef TAU_WINDOWS
+void FunctionInfo::addPcSample(unsigned long *pcStack, int tid, double interval[TAU_MAX_COUNTERS]) {
+  //  static int numSamples = 0;
+  if (!TauEnv_get_ebs_enabled()) {
+    // This should be an error! We'll ignore it for now!
+    return;
+  }
+  // *CWL* - pcHistogram should never be NULL but ...
+  if (pathHistogram[tid] == NULL) {
+    // *CWL* - For the use of the PathHash, we *cannot* initialize the
+    //         mmap memory manager here! That risks signal safety issues.
+    pathHistogram[tid] = new TauPathHashTable<TauPathAccumulator>(tid);
+  }
+  // Add to the mmap-ed histogram. We start with a temporary conversion. This
+  //   becomes unnecessary once we stop using the vector.
+  //TAU_VERBOSE("TAU<%d,%d>: addPcSample()\n", RtsLayer::myNode(), RtsLayer::myThread());
+  TauPathAccumulator *accumulator;
+  accumulator = pathHistogram[tid]->get(pcStack);
+  if (accumulator == NULL) {
+    accumulator = new TauPathAccumulator(1,interval);
+    bool success = pathHistogram[tid]->insert(pcStack, *accumulator);
+    if (!success) {
+      fprintf(stderr,"addPcSample: Failed to insert sample.\n");
+    }
+  } else {
+    (accumulator->count)++;
+    int i;
+    for (i = 0; i < Tau_Global_numCounters; i++) {
+      accumulator->accumulator[i] += interval[i];
+    }
+  }
+}
+#endif // TAU_WINDOWS
 /***************************************************************************
  * $RCSfile: FunctionInfo.cpp,v $   $Author: amorris $
- * $Revision: 1.82 $   $Date: 2009/12/21 17:58:01 $
- * VERSION_ID: $Id: FunctionInfo.cpp,v 1.82 2009/12/21 17:58:01 amorris Exp $ 
+ * $Revision: 1.84 $   $Date: 2010/04/27 23:13:55 $
+ * VERSION_ID: $Id: FunctionInfo.cpp,v 1.84 2010/04/27 23:13:55 amorris Exp $ 
  ***************************************************************************/
