@@ -17,8 +17,13 @@
 //#define DEBUG_PROF
 #include <Profile/Profiler.h>
 #include <Profile/TauMetrics.h>
+#ifndef TAU_WINDOWS
 #include <Profile/TauSampling.h>
-
+#endif
+#include <Profile/TauSnapshot.h>
+//#ifdef TAU_GPU
+extern "C" int Tau_profile_exit_all_tasks();
+//#endif
 //#include <tau_internal.h>
 
 #ifdef TAU_PERFSUITE
@@ -75,16 +80,13 @@ void esd_exit (elg_ui4 rid);
 #endif /* SCALASCA */
 #endif /* TAU_EPILOG */
 
-#include <Profile/TauTrace.h>
-
+#include <TauTrace.h>
+#include <TauMetaData.h>
 
 #ifdef RENCI_STFF
 #include "Profile/RenciSTFF.h"
 #endif // RENCI_STFF
 
-
-int Tau_writeProfileMetaData(FILE *fp, int counter);
-
 static int writeUserEvents(FILE *fp, int tid);
 static int matchFunction(FunctionInfo *fi, const char **inFuncs, int numFuncs);
 extern "C" int Tau_get_usesMPI();
@@ -101,6 +103,11 @@ extern "C" int Tau_get_usesMPI();
 #include <Profile/KtauProfiler.h>
 #endif /* TAUKTAU */
 
+#ifdef KTAU_NG
+#include <Profile/KtauNGProfiler.h>
+#endif /* KTAU_NG */
+
+
 // The rest of CurrentProfiler entries are initialized to null automatically
 //TauGroup_t RtsLayer::ProfileMask = TAU_DEFAULT;
 
@@ -195,13 +202,12 @@ void TauProfiler_EnableAllEventsOnCallStack(int tid, Profiler *current) {
 #endif /* TAU_MPITRACE */
 //////////////////////////////////////////////////////////////////////
 
-
+void Tau_unwind_unwindTauContext(Profiler *myProfiler);
 void Profiler::Start(int tid) { 
 #ifdef DEBUG_PROF
   fprintf (stderr, "[%d:%d-%d] Profiler::Start for %s (%p)\n", RtsLayer::getPid(), RtsLayer::getTid(), tid, ThisFunction->GetName(), ThisFunction);
 #endif
 
-
   ParentProfiler = TauInternal_ParentProfiler(tid);
 
   /********************************************************************************/
@@ -259,11 +265,23 @@ void Profiler::Start(int tid) {
   /*** Extras ***/
   /********************************************************************************/
 
-  
+  // An initialization of sorts. Call Paths (if any) will update this.
+#ifndef TAU_WINDOWS
+  if (TauEnv_get_callsite() == 1) {
+    CallSiteAddPath(NULL, tid);
+  }
+#endif /* TAU_WINDOWS */
+
   if (TauEnv_get_callpath()) {
     CallPathStart(tid);
   }
 
+#ifndef TAU_WINDOWS
+  if (TauEnv_get_callsite() == 1) {
+    CallSiteStart(tid);
+  }
+#endif
+
 #ifdef TAU_PROFILEPARAM
   ProfileParamFunction = NULL;
   if (ParentProfiler && ParentProfiler->ProfileParamFunction ) {
@@ -303,9 +321,15 @@ void Profiler::Start(int tid) {
   // Inncrement the number of calls
   ThisFunction->IncrNumCalls(tid);
   
+
   // Increment the parent's NumSubrs()
   if (ParentProfiler != 0) {
-    ParentProfiler->ThisFunction->IncrNumSubrs(tid);	
+    ParentProfiler->ThisFunction->IncrNumSubrs(tid);
+    if (TauEnv_get_callsite()) {	
+      if (ParentProfiler->CallSiteFunction != NULL) {
+        ParentProfiler->CallSiteFunction->IncrNumSubrs(tid);
+      }
+    }    
   }
   
   // If this function is not already on the call stack, put it
@@ -333,6 +357,7 @@ void Profiler::Start(int tid) {
 //////////////////////////////////////////////////////////////////////
 
 x_uint64 Tau_get_firstTimeStamp();
+#ifdef TAU_PERFSUITE
 static x_uint64 getTimeStamp() {
   x_uint64 timestamp;
 #ifdef TAU_WINDOWS
@@ -344,8 +369,9 @@ static x_uint64 getTimeStamp() {
 #endif
   return timestamp;
 }
+#endif /* TAU_PERFSUITE */
 
-
+extern "C" int TauCompensateInitialized(void);
 void Profiler::Stop(int tid, bool useLastTimeStamp) {
 #ifdef DEBUG_PROF
   fprintf (stderr, "[%d:%d-%d] Profiler::Stop  for %s (%p)\n", RtsLayer::getPid(), RtsLayer::getTid(), tid, ThisFunction->GetName(), ThisFunction);
@@ -393,8 +419,8 @@ void Profiler::Stop(int tid, bool useLastTimeStamp) {
 
   
   // first initialize the CurrentTime
-  double CurrentTime[TAU_MAX_COUNTERS];
-  double TotalTime[TAU_MAX_COUNTERS];
+  double CurrentTime[TAU_MAX_COUNTERS] = {0};
+  double TotalTime[TAU_MAX_COUNTERS] = {0};
 
 #ifdef TAU_TRACK_IDLE_THREADS
   int i;
@@ -415,9 +441,10 @@ void Profiler::Stop(int tid, bool useLastTimeStamp) {
   RtsLayer::getUSecD(tid, CurrentTime);
 #endif /* TAU_TRACK_IDLE_THREADS */
 
-
-#ifdef TAU_EXP_SAMPLING
-  Tau_sampling_event_stop(tid, CurrentTime);
+#ifndef TAU_WINDOWS
+  if (TauEnv_get_ebs_enabled()) {
+    Tau_sampling_event_stop(tid, CurrentTime);
+  }
 #endif
 
 #if defined(TAUKTAU)
@@ -485,11 +512,16 @@ void Profiler::Stop(int tid, bool useLastTimeStamp) {
   /*** Tracing ***/
   /********************************************************************************/
     
-    
   if (TauEnv_get_callpath()) {
     CallPathStop(TotalTime, tid);
   }
-    
+
+#ifndef TAU_WINDOWS
+  if (TauEnv_get_callsite()) {
+    CallSiteStop(TotalTime, tid);
+  }
+#endif /* TAU_WINDOWS */
+
 #ifdef RENCI_STFF
   if (TauEnv_get_callpath()) {
     RenciSTFF::recordValues(CallPathFunction, TimeStamp, TotalTime, tid);
@@ -531,6 +563,14 @@ void Profiler::Stop(int tid, bool useLastTimeStamp) {
 	CallPathFunction->ResetExclTimeIfNegative(tid); 
       }
     }
+    if (TauEnv_get_callsite()) {
+      if (ParentProfiler != NULL) {
+	if (CallSiteFunction != NULL) {
+	  CallSiteFunction->ResetExclTimeIfNegative(tid);
+	}
+      }
+    }
+
 #ifdef TAU_PROFILEPARAM
     if (ProfileParamFunction != NULL) {
       ProfileParamFunction->ResetExclTimeIfNegative(tid);
@@ -564,6 +604,9 @@ void Profiler::Stop(int tid, bool useLastTimeStamp) {
       /* Putting AddInclFlag means we can't throttle recursive calls */
       ThisFunction->SetProfileGroup(TAU_DISABLE, tid);
       ThisFunction->SetPrimaryGroupName("TAU_DISABLE");
+      //const char *func_type = ThisFunction->GetType();
+      string ftype(string("[THROTTLED]"));
+      ThisFunction->SetType(ftype);
       //cout <<"TAU<"<<RtsLayer::myNode()<<">: Throttle: Disabling "<<ThisFunction->GetName()<<endl;
       TAU_VERBOSE("TAU<%d,%d>: Throttle: Disabling %s\n", RtsLayer::myNode(), RtsLayer::myThread(), ThisFunction->GetName());
       RtsLayer::UnLockDB();
@@ -574,17 +617,46 @@ void Profiler::Stop(int tid, bool useLastTimeStamp) {
   /********************************************************************************/
     
   if (ParentProfiler == (Profiler *) NULL) {
+    //    printf("No parent profiler on stop\n");
+    if (TauEnv_get_extras()) {
+      /*** Profile Compensation ***/
+      if (TauEnv_get_compensate()) {
+	// If I am still compensating, I do not expect a top level timer. Just pretend
+	// this never happened.
+	if (!TauCompensateInitialized()) {
+	  return;
+	}
+      }
+    }
     /* Should we detect memory leaks here? */
     if (TheSafeToDumpData() && !RtsLayer::isCtorDtor(ThisFunction->GetName())) {
+      Tau_global_callWriteHooks();
       TauDetectMemoryLeaks(); /* the last event should be before final exit */
     }
 
+/* On Crays with -iowrapper, rank 0 is spawned by the clone syscall. This
+    creates a parent thread (rank = -1) that tries to write data at the end
+    of execution and crashes. This fixes it and disables profile output from
+    rank -1. */
+#if (defined (TAU_MPI) && defined(TAU_CRAYCNL))
+    if (RtsLayer::myNode() == -1) TheSafeToDumpData() = 0;
+#endif /* TAU_MPI && TAU_CRAYCNL */
+
     // For Dyninst. tcf gets called after main and all the data structures may not be accessible
     // after main exits. Still needed on Linux - we use TauProgramTermination()
     if (strcmp(ThisFunction->GetName(), "_fini") == 0) {
       TheSafeToDumpData() = 0;
     }
-
+		if (tid == 0) {
+	  	Tau_profile_exit_all_tasks();
+		}
+#ifdef TAU_GPU
+		//Stop all other running tasks.
+		if (tid == 0) {
+			//printf("exiting all tasks....\n");
+		  Tau_profile_exit_all_tasks();
+		}
+#endif
 #ifndef TAU_WINDOWS
     if (tid == 0) {
       atexit(TauAppShutdown);
@@ -597,6 +669,15 @@ void Profiler::Stop(int tid, bool useLastTimeStamp) {
 
 	// Write profile data
 	TauProfiler_StoreData(tid);
+#ifndef TAU_WINDOWS
+        // getpid() not available on Windows
+        TAU_VERBOSE("TAU: <Node=%d.Thread=%d>:<pid=%d>: %s initiated TauProfile_StoreData\n",
+          RtsLayer::myNode(), RtsLayer::myThread(), getpid(), ThisFunction->GetName());
+#endif
+#ifdef TAU_DMAPP
+	TAU_DISABLE_INSTRUMENTATION(); 
+#endif /* TAU_DMAPP */
+
 	  
 #if defined(TAUKTAU) 
 	//AN Removed - New func inside 
@@ -954,10 +1035,12 @@ static int writeUserEvents(FILE *fp, int tid) {
   // Print UserEvent Data if any
   int numEvents = 0;
   for (it = TheEventDB().begin(); it != TheEventDB().end(); ++it) {
-    if ((*it)->GetNumEvents(tid) == 0) { // skip user events with no calls
+    if ((*it) && (*it)->GetNumEvents(tid) == 0) { // skip user events with no calls
       continue;
     }
-    numEvents++;
+    if ((*it)) {
+      numEvents++;
+    }
   }
   
   if (numEvents > 0) {
@@ -968,7 +1051,7 @@ static int writeUserEvents(FILE *fp, int tid) {
     fprintf(fp, "# eventname numevents max min mean sumsqr\n");
     
     for(it = TheEventDB().begin(); it != TheEventDB().end(); ++it) {
-      if ((*it)->GetNumEvents(tid) == 0) { // skip user events with no calls
+      if ((*it) && (*it)->GetNumEvents(tid) == 0) { // skip user events with no calls
 	continue;
       }
       fprintf(fp, "\"%s\" %ld %.16G %.16G %.16G %.16G\n", 
@@ -1075,6 +1158,10 @@ static int writeFunctionData(FILE *fp, int tid, int metric, const char **inFuncs
       continue;
     } 
 
+    if (fi->GetCalls(tid) == 0) { // skip this function
+      continue;
+    } 
+
     // get currently stored values
     double incltime = fi->getDumpInclusiveValues(tid)[metric];
     double excltime = fi->getDumpExclusiveValues(tid)[metric];
@@ -1096,12 +1183,30 @@ static int writeFunctionData(FILE *fp, int tid, int metric, const char **inFuncs
   return 0;
 }
 
+// Writes function event data
+static int getTrueFunctionCount(int count, int tid, const char **inFuncs, int numFuncs) {
+  int trueCount = count;
+  for (vector<FunctionInfo*>::iterator it = TheFunctionDB().begin(); it != TheFunctionDB().end(); it++) {
+    FunctionInfo *fi = *it;
+
+    if (-1 == matchFunction(*it, inFuncs, numFuncs)) { // skip this function
+      trueCount--;
+    } else if (fi->GetCalls(tid) == 0) {
+      trueCount--;
+    }
+  }
+
+  return trueCount;
+}
+
 // Writes a single profile file
 static int writeProfile(FILE *fp, char *metricName, int tid, int metric, 
 			const char **inFuncs, int numFuncs) {
-  writeHeader(fp, TheFunctionDB().size(), metricName);
+  int trueCount = getTrueFunctionCount(TheFunctionDB().size(), tid, inFuncs, numFuncs);
+  //writeHeader(fp, TheFunctionDB().size(), metricName);
+  writeHeader(fp, trueCount, metricName);
   fprintf(fp, " # ");	
-  Tau_writeProfileMetaData(fp, metric);
+  Tau_metadata_writeMetaData(fp, metric);
   fprintf(fp, "\n");
   fflush(fp);
   writeFunctionData(fp, tid, metric, inFuncs, numFuncs);
@@ -1120,14 +1225,18 @@ extern "C" int Tau_profiler_initialization() {
     profileWriteCount[i] = 0;
   }
   profileWriteWarningPrinted = 0;
+  return 0;
 }
 
 
 // Store profile data at the end of execution (when top level timer stops)
+extern "C" void finalizeCallSites_if_necessary();
 int TauProfiler_StoreData(int tid) {
-  int i;
+  TAU_VERBOSE("TAU<%d,%d>: TauProfiler_StoreData\n", RtsLayer::myNode(), tid);
 
   profileWriteCount[tid]++;
+  if ((tid !=0) && (profileWriteCount[tid] > 1)) return 0;
+ 
   if (profileWriteCount[tid] == 10) {
     RtsLayer::LockDB();
     if (profileWriteWarningPrinted == 0) {
@@ -1138,21 +1247,29 @@ int TauProfiler_StoreData(int tid) {
   }
   finalizeTrace(tid);
   
-#ifdef TAU_EXP_SAMPLING
-  Tau_sampling_finalize(tid);
-#endif /* TAU_EXP_SAMPLING */
+#ifndef TAU_WINDOWS  
 
+  if (TauEnv_get_callsite()) {
+    finalizeCallSites_if_necessary();
+  }
+
+  if (TauEnv_get_ebs_enabled()) {
+    // Tau_sampling_finalize(tid);
+    Tau_sampling_finalize_if_necessary();
+  }
+#endif
   if (TauEnv_get_profiling()) {
-    TauProfiler_Snapshot("final", true, tid);
+
+    Tau_snapshot_writeFinal("final");
     
     if (TauEnv_get_profile_format() == TAU_FORMAT_PROFILE) {
       TauProfiler_DumpData(false, tid, "profile");
     }
   }
-#ifdef PTHREADS
+#if defined(PTHREADS) || defined(TAU_OPENMP)
   if (RtsLayer::myThread() == 0 && tid == 0) {
     /* clean up other threads? */
-    for (i =1; i < TAU_MAX_THREADS; i++) {
+    for (int i =1; i < TAU_MAX_THREADS; i++) {
       if (TauInternal_ParentProfiler(i) != (Profiler *) NULL) {
         TauProfiler_StoreData(i);
       }
@@ -1165,13 +1282,37 @@ int TauProfiler_StoreData(int tid) {
 
 // Returns directory name for the location of a particular metric
 static int getProfileLocation(int metric, char *str) {
+#ifndef KTAU_NG
   const char *profiledir = TauEnv_get_profiledir();
+#else
+  static char *profiledir;
+  if(profiledir == NULL){
+    int written_bytes = 0;
+    unsigned int profile_dir_len = KTAU_NG_PREFIX_LEN + HOSTNAME_LEN;
+    profiledir = new char[profile_dir_len];
+    written_bytes = sprintf(profiledir, "%s.", KTAU_NG_PREFIX);
+    gethostname(profiledir + written_bytes, profile_dir_len - written_bytes);
+    
+    // profiledir = new char[KTAU_NG_PREFIX_LEN + (Tau_metadata_getMetaData()["Hostname"]).length() + 1]; //This will remain in memory until TAU closes since their is no corresponding delete.
+    // sprintf(profiledir, "%s.%s", KTAU_NG_PREFIX, Tau_metadata_getMetaData()["Hostname"].c_str());
+  }
+#endif
 
   if (Tau_Global_numCounters <= 1) { 
     sprintf (str, "%s", profiledir);
   } else {
-    const char *metricName = TauMetrics_getMetricName(metric);
-    sprintf (str, "%s/MULTI__%s", profiledir, metricName);
+    string metricStr = string(TauMetrics_getMetricName(metric));
+		
+		//sanitize metricName before creating a directory name from it.
+		string illegalChars("/\\?%*:|\"<> ");
+		size_t found;
+		found=metricStr.find_first_of(illegalChars, 0);
+		while (found!=string::npos)
+		{
+			metricStr[found] = '_';
+			found=metricStr.find_first_of(illegalChars,found+1);
+		}
+    sprintf (str, "%s/MULTI__%s", profiledir, metricStr.c_str());
   }
 
   return 0;
@@ -1179,6 +1320,7 @@ static int getProfileLocation(int metric, char *str) {
 
 
 int TauProfiler_DumpData(bool increment, int tid, const char *prefix) {
+  TAU_VERBOSE("TAU<%d,%d>: TauProfiler_DumpData\n", RtsLayer::myNode(), tid);
   return TauProfiler_writeData(tid, prefix, increment);
 }
 
@@ -1243,11 +1385,17 @@ int TauProfiler_writeData(int tid, const char *prefix, bool increment, const cha
 
 	char cwd[1024];
 	char *tst = getcwd(cwd, 1024);
-	TAU_VERBOSE("TAU: Writing profile %s, cwd = %s\n", dumpfile, cwd);
+#ifndef TAU_WINDOWS
+	TAU_VERBOSE("[pid=%d], TAU: Writing profile %s, cwd = %s\n", getpid(), dumpfile, cwd);
+#endif
 
       } else {
 	int flags = O_CREAT | O_EXCL | O_WRONLY;
+#ifdef TAU_DISABLE_SIGUSR
+	int mode = 0;
+#else
 	int mode = S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH;
+#endif
 	int node = RtsLayer::myNode();
 	sprintf(dumpfile,"%s/%s%s.%d.%d.%d", profileLocation, selectivePrefix, prefix, 
 		node, RtsLayer::myContext(), tid);
@@ -1281,7 +1429,9 @@ int TauProfiler_writeData(int tid, const char *prefix, bool increment, const cha
 	  }
 	  char cwd[1024];
 	  char *tst = getcwd(cwd, 1024);
-	  TAU_VERBOSE("TAU: Writing profile %s, cwd = %s\n", dumpfile, cwd);
+#ifndef TAU_WINDOWS
+	  TAU_VERBOSE("[pid=%d], TAU: Writing profile %s, cwd = %s\n", getpid(), dumpfile, cwd);
+#endif
 	}
       }
       writeProfile(fp, metricHeader, tid, i, inFuncs, numFuncs);
@@ -1302,6 +1452,7 @@ int TauProfiler_dumpFunctionValues(const char **inFuncs,
   
   TAU_PROFILE("TAU_DUMP_FUNC_VALS()", " ", TAU_IO);
 
+  TAU_VERBOSE("TAU<%d,%d>: TauProfiler_dumpFunctionValues\n", RtsLayer::myNode(), RtsLayer::myThread());
   TauProfiler_writeData(tid, prefix, increment, inFuncs, numFuncs);
   return 0;
 }
@@ -1313,15 +1464,9 @@ bool TauProfiler_createDirectories() {
   if (flag && Tau_Global_numCounters > 1) {
     for (int i=0;i<Tau_Global_numCounters;i++) {
       if (TauMetrics_getMetricUsed(i)) {
-	const char * tmpChar = TauMetrics_getMetricName(i);
 	char *newdirname = new char[1024];
-	//char *rmdircommand = new char[1024];
 	char *mkdircommand = new char[1024];
-	
-	const char *dirname = TauEnv_get_profiledir();
-	
-	sprintf(newdirname,"%s/MULTI__%s",dirname,tmpChar);
-	//sprintf(rmdircommand,"rm -rf %s",newdirname);
+	getProfileLocation(i,	newdirname);
 	sprintf(mkdircommand,"mkdir -p %s",newdirname);
 	
 	//system(rmdircommand);
@@ -1337,13 +1482,19 @@ bool TauProfiler_createDirectories() {
       }
     }
     flag = false;
+  }else{
+#ifdef KTAU_NG
+	char *newdirname = new char[1024];
+	getProfileLocation(Tau_Global_numCounters, newdirname);
+	mkdir(newdirname, S_IRWXU | S_IRGRP | S_IXGRP);
+#endif
+	flag = false;
   }
-
   return true;
 }
 
 /***************************************************************************
- * $RCSfile: Profiler.cpp,v $   $Author: amorris $
- * $Revision: 1.263 $   $Date: 2010/02/22 18:38:38 $
- * VERSION_ID: $Id: Profiler.cpp,v 1.263 2010/02/22 18:38:38 amorris Exp $ 
+ * $RCSfile: Profiler.cpp,v $   $Author: sameer $
+ * $Revision: 1.271 $   $Date: 2010/05/25 23:06:19 $
+ * VERSION_ID: $Id: Profiler.cpp,v 1.271 2010/05/25 23:06:19 sameer Exp $ 
  ***************************************************************************/
