@@ -67,10 +67,18 @@ using namespace std;
 #include <time.h>
 #include <stdlib.h>
 
+#ifdef KTAU_NG
+#ifdef __linux //To make getLinuxKernelTid work for ktau style file naming
+#include <unistd.h>
+#include <sys/syscall.h>
+#include <sys/types.h>
+#endif
+#endif /* KTAU_NG */
+
 #ifdef TAU_WINDOWS
 //include the header for windows time functions.
-#include <Windows.h>	//Various defines needed in Winbase.h.
-#include <Winbase.h>	//For QueryPerformanceCounter/Frequency function (down to microsecond
+#include <windows.h>	//Various defines needed in Winbase.h.
+#include <winbase.h>	//For QueryPerformanceCounter/Frequency function (down to microsecond
                         //resolution depending on the platform. 
 #include <sys/timeb.h>	//For _ftime function (millisecond resolution).
 //Map strncasecmp and strcasecmp to strnicmp and stricmp.
@@ -242,6 +250,9 @@ TauGroup_t RtsLayer::resetProfileGroup(void) {
 
 /////////////////////////////////////////////////////////////////////////
 int RtsLayer::setMyNode(int NodeId, int tid) {
+#ifndef TAU_WINDOWS
+  TAU_VERBOSE("pid [%d] RtsLayer::setMyNode: %d\n", getpid(), NodeId);
+#endif
 #if (TAU_MAX_THREADS != 1)
   int oldid = TheNode();
   int newid = NodeId;
@@ -349,13 +360,13 @@ double TauWindowsUsecD(void) {
       //but need to be on the safe side!
       if (Frequency.QuadPart != 0) {
 	Multiplier = (double) 1000000/Frequency.QuadPart;
-	cout << "The value of the multiplier is: " << Multiplier << endl;
+	DEBUGPROFMSG("The value of the multiplier is: " << Multiplier << endl;);
       } else {
-	cout << "There was a problem with the counter ... should not have happened!!" << endl;
+	DEBUGPROFMSG("There was a problem with the counter ... should not have happened!!" << endl;);
 	return -1;
       }
     } else {
-      cout << "No performace clock available ... using millisecond timers." << endl;
+      DEBUGPROFMSG("No performace clock available ... using millisecond timers." << endl;);
     }
   }
 
@@ -365,7 +376,7 @@ double TauWindowsUsecD(void) {
       //As mentioned above, assuming double value.
       return Multiplier * (double) ClockValue.QuadPart;
     } else {
-      cout << "There was a problem with the counter ... should not have happened!!" << endl;
+      DEBUGPROFMSG("There was a problem with the counter ... should not have happened!!" << endl;);
       return -1;
     }
   } else {
@@ -411,6 +422,12 @@ int RtsLayer::getPid() {
 // _syscall0(pid_t,gettid)
 // #endif
 
+// C interface.
+extern "C" int Tau_RtsLayer_getTid()
+{
+	return RtsLayer::getTid();
+}
+
 int RtsLayer::getTid() {
 #ifdef __linux
   //  return gettid();
@@ -420,6 +437,14 @@ int RtsLayer::getTid() {
 #endif
 }
 
+#ifdef KTAU_NG
+int RtsLayer::getLinuxKernelTid(){
+ pid_t tid;
+ tid =  syscall(SYS_gettid);
+ return tid;
+}
+#endif /* KTAU_NG */
+
 const char *RtsLayer::getCounterName(int i) {
   const char *foo = TauMetrics_getMetricName(i);
   return TauMetrics_getMetricName(i);
