@@ -26,6 +26,8 @@ using namespace std;
 #include <limits.h>
 
 #include <Profile/TauMetrics.h>
+#include <Profile/TauSnapshot.h>
+#include <Profile/TauTrace.h>
 
 #if (!defined(TAU_WINDOWS)) 
 /* Needed for fork */
@@ -37,12 +39,6 @@ using namespace std;
 #include <Profile/KtauProfiler.h>
 #endif //TAUKTAU
 
-#include <Profile/TauTrace.h>
-
-
-#if defined(TAUKTAU)
-#include <Profile/KtauProfiler.h>
-#endif /* TAUKTAU */
 
 #ifdef TAU_EPILOG
 #include "elg_trc.h"
@@ -60,14 +56,16 @@ void esd_exit (elg_ui4 rid);
 #include "Profile/TauVampirTrace.h"
 #endif /* TAU_VAMPIRTRACE */
 
-#ifdef TAU_SILC
-#include <Profile/TauSilc.h>
+#ifdef TAU_SCOREP
+#include <Profile/TauSCOREP.h>
 #endif
 
 
 extern "C" void * Tau_get_profiler(const char *fname, const char *type, TauGroup_t group, const char *gr_name) {
   FunctionInfo *f;
 
+  Tau_global_incr_insideTAU();
+
   DEBUGPROFMSG("Inside get_profiler group = " << group<<endl;);
 
   // since we're using new, we should set InitData to true in FunctionInfoInit
@@ -81,6 +79,8 @@ extern "C" void * Tau_get_profiler(const char *fname, const char *type, TauGroup
     f = new FunctionInfo(fname, type, group, gr_name, true);
   }
 
+  Tau_global_decr_insideTAU();
+
   return (void *) f;
 }
 
@@ -90,18 +90,102 @@ extern "C" void * Tau_get_profiler(const char *fname, const char *type, TauGroup
 static Profiler *Tau_global_stack[TAU_MAX_THREADS];
 static int Tau_global_stackdepth[TAU_MAX_THREADS];
 static int Tau_global_stackpos[TAU_MAX_THREADS];
+static int Tau_global_insideTAU[TAU_MAX_THREADS];
+static int Tau_is_thread_fake_for_task_api[TAU_MAX_THREADS];
+int lightsOut = 0;
 
+static void (*_profile_write_hook)(void) = NULL;
 
-extern "C" void Tau_stack_initialization() {
-  int i;
-  for (i=0; i<TAU_MAX_THREADS; i++) {
-    Tau_global_stackdepth[i] = 0;
-    Tau_global_stackpos[i] = -1;
-    Tau_global_stack[i] = NULL;
+extern "C" void Tau_global_addWriteHook(void (*hook)(void)) {
+  _profile_write_hook = hook;
+}
+
+extern "C" void Tau_global_callWriteHooks() {
+  if (_profile_write_hook != NULL) {
+    _profile_write_hook();
   }
 }
 
 
+static void Tau_stack_checkInit() {
+  static int init = 0;
+  if (init != 0) {
+    return;
+  }
+  init = 1;
+
+  lightsOut = 0;
+  _profile_write_hook = 0;
+
+  for (int i=0; i<TAU_MAX_THREADS; i++) {
+    Tau_global_stackdepth[i] = 0;
+    Tau_global_stackpos[i] = -1;
+    Tau_global_stack[i] = NULL;
+    Tau_global_insideTAU[i] = 0;
+    Tau_is_thread_fake_for_task_api[i] = 0; /* by default all threads are real*/
+  }
+}
+
+extern "C" int Tau_global_getLightsOut() {
+  Tau_stack_checkInit();
+  return lightsOut;
+}
+
+extern "C" void Tau_global_setLightsOut() {
+  Tau_stack_checkInit();
+  lightsOut = 1;
+}
+
+/* the task API does not have a real thread associated with the tid */
+extern "C" int Tau_is_thread_fake(int tid) {
+  return Tau_is_thread_fake_for_task_api[tid]; 
+}
+
+extern "C" void Tau_set_thread_fake(int tid) {
+  Tau_is_thread_fake_for_task_api[tid] = 1; 
+}
+
+extern "C" void Tau_stack_initialization() {
+  Tau_stack_checkInit();
+}
+
+extern "C" int Tau_global_get_insideTAU() {
+  Tau_stack_checkInit();
+  int tid = RtsLayer::myThread();
+  return Tau_global_insideTAU[tid];
+}
+
+extern "C" int Tau_global_get_insideTAU_tid(int tid) {
+  Tau_stack_checkInit();
+  return Tau_global_insideTAU[tid];
+}
+
+extern "C" int Tau_global_incr_insideTAU() {
+  Tau_stack_checkInit();
+  int tid = RtsLayer::myThread();
+  Tau_global_insideTAU[tid]++;
+  return Tau_global_insideTAU[tid];
+}
+
+extern "C" int Tau_global_decr_insideTAU() {
+  Tau_stack_checkInit();
+  int tid = RtsLayer::myThread();
+  Tau_global_insideTAU[tid]--;
+  return Tau_global_insideTAU[tid];
+}
+
+extern "C" int Tau_global_incr_insideTAU_tid(int tid) {
+  Tau_stack_checkInit();
+  Tau_global_insideTAU[tid]++;
+  return Tau_global_insideTAU[tid];
+}
+
+extern "C" int Tau_global_decr_insideTAU_tid(int tid) {
+  Tau_stack_checkInit();
+  Tau_global_insideTAU[tid]--;
+  return Tau_global_insideTAU[tid];
+}
+
 extern "C" Profiler *TauInternal_CurrentProfiler(int tid) {
   int pos = Tau_global_stackpos[tid];
   if (pos < 0) {
@@ -119,49 +203,30 @@ extern "C" Profiler *TauInternal_ParentProfiler(int tid) {
 }
 
 
-
-
 ///////////////////////////////////////////////////////////////////////////
 extern "C" void Tau_start_timer(void *functionInfo, int phase, int tid) {
-  
-#ifdef TAU_EXP_SAMPLING
-  Tau_sampling_suspend();
-#endif /* TAU_EXP_SAMPLING */
+  Tau_global_insideTAU[tid]++;
+
+#ifndef TAU_WINDOWS
+  if (TauEnv_get_ebs_enabled()) {
+    Tau_sampling_init_if_necessary();
+    Tau_sampling_suspend(tid);
+  }
+#endif
 
   //int tid = RtsLayer::myThread();
   FunctionInfo *fi = (FunctionInfo *) functionInfo; 
 
   if ( !RtsLayer::TheEnableInstrumentation() || !(fi->GetProfileGroup() & RtsLayer::TheProfileMask())) {
-#ifdef TAU_EXP_SAMPLING
-    Tau_sampling_resume();
-#endif /* TAU_EXP_SAMPLING */
+#ifndef TAU_WINDOWS
+    if (TauEnv_get_ebs_enabled()) {
+      Tau_sampling_resume(tid);
+    }
+#endif
+    Tau_global_insideTAU[tid]--;
     return; /* disabled */
   }
 
-  /********************************************************************************/
-  /*** Extras ***/
-  /********************************************************************************/
-  if (TauEnv_get_extras()) {
-    /*** Memory Profiling ***/
-    if (TauEnv_get_track_memory_heap()) {
-      TAU_REGISTER_CONTEXT_EVENT(memHeapEvent, "Heap Memory Used (KB) : Entry");
-      TAU_CONTEXT_EVENT(memHeapEvent, TauGetMaxRSS());
-    }
-    
-    if (TauEnv_get_track_memory_headroom()) {
-      TAU_REGISTER_CONTEXT_EVENT(memEvent, "Memory Headroom Available (MB) : Entry");
-      TAU_CONTEXT_EVENT(memEvent, TauGetFreeMemory());
-    }
-    
-#ifdef TAU_PROFILEMEMORY
-    ThisFunction->GetMemoryEvent()->TriggerEvent(TauGetMaxRSS());
-#endif /* TAU_PROFILEMEMORY */
-    
-#ifdef TAU_PROFILEHEADROOM
-    ThisFunction->GetHeadroomEvent()->TriggerEvent((double)TauGetFreeMemory());
-#endif /* TAU_PROFILEHEADROOM */
-
-  }
 
 #ifdef TAU_TRACK_IDLE_THREADS
   /* If we are performing idle thread tracking, we start a top level timer */
@@ -170,30 +235,44 @@ extern "C" void Tau_start_timer(void *functionInfo, int phase, int tid) {
   }
 #endif
 
-  /********************************************************************************/
-  /*** Extras ***/
-  /********************************************************************************/
-
 
 #ifdef TAU_EPILOG
   esd_enter(fi->GetFunctionId());
+#ifndef TAU_WINDOWS
+  if (TauEnv_get_ebs_enabled()) {
+    Tau_sampling_resume(tid);
+  }
+#endif
+  Tau_global_insideTAU[tid]--;
   return;
 #endif
 
 #ifdef TAU_VAMPIRTRACE 
-  x_uint64 TimeStamp = vt_pform_wtime();
+  uint64_t TimeStamp = vt_pform_wtime();
+#ifdef TAU_VAMPIRTRACE_5_12_API
+  vt_enter(VT_CURRENT_THREAD, (uint64_t *) &TimeStamp, fi->GetFunctionId());
+#else
   vt_enter((uint64_t *) &TimeStamp, fi->GetFunctionId());
+#endif /* TAU_VAMPIRTRACE_5_12_API */
+#ifndef TAU_WINDOWS
+  if (TauEnv_get_ebs_enabled()) {
+    Tau_sampling_resume(tid);
+  }
+#endif
+  Tau_global_insideTAU[tid]--;
   return;
 #endif
 
-#ifdef TAU_SILC
-  SILC_EnterRegion(fi->GetFunctionId());
+#ifdef TAU_SCOREP
+  SCOREP_Tau_EnterRegion(fi->GetFunctionId());
 #endif
 
 
   // move the stack pointer
   Tau_global_stackpos[tid]++; /* push */
 
+
+
   if (Tau_global_stackpos[tid] >= Tau_global_stackdepth[tid]) {
     int oldDepth = Tau_global_stackdepth[tid];
     int newDepth = oldDepth + STACK_DEPTH_INCREMENT;
@@ -206,11 +285,8 @@ extern "C" void Tau_start_timer(void *functionInfo, int phase, int tid) {
   Profiler *p = &(Tau_global_stack[tid][Tau_global_stackpos[tid]]);
 
   p->MyProfileGroup_ = fi->GetProfileGroup();
-  p->ThisFunction = fi; 
-
-#ifdef TAU_EXP_SAMPLING
+  p->ThisFunction = fi;
   p->needToRecordStop = 0;
-#endif /* TAU_EXP_SAMPLING */
 
 #ifdef TAU_MPITRACE
   p->RecordEvent = false; /* by default, we don't record this event */
@@ -229,48 +305,84 @@ extern "C" void Tau_start_timer(void *functionInfo, int phase, int tid) {
   static int userspecifieddepth = TauEnv_get_depth_limit();
   int mydepth = Tau_global_stackpos[tid];
   if (mydepth >= userspecifieddepth) { 
+#ifndef TAU_WINDOWS
+    if (TauEnv_get_ebs_enabled()) {
+      Tau_sampling_resume(tid);
+    }
+#endif
+    Tau_global_insideTAU[tid]--;
     return; 
   }
 #endif /* TAU_DEPTH_LIMIT */
 
   p->Start(tid);
 
-#ifdef TAU_EXP_SAMPLING
-  // p->address = Tau_sampling_event_start(tid);
-  Tau_sampling_event_start(tid, p->address);
+  /********************************************************************************/
+  /*** Extras ***/
+  /********************************************************************************/
+  if (TauEnv_get_extras()) {
+    /*** Memory Profiling ***/
+    if (TauEnv_get_track_memory_heap()) {
+      TAU_REGISTER_CONTEXT_EVENT(memHeapEvent, "Heap Memory Used (KB) at Entry");
+      TAU_CONTEXT_EVENT(memHeapEvent, TauGetMaxRSS());
+    }
+    
+    if (TauEnv_get_track_memory_headroom()) {
+      TAU_REGISTER_CONTEXT_EVENT(memEvent, "Memory Headroom Available (MB) at Entry");
+      TAU_CONTEXT_EVENT(memEvent, TauGetFreeMemory());
+    }
+    
+#ifdef TAU_PROFILEMEMORY
+    p->ThisFunction->GetMemoryEvent()->TriggerEvent(TauGetMaxRSS());
+#endif /* TAU_PROFILEMEMORY */
+    
+#ifdef TAU_PROFILEHEADROOM
+    p->ThisFunction->GetHeadroomEvent()->TriggerEvent((double)TauGetFreeMemory());
+#endif /* TAU_PROFILEHEADROOM */
+  }
+  /********************************************************************************/
+  /*** Extras ***/
+  /********************************************************************************/
+
+#ifndef TAU_WINDOWS
+  if (TauEnv_get_ebs_enabled()) {
+    Tau_sampling_resume(tid);
+    Tau_sampling_event_start(tid, p->address);
+  }
 #endif
-
-#ifdef TAU_EXP_SAMPLING
-  Tau_sampling_resume();
-#endif /* TAU_EXP_SAMPLING */
+  Tau_global_insideTAU[tid]--;
 }
 
 
 
 
-
 ///////////////////////////////////////////////////////////////////////////
 static void reportOverlap (FunctionInfo *stack, FunctionInfo *caller) {
-  printf("[%d:%d-%d] TAU: Runtime overlap: found %s (%p) on the stack, but stop called on %s (%p)\n", 
+  fprintf(stderr, "[%d:%d-%d] TAU: Runtime overlap: found %s (%p) on the stack, but stop called on %s (%p)\n", 
 	 RtsLayer::getPid(), RtsLayer::getTid(), RtsLayer::myThread(),
 	 stack->GetName(), stack, caller->GetName(), caller);
 }
 
 ///////////////////////////////////////////////////////////////////////////
 extern "C" int Tau_stop_timer(void *function_info, int tid ) {
-#ifdef TAU_EXP_SAMPLING
-    Tau_sampling_suspend();
-#endif /* TAU_EXP_SAMPLING */
-
+  Tau_global_insideTAU[tid]++;
+#ifndef TAU_WINDOWS
+  if (TauEnv_get_ebs_enabled()) {
+    Tau_sampling_suspend(tid);
+  }
+#endif
   FunctionInfo *fi = (FunctionInfo *) function_info; 
 
   //int tid = RtsLayer::myThread();
   Profiler *profiler;
 
   if ( !RtsLayer::TheEnableInstrumentation() || !(fi->GetProfileGroup()) & RtsLayer::TheProfileMask()) {
-#ifdef TAU_EXP_SAMPLING
-    Tau_sampling_resume();
-#endif /* TAU_EXP_SAMPLING */
+#ifndef TAU_WINDOWS
+    if (TauEnv_get_ebs_enabled()) {
+      Tau_sampling_resume(tid);
+    }
+#endif
+    Tau_global_insideTAU[tid]--;
     return 0; /* disabled */
   }
 
@@ -281,12 +393,12 @@ extern "C" int Tau_stop_timer(void *function_info, int tid ) {
   if (TauEnv_get_extras()) {
     /*** Memory Profiling ***/
     if (TauEnv_get_track_memory_heap()) {
-      TAU_REGISTER_CONTEXT_EVENT(memHeapEvent, "Heap Memory Used (KB) : Exit");
+      TAU_REGISTER_CONTEXT_EVENT(memHeapEvent, "Heap Memory Used (KB) at Exit");
       TAU_CONTEXT_EVENT(memHeapEvent, TauGetMaxRSS());
     }
     
     if (TauEnv_get_track_memory_headroom()) {
-      TAU_REGISTER_CONTEXT_EVENT(memEvent, "Memory Headroom Available (MB) : Exit");
+      TAU_REGISTER_CONTEXT_EVENT(memEvent, "Memory Headroom Available (MB) at Exit");
       TAU_CONTEXT_EVENT(memEvent, TauGetFreeMemory());
     }
   }
@@ -297,21 +409,47 @@ extern "C" int Tau_stop_timer(void *function_info, int tid ) {
 
 #ifdef TAU_EPILOG
   esd_exit(fi->GetFunctionId());
+#ifndef TAU_WINDOWS
+    if (TauEnv_get_ebs_enabled()) {
+      Tau_sampling_resume(tid);
+    }
+#endif
+  Tau_global_insideTAU[tid]--;
   return 0;
 #endif
 
 #ifdef TAU_VAMPIRTRACE 
-  x_uint64 TimeStamp = vt_pform_wtime();
+  uint64_t TimeStamp = vt_pform_wtime();
+
+#ifdef TAU_VAMPIRTRACE_5_12_API
+  vt_exit(VT_CURRENT_THREAD, (uint64_t *)&TimeStamp);
+#else 
   vt_exit((uint64_t *)&TimeStamp);
+#endif /* TAU_VAMPIRTRACE_5_12_API */
+
+#ifndef TAU_WINDOWS
+    if (TauEnv_get_ebs_enabled()) {
+      Tau_sampling_resume(tid);
+    }
+#endif
+  Tau_global_insideTAU[tid]--;
   return 0;
 #endif
 
-#ifdef TAU_SILC
-  SILC_ExitRegion(fi->GetFunctionId());
+#ifdef TAU_SCOREP
+  SCOREP_Tau_ExitRegion(fi->GetFunctionId());
 #endif
 
 
-  if (Tau_global_stackpos[tid] < 0) { return 0; }
+  if (Tau_global_stackpos[tid] < 0) { 
+#ifndef TAU_WINDOWS
+    if (TauEnv_get_ebs_enabled()) {
+      Tau_sampling_resume(tid);
+    }
+#endif
+    Tau_global_insideTAU[tid]--;
+    return 0; 
+  }
 
   profiler = &(Tau_global_stack[tid][Tau_global_stackpos[tid]]);
   
@@ -325,6 +463,12 @@ extern "C" int Tau_stop_timer(void *function_info, int tid ) {
   int mydepth = Tau_global_stackpos[tid];
   if (mydepth >= userspecifieddepth) { 
     Tau_global_stackpos[tid]--; /* pop */
+#ifndef TAU_WINDOWS
+    if (TauEnv_get_ebs_enabled()) {
+      Tau_sampling_resume(tid);
+    }
+#endif
+    Tau_global_insideTAU[tid]--;
     return 0; 
   }
 #endif /* TAU_DEPTH_LIMIT */
@@ -334,10 +478,13 @@ extern "C" int Tau_stop_timer(void *function_info, int tid ) {
 
   Tau_global_stackpos[tid]--; /* pop */
 
-#ifdef TAU_EXP_SAMPLING
-    Tau_sampling_resume();
-#endif /* TAU_EXP_SAMPLING */
+#ifndef TAU_WINDOWS
+  if (TauEnv_get_ebs_enabled()) {
+    Tau_sampling_resume(tid);
+  }
+#endif
 
+  Tau_global_insideTAU[tid]--;
   return 0;
 }
 
@@ -359,22 +506,58 @@ extern "C" int Tau_stop_current_timer() {
 ///////////////////////////////////////////////////////////////////////////
 
 
+extern "C" int Tau_profile_exit_all_tasks() {
+	int tid = 1;
+	while (tid < TAU_MAX_THREADS)
+	{
+		while (Tau_global_stackpos[tid] >= 0) {
+			Profiler *p = &(Tau_global_stack[tid][Tau_global_stackpos[tid]]);
+			Tau_stop_timer(p->ThisFunction, tid);
+		}
+	tid++;
+	}
+  Tau_disable_instrumentation();
+  return 0;
+}
+
+
+extern "C" int Tau_profile_exit_all_threads() {
+	int tid = 0;
+	while (tid < TAU_MAX_THREADS)
+	{
+		while (Tau_global_stackpos[tid] >= 0) {
+			Profiler *p = &(Tau_global_stack[tid][Tau_global_stackpos[tid]]);
+			Tau_stop_timer(p->ThisFunction, Tau_get_tid());
+			// DO NOT pop. It is popped in stop above: Tau_global_stackpos[tid]--;
+		}
+	tid++;
+	}
+  Tau_disable_instrumentation();
+  return 0;
+}
+
 
 extern "C" int Tau_profile_exit() {
   int tid = RtsLayer::myThread();
-  while (Tau_global_stackpos[tid] >= 0) {
-    Profiler *p = &(Tau_global_stack[tid][Tau_global_stackpos[tid]]);
-    p->Stop();
-    Tau_global_stackpos[tid]--;
-  }
+	while (Tau_global_stackpos[tid] >= 0) {
+		Profiler *p = &(Tau_global_stack[tid][Tau_global_stackpos[tid]]);
+		Tau_stop_timer(p->ThisFunction, Tau_get_tid());
+		// DO NOT pop. It is popped in stop above: Tau_global_stackpos[tid]--;
+	}
   return 0;
 }
 
 
 ///////////////////////////////////////////////////////////////////////////
 extern "C" void Tau_exit(const char * msg) {
+  Tau_global_incr_insideTAU();
+
+#ifdef TAU_CUDA
+	Tau_profile_exit_all_threads();
+#else
   Tau_profile_exit();
-  
+#endif
+
 #ifdef TAUKTAU
   KtauProfiler::PutKtauProfiler();
 #endif /* TAUKTAU */
@@ -382,6 +565,7 @@ extern "C" void Tau_exit(const char * msg) {
 #ifdef RENCI_STFF  
   RenciSTFF::cleanup();
 #endif // RENCI_STFF  
+  Tau_global_decr_insideTAU();
 }
 
 ///////////////////////////////////////////////////////////////////////////
@@ -396,6 +580,7 @@ extern "C" void Tau_init(int argc, char **argv) {
 
 ///////////////////////////////////////////////////////////////////////////
 extern "C" void Tau_set_node(int node) {
+  if (node >= 0) TheSafeToDumpData()=1;
   RtsLayer::setMyNode(node);
 }
 
@@ -426,25 +611,33 @@ extern "C" void Tau_profile_callstack(void) {
 
 ///////////////////////////////////////////////////////////////////////////
 extern "C" int Tau_dump(void) {
+  Tau_global_incr_insideTAU();
   TauProfiler_DumpData();
+  Tau_global_decr_insideTAU();
   return 0;
 }
 
 ///////////////////////////////////////////////////////////////////////////
 extern "C" int Tau_dump_prefix(const char *prefix) {
+  Tau_global_incr_insideTAU();
   TauProfiler_DumpData(false, RtsLayer::myThread(), prefix);
+  Tau_global_decr_insideTAU();
   return 0;
 }
 
 ///////////////////////////////////////////////////////////////////////////
 extern "C" int Tau_dump_prefix_task(const char *prefix, int taskid) {
+  Tau_global_incr_insideTAU();
   TauProfiler_DumpData(false, taskid, prefix);
+  Tau_global_decr_insideTAU();
   return 0;
 }
 
 ///////////////////////////////////////////////////////////////////////////
 extern "C" int Tau_dump_incr(void) {
+  Tau_global_incr_insideTAU();
   TauProfiler_DumpData(true);
+  Tau_global_decr_insideTAU();
   return 0;
 }
 
@@ -574,7 +767,6 @@ extern "C" void Tau_profile_set_group(void *ptr, TauGroup_t group) {
 
 extern "C" const char *Tau_profile_get_group_name(void *ptr) {
   FunctionInfo *f = (FunctionInfo*)ptr;
-  printf ("returning %s\n", f->GroupName);
   return f->GroupName;
 }
 
@@ -636,9 +828,23 @@ extern "C" int& tau_totalnodes(int set_or_get, int value)
 }
 
 
-#ifdef TAU_MPI
+#if (defined(TAU_MPI) || defined(TAU_SHMEM) || defined(TAU_DMAPP) )
+
+
+
+#ifdef TAU_SYSTEMWIDE_TRACK_MSG_SIZE_AS_CTX_EVENT 
+#define TAU_GEN_EVENT(e, msg) TauContextUserEvent* e () { \
+        static TauContextUserEvent ce(msg); return &ce; }
+#undef TAU_EVENT
+#define TAU_EVENT(event,data) Tau_context_userevent(event, data);
+#else
 #define TAU_GEN_EVENT(e, msg) TauUserEvent* e () { \
 	static TauUserEvent u(msg); return &u; } 
+#endif /* TAU_SYSTEMWIDE_TRACK_MSG_SIZE_AS_CTX_EVENT */
+
+
+#define TAU_GEN_CONTEXT_EVENT(e, msg) TauContextUserEvent* e () { \
+	static TauContextUserEvent ce(msg); return &ce; } 
 
 TAU_GEN_EVENT(TheSendEvent,"Message size sent to all nodes")
 TAU_GEN_EVENT(TheRecvEvent,"Message size received from all nodes")
@@ -651,6 +857,7 @@ TAU_GEN_EVENT(TheAlltoallEvent,"Message size for all-to-all")
 TAU_GEN_EVENT(TheScatterEvent,"Message size for scatter")
 TAU_GEN_EVENT(TheGatherEvent,"Message size for gather")
 TAU_GEN_EVENT(TheAllgatherEvent,"Message size for all-gather")
+TAU_GEN_CONTEXT_EVENT(TheWaitEvent,"Message size received in wait")
 
 
 TauContextUserEvent**& TheMsgVolContextEvent() {
@@ -659,21 +866,36 @@ TauContextUserEvent**& TheMsgVolContextEvent() {
 }
 
 int register_events(void) {
-  if (TauEnv_get_comm_matrix()) {
-    char str[256];
-    int i;
-    
-    TheMsgVolContextEvent() = (TauContextUserEvent **) malloc(sizeof(TauContextUserEvent *)*tau_totalnodes(0,0));
-    for (i =0; i < tau_totalnodes(0,0); i++) {
-      sprintf(str, "Message size sent to node %d", i);
-      TheMsgVolContextEvent()[i] = (TauContextUserEvent *) new TauContextUserEvent((const char *)str);
+  static int flag = 0; 
+  
+  if (flag == 0) {
+
+    if (TauEnv_get_comm_matrix()) {
+      char str[256];
+      int i;
+      
+      TheMsgVolContextEvent() = (TauContextUserEvent **) malloc(sizeof(TauContextUserEvent *)*tau_totalnodes(0,0));
+      for (i =0; i < tau_totalnodes(0,0); i++) {
+        sprintf(str, "Message size sent to node %d", i);
+        TheMsgVolContextEvent()[i] = (TauContextUserEvent *) new TauContextUserEvent((const char *)str);
+      }
     }
+    flag = 1;
   }
   return 0;
 }
+
+///////////////////////////////////////////////////////////////////////////
+#ifdef TAU_SHMEM 
+extern "C" int shmem_n_pes(void); 
+#endif /* TAU_SHMEM */
+
 ///////////////////////////////////////////////////////////////////////////
 extern "C" void Tau_trace_sendmsg(int type, int destination, int length) {
+  if (!RtsLayer::TheEnableInstrumentation()) return; 
   static int initialize = register_events();
+#ifdef DEBUG_PROF
+#endif /* DEBUG_PROF */
 
 #ifdef TAU_PROFILEPARAM
 #ifndef TAU_DISABLE_PROFILEPARAM_IN_MPI
@@ -684,6 +906,15 @@ extern "C" void Tau_trace_sendmsg(int type, int destination, int length) {
   TAU_EVENT(TheSendEvent(), length);
 
   if (TauEnv_get_comm_matrix()) {
+    if (destination >= tau_totalnodes(0,0)) {
+#if (defined (TAU_SHMEM))
+      tau_totalnodes(1,shmem_n_pes());
+      register_events();
+#else /* TAU_SHMEM */
+      fprintf(stderr, "TAU Error: Comm Matrix destination %d exceeds node count %d. Was MPI_Init/shmem_init wrapper never called? Please disable TAU_COMM_MATRIX or add calls to the init function in your source code.\n", destination, tau_totalnodes(0,0));
+      exit(-1);
+#endif /* TAU_SHMEM */
+    }
     TheMsgVolContextEvent()[destination]->TriggerEvent(length, RtsLayer::myThread());
   }
 
@@ -712,6 +943,57 @@ extern "C" void Tau_trace_recvmsg(int type, int source, int length) {
   }
 }
 
+///////////////////////////////////////////////////////////////////////////
+extern "C" void Tau_trace_recvmsg_remote(int type, int source, int length, int remoteid) {
+
+  if (!RtsLayer::TheEnableInstrumentation()) return; 
+  if (TauEnv_get_tracing()) {
+    if (source >= 0) {
+      TauTraceRecvMsgRemote(type, source, length, remoteid);
+    }
+  }
+}
+
+///////////////////////////////////////////////////////////////////////////
+extern "C" void Tau_trace_sendmsg_remote(int type, int destination, int length, int remoteid) {
+  if (!RtsLayer::TheEnableInstrumentation()) return; 
+
+  if (TauEnv_get_tracing()) {
+    if (destination >= 0) {
+      TauTraceSendMsgRemote(type, destination, length, remoteid);
+    }
+  }
+  if (TauEnv_get_comm_matrix())  {
+  static int initialize = register_events();
+#ifdef DEBUG_PROF
+#endif /* DEBUG_PROF */
+
+#ifdef TAU_PROFILEPARAM
+#ifndef TAU_DISABLE_PROFILEPARAM_IN_MPI
+  TAU_PROFILE_PARAM1L(length, "message size");
+#endif /* TAU_DISABLE_PROFILEPARAM_IN_MPI */
+#endif  /* TAU_PROFILEPARAM */
+
+  //TAU_EVENT(TheSendEvent(), length); 
+
+  if (TauEnv_get_comm_matrix()) {
+    if (destination >= tau_totalnodes(0,0)) {
+     
+#if (defined (TAU_SHMEM))
+      tau_totalnodes(1,shmem_n_pes());
+      register_events();
+#else /* TAU_SHMEM */
+      fprintf(stderr, "TAU Error: Comm Matrix destination %d exceeds node count %d. Was MPI_Init/shmem_init wrapper never called? Please disable TAU_COMM_MATRIX or add calls to the init function in your source code.\n", destination, tau_totalnodes(0,0));
+      exit(-1);
+#endif /* TAU_SHMEM */
+    }
+    TheMsgVolContextEvent()[remoteid]->TriggerEvent(length, RtsLayer::myThread());
+  }
+
+  }
+}
+
+
 extern "C" void Tau_bcast_data(int data) {
   TAU_EVENT(TheBcastEvent(), data);
 }
@@ -736,6 +1018,10 @@ extern "C" void Tau_allgather_data(int data) {
   TAU_EVENT(TheAllgatherEvent(), data);
 }
 
+extern "C" void Tau_wait_data(int data) {
+  TAU_CONTEXT_EVENT(TheWaitEvent(), data);
+}
+
 extern "C" void Tau_allreduce_data(int data) {
   TAU_EVENT(TheAllReduceEvent(), data);
 }
@@ -747,16 +1033,24 @@ extern "C" void Tau_scan_data(int data) {
 extern "C" void Tau_reducescatter_data(int data) {
   TAU_EVENT(TheReduceScatterEvent(), data);
 }
-#else /* !TAU_MPI */
+#else /* !(TAU_MPI || TAU_SHMEM || TAU_DMAPP)*/
 ///////////////////////////////////////////////////////////////////////////
 extern "C" void Tau_trace_sendmsg(int type, int destination, int length) {
   TauTraceSendMsg(type, destination, length);
 }
 ///////////////////////////////////////////////////////////////////////////
+extern "C" void Tau_trace_sendmsg_remote(int type, int destination, int length, int remoteid) {
+  TauTraceSendMsgRemote(type, destination, length, remoteid);
+}
+///////////////////////////////////////////////////////////////////////////
 extern "C" void Tau_trace_recvmsg(int type, int source, int length) {
   TauTraceRecvMsg(type, source, length);
 }
-#endif /* TAU_MPI */
+///////////////////////////////////////////////////////////////////////////
+extern "C" void Tau_trace_recvmsg_remote(int type, int source, int length, int remoteid) {
+  TauTraceRecvMsgRemote(type, source, length, remoteid);
+}
+#endif /* TAU_MPI || TAU_SHMEM*/
 
 ///////////////////////////////////////////////////////////////////////////
 // User Defined Events 
@@ -773,10 +1067,14 @@ extern "C" void Tau_userevent(void *ue, double data) {
   t->TriggerEvent(data);
 } 
 
+extern "C" void Tau_userevent_thread(void *ue, double data, int tid) {
+  TauUserEvent *t = (TauUserEvent *) ue;
+  t->TriggerEvent(data, tid);
+}
+
 ///////////////////////////////////////////////////////////////////////////
 extern "C" void Tau_get_context_userevent(void **ptr, char *name)
 {
-  
   if (*ptr == 0) {
     RtsLayer::LockEnv();
 
@@ -797,6 +1095,12 @@ extern "C" void Tau_context_userevent(void *ue, double data) {
   t->TriggerEvent(data);
 } 
 
+///////////////////////////////////////////////////////////////////////////
+extern "C" void Tau_context_userevent_thread(void *ue, double data, int tid) {
+  TauContextUserEvent *t = (TauContextUserEvent *) ue;
+  t->TriggerEvent(data, tid);
+}
+
 ///////////////////////////////////////////////////////////////////////////
 extern "C" void Tau_set_event_name(void *ue, char *name) {
   TauUserEvent *t = (TauUserEvent *) ue;
@@ -844,6 +1148,7 @@ extern "C" void Tau_profile_c_timer(void **ptr, const char *name, const char *ty
   if (*ptr == 0) {
     RtsLayer::LockEnv();
     if (*ptr == 0) {  
+      Tau_global_incr_insideTAU();
       // remove garbage characters from the end of name
       char *fixedname = strdup(name);
       for (unsigned int i=0; i<strlen(fixedname); i++) {
@@ -854,6 +1159,7 @@ extern "C" void Tau_profile_c_timer(void **ptr, const char *name, const char *ty
       }
       *ptr = Tau_get_profiler(fixedname, type, group, group_name);
       free (fixedname);
+      Tau_global_decr_insideTAU();
     }
     RtsLayer::UnLockEnv();
   }
@@ -866,6 +1172,48 @@ extern "C" void Tau_profile_c_timer(void **ptr, const char *name, const char *ty
 /* We need a routine that will create a top level parent profiler and give
  * it a dummy name for the application, if just the MPI wrapper interposition
  * library is used without any instrumentation in main */
+extern "C" void Tau_create_top_level_timer_if_necessary_task(int tid) {
+
+
+  int disabled = 0;
+#ifdef TAU_VAMPIRTRACE
+  disabled = 1;
+#endif
+#ifdef TAU_EPILOG
+  disabled = 1;
+#endif
+  if (disabled) {
+    return;
+  }
+
+  static bool initialized = false;
+  static bool initthread[TAU_MAX_THREADS];
+  if (!initialized) {
+    RtsLayer::LockDB();
+    if (!initialized) {
+      for (int i=0; i<TAU_MAX_THREADS; i++) {
+	initthread[i] = false;
+      }
+    }
+    RtsLayer::UnLockDB();
+    initialized = true;
+  }
+  if (initthread[tid] == true) {
+    return;
+  }
+  
+	FunctionInfo *ptr;
+  if (TauInternal_CurrentProfiler(tid) == NULL) {
+			printf("in create_top_level_timer.\n");
+    initthread[tid] = true;
+    ptr = (FunctionInfo *) Tau_get_profiler(".TAU application", " ", TAU_DEFAULT, "TAU_DEFAULT");
+    if (ptr) {
+      Tau_start_timer(ptr, 0, tid);
+    }
+  }
+  atexit(Tau_destructor_trigger);
+}
+
 extern "C" void Tau_create_top_level_timer_if_necessary(void) {
   int disabled = 0;
 #ifdef TAU_VAMPIRTRACE
@@ -902,6 +1250,7 @@ extern "C" void Tau_create_top_level_timer_if_necessary(void) {
       Tau_start_timer(ptr, 0, Tau_get_tid());
     }
   }
+  atexit(Tau_destructor_trigger);
 }
 
 
@@ -1039,6 +1388,10 @@ extern "C" void Tau_profile_param1l(long data, const char *dataname) {
   string dname(dataname);
 #ifdef TAU_PROFILEPARAM
   TauProfiler_AddProfileParamData(data, dataname);
+#ifdef TAU_SCOREP
+  SCOREP_Tau_ParamHandle handle = SCOREP_TAU_INIT_PARAM_HANDLE;
+  SCOREP_Tau_Parameter_INT64(&handle, dataname, data);
+#endif
 #endif
 }
 
@@ -1047,9 +1400,8 @@ extern "C" void Tau_profile_param1l(long data, const char *dataname) {
   The following is for supporting pure and elemental fortran subroutines
 */
 
-
-map<string, FunctionInfo *>& ThePureMap() {
-  static map<string, FunctionInfo *> pureMap;
+TAU_HASH_MAP<string, FunctionInfo *>& ThePureMap() {
+  static TAU_HASH_MAP<string, FunctionInfo *> pureMap;
   return pureMap;
 }
 
@@ -1062,39 +1414,44 @@ extern "C" void Tau_pure_start_task(const char *name, int tid)
 {
   FunctionInfo *fi = 0;
   string n = string(name);
-  map<string, FunctionInfo *>::iterator it = ThePureMap().find(n);
+  RtsLayer::LockDB();
+  TAU_HASH_MAP<string, FunctionInfo *>::iterator it = ThePureMap().find(n);
   if (it == ThePureMap().end()) {
     tauCreateFI((void**)&fi,n,"",TAU_USER,"TAU_USER");
     ThePureMap()[n] = fi;
   } else {
     fi = (*it).second;
   }
+  RtsLayer::UnLockDB();
   Tau_start_timer(fi,0, tid);
 }
 extern "C" void Tau_pure_start(const char *name) {
-	Tau_pure_start_task(name, Tau_get_tid());
+  Tau_pure_start_task(name, Tau_get_tid());
 }
 
 extern "C" void Tau_pure_stop_task(const char *name, int tid) {
   FunctionInfo *fi;
   string n = string(name);
-  map<string, FunctionInfo *>::iterator it = ThePureMap().find(n);
+  RtsLayer::LockDB();
+  TAU_HASH_MAP<string, FunctionInfo *>::iterator it = ThePureMap().find(n);
   if (it == ThePureMap().end()) {
     fprintf (stderr, "\nTAU Error: Routine \"%s\" does not exist, did you misspell it with TAU_STOP()?\nTAU Error: You will likely get an overlapping timer message next\n\n", name);
   } else {
     fi = (*it).second;
-    Tau_stop_timer(fi, tid);
   }
+  RtsLayer::UnLockDB();
+  Tau_stop_timer(fi, tid);
 }
-extern "C" void Tau_pure_stop(const char *name)
-{
-	Tau_pure_stop_task(name, Tau_get_tid());
+extern "C" void Tau_pure_stop(const char *name) {
+  Tau_pure_stop_task(name, Tau_get_tid());
 }
 
 extern "C" void Tau_static_phase_start(char *name) {
+
+printf("Static phase: %s\n", name);
   FunctionInfo *fi = 0;
   string n = string(name);
-  map<string, FunctionInfo *>::iterator it = ThePureMap().find(n);
+  TAU_HASH_MAP<string, FunctionInfo *>::iterator it = ThePureMap().find(n);
   if (it == ThePureMap().end()) {
     tauCreateFI((void**)&fi,n,"",TAU_USER,"TAU_USER");
     Tau_mark_group_as_phase(fi);
@@ -1108,7 +1465,7 @@ extern "C" void Tau_static_phase_start(char *name) {
 extern "C" void Tau_static_phase_stop(char *name) {
   FunctionInfo *fi;
   string n = string(name);
-  map<string, FunctionInfo *>::iterator it = ThePureMap().find(n);
+  TAU_HASH_MAP<string, FunctionInfo *>::iterator it = ThePureMap().find(n);
   if (it == ThePureMap().end()) {
     fprintf (stderr, "\nTAU Error: Routine \"%s\" does not exist, did you misspell it with TAU_STOP()?\nTAU Error: You will likely get an overlapping timer message next\n\n", name);
   } else {
@@ -1150,7 +1507,7 @@ extern "C" void Tau_dynamic_start(char *name, int isPhase) {
   free(newName);
   
   RtsLayer::LockDB();
-  map<string, FunctionInfo *>::iterator it = ThePureMap().find(n);
+  TAU_HASH_MAP<string, FunctionInfo *>::iterator it = ThePureMap().find(n);
   if (it == ThePureMap().end()) {
     tauCreateFI((void**)&fi,n,"",TAU_USER,"TAU_USER");
     if (isPhase) {
@@ -1182,7 +1539,7 @@ extern "C" void Tau_dynamic_stop(char *name, int isPhase) {
   string n (newName);
   free(newName);
   RtsLayer::LockDB();
-  map<string, FunctionInfo *>::iterator it = ThePureMap().find(n);
+  TAU_HASH_MAP<string, FunctionInfo *>::iterator it = ThePureMap().find(n);
   if (it == ThePureMap().end()) {
     fprintf (stderr, "\nTAU Error: Routine \"%s\" does not exist, did you misspell it with TAU_STOP()?\nTAU Error: You will likely get an overlapping timer message next\n\n", name);
     RtsLayer::UnLockDB();
@@ -1219,14 +1576,14 @@ extern "C" pid_t tau_fork() {
 // Snapshot related routines
 //////////////////////////////////////////////////////////////////////
 
-extern "C" void Tau_profile_snapshot_1l(char *name, int number) {
+extern "C" void Tau_profile_snapshot_1l(const char *name, int number) {
   char buffer[4096];
   sprintf (buffer, "%s %d", name, number);
-  TauProfiler_Snapshot(buffer);
+  Tau_snapshot_writeIntermediate(buffer);
 }
 
-extern "C" void Tau_profile_snapshot(char *name) {
-  TauProfiler_Snapshot(name);
+extern "C" void Tau_profile_snapshot(const char *name) {
+  Tau_snapshot_writeIntermediate(name);
 }
 
 
@@ -1319,11 +1676,17 @@ extern "C" int Tau_get_tid(void) {
   return RtsLayer::myThread();
 }
 
+extern "C" int Tau_create_tid(void) {
+  return RtsLayer::threadId();
+}
+
 // this routine is called by the destructors of our static objects
 // ensuring that the profiles are written out while the objects are still valid
 void Tau_destructor_trigger() {
+  Tau_stop_top_level_timer_if_necessary();
+  //printf ("FIvector destructor\n");
+  Tau_global_setLightsOut();
   if ((TheUsingDyninst() || TheUsingCompInst()) && TheSafeToDumpData()) {
-    //printf ("FIvector destructor\n");
 #ifndef TAU_VAMPIRTRACE
     TAU_PROFILE_EXIT("FunctionDB destructor");
     TheSafeToDumpData() = 0;
@@ -1333,10 +1696,15 @@ void Tau_destructor_trigger() {
 
 //////////////////////////////////////////////////////////////////////
 extern "C" int Tau_create_task(void) {
+  int taskid;
   if (TAU_MAX_THREADS == 1) {
     printf("TAU: ERROR: Please re-configure TAU with -useropt=-DTAU_MAX_THREADS=100  and rebuild it to use the new TASK API\n");
   }
-  return RtsLayer::RegisterThread() - 1; /* it returns 1 .. N, we want 0 .. N-1 */
+  taskid= RtsLayer::RegisterThread() - 1; /* it returns 1 .. N, we want 0 .. N-1 */
+  /* specify taskid is a fake thread used in the Task API */
+  Tau_is_thread_fake_for_task_api[taskid] = 1; /* This thread is fake! */
+ 	//printf("create task with id: %d.\n", taskid); 
+  return taskid;
 }
 
 
@@ -1364,7 +1732,7 @@ void *Tau_query_parent_event(void *event) {
   if (event == topOfStack) {
     return NULL;
   } else {
-    long loc = (long)event;
+    long loc = Tau_convert_ptr_to_long(event);
     return (void*)(loc - (sizeof(Profiler)));
   }
 }
@@ -1374,7 +1742,6 @@ void *Tau_query_parent_event(void *event) {
 //////////////////////////////////////////////////////////////////////
 // User definable clock
 //////////////////////////////////////////////////////////////////////
-
 extern "C" void Tau_set_user_clock(double value) {
   int tid = RtsLayer::myThread();
   metric_write_userClock(tid, value);
@@ -1384,6 +1751,17 @@ extern "C" void Tau_set_user_clock_thread(double value, int tid) {
   metric_write_userClock(tid, value);
 }
 
+extern "C" long Tau_convert_ptr_to_long(void *ptr) {
+  long long a = (long long) ptr;
+  long ret = (long) a;
+  return ret;
+}
+
+extern "C" unsigned long Tau_convert_ptr_to_unsigned_long(void *ptr) {
+  unsigned long long a = (unsigned long long) ptr;
+  unsigned long ret = (unsigned long) a;
+  return ret;
+}
 
 //////////////////////////////////////////////////////////////////////
 // Sometimes we may link in a library that needs the POMP stuff
@@ -1420,11 +1798,21 @@ int *tau_pomp_rd_table = 0;
 // #endif
 #endif
 
+#ifndef TAU_BGP
+extern "C" void Tau_Bg_hwp_counters_start(int *error) {
+}
+
+extern "C" void Tau_Bg_hwp_counters_stop(int* numCounters, x_uint64 counters[], int* mode, int *error) {
+}
+
+extern "C" void Tau_Bg_hwp_counters_output(int* numCounters, x_uint64 counters[], int* mode, int* error) {
+}
+#endif /* TAU_BGP */
                     
 
 /***************************************************************************
- * $RCSfile: TauCAPI.cpp,v $   $Author: amorris $
- * $Revision: 1.143 $   $Date: 2010/02/22 17:50:58 $
- * VERSION: $Id: TauCAPI.cpp,v 1.143 2010/02/22 17:50:58 amorris Exp $
+ * $RCSfile: TauCAPI.cpp,v $   $Author: sameer $
+ * $Revision: 1.158 $   $Date: 2010/05/28 17:45:49 $
+ * VERSION: $Id: TauCAPI.cpp,v 1.158 2010/05/28 17:45:49 sameer Exp $
  ***************************************************************************/
 
