@@ -23,7 +23,6 @@
 
 
 
-
 extern "C" void Tau_pure_start(const char *name);
 extern "C" void Tau_pure_stop(const char *name);
 
@@ -92,7 +91,7 @@ void Tau_dynamic_stop(char *name, int isPhase);
 char * Tau_append_iteration_to_name(int iteration, char *name);
 int Tau_get_tid(void);
 void Tau_profile_param1l(long data, const char *dataname);
-  
+void Tau_mon_onlineDump();
 
 
 #define EXTRACT_GROUP(n, l, gr, gr_name) TauGroup_t gr; char *gr_name = NULL; tau_extract_groupinfo(n, gr, gr_name); 
@@ -1818,6 +1817,22 @@ void TAU_PROFILE_SNAPSHOT(char *name, int slen) {
   tau_profile_snapshot_(name, slen);
 }
 
+void tau_online_dump_() {
+  Tau_mon_onlineDump();
+}
+
+void tau_online_dump() {
+  Tau_mon_onlineDump();
+}
+
+void tau_online_dump__() {
+  Tau_mon_onlineDump();
+}
+
+void TAU_ONLINE_DUMP() {
+  Tau_mon_onlineDump();
+}
+
 //////////////////////////////////////////////////////////////////////
 // Parameter Profiling
 //////////////////////////////////////////////////////////////////////
@@ -2001,7 +2016,7 @@ void TAU_DISABLE_TRACKING_MUSE_EVENTS(void) {}
 
 
 /***************************************************************************
- * $RCSfile: TauFAPI.cpp,v $   $Author: amorris $
- * $Revision: 1.81 $   $Date: 2010/02/23 07:42:19 $
- * POOMA_VERSION_ID: $Id: TauFAPI.cpp,v 1.81 2010/02/23 07:42:19 amorris Exp $ 
+ * $RCSfile: TauFAPI.cpp,v $   $Author: cheelee $
+ * $Revision: 1.84 $   $Date: 2010/06/08 01:09:53 $
+ * POOMA_VERSION_ID: $Id: TauFAPI.cpp,v 1.84 2010/06/08 01:09:53 cheelee Exp $ 
  ***************************************************************************/
