@@ -21,6 +21,10 @@
 #include <string.h>
 #include <Profile/Profiler.h>
 
+#ifdef __GNUC__
+#include <cxxabi.h>
+#endif /* __GNUC__ */
+
 #ifdef TAU_WINDOWS
 //#include <vector>
 //#include <string>
@@ -30,10 +34,10 @@ using namespace std;
 #include <stdlib.h>
 
 //#define DEBUG_PROF
-//int debugPrint = 0;
+//int debugPrint = 1;
 // control debug printf statements
 //#define dprintf if (debugPrint) printf
-//#define dprintf printf
+#define dprintf TAU_VERBOSE
 #ifdef DEBUG_PROF
 #define dprintf printf
 #else // DEBUG_PROF 
@@ -44,6 +48,7 @@ using namespace std;
 #define TAUDYNVEC 1
 //extern "C" void Tau_get_func_name(long addr, char * fname, char *filename);
 
+extern "C" void tau_dyninst_init(int isMPI);
 
 #ifndef __ia64
 int TheFlag[TAU_MAX_THREADS] ;
@@ -98,7 +103,11 @@ void TauInitCode(char *arg, int isMPI)
 */
   for (j=1, str1 = arg; ; j++, str1 = NULL) 
   { 
+#ifdef TAU_WINDOWS
+    name = strtok(str1, "|");
+#else
     name = strtok_r(str1, "|", &saveptr);
+#endif
     if (name == NULL) 
       break;
     dprintf("After loop: name = %s\n", name);
@@ -266,6 +275,11 @@ void TauMPIInitStub(int *rank)
   dprintf("Setting rank = %d\n", *rank);
 }
 
+void TauMPIInitStubInt (int rank)
+{
+  TauMPIInitStub(&rank);
+}
+
 int TauRenameTimer(char *oldName, char *newName)
 {
   vector<FunctionInfo *>::iterator it;
@@ -287,14 +301,45 @@ int TauRenameTimer(char *oldName, char *newName)
 }
 
 
-static int tauFiniID; 
+static int tauFiniID = -1; 
 static int tauDyninstEnabled[TAU_MAX_THREADS];
 void trace_register_func(char *func, int id)
 {
   static int invocations = 0;
+  int i;
   int tid = RtsLayer::myThread();
+  dprintf("trace_register_func: func = %s, id = %d\n", func, id); 
+  if (invocations == 0) {
+    if (!tauDyninstEnabled[tid]) {
+#ifdef TAU_MPI
+      tau_dyninst_init(1); 
+#else
+      tau_dyninst_init(0); 
+#endif /* TAU_MPI */
+    }
+  }
+
+  int len = strlen(func); 
+  int startbracket = 0; 
+  int stopbracket = 0;
+  for (i=0; i < len; i++) {
+    if (func[i] == '[') startbracket = i; 
+    if (func[i] == ']') stopbracket = i; 
+    if (!isprint(func[i])) {
+      dprintf("TauHooks.cpp: trace_register_func(): func=%s - isprint is false at i = %d\n", func, i);
+      func[i] = '\0';
+      if (i == 0) strcpy(func, "<unknown>");
+    }
+  }
+  if (startbracket > 0 && stopbracket == 0) { /* didn't find stop bracket */
+    dprintf("func=%s, before chopping off the bracket! \n", func);
+    func[startbracket] = '\0'; /* chop it off - no need to show the name */
+    dprintf("func=%s, after chopping off the bracket! \n", func);
+  }
+
+
+    
   if (!tauDyninstEnabled[tid]) return;
-  dprintf("trace_register_func: func = %s, id = %d\n", func, id);
 
   void *taufi;
   TAU_PROFILER_CREATE(taufi, func, " ", TAU_DEFAULT);
@@ -329,14 +374,17 @@ void trace_register_func(char *func, int id)
     TheTauBinDynFI().push_back(taufi);
   else {
     printf("WARNING: trace_register_func: id does not match invocations\n");
+    TheTauBinDynFI().resize(id+1);
     TheTauBinDynFI()[id] = taufi;
   } 
   invocations ++;
+  dprintf("Exiting trace_register_func\n");
 }
 
 void traceEntry(int id)
 {
   int tid = RtsLayer::myThread();
+  if ( !RtsLayer::TheEnableInstrumentation()) return; 
   if (!tauDyninstEnabled[tid]) return;
   void *fi = TheTauBinDynFI()[id];
 
@@ -357,12 +405,15 @@ void traceEntry(int id)
   dprintf("Inside traceEntry: id = %d fi = %lx\n", id, fi);
   dprintf("Name = %s\n", ((FunctionInfo *)fi)->GetName());
   if (id == tauFiniID) { 
+    Tau_stop_top_level_timer_if_necessary(); 
+	/* if there is .TAU application from tau_exec, write the files out */
     TAU_DISABLE_INSTRUMENTATION();
     dprintf("Disabling instrumentation found id = %d\n", id);
   } 
   else {
     if (fi != NULL) {
-      TAU_PROFILER_START(fi);
+      //TAU_PROFILER_START(fi);
+      Tau_start_timer(fi, 0, tid);
     } else {
       dprintf("ERROR?: traceEntry: fi = null!\n");
     }
@@ -375,10 +426,17 @@ void traceExit(int id)
 {
   const char *strcurr;
   const char *strbin;
+  dprintf("Inside traceExit: id = %d\n", id);  
+  
+  if ( !RtsLayer::TheEnableInstrumentation()) return; 
   int tid = RtsLayer::myThread();
+
   if (!tauDyninstEnabled[tid]) return;
   void *fi = TheTauBinDynFI()[id];
-  dprintf("traceExit: Name = %s, %lx\n", ((FunctionInfo *)fi)->GetName(), fi);
+  if (fi) 
+    dprintf("traceExit: Name = %s, %lx\n", ((FunctionInfo *)fi)->GetName(), fi);
+  else
+    return;
 
   TAU_QUERY_DECLARE_EVENT(curr);
   TAU_QUERY_GET_CURRENT_EVENT(curr);
@@ -393,7 +451,8 @@ void traceExit(int id)
     }
   }
   if (fi != NULL) {
-    TAU_PROFILER_STOP(fi);
+    //TAU_PROFILER_STOP(fi);
+     Tau_stop_timer(fi, tid);
   } else {
     printf("ERROR: traceExit: fi = null!\n");
   }
@@ -434,7 +493,10 @@ void tau_dyninst_init(int isMPI)
   }
   int tid = RtsLayer::myThread();
   if (!tauDyninstEnabled[tid]) {
-    tauDyninstEnabled[tid] = 1;
+    RtsLayer::LockDB();
+    for (int i = 0; i < TAU_MAX_THREADS; i++) 
+      tauDyninstEnabled[i] = 1;
+    RtsLayer::UnLockDB();
   }
 }
 
@@ -443,13 +505,53 @@ void tau_dyninst_cleanup()
   dprintf("Inside tau_dyninst_cleanup\n");
 }
 
-
+/* PEBIL */
+char * tau_demangle_name(char **funcname) {
+  std::size_t len=1024;
+  int stat;
+  char *out_buf= (char *) malloc (len);
+  char *dem_name = NULL; 
+#ifdef __GNUC__
+  char *name = abi::__cxa_demangle(*funcname, out_buf, &len, &stat);
+  if (stat == 0) dem_name = out_buf;
+  else dem_name = *funcname;
+  return dem_name; 
+#else  /* __GNUC__ */
+  return *funcname; 
+  /* return the original name pass it through c++filt <name> */
+#endif /* __GNUC__ */
+  
 }
-// extern "C"
+
+void  tau_register_func(char **func, char** file, int* lineno, 
+  int* id) {
+    if (*file == NULL){
+      dprintf("TAU: tau_register_func: name = %s, id = %d\n", *func, *id);
+      trace_register_func(tau_demangle_name(func), *id);
+    } else {
+      char funcname[2048];
+      sprintf(funcname, "%s [{%s}{%d}]", tau_demangle_name(func), *file, *lineno);
+      trace_register_func(funcname, *id);
+      dprintf("TAU : tau_register_func: name = %s, id = %d\n", funcname, *id);
+    }
+}
+
+void tau_trace_entry(int* id) {
+  dprintf("TAU: tau_trace_entry: id = %d\n", *id);
+  traceEntry(*id);
+}
+
+void tau_trace_exit(int* id) {
+  dprintf("TAU: tau_trace_exit : id = %d\n", *id);
+  traceExit(*id);
+}
+
+} /* extern "C" */
+  
 
 // EOF TauHooks.cpp
 /***************************************************************************
- * $RCSfile: TauHooks.cpp,v $   $Author: amorris $
- * $Revision: 1.33 $   $Date: 2009/11/03 17:34:17 $
- * TAU_VERSION_ID: $Id: TauHooks.cpp,v 1.33 2009/11/03 17:34:17 amorris Exp $ 
+ * $RCSfile: TauHooks.cpp,v $   $Author: sameer $
+ * $Revision: 1.35 $   $Date: 2010/06/09 15:11:36 $
+ * TAU_VERSION_ID: $Id: TauHooks.cpp,v 1.35 2010/06/09 15:11:36 sameer Exp $ 
  ***************************************************************************/
