@@ -23,15 +23,43 @@
 #include <tau_internal.h>
 #include <Profile/Profiler.h>
 #include <Profile/TauTrace.h>
+#ifdef CUPTI
+#include <Profile/CuptiLayer.h>
+#endif //CUPTI
 
 #ifdef TAUKTAU_SHCTR
 #include "Profile/KtauCounters.h"
 #endif //TAUKTAU_SHCTR
 
+
+void metric_read_nullClock(int tid, int idx, double values[]);
+void metric_write_userClock(int tid, double value);
+void metric_read_userClock(int tid, int idx, double values[]);
+void metric_read_logicalClock(int tid, int idx, double values[]);
+void metric_read_gettimeofday(int tid, int idx, double values[]);
+void metric_read_clock_gettime(int tid, int idx, double values[]);
+void metric_read_linuxtimers(int tid, int idx, double values[]);
+void metric_read_bgtimers(int tid, int idx, double values[]);
+void metric_read_craytimers(int tid, int idx, double values[]);
+void metric_read_cputime(int tid, int idx, double values[]);
+void metric_read_messagesize(int tid, int idx, double values[]);
+void metric_read_papivirtual(int tid, int idx, double values[]);
+void metric_read_papiwallclock(int tid, int idx, double values[]);
+void metric_read_papi(int tid, int idx, double values[]);
+void metric_read_ktau(int tid, int idx, double values[]);
+void metric_read_cudatime(int tid, int idx, double values[]);
+void metric_read_cupti(int tid, int idx, double values[]);
+
+
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 int TauMetrics_init();
+int Tau_init_check_initialized(void); 
 
 static void metricv_add(const char *name);
-static void reorder_metrics();
 static void read_env_vars();
 static void initialize_functionArray();
 
@@ -57,20 +85,10 @@ static int traceMetric = 0;
 /* array of function pointers used to get metric data */
 static function functionArray[TAU_MAX_METRICS];
 
-void metric_read_nullClock(int tid, int idx, double values[]);
-void metric_write_userClock(int tid, double value);
-void metric_read_userClock(int tid, int idx, double values[]);
-void metric_read_logicalClock(int tid, int idx, double values[]);
-void metric_read_gettimeofday(int tid, int idx, double values[]);
-void metric_read_linuxtimers(int tid, int idx, double values[]);
-void metric_read_bgtimers(int tid, int idx, double values[]);
-void metric_read_craytimers(int tid, int idx, double values[]);
-void metric_read_cputime(int tid, int idx, double values[]);
-void metric_read_messagesize(int tid, int idx, double values[]);
-void metric_read_papivirtual(int tid, int idx, double values[]);
-void metric_read_papiwallclock(int tid, int idx, double values[]);
-void metric_read_papi(int tid, int idx, double values[]);
-void metric_read_ktau(int tid, int idx, double values[]);
+/* gtod based initial timestamp, used for snapshots and other stuff */
+static x_uint64 initialTimeStamp;
+
+
 
 /*********************************************************************
  * Remove _'s, convert case, and compare
@@ -211,7 +229,16 @@ static void read_env_vars() {
     }
 
     if (nmetrics == 0) {
+#if defined(BGL_TIMERS)
+      metricv_add("BGL_TIMERS");
+#elif defined(BGP_TIMERS)
+      metricv_add("BGP_TIMERS");
+#elif defined(BGQ_TIMERS)
+      metricv_add("BGQ_TIMERS");
+#else
+      // NOTE: Probably need more #elif defined() for other platforms...
       metricv_add("TIME");
+#endif
     }
   }
 }
@@ -254,10 +281,26 @@ static int is_papi_metric(char *str) {
   return 0;
 }
 
+#ifdef CUPTI
+/*********************************************************************
+ * Query if a string is a CUPTI metric
+ ********************************************************************/
+static int is_cupti_metric(char *str) {
+  if (strncmp("CUDA", str, 4) == 0) {
+		if (Tau_CuptiLayer_is_cupti_counter(str))
+		{
+			return 1;
+		}
+  }
+  return 0;
+}
+#endif //CUPTI
+
 /*********************************************************************
  * Initialize the function array
  ********************************************************************/
-static void initialize_functionArray() {
+static void initialize_functionArray() 
+{
   int usingPAPI = 0;
   int pos = 0;
   int found = 0;
@@ -279,6 +322,8 @@ static void initialize_functionArray() {
       functionArray[pos++] = metric_read_userClock;
     } else if (compareMetricString(metricv[i], "GET_TIME_OF_DAY")) {
       functionArray[pos++] = metric_read_gettimeofday;
+    } else if (compareMetricString(metricv[i], "CLOCK_GET_TIME")) {
+      functionArray[pos++] = metric_read_clock_gettime;
     } else if (compareMetricString(metricv[i], "TIME")) {
       functionArray[pos++] = metric_read_gettimeofday;
     } else if (compareMetricString(metricv[i], "CPU_TIME")) {
@@ -291,10 +336,19 @@ static void initialize_functionArray() {
       functionArray[pos++] = metric_read_bgtimers;
     } else if (compareMetricString(metricv[i], "BGP_TIMERS")) {
       functionArray[pos++] = metric_read_bgtimers;
+    } else if (compareMetricString(metricv[i], "BGQ_TIMERS")) {
+      functionArray[pos++] = metric_read_bgtimers;
     } else if (compareMetricString(metricv[i], "CRAY_TIMERS")) {
       functionArray[pos++] = metric_read_craytimers;
     } else if (compareMetricString(metricv[i], "TAU_MPI_MESSAGE_SIZE")) {
       functionArray[pos++] = metric_read_messagesize;
+#ifdef CUPTI
+		} else if (is_cupti_metric(metricv[i])) {
+			/* CUPTI handled separately */
+			/* setup CUPTI metrics */
+			functionArray[pos++] = metric_read_cupti;
+			Tau_CuptiLayer_register_string(metricv[i]);
+#endif //CUPTI
 #ifdef TAU_PAPI
     } else if (compareMetricString(metricv[i], "P_WALL_CLOCK_TIME")) {
       usingPAPI = 1;
@@ -309,6 +363,8 @@ static void initialize_functionArray() {
       usingPAPI = 1;
       functionArray[pos++] = metric_read_papivirtual;
 #endif /* TAU_PAPI */
+    } else if (compareMetricString(metricv[i], "TAUGPU_TIME")) {
+      functionArray[pos++] = metric_read_cudatime;
     } else {
       if (papi_available && is_papi_metric(metricv[i])) {
         /* PAPI handled separately */
@@ -342,7 +398,7 @@ static void initialize_functionArray() {
       usingPAPI = 1;
       break;
     }
-  }
+	}
 
 #ifdef TAUKTAU_SHCTR
   for (int i = 0; i < nmetrics; i++) {
@@ -359,6 +415,7 @@ static void initialize_functionArray() {
     PapiLayer::initializePapiLayer();
 #endif
   }
+	
 
   for (int i = 0; i < nmetrics; i++) {
     if (is_papi_metric(metricv[i])) {
@@ -396,7 +453,7 @@ static void initialize_functionArray() {
 /*********************************************************************
  * Returns metric name for an index
  ********************************************************************/
-const char *TauMetrics_getMetricName(int metric) {
+extern "C" const char *TauMetrics_getMetricName(int metric) {
   return metricv[metric];
 }
 
@@ -414,24 +471,57 @@ int TauMetrics_getMetricUsed(int metric) {
 /*********************************************************************
  * Read the metrics
  ********************************************************************/
-void TauMetrics_getMetrics(int tid, double values[]) {
-  for (int i = 0; i < nfunctions; i++) {
-    functionArray[i](tid, i, values);
+extern "C"  bool TauCompensateInitialized(void);
+void TauMetrics_getMetrics(int tid, double values[]) 
+{
+  if (Tau_init_check_initialized()) {
+      for (int i = 0; i < nfunctions; i++) {
+        functionArray[i](tid, i, values);
+      }
+  } else {
+    // *CWL* - Safe only if Compensation is safely initialized. Otherwise
+    //         we would be in the middle of re-entrant behavior and
+    //         would be re-initializing metrics each time.
+    if (TauCompensateInitialized()) {
+      TauMetrics_init();
+    }
   }
 }
 
+
+extern "C" x_uint64 TauMetrics_getInitialTimeStamp() {
+  return initialTimeStamp;
+}
+
+
+extern "C" x_uint64 TauMetrics_getTimeOfDay() {
+  x_uint64 timestamp;
+#ifdef TAU_WINDOWS
+  timestamp = TauWindowsUsecD();
+#else
+  struct timeval tp;
+  gettimeofday (&tp, 0);
+  timestamp = (x_uint64)tp.tv_sec * (x_uint64)1e6 + (x_uint64)tp.tv_usec;
+#endif
+  return timestamp;
+}
+
 /*********************************************************************
  * Initialize the metrics module
  ********************************************************************/
 int TauMetrics_init() {
   int i;
 
-#ifdef TAU_EXP_SAMPLING
-  //metricv_add("TIME");
-  if (strcmp(TauEnv_get_ebs_source(),"itimer")!=0) {
-    metricv_add(TauEnv_get_ebs_source());
+  initialTimeStamp = TauMetrics_getTimeOfDay();
+
+  if (TauEnv_get_ebs_enabled()) {
+    // *CWL* - keep an eye on this. *must* we do this? Or can we
+    //         keep PAPI overflow signal triggers separate from
+    //         user-selected metrics to be measured.
+    if (strcmp(TauEnv_get_ebs_source(),"itimer")!=0) {
+      metricv_add(TauEnv_get_ebs_source());
+    }
   }
-#endif
 
   /* Set the user clock values to 0 */
   for (i = 0; i < TAU_MAX_THREADS; i++) {
@@ -446,7 +536,7 @@ int TauMetrics_init() {
 
   initialize_functionArray();
 
-  Tau_Global_numCounters = nmetrics;
+	Tau_Global_numCounters = nmetrics;
 
   /* Create atomic events for tracing */
   if (TauEnv_get_tracing()) {
@@ -504,3 +594,41 @@ double TauMetrics_getTraceMetricValue(int tid) {
   TauMetrics_getMetrics(tid, values);
   return values[traceMetric];
 }
+
+/**********************************************************************
+ * Returns the index in the metric vector of a particular metric string
+ *    *CWL* Intended for EBS to resolve the index location of the metric
+ *    source at data output time. This assumes the metric vector does
+ *    not change between the time it is read and when it is used. This
+ *    is not true, I believe, so we need to keep an eye on this.
+ *    There are also other issues of name matching ... EBS (this ought
+ *    to be changed) uses "itimer" instead of "TIME". So, we are going
+ *    to do the unethical practice of assuming it is TIME if there is
+ *    a failure to match the presented name against the names in the
+ *    metric vector.
+ **********************************************************************/
+int TauMetrics_getMetricIndexFromName(const char *metricString) {
+  for (int i=0; i<nmetrics; i++) {
+    if (compareMetricString(metricv[i], metricString) == 1) {
+      return i;
+    }
+  }
+  /* EBS ONLY:
+     Try again assuming TIME. The reason we loop again is because in the
+     general case, TIME isn't necessarily in position 0. */
+  if (TauEnv_get_ebs_enabled()) {
+    for (int i=0; i<nmetrics; i++) {
+      if (compareMetricString(metricv[i], "TIME") == 1) {
+	return i;
+      }
+    }
+  }
+  /* This is a bad failure value. EBS cannot handle this. Other features
+     might. */
+  return -1;
+}
+
+
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
