@@ -39,9 +39,11 @@ using namespace std;
 #define INIT_PARAM 3
 
 /* Trace buffer settings */
-#define TAU_MAX_RECORDS 64*1024
 #define TAU_BUFFER_SIZE sizeof(TAU_EV)*TAU_MAX_RECORDS
 
+static unsigned long long TauMaxTraceRecords = 0; 
+static int TauBufferSize = 0; 
+
 /* Trace buffer */
 static TAU_EV *TraceBuffer[TAU_MAX_THREADS]; 
 
@@ -133,6 +135,7 @@ int TauTraceGetFlushEvents() {
 
 /* Check that the trace file is initialized */
 static int checkTraceFileInitialized(int tid) {
+
   if ( !(TraceFileInitialized[tid]) && (RtsLayer::myNode() > -1)) { 
     TraceFileInitialized[tid] = 1;
     const char *dirname;
@@ -146,10 +149,19 @@ static int checkTraceFileInitialized(int tid) {
       exit (1);
     }
 
+    //    printf("checkTraceFileInitialized [%d]: TauTraceFd[%d] for [%s] is %d\n", RtsLayer::myNode(), 
+    //	   tid, tracefilename, TauTraceFd[tid]);
+
     if (TraceBuffer[tid][0].ev == TAU_EV_INIT) { 
       /* first record is init */
       for (int iter = 0; iter < TauCurrentEvent[tid]; iter ++) {
-	TraceBuffer[tid][iter].nid = RtsLayer::myNode();
+        int mynodeid = RtsLayer::myNode();
+	if ((mynodeid > 0) && (TraceBuffer[tid][iter].nid == 0)) {
+          TraceBuffer[tid][iter].nid = RtsLayer::myNode();
+        } else {
+            if ((mynodeid > 0) && (TraceBuffer[tid][iter].nid > 0))
+	      break;
+        }
       }
     }
   }
@@ -158,10 +170,11 @@ static int checkTraceFileInitialized(int tid) {
 
 /* Flush the trace buffer */
 void TauTraceFlushBuffer(int tid) {
+  Tau_global_incr_insideTAU_tid(tid);
   checkTraceFileInitialized(tid);
 
   int ret;
-  if (TauTraceFd[tid] == 0) {
+  if (TauTraceFd[tid] == -1) {
     printf("Error: TauTraceFlush(%d): Fd is -1. Trace file not initialized \n", tid);
     if (RtsLayer::myNode() == -1) {
       fprintf (stderr, "ERROR in configuration. Trace file not initialized. If this is an MPI application, please ensure that TAU MPI wrapper library is linked. If not, please ensure that TAU_PROFILE_SET_NODE(id); is called in the program (0 for sequential).\n");
@@ -187,6 +200,7 @@ void TauTraceFlushBuffer(int tid) {
     }
   }
   TauCurrentEvent[tid] = 0;
+  Tau_global_decr_insideTAU_tid(tid);
 }
 
 
@@ -207,7 +221,14 @@ bool *TauBufferAllocated() {
    the trace file is initialized */
 int TauTraceInit(int tid) {
    if (!TauBufferAllocated()[tid]) {
-     TraceBuffer[tid] = (TAU_EV*) malloc(TAU_BUFFER_SIZE);
+     TauMaxTraceRecords = (unsigned long long) TauEnv_get_max_records(); 
+     TauBufferSize = sizeof(TAU_EV)*TauMaxTraceRecords; 
+     //TraceBuffer[tid] = (TAU_EV*) malloc(TAU_BUFFER_SIZE);
+     TraceBuffer[tid] = (TAU_EV*) malloc(TauBufferSize);
+     if (TraceBuffer[tid] == (TAU_EV *) NULL) {
+       fprintf(stderr, "TAU: FATAL Error: Trace buffer malloc failed. Please rerun the application with the TAU_MAX_RECORDS environment variable set to a smaller value\n");
+       exit(1); 
+     }
      TauBufferAllocated()[tid] = true;
    }
   int retvalue = 0; 
@@ -277,9 +298,10 @@ void TauTraceEventSimple(long int ev, x_int64 par, int tid) {
 
 
 /* Write event to buffer */
-void TauTraceEvent(long int ev, x_int64 par, int tid, x_uint64 ts, int use_ts) {
+void TauTraceEventWithNodeId(long int ev, x_int64 par, int tid, x_uint64 ts, int use_ts, int node_id) {
   int i;
   int records_created = TauTraceInit(tid);
+  x_uint64 timestamp;
   TAU_EV *event = &TraceBuffer[tid][TauCurrentEvent[tid]];  
 
   if (TauEnv_get_synchronize_clocks()) {
@@ -320,22 +342,44 @@ void TauTraceEvent(long int ev, x_int64 par, int tid, x_uint64 ts, int use_ts) {
     } 
   } 
         
+
   event->ev  = ev;
   if (use_ts) {
     event->ti = ts;
+    timestamp = ts; 
   } else {
-    event->ti = TauTraceGetTimeStamp(tid);
+    timestamp = TauTraceGetTimeStamp(tid);
+    event->ti = timestamp; 
   }
   event->par = par;
-  event->nid = RtsLayer::myNode();
+  event->nid = node_id;
   event->tid = tid ;
   TauCurrentEvent[tid]++;
 
-  if (TauCurrentEvent[tid] >= TAU_MAX_RECORDS-1) {
+  if (TauCurrentEvent[tid] >= TauMaxTraceRecords-2) {
+    //TauTraceEventSimple (TAU_EV_FLUSH, 0, tid);
+    event = &TraceBuffer[tid][TauCurrentEvent[tid]];
+    event->ev = TAU_EV_FLUSH;  event->ti = timestamp; event->par = 1;
+    event->nid = node_id; event->tid = tid; 
+    TauCurrentEvent[tid]++;
+
+    // Flush the buffer! 
     TauTraceFlushBuffer(tid); 
+
+    //TauTraceEventSimple (TAU_EV_FLUSH, 0, tid);
+    timestamp = TauTraceGetTimeStamp(tid);
+    event = &TraceBuffer[tid][TauCurrentEvent[tid]];
+    event->ev = TAU_EV_FLUSH;  event->ti = timestamp; event->par = -1;
+    event->nid = node_id; event->tid = tid; 
+    TauCurrentEvent[tid]++;
   }
 }
 
+/* Write event to buffer */
+void TauTraceEvent(long int ev, x_int64 par, int tid, x_uint64 ts, int use_ts) {
+  TauTraceEventWithNodeId(ev, par, tid, ts, use_ts, RtsLayer::myNode());
+}
+
 /* Close the trace */
 void TauTraceClose(int tid) {
   TauTraceEventSimple (TAU_EV_CLOSE, 0, tid);
@@ -427,16 +471,21 @@ int TauTraceDumpEDF(int tid) {
   // id group tag "name type" parameters
   
   numEvents = TheFunctionDB().size() + TheEventDB().size();
-  
+#ifdef TAU_GPU 
+  numExtra = 13; // Added four ONESIDED msg events
+#else
   numExtra = 9; // Number of extra events
+#endif	
   numEvents += numExtra;
   
-  fprintf(fp,"%d dynamic_trace_events\n", numEvents);
+  fprintf(fp,"%d dynamic_trace_events\n", numEvents+1);
   
   fprintf(fp,"# FunctionId Group Tag \"Name Type\" Parameters\n");
+
+  fprintf(fp,"0 TAUEVENT 0 \".TAU <unknown event>\" TriggerValue\n");
   
   for (it = TheFunctionDB().begin(); it != TheFunctionDB().end(); it++) {
-    fprintf(fp, "%ld %s 0 \"%s %s\" EntryExit\n", (*it)->GetFunctionId(),
+    fprintf(fp, "%ld %s 0 \"%s %s\" EntryExit\n", (long)((*it)->GetFunctionId()),
 	    (*it)->GetPrimaryGroup(), (*it)->GetName(), (*it)->GetType() );
   }
   
@@ -446,19 +495,30 @@ int TauTraceDumpEDF(int tid) {
     if ((*uit)->GetMonotonicallyIncreasing()) { 
       monoInc = 1;
     }
-    fprintf(fp, "%ld TAUEVENT %d \"%s\" TriggerValue\n", (*uit)->GetEventId(), monoInc, (*uit)->GetEventName());
+    fprintf(fp, "%ld TAUEVENT %d \"%s\" TriggerValue\n", (long)((*uit)->GetEventId()), monoInc, (*uit)->GetEventName());
   }
 
   // Now add the nine extra events 
   fprintf(fp,"%ld TRACER 0 \"EV_INIT\" none\n", (long) TAU_EV_INIT); 
-  fprintf(fp,"%ld TRACER 0 \"FLUSH_ENTER\" none\n", (long) TAU_EV_FLUSH_ENTER); 
-  fprintf(fp,"%ld TRACER 0 \"FLUSH_EXIT\" none\n", (long) TAU_EV_FLUSH_EXIT); 
+  fprintf(fp,"%ld TRACER 0 \"FLUSH\" EntryExit\n", (long) TAU_EV_FLUSH); 
+//  fprintf(fp,"%ld TRACER 0 \"FLUSH_EXIT\" none\n", (long) TAU_EV_FLUSH_EXIT); 
   fprintf(fp,"%ld TRACER 0 \"FLUSH_CLOSE\" none\n", (long) TAU_EV_CLOSE); 
   fprintf(fp,"%ld TRACER 0 \"FLUSH_INITM\" none\n", (long) TAU_EV_INITM); 
   fprintf(fp,"%ld TRACER 0 \"WALL_CLOCK\" none\n", (long) TAU_EV_WALL_CLOCK); 
   fprintf(fp,"%ld TRACER 0 \"CONT_EVENT\" none\n", (long) TAU_EV_CONT_EVENT); 
   fprintf(fp,"%ld TAU_MESSAGE -7 \"MESSAGE_SEND\" par\n", (long) TAU_MESSAGE_SEND); 
   fprintf(fp,"%ld TAU_MESSAGE -8 \"MESSAGE_RECV\" par\n", (long) TAU_MESSAGE_RECV); 
+
+#ifdef TAU_GPU
+  fprintf(fp,"%ld TAUEVENT 0 \"ONESIDED_MESSAGE_SEND\" TriggerValue\n", (long)
+	TAU_ONESIDED_MESSAGE_SEND); 
+  fprintf(fp,"%ld TAUEVENT 0 \"ONESIDED_MESSAGE_RECV\" TriggerValue\n", (long)
+	TAU_ONESIDED_MESSAGE_RECV); 
+  fprintf(fp,"%ld TAUEVENT 0 \"ONESIDED_MESSAGE_ID_TriggerValueT1\" TriggerValue\n", (long)
+	TAU_ONESIDED_MESSAGE_ID_1); 
+  fprintf(fp,"%ld TAUEVENT 0 \"ONESIDED_MESSAGE_ID_TriggerValueT2\" TriggerValue\n", (long)
+	TAU_ONESIDED_MESSAGE_ID_2); 
+#endif
   
   fclose(fp);
   RtsLayer::UnLockDB();
@@ -535,11 +595,25 @@ int TauTraceMergeAndConvertTracesIfNecessary(void) {
   return 0;
 }
 
+#ifdef TAU_GPU
+
+void TauTraceOneSidedMsg(bool type, gpuId *gpu, int length, int threadId)
+{
+		/* there are three user events that make up a one-sided msg */
+		if (type == MESSAGE_SEND)
+    	TauTraceEventSimple(TAU_ONESIDED_MESSAGE_SEND, length, threadId); 
+		else
+    	TauTraceEventSimple(TAU_ONESIDED_MESSAGE_RECV, length, threadId); 
+    TauTraceEventSimple(TAU_ONESIDED_MESSAGE_ID_1, gpu->id_p1(), threadId); 
+    TauTraceEventSimple(TAU_ONESIDED_MESSAGE_ID_2, gpu->id_p2(), threadId); 
+}
+
+#endif
 
 //////////////////////////////////////////////////////////////////////
 // TraceSendMsg traces the message send
 //////////////////////////////////////////////////////////////////////
-void TauTraceSendMsg(int type, int destination, int length) {
+void TauTraceSendMsgOld(int type, int destination, int length) {
   x_int64 parameter;
   x_uint64 xother, xtype, xlength, xcomm;
 
@@ -592,7 +666,7 @@ void TauTraceSendMsg(int type, int destination, int length) {
 //////////////////////////////////////////////////////////////////////
 // TraceRecvMsg traces the message recv
 //////////////////////////////////////////////////////////////////////
-void TauTraceRecvMsg(int type, int source, int length) {
+extern "C" void TauTraceMsg(int send_or_recv, int type, int other_id, int length, x_uint64 ts, int use_ts, int node_id) {
   x_int64 parameter;
   x_uint64 xother, xtype, xlength, xcomm;
 
@@ -601,11 +675,34 @@ void TauTraceRecvMsg(int type, int source, int length) {
     /* for recv, othernode is sender or source*/
     xtype = type;
     xlength = length;
-    xother = source;
+    xother = other_id;
     xcomm = 0;
 
-    // see TraceSendMsg for documentation
 
+    /* Format for parameter is
+       63 ..... 56 55 ..... 48 47............. 32
+          other       type          length
+
+       These are the high order bits, below are the low order bits
+
+       31 ..... 24 23 ..... 16 15..............0
+          other       type          length       
+
+       e.g.
+
+       xtype = 0xAABB;
+       xother = 0xCCDD;
+       xlength = 0xDEADBEEF;
+       result = 0xccaaDEADdddbbBEEF
+
+     parameter = ((xlength >> 16) << 32) | 
+       ((xtype >> 8 & 0xFF) << 48) |
+       ((xother >> 8 & 0xFF) << 56) |
+       (xlength & 0xFFFF) | 
+       ((xtype & 0xFF)  << 16) | 
+       ((xother & 0xFF) << 24);
+
+     */
     parameter = (xlength >> 16 << 54 >> 22) |
       ((xtype >> 8 & 0xFF) << 48) |
       ((xother >> 8 & 0xFF) << 56) |
@@ -614,7 +711,40 @@ void TauTraceRecvMsg(int type, int source, int length) {
       ((xother & 0xFF) << 24) |
       (xcomm << 58 >> 16);
 
-    TauTraceEventSimple(TAU_MESSAGE_RECV, parameter, RtsLayer::myThread()); 
+    TauTraceEventWithNodeId(send_or_recv, parameter, RtsLayer::myThread(), ts, use_ts, node_id); 
   }
 }
 
+//////////////////////////////////////////////////////////////////////
+// TauTraceRecvMsg traces the message recv
+//////////////////////////////////////////////////////////////////////
+void TauTraceRecvMsg(int type, int source, int length) {
+  TauTraceMsg(TAU_MESSAGE_RECV, type, source, length, 0, 0, RtsLayer::myNode()); 
+  /* 0, 0 is for ts and use_ts so TAU generates the timestamp */
+}
+
+//////////////////////////////////////////////////////////////////////
+// TraceSendMsg traces the message send
+//////////////////////////////////////////////////////////////////////
+void TauTraceSendMsg(int type, int destination, int length) {
+  TauTraceMsg(TAU_MESSAGE_SEND, type, destination, length, 0, 0, RtsLayer::myNode()); 
+  /* 0, 0 is for ts and use_ts so TAU generates the timestamp */
+}
+
+
+//////////////////////////////////////////////////////////////////////
+// TauTraceRecvMsgRemote traces the message recv for a remote RMA operation
+//////////////////////////////////////////////////////////////////////
+void TauTraceRecvMsgRemote(int type, int source, int length, int remote_id) {
+  TauTraceMsg(TAU_MESSAGE_RECV, type, source, length, 0, 0, remote_id); 
+  /* 0, 0 is for ts and use_ts so TAU generates the timestamp */
+}
+
+//////////////////////////////////////////////////////////////////////
+// TraceSendMsgRemote traces the message send for a remote RMA operation
+//////////////////////////////////////////////////////////////////////
+void TauTraceSendMsgRemote(int type, int destination, int length, int remote_id) {
+  TauTraceMsg(TAU_MESSAGE_SEND, type, destination, length, 0, 0, remote_id);
+  /* 0, 0 is for ts and use_ts so TAU generates the timestamp */
+}
+
