@@ -24,6 +24,10 @@
 // Include Files 
 //////////////////////////////////////////////////////////////////////
 
+#ifdef TAU_CRAYXMT
+#pragma mta instantiate used
+#endif /* TAU_CRAYXMT */
+
 //#define DEBUG_PROF
 
 #include "Profile/Profiler.h"
@@ -50,8 +54,12 @@ using namespace std;
 #include "elg_trc.h"
 #endif /* TAU_EPILOG */
 
-#include <Profile/TauTrace.h>
+#ifdef TAU_SCOREP
+#include <scorep/SCOREP_Tau.h>
+#endif
 
+#include <TauTrace.h>
+#include <TauInit.h>
 
 
 #ifdef PGI
@@ -62,8 +70,24 @@ template TauUserEvent** uninitialized_copy(TauUserEvent**,TauUserEvent**,TauUser
 
 
 
+class AtomicEventDB : public vector<TauUserEvent*> {
+public :
+  ~AtomicEventDB() {
+    Tau_destructor_trigger();
+  }
+};
+
+
 vector<TauUserEvent*>& TheEventDB(void) {
-  static vector<TauUserEvent*> EventDB;
+  static AtomicEventDB EventDB;
+
+  static int flag = 1;
+  if (flag) {
+    flag = 0;
+    Tau_init_initializeTAU();
+
+  }
+
   return EventDB;
 }
 
@@ -76,25 +100,42 @@ void TauUserEvent::AddEventToDB() {
   /* Set user event id */
   EventId = RtsLayer::GenerateUniqueId();
 #ifdef TAU_VAMPIRTRACE
+#ifdef TAU_VAMPIRTRACE_5_12_API
+  uint32_t gid = vt_def_counter_group(VT_CURRENT_THREAD, "TAU Events");
+  EventId = vt_def_counter(VT_CURRENT_THREAD, GetEventName(), OTF_COUNTER_TYPE_ABS|OTF_COUNTER_SCOPE_NEXT, gid, "#");
+#else
   uint32_t gid = vt_def_counter_group("TAU Events");
   EventId = vt_def_counter(GetEventName(), OTF_COUNTER_TYPE_ABS|OTF_COUNTER_SCOPE_NEXT, gid, "#");
+#endif /* TAU_VAMPIRTRACE_5_12_API */
 #endif /* TAU_VAMPIRTRACE */
+
+#ifdef TAU_SCOREP
+ SCOREP_Tau_MetricHandle handle = SCOREP_TAU_INIT_METRIC_HANDLE; 
+
+SCOREP_Tau_InitMetric( &handle, GetEventName(), "units");
+EventId=handle;
+#endif
   RtsLayer::UnLockDB();
   return;
 }
 
-long TauUserEvent::GetEventId(void) {
+x_uint64 TauUserEvent::GetEventId(void) {
   return EventId;
 }
 
-extern "C" long TauUserEvent_GetEventId(TauUserEvent *evt) {
+extern "C" x_uint64 TauUserEvent_GetEventId(TauUserEvent *evt) {
   return evt->GetEventId();
 }
 
 TauUserEvent::TauUserEvent(const char * EName, bool increasing) {
   DEBUGPROFMSG("Inside ctor of TauUserEvent EName = "<< EName << endl;);
 
-  EventName 	= EName;
+  //EventName 	= EName;
+#ifdef TAU_PGI
+  EventName.assign(EName, 1024);
+#else
+  EventName = EName;
+#endif /* TAU_PGI */
   // Assign event name and then set the default values
   DisableMin 	= false; 	// Min 	    is calculated 
   DisableMax 	= false; 	// Max      is calculated 
@@ -206,16 +247,42 @@ void TauUserEvent::TriggerEvent(TAU_EVENT_DATATYPE data, int tid) {
 
 void TauUserEvent::TriggerEvent(TAU_EVENT_DATATYPE data, int tid, double timestamp, int use_ts) { 
 #ifdef TAU_VAMPIRTRACE
+  // *CWL* - x_uint64 (unsigned long long) violates the vampirtrace interface which expects
+  //         unsigned long (previously uint64_t). The change from uint64_t to x_uint64 was
+  //         previously made in response to problems with SCORE-P but was done as a global
+  //         cut-and-paste which turned out to be unsafe. Since the use of time and cval
+  //         are guarded for just vampirtrace, it should be safe to revert the changes
+  //         for just vampirtrace.
+  //
+  //         Keep an eye on this. We should expect trouble as long as we cannot provide 
+  //         a proper abstraction for what constitutes a 64-bit unsigned integer in TAU.
+  //         This should be a TODO item.
+  // x_uint64 time;
+  // x_uint64 cval;
   uint64_t time;
   uint64_t cval;
   int id = GetEventId();
   time = vt_pform_wtime();
+  // cval = (x_uint64) data;
   cval = (uint64_t) data;
+#ifdef TAU_VAMPIRTRACE_5_12_API
+  vt_count(VT_CURRENT_THREAD, &time, id, 0);
+#else
   vt_count(&time, id, 0);
+#endif /* TAU_VAMPIRTRACE_5_12_API */
   time = vt_pform_wtime();
+#ifdef TAU_VAMPIRTRACE_5_12_API
+  vt_count(VT_CURRENT_THREAD, &time, id, cval);
+#else
   vt_count(&time, id, cval);
+#endif /* TAU_VAMPIRTRACE_5_12_API */
   time = vt_pform_wtime();
+#ifdef TAU_VAMPIRTRACE_5_12_API
+  vt_count(VT_CURRENT_THREAD, &time, id, 0);
+#else
   vt_count(&time, id, 0);
+#endif /* TAU_VAMPIRTRACE_5_12_API */
+
 #else /* TAU_VAMPIRTRACE */
 #ifndef TAU_EPILOG
   if (TauEnv_get_tracing()) {
@@ -227,6 +294,12 @@ void TauUserEvent::TriggerEvent(TAU_EVENT_DATATYPE data, int tid, double timesta
   /* Timestamp is 0, and use_ts is 0, so tracing layer gets timestamp */
 #endif /* TAU_VAMPIRTRACE */
 
+#ifdef TAU_SCOREP
+ SCOREP_Tau_TriggerMetricDouble( GetEventId(), data );
+#endif /*TAU_SCOREP*/
+
+
+
 #ifdef PROFILING_ON
   // Record this value  
   LastValueRecorded[tid] = data;
@@ -476,12 +549,22 @@ struct TaultUserEventLong {
 };
 
 
+
+class ContextEventMap : public map<TAU_CONTEXT_MAP_TYPE > {
+public :
+  ~ContextEventMap() {
+    Tau_destructor_trigger();
+  }
+};
+
+
+
 /////////////////////////////////////////////////////////////////////////
 // We use one global map to store the callpath information
 /////////////////////////////////////////////////////////////////////////
-map<TAU_CONTEXT_MAP_TYPE >& TheContextMap(void) { 
+ContextEventMap& TheContextMap(void) { 
   // to avoid initialization problems of non-local static variables
-  static map<TAU_CONTEXT_MAP_TYPE > contextmap;
+  static ContextEventMap contextmap;
   return contextmap;
 }
 
@@ -504,12 +587,12 @@ long* TauFormulateContextComparisonArray(Profiler *p, TauUserEvent *uevent) {
   int index = 1; /* start writing to index 1, we fill in the depth after */
 
   while (current != NULL && depth != 0) {
-    ary[index++] = (long) current->ThisFunction;
+    ary[index++] = Tau_convert_ptr_to_long(current->ThisFunction);
     depth--;
     current = current->ParentProfiler;
   }
   
-  ary[index++] = (long) uevent;
+  ary[index++] = Tau_convert_ptr_to_long(uevent);
   ary[0] = index-1; /* set the depth */
   return ary;
 }
@@ -525,11 +608,11 @@ string * TauFormulateContextNameString(Profiler *p) {
 
   while (current != NULL && depth != 0) {
     if (current != p) {
-      *name =  current->ThisFunction->GetName() + string(" ") +
-               current->ThisFunction->GetType() + delimiter + *name;
+      *name = current->ThisFunction->GetName() + string(" ") +
+	current->ThisFunction->GetType() + delimiter + *name;
     } else {
-      *name =  current->ThisFunction->GetName() + string (" ") +
-               current->ThisFunction->GetType();
+      *name = current->ThisFunction->GetName() + string (" ") +
+	current->ThisFunction->GetType();
     }
     current = current->ParentProfiler;
     depth --;
@@ -547,11 +630,12 @@ TauContextUserEvent::TauContextUserEvent(const char *EName, bool MonoIncr) {
   uevent = new TauUserEvent(EName, MonoIncr);
   DisableContext = false; /* context tracking is enabled by default */
 
+#ifndef TAU_SCOREP 
   int depth = TauEnv_get_callpath_depth();
   if (depth == 0) {
     DisableContext = true;
   }
-
+#endif /*TAU_SCOREP*/
   MonotonicallyIncreasing = MonoIncr;
 }
 
@@ -589,6 +673,8 @@ void TauContextUserEvent::TriggerEvent( TAU_EVENT_DATATYPE data, int tid) {
 }
 
 void TauContextUserEvent::TriggerEvent( TAU_EVENT_DATATYPE data, int tid, double timestamp, int use_ts) {
+  Tau_global_incr_insideTAU();
+
   if (!DisableContext) {
     long *comparison = 0;
     TauUserEvent *ue;
@@ -606,6 +692,7 @@ void TauContextUserEvent::TriggerEvent( TAU_EVENT_DATATYPE data, int tid, double
 	string contextname(uevent->EventName  + " : " + *ctxname);
 	
 	ue = new TauUserEvent((const char *)(contextname.c_str()), MonotonicallyIncreasing);
+
 	TheContextMap().insert(map<TAU_CONTEXT_MAP_TYPE>::value_type(comparison, ue));
 	
 	ue->ctxevt = this; /* store the current object in the user event */
@@ -631,10 +718,12 @@ void TauContextUserEvent::TriggerEvent( TAU_EVENT_DATATYPE data, int tid, double
     }
   }
   uevent->TriggerEvent(data, tid, timestamp, use_ts);
+
+  Tau_global_decr_insideTAU();
 }
 
 /***************************************************************************
  * $RCSfile: UserEvent.cpp,v $   $Author: amorris $
- * $Revision: 1.42 $   $Date: 2009/09/29 00:37:03 $
- * POOMA_VERSION_ID: $Id: UserEvent.cpp,v 1.42 2009/09/29 00:37:03 amorris Exp $ 
+ * $Revision: 1.46 $   $Date: 2010/05/07 22:16:23 $
+ * POOMA_VERSION_ID: $Id: UserEvent.cpp,v 1.46 2010/05/07 22:16:23 amorris Exp $ 
  ***************************************************************************/
