@@ -19,6 +19,12 @@
 #include "TAU_tf_headers.h"
 #include <Profile/tau_types.h>
 
+extern "C" long Tau_convert_ptr_to_long_trc(void *ptr) {
+  long long a = (long long) ptr;
+  long ret = (long) a;
+  return ret;
+}
+
 
 #ifdef __cplusplus
 extern "C" {
@@ -301,7 +307,7 @@ extern "C" {
     Ttf_fileT *tFile = (Ttf_fileT*)file;
 
     if (tFile->forWriting == false) {
-      return (int)((long)Ttf_CloseFile(tFile));
+      return (int)(Tau_convert_ptr_to_long_trc(Ttf_CloseFile(tFile)));
     }
 
     for (NidTidMapT::iterator it = tFile->NidTidMap->begin(); it != tFile->NidTidMap->end(); ++it) {
@@ -478,6 +484,32 @@ extern "C" {
     return 0;
   }
 
+  /*
+	This is a helper function to write out user defined events to the trace file. 
+	Trace writer APIs can not be directly used here as we need to use the entire 
+	bytes of the parameter. 
+*/
+
+int  Ttf_LongEventTrigger(Ttf_FileHandleT file,  unsigned long long time, 
+				unsigned int nodeToken, 
+				unsigned int threadToken,  
+				unsigned int userEventToken, 
+				 unsigned long long userEventValue)
+{
+	Ttf_fileT *tFile = (Ttf_fileT*)file;
+	checkFlush(tFile);
+    	int pos = tFile->tracePosition;		
+    	tFile->traceBuffer[pos].ev = userEventToken;
+    	tFile->traceBuffer[pos].nid = nodeToken;
+    	tFile->traceBuffer[pos].tid = threadToken;
+    	tFile->traceBuffer[pos].ti = (x_uint64)time;
+    	tFile->traceBuffer[pos].par = userEventValue;
+    	tFile->tracePosition++;
+    	tFile->lastTimestamp = time;
+    	return 0;
+}
+  
+  
 
 #ifdef __cplusplus
 }
