@@ -38,8 +38,8 @@ public class TraceReader extends TraceFile{
 	long totalRead=0;
 	//int eventSize;
 	
-	HashSet nidTidSeen = new HashSet();
-	HashSet nidTidDone = new HashSet();
+	HashSet<Integer> nidTidSeen = new HashSet<Integer>();
+	HashSet<Integer> nidTidDone = new HashSet<Integer>();
 	
 	public TraceReader(String trace, String edf){
 		
@@ -77,9 +77,9 @@ public class TraceReader extends TraceFile{
 			/* Allocate space for nodeid, thread id map */
 			//tFile.NidTidMap=new HashMap();
 			/* Allocate space for event id map */
-			EventIdMap = new HashMap();
+			EventIdMap = new HashMap<Integer, EventDescr>();
 			/* Allocate space for group id map */
-			GroupIdMap = new HashMap();
+			GroupIdMap = new HashMap<String, Integer>();
 			/* initialize clock */
 			ClkInitialized = false;
 			/* initialize the first timestamp for the trace */
@@ -279,6 +279,12 @@ public class TraceReader extends TraceFile{
 		{
 			linebuf=edf.readLine();
 			
+			if(linebuf==null){
+				int c = i-1;
+				System.out.println("Warning: Expected "+numevents+" event definitions. Found "+c);
+				return false;
+			}
+			
 			if ( (linebuf.charAt(0) == '\n') || (linebuf.charAt(0) == '#') )
 			{
 				/* -- skip empty, header and comment lines -- */
@@ -329,7 +335,7 @@ public class TraceReader extends TraceFile{
 					}
 					else
 					{ /* retrieve the stored group id token */
-						groupid = ((Integer)GroupIdMap.get(eventDescr.getGroup())).intValue();
+						groupid = GroupIdMap.get(eventDescr.getGroup()).intValue();
 					}
 					/* invoke callback for registering a new state */
 					if (eventDescr.getParameter().equals("TriggerValue"))//||eventDescr.Param.equals("none")
@@ -535,7 +541,7 @@ public class TraceReader extends TraceFile{
 			//parameter = traceBuffer[i].getParameter();//event_GetPar(traceBuffer, i);
 			/* Get param entry from EventIdMap */
 			
-			EventDescr eventDescr = (EventDescr)EventIdMap.get(new Integer(evt.evid));
+			EventDescr eventDescr = EventIdMap.get(new Integer(evt.evid));
 			if(eventDescr==null){
 				System.out.println("Warning: no event definiton for event ID "+evt.evid);
 				continue;
