@@ -1,13 +1,20 @@
 package edu.uoregon.tau.paraprof;
 
-import java.util.*;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.Comparator;
+import java.util.Iterator;
+import java.util.List;
 
-import edu.uoregon.tau.common.AlphanumComparator;
 import edu.uoregon.tau.paraprof.enums.SortType;
 import edu.uoregon.tau.paraprof.enums.UserEventValueType;
 import edu.uoregon.tau.paraprof.enums.ValueType;
-import edu.uoregon.tau.perfdmf.*;
+import edu.uoregon.tau.perfdmf.Function;
+import edu.uoregon.tau.perfdmf.FunctionProfile;
+import edu.uoregon.tau.perfdmf.Metric;
 import edu.uoregon.tau.perfdmf.Thread;
+import edu.uoregon.tau.perfdmf.UserEvent;
+import edu.uoregon.tau.perfdmf.UserEventProfile;
 
 /**
  * DataSorter.java
@@ -19,7 +26,7 @@ import edu.uoregon.tau.perfdmf.Thread;
  * @author	Alan Morris, Robert Bell
  * @version	$Revision: 1.18 $
  */
-public class DataSorter implements Comparator {
+public class DataSorter implements Comparator<FunctionProfile> {
 
     private ParaProfTrial ppTrial = null;
 
@@ -66,14 +73,14 @@ public class DataSorter implements Comparator {
         return selectedMetric.getDerivedMetric();
     }
 
-    public List getUserEventProfiles(Thread thread) {
+    public List<PPUserEventProfile> getUserEventProfiles(Thread thread) {
 
         UserEventProfile userEventProfile = null;
 
-        List newList = new ArrayList();
+        List<PPUserEventProfile> newList = new ArrayList<PPUserEventProfile>();
 
-        for (Iterator e1 = thread.getUserEventProfiles(); e1.hasNext();) {
-            userEventProfile = (UserEventProfile) e1.next();
+        for (Iterator<UserEventProfile> e1 = thread.getUserEventProfiles(); e1.hasNext();) {
+            userEventProfile = e1.next();
             if (userEventProfile != null) {
                 PPUserEventProfile ppUserEventProfile = new PPUserEventProfile(this, thread, userEventProfile);
                 newList.add(ppUserEventProfile);
@@ -83,14 +90,14 @@ public class DataSorter implements Comparator {
         return newList;
     }
 
-    private List createFunctionProfileList(Thread thread, boolean callpath) {
-        List newList = null;
+    private List<PPFunctionProfile> createFunctionProfileList(Thread thread, boolean callpath) {
+        List<PPFunctionProfile> newList = null;
 
-        List functionList = thread.getFunctionProfiles();
-        newList = new ArrayList();
+        List<FunctionProfile> functionList = thread.getFunctionProfiles();
+        newList = new ArrayList<PPFunctionProfile>();
 
         for (int i = 0; i < functionList.size(); i++) {
-            FunctionProfile functionProfile = (FunctionProfile) functionList.get(i);
+            FunctionProfile functionProfile = functionList.get(i);
             if (functionProfile != null) {
                 if (callpath) {
                     if (functionProfile.getFunction().isPhaseMember(phase)) {
@@ -110,23 +117,23 @@ public class DataSorter implements Comparator {
         return newList;
     }
 
-    public List getCallPathFunctionProfiles(Thread thread) {
+    public List<PPFunctionProfile> getCallPathFunctionProfiles(Thread thread) {
         return createFunctionProfileList(thread, true);
     }
 
-    public List getFunctionProfiles(Thread thread) {
+    public List<PPFunctionProfile> getFunctionProfiles(Thread thread) {
         return createFunctionProfileList(thread, false);
     }
 
-    public List getBasicFunctionProfiles(Thread thread) {
+    public List<FunctionProfile> getBasicFunctionProfiles(Thread thread) {
 
-        List newList = null;
+        List<FunctionProfile> newList = null;
 
-        List functionList = thread.getFunctionProfiles();
-        newList = new ArrayList();
+        List<FunctionProfile> functionList = thread.getFunctionProfiles();
+        newList = new ArrayList<FunctionProfile>();
 
         for (int i = 0; i < functionList.size(); i++) {
-            FunctionProfile functionProfile = (FunctionProfile) functionList.get(i);
+            FunctionProfile functionProfile = functionList.get(i);
             if (functionProfile != null && ppTrial.displayFunction(functionProfile.getFunction())) {
                 newList.add(functionProfile);
             }
@@ -135,10 +142,10 @@ public class DataSorter implements Comparator {
         return newList;
     }
 
-    public List getAllFunctionProfiles() {
+    public List<PPThread> getAllFunctionProfiles() {
         long time = System.currentTimeMillis();
 
-        List threads = new ArrayList();
+        List<PPThread> threads = new ArrayList<PPThread>();
         Thread thread;
         PPThread ppThread;
 
@@ -148,8 +155,8 @@ public class DataSorter implements Comparator {
         if (ppTrial.getDataSource().getAllThreads().size() > 1) {
             thread = ppTrial.getDataSource().getStdDevData();
             ppThread = new PPThread(thread, this.ppTrial);
-            for (Iterator it = thread.getFunctionProfiles().iterator(); it.hasNext();) {
-                FunctionProfile functionProfile = (FunctionProfile) it.next();
+            for (Iterator<FunctionProfile> it = thread.getFunctionProfiles().iterator(); it.hasNext();) {
+                FunctionProfile functionProfile = it.next();
                 if (functionProfile != null && ppTrial.displayFunction(functionProfile.getFunction())
                         && functionProfile.getFunction().isPhaseMember(phase)) {
                     PPFunctionProfile ppFunctionProfile = new PPFunctionProfile(this, thread, functionProfile);
@@ -161,8 +168,8 @@ public class DataSorter implements Comparator {
 
             thread = ppTrial.getDataSource().getMeanData();
             ppThread = new PPThread(thread, this.ppTrial);
-            for (Iterator it = thread.getFunctionProfiles().iterator(); it.hasNext();) {
-                FunctionProfile functionProfile = (FunctionProfile) it.next();
+            for (Iterator<FunctionProfile> it = thread.getFunctionProfiles().iterator(); it.hasNext();) {
+                FunctionProfile functionProfile = it.next();
                 if (functionProfile != null && ppTrial.displayFunction(functionProfile.getFunction())
                         && functionProfile.getFunction().isPhaseMember(phase)) {
                     PPFunctionProfile ppFunctionProfile = new PPFunctionProfile(this, thread, functionProfile);
@@ -189,12 +196,12 @@ public class DataSorter implements Comparator {
 
         }
 
-        for (Iterator it = ppTrial.getDataSource().getAllThreads().iterator(); it.hasNext();) {
-            thread = (Thread) it.next();
+        for (Iterator<Thread> it = ppTrial.getDataSource().getAllThreads().iterator(); it.hasNext();) {
+            thread = it.next();
 
             ppThread = new PPThread(thread, this.ppTrial);
-            for (Iterator it2 = order.getFunctionListIterator(); it2.hasNext();) {
-                PPFunctionProfile orderfp = (PPFunctionProfile) it2.next();
+            for (Iterator<PPFunctionProfile> it2 = order.getFunctionListIterator(); it2.hasNext();) {
+                PPFunctionProfile orderfp = it2.next();
 
                 FunctionProfile fp = thread.getFunctionProfile(orderfp.getFunction());
 
@@ -249,12 +256,12 @@ public class DataSorter implements Comparator {
         return threads;
     }
 
-    private void addThread(List threads, List order, Thread thread) {
+    private void addThread(List<List<FunctionProfile>> threads, List<FunctionProfile> order, Thread thread) {
 
-        List list = new ArrayList();
+        List<FunctionProfile> list = new ArrayList<FunctionProfile>();
 
         for (int i = 0, n = order.size(); i < n; i++) {
-            FunctionProfile orderfp = (FunctionProfile) order.get(i);
+            FunctionProfile orderfp = order.get(i);
 
             FunctionProfile fp = thread.getFunctionProfile(orderfp.getFunction());
 
@@ -273,19 +280,19 @@ public class DataSorter implements Comparator {
      *
      * @return a list of lists of FunctionProfiles
      */
-    public List getAllFunctionProfilesMinimal() {
+    public List<List<FunctionProfile>> getAllFunctionProfilesMinimal() {
         long time = System.currentTimeMillis();
 
         // a list of lists of FunctionProfiles
-        List threads = new ArrayList();
+        List<List<FunctionProfile>> threads = new ArrayList<List<FunctionProfile>>();
 
         // a list of FunctionProfiles that represents the ordering
-        List order = new ArrayList();
+        List<FunctionProfile> order = new ArrayList<FunctionProfile>();
 
-        List meanProfiles = ppTrial.getDataSource().getMeanData().getFunctionProfiles();
+        List<FunctionProfile> meanProfiles = ppTrial.getDataSource().getMeanData().getFunctionProfiles();
 
         for (int i = 0, n = meanProfiles.size(); i < n; i++) {
-            FunctionProfile functionProfile = (FunctionProfile) meanProfiles.get(i);
+            FunctionProfile functionProfile = meanProfiles.get(i);
             if (functionProfile != null && ppTrial.displayFunction(functionProfile.getFunction())
                     && functionProfile.getFunction().isPhaseMember(phase)) {
                 order.add(functionProfile);
@@ -305,8 +312,8 @@ public class DataSorter implements Comparator {
         threads.add(order);
 
         // add all the other threads
-        for (Iterator it = ppTrial.getDataSource().getAllThreads().iterator(); it.hasNext();) {
-            Thread thread = (Thread) it.next();
+        for (Iterator<Thread> it = ppTrial.getDataSource().getAllThreads().iterator(); it.hasNext();) {
+            Thread thread = it.next();
             addThread(threads, order, thread);
         }
 
@@ -319,12 +326,12 @@ public class DataSorter implements Comparator {
     public FunctionOrdering getOrdering() {
         long time = System.currentTimeMillis();
 
-        List order = new ArrayList();
+        List<FunctionProfile> order = new ArrayList<FunctionProfile>();
 
-        List meanProfiles = ppTrial.getDataSource().getMeanData().getFunctionProfiles();
+        List<FunctionProfile> meanProfiles = ppTrial.getDataSource().getMeanData().getFunctionProfiles();
 
         for (int i = 0, n = meanProfiles.size(); i < n; i++) {
-            FunctionProfile functionProfile = (FunctionProfile) meanProfiles.get(i);
+            FunctionProfile functionProfile = meanProfiles.get(i);
             if (functionProfile != null && ppTrial.displayFunction(functionProfile.getFunction())
                     && functionProfile.getFunction().isPhaseMember(phase)) {
                 order.add(functionProfile);
@@ -335,7 +342,7 @@ public class DataSorter implements Comparator {
 
         Function functions[] = new Function[order.size()];
         for (int i = 0, n = order.size(); i < n; i++) {
-            functions[i] = ((FunctionProfile) order.get(i)).getFunction();
+            functions[i] = order.get(i).getFunction();
         }
 
         FunctionOrdering fo = new FunctionOrdering(this);
@@ -347,24 +354,84 @@ public class DataSorter implements Comparator {
         return fo;
     }
 
-    public List getThreads() {
-        ArrayList threads = new ArrayList();
+    
+    boolean filterThread(Thread thread,int[] exList){
+    	if(thread==null)
+    		return false;
+    	if(exList==null)
+    		return true;
+
+    	for(int i=0;i<exList.length;i++){
+    		if(thread.getThreadID()==exList[i])
+    			return false;
+    	}
+    	return true;
+    }
+    
+    public List<Thread> getThreads(int[] exclude){
+        ArrayList<Thread> threads = new ArrayList<Thread>();
+        Thread thread=null;
         if (ppTrial.getDataSource().getAllThreads().size() > 1) {
-            threads.add(ppTrial.getDataSource().getStdDevData());
-            //threads.add(ppTrial.getDataSource().getTotalData());
-            threads.add(ppTrial.getDataSource().getMeanData());
+        	thread=ppTrial.getDataSource().getStdDevData();
+        	if(filterThread(thread,exclude)){
+        		threads.add(thread);
+        	}
+            //threads.add(ppTrial.getDataSource().getStdDevData());
+            
+            thread=ppTrial.getDataSource().getMeanData();
+        	if(filterThread(thread,exclude)){
+        		threads.add(thread);
+        	}
+            thread=ppTrial.getDataSource().getTotalData();
+        	if(filterThread(thread,exclude)){
+        		threads.add(thread);
+        	}
+            
+            thread=ppTrial.getDataSource().getMaxData();
+            if(filterThread(thread,exclude))
+            	threads.add(thread);
+            thread=ppTrial.getDataSource().getMinData();
+            if(filterThread(thread,exclude))
+            	threads.add(thread);
+            
         }
 
         // add all the other threads
-        for (Iterator it = ppTrial.getDataSource().getAllThreads().iterator(); it.hasNext();) {
-            Thread thread = (Thread) it.next();
-            threads.add(thread);
+        for (Iterator<Thread> it = ppTrial.getDataSource().getAllThreads().iterator(); it.hasNext();) {
+            thread = it.next();
+            if(filterThread(thread,exclude))
+            	threads.add(thread);
         }
         return threads;
     }
+    
+    public List<Thread> getThreads() {
+//        ArrayList<Thread> threads = new ArrayList<Thread>();
+//        if (ppTrial.getDataSource().getAllThreads().size() > 1) {
+//            threads.add(ppTrial.getDataSource().getStdDevData());
+//            
+//            threads.add(ppTrial.getDataSource().getMeanData());
+//            threads.add(ppTrial.getDataSource().getTotalData());
+//            
+//            Thread maxData=ppTrial.getDataSource().getMaxData();
+//            if(maxData!=null)
+//            	threads.add(maxData);
+//            Thread minData=ppTrial.getDataSource().getMinData();
+//            if(minData!=null)
+//            	threads.add(minData);
+//            
+//        }
+//
+//        // add all the other threads
+//        for (Iterator<Thread> it = ppTrial.getDataSource().getAllThreads().iterator(); it.hasNext();) {
+//            Thread thread = it.next();
+//            threads.add(thread);
+//        }
+        return getThreads(null);
+    }
 
-    public List getFunctionData(Function function, boolean includeMean, boolean includeStdDev) {
-        List newList = new ArrayList();
+    public List<PPFunctionProfile> getFunctionData(Function function, boolean includeMean, boolean includeStdDev) {
+        List<PPFunctionProfile> newList = new ArrayList<PPFunctionProfile>();
 
         Thread thread;
 
@@ -377,6 +444,26 @@ public class DataSorter implements Comparator {
                     PPFunctionProfile ppFunctionProfile = new PPFunctionProfile(this, thread, functionProfile);
                     newList.add(ppFunctionProfile);
                 }
+                
+                
+                thread=ppTrial.getDataSource().getMinData();
+                
+                if(thread!=null){
+                
+                functionProfile = thread.getFunctionProfile(function);
+                
+                	PPFunctionProfile ppFunctionProfile = new PPFunctionProfile(this, thread, functionProfile);
+                    newList.add(ppFunctionProfile);
+                }
+                
+                thread=ppTrial.getDataSource().getMaxData();
+                if(thread!=null){
+                	
+                    functionProfile = thread.getFunctionProfile(function);
+                	PPFunctionProfile ppFunctionProfile = new PPFunctionProfile(this, thread, functionProfile);
+                    newList.add(ppFunctionProfile);
+                }
+                
             }
 
             if (includeStdDev) {
@@ -398,8 +485,8 @@ public class DataSorter implements Comparator {
 
             }
         }
-        for (Iterator it = ppTrial.getDataSource().getAllThreads().iterator(); it.hasNext();) {
-            thread = (Thread) it.next();
+        for (Iterator<Thread> it = ppTrial.getDataSource().getAllThreads().iterator(); it.hasNext();) {
+            thread = it.next();
             FunctionProfile functionProfile = thread.getFunctionProfile(function);
             if (functionProfile != null) {
                 //Create a new thread data object.
@@ -412,16 +499,16 @@ public class DataSorter implements Comparator {
         return newList;
     }
 
-    public List getFunctionAcrossPhases(Function function, Thread thread) {
-        List newList = new ArrayList();
+    public List<PPFunctionProfile> getFunctionAcrossPhases(Function function, Thread thread) {
+        List<PPFunctionProfile> newList = new ArrayList<PPFunctionProfile>();
 
         String functionName = function.getName();
         if (function.isCallPathFunction()) {
             functionName = functionName.substring(functionName.indexOf("=>") + 2).trim();
         }
 
-        for (Iterator it = thread.getFunctionProfileIterator(); it.hasNext();) {
-            FunctionProfile functionProfile = (FunctionProfile) it.next();
+        for (Iterator<FunctionProfile> it = thread.getFunctionProfileIterator(); it.hasNext();) {
+            FunctionProfile functionProfile = it.next();
             if (functionProfile != null) {
 
                 if (functionProfile.isCallPathFunction()) {
@@ -438,8 +525,8 @@ public class DataSorter implements Comparator {
         return newList;
     }
 
-    public List getUserEventData(UserEvent userEvent) {
-        List newList = new ArrayList();
+    public List<PPUserEventProfile> getUserEventData(UserEvent userEvent) {
+        List<PPUserEventProfile> newList = new ArrayList<PPUserEventProfile>();
 
         UserEventProfile userEventProfile;
 
@@ -459,8 +546,8 @@ public class DataSorter implements Comparator {
             newList.add(ppUserEventProfile);
         }
 
-        for (Iterator it = ppTrial.getDataSource().getAllThreads().iterator(); it.hasNext();) {
-            thread = (Thread) it.next();
+        for (Iterator<Thread> it = ppTrial.getDataSource().getAllThreads().iterator(); it.hasNext();) {
+            thread = it.next();
 
             userEventProfile = thread.getUserEventProfile(userEvent);
             if (userEventProfile != null) {
@@ -476,7 +563,7 @@ public class DataSorter implements Comparator {
     // Comparison stuff
     //////////////////////////////////////////////////////////////////////////
 
-    public int compare(Object arg0, Object arg1) {
+    public int compare(FunctionProfile arg0, FunctionProfile arg1) {
         FunctionProfile left = (FunctionProfile) arg0;
         FunctionProfile right = (FunctionProfile) arg1;
         if (descendingOrder) {
