@@ -1,12 +1,25 @@
 package edu.uoregon.tau.paraprof;
 
-import java.awt.*;
+import java.awt.Component;
+import java.awt.Dimension;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
+import java.awt.Rectangle;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.util.Observable;
 import java.util.Observer;
 
-import javax.swing.*;
+import javax.swing.JCheckBoxMenuItem;
+import javax.swing.JFrame;
+import javax.swing.JLabel;
+import javax.swing.JMenu;
+import javax.swing.JMenuBar;
+import javax.swing.JMenuItem;
+import javax.swing.JSeparator;
+import javax.swing.JSlider;
+import javax.swing.JTextArea;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 import javax.swing.event.MenuEvent;
@@ -16,7 +29,6 @@ import edu.uoregon.tau.paraprof.barchart.AbstractBarChartModel;
 import edu.uoregon.tau.paraprof.barchart.BarChartPanel;
 import edu.uoregon.tau.paraprof.barchart.GlobalBarChartModel;
 import edu.uoregon.tau.paraprof.enums.SortType;
-import edu.uoregon.tau.paraprof.enums.ValueType;
 import edu.uoregon.tau.paraprof.interfaces.ParaProfWindow;
 import edu.uoregon.tau.paraprof.interfaces.SortListener;
 import edu.uoregon.tau.perfdmf.Function;
@@ -31,7 +43,11 @@ import edu.uoregon.tau.perfdmf.Function;
  */
 public class GlobalDataWindow extends JFrame implements ActionListener, Observer, ChangeListener, ParaProfWindow, SortListener {
 
-    private ParaProfTrial ppTrial;
+    /**
+	 * 
+	 */
+	private static final long serialVersionUID = 5507720641033902693L;
+	private ParaProfTrial ppTrial;
     private Function phase; // null for non-phase profiles
 
     private BarChartPanel panel;
@@ -42,6 +58,7 @@ public class GlobalDataWindow extends JFrame implements ActionListener, Observer
     private JMenu optionsMenu;
     private JCheckBoxMenuItem nameCheckBox = new JCheckBoxMenuItem("Sort By Name", false);
     private JCheckBoxMenuItem normalizeCheckBox = new JCheckBoxMenuItem("Normalize Bars", true);
+    private JCheckBoxMenuItem hideTotalCheckBox = new JCheckBoxMenuItem("Hide Total", true);
     private JCheckBoxMenuItem orderByMeanCheckBox = new JCheckBoxMenuItem("Order By Mean", true);
     private JCheckBoxMenuItem orderCheckBox = new JCheckBoxMenuItem("Descending Order", true);
     private JCheckBoxMenuItem stackBarsCheckBox = new JCheckBoxMenuItem("Stack Bars Together", true);
@@ -155,6 +172,9 @@ public class GlobalDataWindow extends JFrame implements ActionListener, Observer
 
         normalizeCheckBox.addActionListener(this);
         optionsMenu.add(normalizeCheckBox);
+        
+        hideTotalCheckBox.addActionListener(this);
+        optionsMenu.add(hideTotalCheckBox);
 
         //        orderByMeanCheckBox.addActionListener(this);
         //        optionsMenu.add(orderByMeanCheckBox);
@@ -201,6 +221,8 @@ public class GlobalDataWindow extends JFrame implements ActionListener, Observer
                     showWidthSlider(slidersCheckBox.isSelected());
                 } else if (arg.equals("Show Meta Data in Panel")) {
                     setShowMetaData(metaDataCheckBox.isSelected());
+                }else if (arg.equals("Hide Total")) {
+                    setHideTotal(hideTotalCheckBox.isSelected());
                 }
             }
         } catch (Exception e) {
@@ -290,8 +312,18 @@ public class GlobalDataWindow extends JFrame implements ActionListener, Observer
             return "Phase: " + phase + "\nMetric: " + ppTrial.getDefaultMetric().getName() + "\nValue: "
                     + "Exclusive" + "\n";
         } else {
-            return "Metric: " + dataSorter.getSelectedMetric().getName() + "\nValue: "
+            String header = "Metric: " + dataSorter.getSelectedMetric().getName() + "\nValue: "
                     + dataSorter.getValueType() + "\n";
+            	if(dataSorter.getSortType()==SortType.NAME){
+            		header+="Sorted By: Name";
+            	}
+            	else if(!dataSorter.getSortByVisible()){
+            		header+="Sorted By: "+dataSorter.getSortValueType().toString();
+            		if(dataSorter.getSortMetric()!=dataSorter.getSelectedMetric()){
+            			header+=" ("+dataSorter.getSortMetric()+")";
+            		}
+            	}
+            	return header;
         }
     }
 
@@ -426,6 +458,13 @@ public class GlobalDataWindow extends JFrame implements ActionListener, Observer
         panel.getBarChart().setNormalized(normalizeCheckBox.isSelected());
         panel.repaint();
     }
+    
+    public void setHideTotal(boolean value) {
+        hideTotalCheckBox.setSelected(value);
+        ((GlobalBarChartModel)model).setHideTotal(hideTotalCheckBox.isSelected());
+        model.reloadData();
+        //panel.repaint();
+    }
 
     public boolean getSortByMean() {
         return orderByMeanCheckBox.isSelected();
