@@ -1,6 +1,14 @@
 package edu.uoregon.tau.paraprof;
 
-import java.awt.*;
+import java.awt.Color;
+import java.awt.Component;
+import java.awt.Container;
+import java.awt.Dimension;
+import java.awt.Graphics;
+import java.awt.Graphics2D;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.print.PageFormat;
@@ -10,8 +18,17 @@ import java.util.List;
 import java.util.Observable;
 import java.util.Observer;
 
-import javax.swing.*;
-import javax.swing.event.*;
+import javax.swing.JCheckBoxMenuItem;
+import javax.swing.JFrame;
+import javax.swing.JLabel;
+import javax.swing.JMenu;
+import javax.swing.JMenuBar;
+import javax.swing.JMenuItem;
+import javax.swing.JSlider;
+import javax.swing.event.ChangeEvent;
+import javax.swing.event.ChangeListener;
+import javax.swing.event.MenuEvent;
+import javax.swing.event.MenuListener;
 
 import org.jfree.chart.ChartFactory;
 import org.jfree.chart.ChartPanel;
@@ -45,7 +62,11 @@ import edu.uoregon.tau.perfdmf.UtilFncs;
 public class HistogramWindow extends JFrame implements ActionListener, MenuListener, Observer, ChangeListener, ParaProfWindow,
         UnitListener, Printable, ImageExport {
 
-    private ParaProfTrial ppTrial;
+    /**
+	 * 
+	 */
+	private static final long serialVersionUID = 7469676193580067451L;
+	private ParaProfTrial ppTrial;
     private DataSorter dataSorter;
     private Function function;
 
@@ -54,7 +75,7 @@ public class HistogramWindow extends JFrame implements ActionListener, MenuListe
     // hold on to these two for 'menuSelected'
     private JMenu unitsSubMenu = null;
 
-    private List data = null;
+    private List<PPFunctionProfile> data = null;
 
     private int units = ParaProf.preferences.getUnits();
 
@@ -118,7 +139,7 @@ public class HistogramWindow extends JFrame implements ActionListener, MenuListe
 
     private void setupMenus() {
         JMenuBar mainMenu = new JMenuBar();
-        JMenu subMenu = null;
+        JMenu subMenu = ParaProfUtils.createMetricSelectionMenu(ppTrial, "Select Metric...", false, false, dataSorter, null,this, true);//null;
 
         // options menu
         JMenu optionsMenu = new JMenu("Options");
@@ -126,14 +147,15 @@ public class HistogramWindow extends JFrame implements ActionListener, MenuListe
         slidersCheckBox = new JCheckBoxMenuItem("Show Number of Bins Slider", false);
         slidersCheckBox.addActionListener(this);
         optionsMenu.add(slidersCheckBox);
-
-        ButtonGroup group = null;
-        JRadioButtonMenuItem button = null;
+        
+        
 
         // units submenu
         unitsSubMenu = ParaProfUtils.createUnitsMenu(this, units, true);
         optionsMenu.add(unitsSubMenu);
-
+/*
+  		ButtonGroup group = null;
+        JRadioButtonMenuItem button = null;
         //Set the value type options.
         subMenu = new JMenu("Select Value Type");
         group = new ButtonGroup();
@@ -167,7 +189,7 @@ public class HistogramWindow extends JFrame implements ActionListener, MenuListe
         button.addActionListener(this);
         group.add(button);
         subMenu.add(button);
-
+*/
         optionsMenu.add(subMenu);
 
         optionsMenu.addMenuListener(this);
@@ -183,6 +205,10 @@ public class HistogramWindow extends JFrame implements ActionListener, MenuListe
     }
 
     public void actionPerformed(ActionEvent evt) {
+    	if(evt==null){
+    		sortLocalData();
+    		return;
+    	}
         try {
             Object EventSrc = evt.getSource();
 
@@ -262,11 +288,12 @@ public class HistogramWindow extends JFrame implements ActionListener, MenuListe
 
     public void menuSelected(MenuEvent evt) {
         try {
-            if (ppTrial.isTimeMetric()) {
-                unitsSubMenu.setEnabled(true);
-            } else {
-                unitsSubMenu.setEnabled(false);
-            }
+        	
+        	 if (dataSorter.isTimeMetric()) {
+                 unitsSubMenu.setEnabled(true);
+             } else {
+                 unitsSubMenu.setEnabled(false);
+             }
         } catch (Exception e) {
             ParaProfUtils.handleException(e);
         }
@@ -350,7 +377,7 @@ public class HistogramWindow extends JFrame implements ActionListener, MenuListe
         }
     }
 
-    public List getData() {
+    public List<PPFunctionProfile> getData() {
         return data;
     }
 
@@ -405,7 +432,7 @@ public class HistogramWindow extends JFrame implements ActionListener, MenuListe
         boolean start = true;
 
         for (int i = 0; i < data.size(); i++) {
-            PPFunctionProfile ppFunctionProfile = (PPFunctionProfile) data.get(i);
+            PPFunctionProfile ppFunctionProfile = data.get(i);
             double value = ppFunctionProfile.getValue();
             if (start) {
                 minValue = value;
@@ -417,7 +444,7 @@ public class HistogramWindow extends JFrame implements ActionListener, MenuListe
 
         double[] values = new double[data.size()];
         for (int i = 0; i < data.size(); i++) {
-            PPFunctionProfile ppFunctionProfile = (PPFunctionProfile) data.get(i);
+            PPFunctionProfile ppFunctionProfile = data.get(i);
             values[i] = ppFunctionProfile.getValue();
         }
 
@@ -450,7 +477,7 @@ public class HistogramWindow extends JFrame implements ActionListener, MenuListe
 
         // create the tooltip generator
         XYItemRenderer renderer = chart.getXYPlot().getRenderer();
-        renderer.setToolTipGenerator(new XYToolTipGenerator() {
+        renderer.setBaseToolTipGenerator(new XYToolTipGenerator() {
             public String generateToolTip(XYDataset dataset, int arg1, int arg2) {
                 String minString = UtilFncs.getOutputString(units(), dataset.getXValue(arg1, arg2) - (binWidth / 2), 5, ppTrial.getDefaultMetric().isTimeDenominator());
                 String maxString = UtilFncs.getOutputString(units(), dataset.getXValue(arg1, arg2) + (binWidth / 2), 5, ppTrial.getDefaultMetric().isTimeDenominator());
@@ -465,7 +492,7 @@ public class HistogramWindow extends JFrame implements ActionListener, MenuListe
             ((XYBarRenderer) chart.getXYPlot().getRenderer()).setMargin(0.10);
         }
 
-        ((XYBarRenderer) chart.getXYPlot().getRenderer()).setOutlinePaint(Color.black);
+        ((XYBarRenderer) chart.getXYPlot().getRenderer()).setBaseOutlinePaint(Color.black);
 
         return chart;
     }
