@@ -1,13 +1,28 @@
 package edu.uoregon.tau.paraprof;
 
-import java.awt.*;
+import java.awt.Component;
+import java.awt.Container;
+import java.awt.Dimension;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
+import java.awt.Point;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.io.File;
 
-import javax.swing.*;
+import javax.swing.JButton;
+import javax.swing.JCheckBox;
+import javax.swing.JComboBox;
+import javax.swing.JFileChooser;
+import javax.swing.JFrame;
+import javax.swing.JLabel;
+import javax.swing.JOptionPane;
+import javax.swing.JTextField;
 
 import edu.uoregon.tau.perfdmf.DataSource;
+import edu.uoregon.tau.perfdmf.CubeDataSource;
+
 
 /**
  * A window that lets the user select a profile format and launch a JFileChooser
@@ -18,7 +33,12 @@ import edu.uoregon.tau.perfdmf.DataSource;
  */
 public class LoadTrialWindow extends JFrame implements ActionListener {
 
-    private static int defaultIndex;
+    /**
+	 * 
+	 */
+	private static final long serialVersionUID = 6863218330000263005L;
+
+	private static int defaultIndex;
 
     static String lastDirectory;
 
@@ -70,7 +90,6 @@ public class LoadTrialWindow extends JFrame implements ActionListener {
         setTitle("TAU: ParaProf: Load Trial");
         ParaProfUtils.setFrameIcon(this);
 
-
         addWindowListener(new java.awt.event.WindowAdapter() {
             public void windowClosing(java.awt.event.WindowEvent evt) {
                 thisWindowClosing(evt);
@@ -151,7 +170,7 @@ public class LoadTrialWindow extends JFrame implements ActionListener {
         }
 
     }
-
+    private static final String locationSeparator=", ";
     public void actionPerformed(ActionEvent evt) {
         try {
             String arg = evt.getActionCommand();
@@ -171,17 +190,39 @@ public class LoadTrialWindow extends JFrame implements ActionListener {
                 JFileChooser jFileChooser = new JFileChooser(lastDirectory);
                 jFileChooser.setFileSelectionMode(JFileChooser.FILES_ONLY);
 
-                if (trialTypes.getSelectedIndex() == DataSource.PPK || trialTypes.getSelectedIndex() == DataSource.MPIP
-                        || trialTypes.getSelectedIndex() == DataSource.PPROF || trialTypes.getSelectedIndex() == DataSource.CUBE) {
+                if (	   trialTypes.getSelectedIndex() == DataSource.PPK ||  trialTypes.getSelectedIndex() == DataSource.SNAP
+			|| trialTypes.getSelectedIndex() == DataSource.MPIP
+                        || trialTypes.getSelectedIndex() == DataSource.PPROF 
+			|| trialTypes.getSelectedIndex() == DataSource.CUBE3
+			|| trialTypes.getSelectedIndex() == DataSource.CUBE
+		    ) 
+		{
                     // These formats are in a single file only
                     jFileChooser.setMultiSelectionEnabled(false);
                 } else {
                     // others may have multiple files
                     jFileChooser.setMultiSelectionEnabled(true);
                 }
+
+                if ( trialTypes.getSelectedIndex() == DataSource.CUBE
+		    )
+		{
+                    // These formats are in a single file only
+                    jFileChooser.addChoosableFileFilter(CubeDataSource.getFilesFilter());
+                } else {
+                    // others may have multiple files
+                    jFileChooser.setMultiSelectionEnabled(true);
+                }
+
+
                 if (trialTypes.getSelectedIndex() == DataSource.PPK) {
                     jFileChooser.setFileFilter(new ParaProfFileFilter(ParaProfFileFilter.PPK));
                 }
+                else
+                if (trialTypes.getSelectedIndex() == DataSource.SNAP) {
+                    jFileChooser.setFileFilter(new ParaProfFileFilter(ParaProfFileFilter.XML));
+                }
+                
                 jFileChooser.setDialogTitle("Select File(s)");
                 jFileChooser.setApproveButtonText("Select");
                 if ((jFileChooser.showOpenDialog(this)) != JFileChooser.APPROVE_OPTION) {
@@ -195,33 +236,45 @@ public class LoadTrialWindow extends JFrame implements ActionListener {
                     selectedFiles[0] = jFileChooser.getSelectedFile();
                 }
 
-                if (selectedFiles.length > 1) {
-                    dirLocationField.setText("<Multiple Files Selected>");
-                    dirLocationField.setEditable(false);
-                } else {
-                    dirLocationField.setText(selectedFiles[0].toString());
-                    dirLocationField.setEditable(true);
+//                if (selectedFiles.length > 1) {
+//                    dirLocationField.setText("<Multiple Files Selected>");
+//                    dirLocationField.setEditable(false);
+//                } else {
+                String selText="";
+                for(int i=0;i<selectedFiles.length;i++){
+                	if(i>0)
+                		selText+=locationSeparator;
+                	selText+=selectedFiles[i].toString();
                 }
+                    dirLocationField.setText(selText);//(selectedFiles[0].toString());
+                    dirLocationField.setEditable(true);
+//                }
             } else if (arg.equals("Cancel")) {
                 // note that these are null if they're not top level (so this won't delete an application that has other experiments)
-
-                if (newExperiment) {
+        	   if (newApplication) {
+                       paraProfManagerWindow.handleDelete(application);
+                   }else if (newExperiment) {
                     paraProfManagerWindow.handleDelete(experiment);
                 }
-                if (newApplication) {
-                    paraProfManagerWindow.handleDelete(application);
-                }
+             
                 closeThisWindow();
             } else if (arg.equals("Ok")) {
-                if (trialTypes.getSelectedIndex() == 0) {
-                    File files[] = new File[1];
-                    files[0] = new File(dirLocationField.getText().trim());
+            	String dirLoc=dirLocationField.getText().trim();
+            	String[] locs = dirLoc.split(locationSeparator);
+                if (trialTypes.getSelectedIndex() == 0||trialTypes.getSelectedIndex() == 2) {
+                	File files[] = new File[1];
+                    for(int i =0;i<locs.length;i++){
+                    files[0] = new File(locs[i]);
+
                     if (!files[0].exists()) {
-                        JOptionPane.showMessageDialog(this, dirLocationField.getText().trim() + " does not exist");
-                        return;
+                        if (!files[0].toString().toLowerCase().startsWith("http:")) {
+                            JOptionPane.showMessageDialog(this, dirLocationField.getText().trim() + " does not exist");
+                            //return;
+                        }
                     }
                     paraProfManagerWindow.addTrial(application, experiment, files, trialTypes.getSelectedIndex(), false,
                             monitorTrialCheckBox.isSelected());
+                    }
                 } else {
                     if (selectedFiles == null) {
                         selectedFiles = new File[1];
