@@ -16,7 +16,13 @@ package edu.uoregon.tau.paraprof;
 
 import java.awt.EventQueue;
 import java.io.File;
-import java.util.*;
+import java.util.ArrayList;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Observable;
+import java.util.Observer;
+import java.util.Set;
+import java.util.Vector;
 
 import javax.swing.tree.DefaultMutableTreeNode;
 import javax.swing.tree.TreePath;
@@ -25,8 +31,16 @@ import edu.uoregon.tau.paraprof.script.ParaProfScript;
 import edu.uoregon.tau.paraprof.script.ParaProfTrialScript;
 import edu.uoregon.tau.paraprof.util.FileMonitor;
 import edu.uoregon.tau.paraprof.util.FileMonitorListener;
-import edu.uoregon.tau.perfdmf.*;
+import edu.uoregon.tau.perfdmf.DataSource;
+import edu.uoregon.tau.perfdmf.Database;
+import edu.uoregon.tau.perfdmf.DatabaseAPI;
+import edu.uoregon.tau.perfdmf.FileList;
+import edu.uoregon.tau.perfdmf.Function;
+import edu.uoregon.tau.perfdmf.Group;
+import edu.uoregon.tau.perfdmf.Metric;
 import edu.uoregon.tau.perfdmf.Thread;
+import edu.uoregon.tau.perfdmf.Trial;
+import edu.uoregon.tau.perfdmf.UserEvent;
 
 public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObject {
 
@@ -61,8 +75,10 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
 
     private boolean monitored;
     //private Timer monitorTimer;
+    
+    //JRadioButtonMenuItem metricButton = null;
 
-    private List obs = new ArrayList();
+    private List<Observer> obs = new ArrayList<Observer>();
 
     private FileMonitorListener fileMonitorListener;
 
@@ -81,7 +97,7 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
         assignDefaultMetric();
     }
 
-    public Iterator getFunctions() {
+    public Iterator<Function> getFunctions() {
         return getDataSource().getFunctions();
     }
 
@@ -270,7 +286,7 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
     }
 
     //Override this function.
-    public List getMetrics() {
+    public List<Metric> getMetrics() {
         if (trial == null) {
             return null;
         }
@@ -333,11 +349,11 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
     }
 
     // return a vector of only those functions that are currently "displayed" (i.e. group masks, etc)
-    public List getDisplayedFunctions() {
-        List displayedFunctions = new ArrayList();
+    public List<Function> getDisplayedFunctions() {
+        List<Function> displayedFunctions = new ArrayList<Function>();
 
-        for (Iterator it = this.getDataSource().getFunctions(); it.hasNext();) {
-            Function function = (Function) it.next();
+        for (Iterator<Function> it = this.getDataSource().getFunctions(); it.hasNext();) {
+            Function function = it.next();
             if (this.displayFunction(function)) {
                 displayedFunctions.add(function);
             }
@@ -354,8 +370,8 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
     }
 
     public void showGroup(Group group) {
-        for (Iterator it = getDataSource().getFunctions(); it.hasNext();) {
-            Function function = (Function) it.next();
+        for (Iterator<Function> it = getDataSource().getFunctions(); it.hasNext();) {
+            Function function = it.next();
             if (function.isGroupMember(group)) {
                 functionMask[function.getID()] = true;
             }
@@ -366,8 +382,8 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
     }
 
     public void hideGroup(Group group) {
-        for (Iterator it = getDataSource().getFunctions(); it.hasNext();) {
-            Function function = (Function) it.next();
+        for (Iterator<Function> it = getDataSource().getFunctions(); it.hasNext();) {
+            Function function = it.next();
             if (function.isGroupMember(group)) {
                 functionMask[function.getID()] = false;
             }
@@ -378,8 +394,8 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
     }
 
     public void showGroupOnly(Group group) {
-        for (Iterator it = getDataSource().getFunctions(); it.hasNext();) {
-            Function function = (Function) it.next();
+        for (Iterator<Function> it = getDataSource().getFunctions(); it.hasNext();) {
+            Function function = it.next();
             if (function.isGroupMember(group)) {
                 functionMask[function.getID()] = true;
             } else {
@@ -392,8 +408,8 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
     }
 
     public void showAllExcept(Group group) {
-        for (Iterator it = getDataSource().getFunctions(); it.hasNext();) {
-            Function function = (Function) it.next();
+        for (Iterator<Function> it = getDataSource().getFunctions(); it.hasNext();) {
+            Function function = it.next();
             if (function.isGroupMember(group)) {
                 functionMask[function.getID()] = false;
             } else {
@@ -442,8 +458,8 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
             }
         }
 
-        for (Iterator it = getDataSource().getFunctions(); it.hasNext();) {
-            Function function = (Function) it.next();
+        for (Iterator<Function> it = getDataSource().getFunctions(); it.hasNext();) {
+            Function function = it.next();
             String name = function.getName();
             if (caseSensitive) {
                 name = name.toUpperCase();
@@ -479,8 +495,8 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
         }
 
         // set the default metric to the first time based metric (if it exists)
-        for (Iterator it = getMetrics().iterator(); it.hasNext();) {
-            Metric metric = (Metric) it.next();
+        for (Iterator<Metric> it = getMetrics().iterator(); it.hasNext();) {
+            Metric metric = it.next();
             if (metric.isTimeMetric()) {
                 setDefaultMetric(metric);
                 break;
@@ -488,8 +504,8 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
         }
 
         // set the default metric to the first metric named "Time" (if it exists), higher priority than above
-        for (Iterator it = getMetrics().iterator(); it.hasNext();) {
-            Metric metric = (Metric) it.next();
+        for (Iterator<Metric> it = getMetrics().iterator(); it.hasNext();) {
+            Metric metric = it.next();
             if (metric.getName().equalsIgnoreCase(("time"))) {
                 setDefaultMetric(metric);
                 break;
@@ -507,7 +523,7 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
         // Inside ParaProf, these need to be ParaProfMetrics.
 
         int numberOfMetrics = trial.getDataSource().getNumberOfMetrics();
-        Vector ppMetrics = new Vector();
+        Vector<Metric> ppMetrics = new Vector<Metric>();
         for (int i = 0; i < numberOfMetrics; i++) {
             ParaProfMetric ppMetric = new ParaProfMetric();
             ppMetric.setName(trial.getDataSource().getMetricName(i));
@@ -541,7 +557,7 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
 
         // run any scripts
         for (int i = 0; i < ParaProf.scripts.size(); i++) {
-            ParaProfScript pps = (ParaProfScript) ParaProf.scripts.get(i);
+            ParaProfScript pps = ParaProf.scripts.get(i);
             if (pps instanceof ParaProfTrialScript) {
                 try {
                     ((ParaProfTrialScript) pps).trialLoaded(this);
@@ -625,10 +641,10 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
 
             FileMonitor fileMonitor = new FileMonitor(1000);
 
-            List files = trial.getDataSource().getFiles();
+            List<File> files = trial.getDataSource().getFiles();
 
-            for (Iterator it = files.iterator(); it.hasNext();) {
-                File file = (File) it.next();
+            for (Iterator<File> it = files.iterator(); it.hasNext();) {
+                File file = it.next();
                 fileMonitor.addFile(file);
             }
 
@@ -696,7 +712,7 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
         obs.remove(o);
     }
 
-    public List getObservers() {
+    public List<Observer> getObservers() {
         return obs;
     }
 
@@ -728,15 +744,15 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
         return experiment.getDatabase();
     }
 
-    public List getThreads() {
+    public List<Thread> getThreads() {
         return getDataSource().getAllThreads();
     }
 
-    public List getThreadNames() {
-        List threadNames = new ArrayList();
+    public List<String> getThreadNames() {
+        List<String> threadNames = new ArrayList<String>();
 
-        for (Iterator it = getDataSource().getAllThreads().iterator(); it.hasNext();) {
-            Thread thread = (Thread) it.next();
+        for (Iterator<Thread> it = getDataSource().getAllThreads().iterator(); it.hasNext();) {
+            Thread thread = it.next();
             if (getDataSource().getExecutionType() == DataSource.EXEC_TYPE_MPI) {
                 threadNames.add(Integer.toString(thread.getNodeID()));
             } else if (getDataSource().getExecutionType() == DataSource.EXEC_TYPE_HYBRID) {
@@ -761,8 +777,8 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
 
         int count = 0;
 
-        for (Iterator it = getMetrics().iterator(); it.hasNext();) {
-            Metric metric = (Metric) it.next();
+        for (Iterator<Metric> it = getMetrics().iterator(); it.hasNext();) {
+            Metric metric = it.next();
             if (metric == null) {
                 continue;
             }
@@ -773,8 +789,8 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
 
         int idx = 0;
 
-        for (Iterator it = getMetrics().iterator(); it.hasNext();) {
-            Metric metric = (Metric) it.next();
+        for (Iterator<Metric> it = getMetrics().iterator(); it.hasNext();) {
+            Metric metric = it.next();
             if (metric == null) {
                 continue;
             }
@@ -784,4 +800,24 @@ public class ParaProfTrial extends Observable implements ParaProfTreeNodeUserObj
         return items;
     }
 
+	public Vector<String> getTopologyArray() {
+		Set<String> keys = getDataSource().getMetaData().keySet();
+		Vector<String> topos = new Vector<String>();
+		for(Iterator<String> it = keys.iterator(); it.hasNext();){
+			String key = it.next();
+			if(key.contains(" isTorus")||key.contains(" Period")){
+				topos.add(key.split(" ")[0]);
+			}
+		}
+//		if(topos.size()==0){
+//			return new String[]{null};
+//		}
+		
+//		topos.add("Sphere");
+//		topos.add("Custom");
+		
+		//String[] a = new String[topos.size()];
+		return topos;//topos.toArray(a);
+	}
+
 }
\ No newline at end of file
