@@ -1,17 +1,49 @@
 package edu.uoregon.tau.paraprof;
 
-import java.awt.*;
-import java.awt.event.*;
-import java.awt.print.*;
+import java.awt.Color;
+import java.awt.Component;
+import java.awt.Dimension;
+import java.awt.EventQueue;
+import java.awt.Frame;
+import java.awt.Graphics;
+import java.awt.Graphics2D;
+import java.awt.Rectangle;
+import java.awt.Toolkit;
+import java.awt.event.ActionEvent;
+import java.awt.event.ActionListener;
+import java.awt.event.InputEvent;
+import java.awt.event.MouseEvent;
+import java.awt.print.PageFormat;
+import java.awt.print.Printable;
+import java.awt.print.PrinterException;
+import java.awt.print.PrinterJob;
 import java.io.File;
 import java.io.FileOutputStream;
 import java.io.PrintStream;
 import java.net.URL;
-import java.text.*;
-import java.util.*;
+import java.text.FieldPosition;
+import java.text.NumberFormat;
+import java.text.ParsePosition;
+import java.util.ArrayList;
+import java.util.Iterator;
 import java.util.List;
+import java.util.Map;
+import java.util.TreeMap;
 
-import javax.swing.*;
+import javax.swing.ButtonGroup;
+import javax.swing.ImageIcon;
+import javax.swing.JColorChooser;
+import javax.swing.JComboBox;
+import javax.swing.JComponent;
+import javax.swing.JFileChooser;
+import javax.swing.JFrame;
+import javax.swing.JMenu;
+import javax.swing.JMenuItem;
+import javax.swing.JOptionPane;
+import javax.swing.JPopupMenu;
+import javax.swing.JRadioButtonMenuItem;
+import javax.swing.JSeparator;
+import javax.swing.JToolBar;
 import javax.swing.event.MenuEvent;
 import javax.swing.event.MenuListener;
 
@@ -20,10 +52,12 @@ import edu.uoregon.tau.common.ImageExport;
 import edu.uoregon.tau.common.Utility;
 import edu.uoregon.tau.common.VectorExport;
 import edu.uoregon.tau.paraprof.barchart.BarChart;
-import edu.uoregon.tau.paraprof.barchart.BarChartModel;
 import edu.uoregon.tau.paraprof.enums.SortType;
 import edu.uoregon.tau.paraprof.enums.ValueType;
-import edu.uoregon.tau.paraprof.interfaces.*;
+import edu.uoregon.tau.paraprof.interfaces.ParaProfWindow;
+import edu.uoregon.tau.paraprof.interfaces.SortListener;
+import edu.uoregon.tau.paraprof.interfaces.ToolBarListener;
+import edu.uoregon.tau.paraprof.interfaces.UnitListener;
 import edu.uoregon.tau.paraprof.script.ParaProfFunctionScript;
 import edu.uoregon.tau.paraprof.script.ParaProfScript;
 import edu.uoregon.tau.paraprof.script.ParaProfTrialScript;
@@ -31,19 +65,27 @@ import edu.uoregon.tau.paraprof.sourceview.SourceViewer;
 import edu.uoregon.tau.paraprof.treetable.ContextEventWindow;
 import edu.uoregon.tau.paraprof.treetable.TreeTableWindow;
 import edu.uoregon.tau.paraprof.util.MapViewer;
-import edu.uoregon.tau.perfdmf.*;
+import edu.uoregon.tau.perfdmf.DataSource;
+import edu.uoregon.tau.perfdmf.DataSourceExport;
+import edu.uoregon.tau.perfdmf.Function;
+import edu.uoregon.tau.perfdmf.Metric;
+import edu.uoregon.tau.perfdmf.PhaseConvertedDataSource;
+import edu.uoregon.tau.perfdmf.Snapshot;
+import edu.uoregon.tau.perfdmf.SourceRegion;
 import edu.uoregon.tau.perfdmf.Thread;
+import edu.uoregon.tau.perfdmf.UserEvent;
+import edu.uoregon.tau.perfdmf.UtilFncs;
 import edu.uoregon.tau.vis.HeatMapWindow;
 
 /**
  * Utility class for ParaProf
  * 
  * <P>
- * CVS $Id: ParaProfUtils.java,v 1.61 2009/12/18 04:21:48 amorris Exp $
+ * CVS $Id: ParaProfUtils.java,v 1.62 2010/05/01 00:26:33 amorris Exp $
  * </P>
  * 
  * @author Alan Morris
- * @version $Revision: 1.61 $
+ * @version $Revision: 1.62 $
  */
 public class ParaProfUtils {
 
@@ -339,7 +381,7 @@ public class ParaProfUtils {
                 menu.add(menuitem);
                 //menu.add
                 for (int i = 0; i < ParaProf.scripts.size(); i++) {
-                    final ParaProfScript pps = (ParaProfScript) ParaProf.scripts.get(i);
+                    final ParaProfScript pps = ParaProf.scripts.get(i);
                     if (pps instanceof ParaProfTrialScript) {
                         JMenuItem menuItem = new JMenuItem("[Script] " + pps.getName());
                         menuItem.addActionListener(new ActionListener() {
@@ -369,11 +411,59 @@ public class ParaProfUtils {
     }
 
     public static void show3dCommMatrix(ParaProfTrial ppTrial, JFrame parentFrame) {
-        JFrame window = ThreeDeeCommMatrixWindow.createCommunicationMatrixWindow(ppTrial, parentFrame);
+    	
+        JFrame window = null; 
+        try {
+        	window = ThreeDeeCommMatrixWindow.createCommunicationMatrixWindow(ppTrial, parentFrame);
+        } catch (UnsatisfiedLinkError e) {
+            JOptionPane.showMessageDialog(parentFrame, "Unable to load jogl library.  Possible reasons:\n"
+                    + "libjogl.so is not in your LD_LIBRARY_PATH.\n"
+                    + "Jogl is not built for this platform.\nOpenGL is not installed\n\n"
+                    + "Jogl is available at jogl.dev.java.net\n\n" + "Message : " + e.getMessage());
+        } catch (UnsupportedClassVersionError e) {
+            JOptionPane.showMessageDialog(parentFrame,
+                    "Unsupported class version.  Are you sure you're using Java 1.4 or above?");
+        } catch (Exception gle) {
+            new ParaProfErrorDialog("Unable to initialize OpenGL: ", gle);
+        }
+        
+        
         if (window != null) {
             window.setVisible(true);
         }
     }
+    
+    public static void show3dVisualization(ParaProfTrial ppTrial,JFrame parentFrame){
+        if (JVMDependent.version.equals("1.3")) {
+            JOptionPane.showMessageDialog(parentFrame, "3D Visualization requires Java 1.4 or above\n"
+                    + "Please make sure Java 1.4 is in your path, then reconfigure TAU and re-run ParaProf");
+            return;
+        }
+
+        //Gears.main(null);
+        //(new Gears()).show();
+
+        JFrame window = null;
+        
+        try {
+            window = ThreeDeeWindow.createThreeDeeWindow(ppTrial, parentFrame);//new ThreeDeeWindow(ppTrial, parentFrame);
+        } catch (UnsatisfiedLinkError e) {
+            JOptionPane.showMessageDialog(parentFrame, "Unable to load jogl library.  Possible reasons:\n"
+                    + "libjogl.so is not in your LD_LIBRARY_PATH.\n"
+                    + "Jogl is not built for this platform.\nOpenGL is not installed\n\n"
+                    + "Jogl is available at jogl.dev.java.net\n\n" + "Message : " + e.getMessage());
+        } catch (UnsupportedClassVersionError e) {
+            JOptionPane.showMessageDialog(parentFrame,
+                    "Unsupported class version.  Are you sure you're using Java 1.4 or above?");
+        } catch (Exception gle) {
+            new ParaProfErrorDialog("Unable to initialize OpenGL: ", gle);
+        }
+
+        if (window != null) {
+            window.setVisible(true);
+        }
+        
+    }
 
     public static JMenu createWindowsMenu(final ParaProfTrial ppTrial, final JFrame owner) {
 
@@ -385,7 +475,7 @@ public class ParaProfUtils {
                     String arg = evt.getActionCommand();
 
                     if (arg.equals("ParaProf Manager")) {
-			ParaProf.paraProfManagerWindow.setVisible(true);
+                        ParaProf.paraProfManagerWindow.setVisible(true);
                     } else if (arg.equals("Function Legend")) {
                         (new LedgerWindow(ppTrial, 0, owner)).setVisible(true);
                     } else if (arg.equals("Group Changer")) {
@@ -404,32 +494,7 @@ public class ParaProfUtils {
                     } else if (arg.equals("3D Communication Matrix")) {
                         ParaProfUtils.show3dCommMatrix(ppTrial, owner);
                     } else if (arg.equals("3D Visualization")) {
-
-                        if (JVMDependent.version.equals("1.3")) {
-                            JOptionPane.showMessageDialog(owner, "3D Visualization requires Java 1.4 or above\n"
-                                    + "Please make sure Java 1.4 is in your path, then reconfigure TAU and re-run ParaProf");
-                            return;
-                        }
-
-                        //Gears.main(null);
-                        //(new Gears()).show();
-
-                        try {
-
-                            (new ThreeDeeWindow(ppTrial, owner)).setVisible(true);
-                            //(new ThreeDeeWindow()).show();
-                        } catch (UnsatisfiedLinkError e) {
-                            JOptionPane.showMessageDialog(owner, "Unable to load jogl library.  Possible reasons:\n"
-                                    + "libjogl.so is not in your LD_LIBRARY_PATH.\n"
-                                    + "Jogl is not built for this platform.\nOpenGL is not installed\n\n"
-                                    + "Jogl is available at jogl.dev.java.net\n\n" + "Message : " + e.getMessage());
-                        } catch (UnsupportedClassVersionError e) {
-                            JOptionPane.showMessageDialog(owner,
-                                    "Unsupported class version.  Are you sure you're using Java 1.4 or above?");
-                        } catch (Exception gle) {
-                            new ParaProfErrorDialog("Unable to initialize OpenGL: ", gle);
-                        }
-
+                    	ParaProfUtils.show3dVisualization(ppTrial, owner);
                     } else if (arg.equals("Close All Sub-Windows")) {
                         ppTrial.updateRegisteredObjects("subWindowCloseEvent");
                     }
@@ -507,7 +572,7 @@ public class ParaProfUtils {
             public void actionPerformed(ActionEvent evt) {
                 String arg = evt.getActionCommand();
 
-                List list = new ArrayList(ppTrial.getDataSource().getAllThreads());
+                List<Thread> list = new ArrayList<Thread>(ppTrial.getDataSource().getAllThreads());
                 if (ppTrial.getDataSource().getAllThreads().size() > 1 && arg.equals("User Event Statistics") == false) {
                     list.add(0, ppTrial.getDataSource().getStdDevData());
                     list.add(1, ppTrial.getDataSource().getMeanData());
@@ -553,6 +618,55 @@ public class ParaProfUtils {
 
         windowsMenu.add(threadWindows);
 
+	/*
+        ActionListener mActionListener = new ActionListener() {
+        	public void actionPerformed(ActionEvent evt) {
+        		String arg = evt.getActionCommand();
+        		if (arg.equals("Summary")) {
+        			JFrame hw = 
+        				MonSummaryWindow.createMonSummaryWindow(ppTrial, 
+        						owner);
+        			hw.setVisible(true);
+
+        		} else if (arg.equals("Clusters")) {
+        			System.out.println("Clusters");
+        		}
+        	}
+        };
+        final JMenu monWindows = new JMenu("Monitoring");
+        monWindows.getPopupMenu().setLightWeightPopupEnabled(false);
+        monWindows.add(createMenuItem("Summary", mActionListener, true));
+        monWindows.add(createMenuItem("Clusters", mActionListener, true));
+
+        ActionListener fmActionListener = new ActionListener() {
+        	public void actionPerformed(ActionEvent evt) {	
+        		FunctionSelectorDialog fSelector = new FunctionSelectorDialog(owner, true,
+        				ppTrial.getDataSource().getFunctions(), null, false, false);
+        		if (fSelector.choose()) {
+        			//Function selectedFunction = (Function) fSelector.getSelectedObject();
+
+        			String arg = evt.getActionCommand();
+        			if (arg.equals("Base Statistics")) {
+        				System.out.println("Monitoring: Base Statistics");
+       				// JFrame hw = MonStatisticsWindow.createMonStatisticsWindow(ppTrial, selectedFunction, owner);
+//        				hw.setVisible(true);
+        			} else if (arg.equals("Histograms")) {
+        				System.out.println("Monitoring: Histograms");
+        			}
+        		}
+        	}
+	    };
+
+	    final JMenu monFunctionWindows = new JMenu("Function");
+	    monFunctionWindows.getPopupMenu().setLightWeightPopupEnabled(false);
+	    monFunctionWindows.add(createMenuItem("Base Statistics",
+	    		fmActionListener, true));
+	    monFunctionWindows.add(createMenuItem("Histograms",
+	    		fmActionListener, true));
+	    monWindows.add(monFunctionWindows);
+
+	    windowsMenu.add(monWindows);
+	*/
         windowsMenu.add(new JSeparator());
 
         menuItem = new JMenuItem("Function Legend");
@@ -606,8 +720,8 @@ public class ParaProfUtils {
     public static void scaleForPrint(Graphics g, PageFormat pageFormat, int width, int height) {
         double pageWidth = pageFormat.getImageableWidth();
         double pageHeight = pageFormat.getImageableHeight();
-        int cols = (int) (width / pageWidth) + 1;
-        int rows = (int) (height / pageHeight) + 1;
+        //int cols = (int) (width / pageWidth) + 1;
+        //int rows = (int) (height / pageHeight) + 1;
         double xScale = pageWidth / width;
         double yScale = pageHeight / height;
         double scale = Math.min(xScale, yScale);
@@ -626,6 +740,94 @@ public class ParaProfUtils {
         g2.translate(tx, ty);
         g2.scale(scale, scale);
     }
+    
+    private static SourceRegion getBacktraceSourceLink(String btTuple){
+    	SourceRegion sourceLink = new SourceRegion();
+    	
+    	int fb = btTuple.indexOf('[',1);
+    	if(fb==-1)
+    		return null;
+    	if(fb==1)
+    		fb = btTuple.indexOf('[',fb+1);
+    	if(fb==-1)
+    		return null;
+    	
+    	int endb=btTuple.indexOf(']',fb+1);
+    	if(endb==-1)
+    		return null;
+    	
+    	String src = btTuple.substring(fb+1, endb);
+    	if(src==null)
+    		return null;
+    	
+    	String[]chunks=src.split(":");
+    	if(chunks.length!=2)
+    		return null;
+    	
+    	if(chunks[0].equals("(unknown)"))
+    		return null;
+    	
+    	sourceLink.setFilename(chunks[0]);
+    	int line = Integer.parseInt(chunks[1]);
+    	sourceLink.setStartLine(line);
+    	sourceLink.setEndLine(line);
+    	
+    	return sourceLink;
+    }
+    
+    public static JPopupMenu createMetadataClickPopUp(final String fName,
+            final Component owner) {
+    	
+    	 final SourceRegion sr = getBacktraceSourceLink(fName);
+    	
+        ActionListener actionListener = new ActionListener() {
+            public void actionPerformed(ActionEvent evt) {
+                try {
+
+                    String arg = evt.getActionCommand();
+
+                     if (arg.equals("Show Source Code")) {
+
+                        if (ParaProf.controlMode) {
+                            ExternalController.outputCommand("sourcecode " + sr);
+                        } 
+//                        else if (ParaProf.insideEclipse) {
+//                            ParaProf.eclipseHandler.openSourceLocation(ppTrial, function);
+//                        } 
+                        else {
+                            // use internal viewer
+                            ParaProf.getDirectoryManager().showSourceCode(sr);
+                        }
+                    }
+
+                } catch (Exception e) {
+                    ParaProfUtils.handleException(e);
+                }
+            }
+
+        };
+
+        JPopupMenu functionPopup = new JPopupMenu();
+
+        
+       
+        
+        if (sr != null) {
+            JMenuItem functionDetailsItem = new JMenuItem("Show Source Code");
+            functionDetailsItem.addActionListener(actionListener);
+            functionPopup.add(functionDetailsItem);
+        }
+        else{
+        	return null;
+        }
+
+
+
+        return functionPopup;
+
+    }
+    
+    
 
     public static JPopupMenu createFunctionClickPopUp(final ParaProfTrial ppTrial, final Function function, final Thread thread,
             final Component owner) {
@@ -643,10 +845,27 @@ public class ParaProfUtils {
                                 ppTrial, function, thread, owner);
                         functionBarChartWindow.setVisible(true);
                     } else if (arg.equals("Show Function Histogram")) {
-                        HistogramWindow hw = new HistogramWindow(ppTrial, function, owner);
-                        hw.setVisible(true);
+                        String dagstuhl_demo = (String) ppTrial.getDataSource().getMetaData().get(
+                                "TAU Internal Profile Attribute");
+                        if (dagstuhl_demo != null && dagstuhl_demo.equals("collate_dump_dagstuhl")) {
+                            JFrame hw = PreCompHistogramWindow.createHistogramWindow(ppTrial, function, thread, owner);
+                            hw.setVisible(true);
+                        } else {
+                            HistogramWindow hw = new HistogramWindow(ppTrial, function, owner);
+                            hw.setVisible(true);
+                        }
                     } else if (arg.equals("Assign Function Color")) {
                         ParaProf.colorMap.assignColor(owner, function);
+                    } else if (arg.equals("Rename")) {
+
+                        String newName = (String) JOptionPane.showInputDialog(owner, "Rename event:", "Rename event",
+                                JOptionPane.PLAIN_MESSAGE, null, null, function.toString());
+
+                        if (newName != null) {
+                            ppTrial.getDataSource().renameFunction(function, newName);
+                            ppTrial.updateRegisteredObjects("dataEvent");
+                        }
+
                     } else if (arg.equals("Reset to Default Color")) {
                         ParaProf.colorMap.removeColor(function);
                         ParaProf.colorMap.reassignColors();
@@ -670,14 +889,14 @@ public class ParaProfUtils {
                             BarChart tmp = (BarChart) owner;
                             metricName = tmp.getBarChartModel().getDataSorter().getSelectedMetric().getName();
                         }
-                        List tools = ExternalTool.findMatchingTools((String) ppTrial.getTrial().getMetaData().get(
-                                DataSource.FILE_TYPE_NAME), (String) ppTrial.getTrial().getName());
+                        List<ExternalTool> tools = ExternalTool.findMatchingTools(ppTrial.getTrial().getMetaData().get(
+                                DataSource.FILE_TYPE_NAME), ppTrial.getTrial().getName());
                         ExternalTool.CommandParameters params = new ExternalTool.CommandParameters();
                         params.function = function.getName();
                         params.metric = metricName;
                         params.nodeID = thread.getNodeID();
                         params.threadID = thread.getThreadID();
-                        Map map = new TreeMap();
+                        Map<String,String> map = new TreeMap<String,String>();
                         map.putAll(thread.getMetaData());
                         map.putAll(ppTrial.getDataSource().getMetaData());
                         params.metadata = map;
@@ -728,8 +947,14 @@ public class ParaProfUtils {
         jMenuItem.addActionListener(actionListener);
         functionPopup.add(jMenuItem);
 
+        if (!function.isGroupMember("TAU_CALLPATH")) {
+            jMenuItem = new JMenuItem("Rename");
+            jMenuItem.addActionListener(actionListener);
+            functionPopup.add(jMenuItem);
+        }
+
         if ((thread.getNodeID() >= 0)
-                && (ExternalTool.matchingToolExists((String) ppTrial.getTrial().getMetaData().get(DataSource.FILE_TYPE_NAME),
+                && (ExternalTool.matchingToolExists(ppTrial.getTrial().getMetaData().get(DataSource.FILE_TYPE_NAME),
                         (String) ppTrial.getTrial().getName()))) {
             JMenuItem toolMenuItem = new JMenuItem("Launch External Tool for this Function & Metric");
             toolMenuItem.addActionListener(actionListener);
@@ -739,7 +964,7 @@ public class ParaProfUtils {
         // count function scripts
         int functionScripts = 0;
         for (int i = 0; i < ParaProf.scripts.size(); i++) {
-            ParaProfScript pps = (ParaProfScript) ParaProf.scripts.get(i);
+            ParaProfScript pps = ParaProf.scripts.get(i);
             if (pps instanceof ParaProfFunctionScript) {
                 functionScripts++;
             }
@@ -748,7 +973,7 @@ public class ParaProfUtils {
             functionPopup.add(new JSeparator());
         }
         for (int i = 0; i < ParaProf.scripts.size(); i++) {
-            final ParaProfScript pps = (ParaProfScript) ParaProf.scripts.get(i);
+            final ParaProfScript pps = ParaProf.scripts.get(i);
             if (pps instanceof ParaProfFunctionScript) {
                 JMenuItem menuItem = new JMenuItem("[Script] " + pps.getName());
                 menuItem.addActionListener(new ActionListener() {
@@ -870,7 +1095,7 @@ public class ParaProfUtils {
         JMenuItem jMenuItem = new JMenuItem(text);
         jMenuItem.addActionListener(new ActionListener() {
             public void actionPerformed(ActionEvent e) {
-                Map map = new TreeMap();
+                Map<String,String> map = new TreeMap<String,String>();
                 map.putAll(thread.getMetaData());
                 map.putAll(ppTrial.getDataSource().getMetaData());
                 Frame w = new MapViewer("Metadata for " + thread, map);
@@ -1120,10 +1345,10 @@ public class ParaProfUtils {
         fSelector.setTitle("Choose Phases");
 
         if (fSelector.choose()) {
-            List phases = fSelector.getSelectedObjects();
+            List<Object> phases = fSelector.getSelectedObjects();
 
-            List phaseStrings = new ArrayList();
-            for (Iterator it = phases.iterator(); it.hasNext();) {
+            List<String> phaseStrings = new ArrayList<String>();
+            for (Iterator<Object> it = phases.iterator(); it.hasNext();) {
                 Function f = (Function) it.next();
                 phaseStrings.add(f.getName());
             }
@@ -1251,6 +1476,16 @@ public class ParaProfUtils {
         }
         return str;
     }
+    
+    //remove the 'throttled' tag from the function name
+    public static String removeThrottledTag(String str){
+    	int dex=str.indexOf("  [THROTTLED]");
+    	if(dex>=0){
+    		str = str.substring(0,dex);
+    	}
+    	
+    	return str;
+    }
 
     // handles reversed callpaths
     public static String getDisplayName(Function function) {
@@ -1287,7 +1522,13 @@ public class ParaProfUtils {
             return "Total";
         } else if (thread.getNodeID() == -3) {
             return "Std. Dev.";
-        } else {
+        }
+        else if (thread.getNodeID() == -4) {
+            return "Min";
+        }
+        else if (thread.getNodeID() == -5) {
+            return "Max";
+        }else {
             if (ParaProf.preferences.getAutoLabels()) {
                 DataSource dataSource = thread.getDataSource();
                 if (dataSource.getHasContexts() == false && dataSource.getHasThreads() == false) {
@@ -1339,7 +1580,12 @@ public class ParaProfUtils {
     public static NumberFormat createNumberFormatter(final int units, final boolean timeDenominator) {
         return new NumberFormat() {
 
-            public Number parse(String source, ParsePosition parsePosition) {
+            /**
+			 * 
+			 */
+			private static final long serialVersionUID = 3533959839796773891L;
+
+			public Number parse(String source, ParsePosition parsePosition) {
                 // TODO Auto-generated method stub
                 return null;
             }
@@ -1386,7 +1632,7 @@ public class ParaProfUtils {
     }
 
     private static Component createMetricMenu(ParaProfTrial ppTrial, final ValueType valueType, boolean enabled,
-            ButtonGroup group, final boolean sort, final DataSorter dataSorter, final SortListener sortListener) {
+            ButtonGroup group, final boolean sort, final DataSorter dataSorter, final SortListener sortListener, final ActionListener al) {
         JRadioButtonMenuItem button = null;
 
         if (ppTrial.getNumberOfMetrics() == 1) {
@@ -1401,7 +1647,12 @@ public class ParaProfUtils {
                     } else {
                         dataSorter.setValueType(valueType);
                     }
-                    sortListener.resort();
+                    if(sortListener!=null)
+                    	sortListener.resort();
+                    	
+                    else{
+                    	al.actionPerformed(null);
+                    }
                 }
             });
             group.add(button);
@@ -1409,8 +1660,8 @@ public class ParaProfUtils {
         } else {
             JMenu subSubMenu = new JMenu(valueType.toString() + "...");
             subSubMenu.getPopupMenu().setLightWeightPopupEnabled(false);
-            for (Iterator it = ppTrial.getMetrics().iterator(); it.hasNext();) {
-                Metric metric = (Metric) it.next();
+            for (Iterator<Metric> it = ppTrial.getMetrics().iterator(); it.hasNext();) {
+                Metric metric =  it.next();
                 if (metric == null) {
                     continue;
                 }
@@ -1437,7 +1688,13 @@ public class ParaProfUtils {
                             dataSorter.setSelectedMetric(useMetric);
                             dataSorter.setValueType(valueType);
                         }
-                        sortListener.resort();
+                        if(sortListener!=null)
+                        	sortListener.resort();
+                        	
+                        else{
+                        	al.actionPerformed(null);
+                        }
+                        //sortListener.resort();
                     }
                 });
                 group.add(button);
@@ -1447,90 +1704,134 @@ public class ParaProfUtils {
         }
     }
 
-    public static JMenu createMetricSelectionMenu(ParaProfTrial ppTrial, String name, final boolean sort, boolean nct,
+    static class SortAction implements ActionListener{
+
+    	DataSorter dataSorter;
+    	SortListener sortListener;
+    	
+    	SortAction(final DataSorter ds, final SortListener sortListener){
+    		dataSorter=ds;
+    		this.sortListener=sortListener;
+    	}
+    	
+		public void actionPerformed(ActionEvent e) {
+			String arg = e.getActionCommand();
+			if(arg.equals("Same as Visible Metric")){
+				dataSorter.setSortType(SortType.VALUE);
+                dataSorter.setSortByVisible(true);
+			}else if(arg.equals("Sort By N,C,T")){
+                dataSorter.setSortType(SortType.NCT);
+			}else if(arg.equals("Name")){
+				dataSorter.setSortType(SortType.NAME);
+			}else if(arg.equals("Number of Calls")){
+                dataSorter.setSortByVisible(false);
+                dataSorter.setSortType(SortType.VALUE);
+                dataSorter.setSortValueType(ValueType.NUMCALLS);
+			}else if(arg.equals("Number of Child Calls")){
+                dataSorter.setSortByVisible(false);
+                dataSorter.setSortType(SortType.VALUE);
+                dataSorter.setSortValueType(ValueType.NUMSUBR);
+			}
+            sortListener.resort();
+		}
+    	
+    }
+    
+    static class MetricAction implements ActionListener{
+
+    	DataSorter dataSorter;
+    	SortListener sortListener;
+    	
+    	MetricAction(final DataSorter ds, final SortListener sortListener){
+    		dataSorter=ds;
+    		this.sortListener=sortListener;
+    	}
+    	
+		public void actionPerformed(ActionEvent e) {
+			String arg = e.getActionCommand();
+			 if(arg.equals("Number of Calls")){
+	                dataSorter.setValueType(ValueType.NUMCALLS);
+				}else if(arg.equals("Number of Child Calls")){
+	                dataSorter.setValueType(ValueType.NUMSUBR);
+				}
+			 sortListener.resort();
+		}
+    	
+    }
+    
+    class HistogramAction implements ActionListener{
+
+    	
+		public void actionPerformed(ActionEvent e) {
+			// TODO Auto-generated method stub
+			
+		}
+    	
+    }
+    
+    public static JMenu createMetricSelectionMenu(final ParaProfTrial ppTrial, String name, final boolean sort, boolean nct,
             final DataSorter dataSorter, final SortListener sortListener, boolean visibleMetric) {
+    	
+        ActionListener al=null;
+        if(sort){
+        	al = new SortAction(dataSorter,sortListener);
+        }else{
+        	al = new MetricAction(dataSorter,sortListener);
+        }
+        
+        return createMetricSelectionMenu(ppTrial,name,sort,nct,dataSorter,sortListener,al,visibleMetric);
+    }
+        
+        public static JMenu createMetricSelectionMenu(final ParaProfTrial ppTrial, String name, final boolean sort, boolean nct,
+                final DataSorter dataSorter, final SortListener sortListener, final ActionListener al, boolean visibleMetric) {
+    	
         JRadioButtonMenuItem button;
         JMenu subMenu = new JMenu(name);
         ButtonGroup group = new ButtonGroup();
 
+
         if (sort) {
 
             if (visibleMetric) {
                 button = new JRadioButtonMenuItem("Same as Visible Metric", dataSorter.getSortByVisible());
-                button.addActionListener(new ActionListener() {
-                    public void actionPerformed(ActionEvent evt) {
-                        dataSorter.setSortType(SortType.VALUE);
-                        dataSorter.setSortByVisible(true);
-                        sortListener.resort();
-                    }
-                });
+                button.addActionListener(al);
                 group.add(button);
                 subMenu.add(button);
             }
 
             if (nct) {
                 button = new JRadioButtonMenuItem("Sort By N,C,T", dataSorter.getSortType() == SortType.NCT);
-                button.addActionListener(new ActionListener() {
-                    public void actionPerformed(ActionEvent e) {
-                        dataSorter.setSortType(SortType.NCT);
-                        sortListener.resort();
-                    }
-                });
+                button.addActionListener(al);
                 group.add(button);
                 subMenu.add(button);
             } else {
                 button = new JRadioButtonMenuItem("Name", dataSorter.getSortType() == SortType.NAME);
-                button.addActionListener(new ActionListener() {
-                    public void actionPerformed(ActionEvent e) {
-                        dataSorter.setSortType(SortType.NAME);
-                        sortListener.resort();
-                    }
-                });
+                button.addActionListener(al);
                 group.add(button);
                 subMenu.add(button);
             }
         }
 
         subMenu.add(createMetricMenu(ppTrial, ValueType.EXCLUSIVE, dataSorter.getValueType() == ValueType.EXCLUSIVE
-                || dataSorter.getValueType() == ValueType.EXCLUSIVE_PERCENT, group, sort, dataSorter, sortListener));
+                || dataSorter.getValueType() == ValueType.EXCLUSIVE_PERCENT, group, sort, dataSorter, sortListener,al));
         subMenu.add(createMetricMenu(ppTrial, ValueType.INCLUSIVE, dataSorter.getValueType() == ValueType.INCLUSIVE
-                || dataSorter.getValueType() == ValueType.INCLUSIVE_PERCENT, group, sort, dataSorter, sortListener));
+                || dataSorter.getValueType() == ValueType.INCLUSIVE_PERCENT, group, sort, dataSorter, sortListener,al));
         subMenu.add(createMetricMenu(ppTrial, ValueType.EXCLUSIVE_PER_CALL,
-                dataSorter.getValueType() == ValueType.EXCLUSIVE_PER_CALL, group, sort, dataSorter, sortListener));
+                dataSorter.getValueType() == ValueType.EXCLUSIVE_PER_CALL, group, sort, dataSorter, sortListener,al));
         subMenu.add(createMetricMenu(ppTrial, ValueType.INCLUSIVE_PER_CALL,
-                dataSorter.getValueType() == ValueType.INCLUSIVE_PER_CALL, group, sort, dataSorter, sortListener));
+                dataSorter.getValueType() == ValueType.INCLUSIVE_PER_CALL, group, sort, dataSorter, sortListener,al));
 
         button = new JRadioButtonMenuItem("Number of Calls", dataSorter.getValueType() == ValueType.NUMCALLS);
-        button.addActionListener(new ActionListener() {
-            public void actionPerformed(ActionEvent evt) {
-                if (sort) {
-                    dataSorter.setSortByVisible(false);
-                    dataSorter.setSortType(SortType.VALUE);
-                    dataSorter.setSortValueType(ValueType.NUMCALLS);
-                } else {
-                    dataSorter.setValueType(ValueType.NUMCALLS);
-                }
-                sortListener.resort();
-            }
-        });
+        button.addActionListener(al);
         group.add(button);
         subMenu.add(button);
 
         button = new JRadioButtonMenuItem("Number of Child Calls", dataSorter.getValueType() == ValueType.NUMSUBR);
-        button.addActionListener(new ActionListener() {
-            public void actionPerformed(ActionEvent evt) {
-                if (sort) {
-                    dataSorter.setSortByVisible(false);
-                    dataSorter.setSortType(SortType.VALUE);
-                    dataSorter.setSortValueType(ValueType.NUMSUBR);
-                } else {
-                    dataSorter.setValueType(ValueType.NUMSUBR);
-                }
-                sortListener.resort();
-            }
-        });
+        button.addActionListener(al);
         group.add(button);
         subMenu.add(button);
+        //if(ppTrial.metricButton!=null)
+        	//group.setSelected(ppTrial.metricButton.getModel(), true);
         return subMenu;
     }
 
