@@ -8,19 +8,43 @@
 
 package edu.uoregon.tau.paraprof;
 
-import java.awt.*;
-import java.awt.event.*;
-import java.util.*;
+import java.awt.Component;
+import java.awt.Container;
+import java.awt.Dimension;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
+import java.awt.Rectangle;
+import java.awt.event.ActionEvent;
+import java.awt.event.ActionListener;
+import java.awt.event.KeyEvent;
+import java.awt.event.KeyListener;
+import java.util.ArrayList;
 import java.util.List;
+import java.util.Observable;
+import java.util.Observer;
 
-import javax.swing.*;
+import javax.swing.ButtonGroup;
+import javax.swing.JCheckBoxMenuItem;
+import javax.swing.JFrame;
+import javax.swing.JMenu;
+import javax.swing.JMenuBar;
+import javax.swing.JMenuItem;
+import javax.swing.JRadioButtonMenuItem;
+import javax.swing.JScrollBar;
+import javax.swing.JScrollPane;
+import javax.swing.JSeparator;
+import javax.swing.JTextArea;
 import javax.swing.event.MenuEvent;
 import javax.swing.event.MenuListener;
 
 import edu.uoregon.tau.paraprof.enums.SortType;
 import edu.uoregon.tau.paraprof.enums.UserEventValueType;
 import edu.uoregon.tau.paraprof.enums.ValueType;
-import edu.uoregon.tau.paraprof.interfaces.*;
+import edu.uoregon.tau.paraprof.interfaces.ParaProfWindow;
+import edu.uoregon.tau.paraprof.interfaces.ScrollBarController;
+import edu.uoregon.tau.paraprof.interfaces.SearchableOwner;
+import edu.uoregon.tau.paraprof.interfaces.UnitListener;
 import edu.uoregon.tau.perfdmf.Function;
 import edu.uoregon.tau.perfdmf.Thread;
 import edu.uoregon.tau.perfdmf.UtilFncs;
@@ -28,7 +52,11 @@ import edu.uoregon.tau.perfdmf.UtilFncs;
 public class StatWindow extends JFrame implements ActionListener, MenuListener, Observer, SearchableOwner, ScrollBarController,
         KeyListener, ParaProfWindow, UnitListener {
 
-    //Instance data.
+    /**
+	 * 
+	 */
+	private static final long serialVersionUID = 1176775089369369534L;
+	//Instance data.
     private ParaProfTrial ppTrial = null;
     private DataSorter dataSorter;
     private Function phase;
@@ -43,14 +71,15 @@ public class StatWindow extends JFrame implements ActionListener, MenuListener,
     private boolean sortByName;
 
     private JCheckBoxMenuItem descendingOrder = null;
-    private JCheckBoxMenuItem showPathTitleInReverse = null;
+    //private JCheckBoxMenuItem showPathTitleInReverse = null;
     private JCheckBoxMenuItem showMetaData = null;
     private JCheckBoxMenuItem showFindPanelBox;
 
     private JScrollPane jScrollpane = null;
     private StatWindowPanel panel = null;
 
-    private List list = new ArrayList();
+    private List<PPUserEventProfile> uepList = new ArrayList<PPUserEventProfile>();
+    private List<PPFunctionProfile>  fpList = new ArrayList<PPFunctionProfile>();
 
     private int units = ParaProf.preferences.getUnits();
 
@@ -85,7 +114,7 @@ public class StatWindow extends JFrame implements ActionListener, MenuListener,
         } else if (nodeID == -3) {
             title = "TAU: ParaProf: Standard Deviation Statistics: ";
         } else {
-            title = "TAU: ParaProf: n,c,t, " + nodeID + "," + contextID + "," + threadID;
+            title = "TAU: ParaProf: "+ ParaProfUtils.getThreadLabel(thread);//n,c,t, " + nodeID + "," + contextID + "," + threadID;
         }
 
         title = title + " - " + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse());
@@ -118,14 +147,14 @@ public class StatWindow extends JFrame implements ActionListener, MenuListener,
 
         mainMenu.addKeyListener(this);
         JMenu subMenu = null;
-        JMenuItem menuItem = null;
+        //JMenuItem menuItem = null;
 
         //######
         //Options menu.
         //######
         optionsMenu = new JMenu("Options");
 
-        JCheckBoxMenuItem box = null;
+        //JCheckBoxMenuItem box = null;
         ButtonGroup group = null;
         JRadioButtonMenuItem button = null;
 
@@ -162,6 +191,11 @@ public class StatWindow extends JFrame implements ActionListener, MenuListener,
             group.add(button);
             subMenu.add(button);
 
+            button = new JRadioButtonMenuItem("Total", false);
+            button.addActionListener(this);
+            group.add(button);
+            subMenu.add(button);
+            
             button = new JRadioButtonMenuItem("Number of Samples", true);
             button.addActionListener(this);
             group.add(button);
@@ -333,6 +367,12 @@ public class StatWindow extends JFrame implements ActionListener, MenuListener,
                     this.setHeader();
                     sortLocalData();
                     panel.repaint();
+                } else if (arg.equals("Total")) {
+                    sortByName = false;
+                    dataSorter.setUserEventValueType(UserEventValueType.TOTAL);
+                    this.setHeader();
+                    sortLocalData();
+                    panel.repaint();    
                 } else if (arg.equals("Number of Samples")) {
                     sortByName = false;
                     dataSorter.setUserEventValueType(UserEventValueType.NUMSAMPLES);
@@ -391,6 +431,15 @@ public class StatWindow extends JFrame implements ActionListener, MenuListener,
     public void update(Observable o, Object arg) {
         String tmpString = (String) arg;
         if (tmpString.equals("prefEvent")) {
+        	if(nodeID>=0){
+        		String phaseName="";
+        		 if (phase != null) {
+        	            phaseName= " Phase: " + phase.getName();
+        	        }
+        	this.setTitle("TAU: ParaProf: Context Events for: " + ParaProfUtils.getThreadLabel(thread)+ " - "
+                    + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse())+phaseName);
+        	}
+        	
             this.setHeader();
             panel.repaint();
         }
@@ -452,16 +501,20 @@ public class StatWindow extends JFrame implements ActionListener, MenuListener,
         dataSorter.setDescendingOrder(descendingOrder.isSelected());
 
         if (userEventWindow) {
-            list = dataSorter.getUserEventProfiles(thread);
+            uepList = dataSorter.getUserEventProfiles(thread);
         } else {
-            list = dataSorter.getFunctionProfiles(thread);
+            fpList = dataSorter.getFunctionProfiles(thread);
         }
 
         panel.resetStringSize();
     }
 
-    public List getData() {
-        return list;
+    public List<PPFunctionProfile> getFunctionProfileData() {
+        return fpList;
+    }
+    
+    public List<PPUserEventProfile> getUserEventProfileData() {
+        return uepList;
     }
 
     public int units() {
@@ -493,7 +546,8 @@ public class StatWindow extends JFrame implements ActionListener, MenuListener,
             jTextArea.setMargin(new Insets(3, 3, 3, 3));
             jTextArea.setEditable(false);
             jTextArea.addKeyListener(this);
-            PreferencesWindow p = ppTrial.getPreferencesWindow();
+            //PreferencesWindow p = 
+            	ppTrial.getPreferencesWindow();
             jTextArea.setFont(ParaProf.preferencesWindow.getFont());
             jTextArea.append(this.getHeaderString());
             jScrollpane.setColumnHeaderView(jTextArea);
