@@ -1,6 +1,12 @@
 package edu.uoregon.tau.paraprof.barchart;
 
-import java.awt.*;
+import java.awt.Color;
+import java.awt.Dimension;
+import java.awt.Font;
+import java.awt.FontMetrics;
+import java.awt.Graphics;
+import java.awt.Graphics2D;
+import java.awt.Rectangle;
 import java.awt.event.MouseEvent;
 import java.awt.event.MouseListener;
 import java.awt.event.MouseMotionListener;
@@ -24,7 +30,12 @@ import edu.uoregon.tau.paraprof.Searcher;
  */
 public class BarChart extends JPanel implements MouseListener, MouseMotionListener, BarChartModelListener {
 
-    private BarChartModel model;
+    /**
+	 * 
+	 */
+	private static final long serialVersionUID = -3802185389413109398L;
+
+	private BarChartModel model;
 
     // internal variables for lazy evaluation
     private int maxRowLabelStringWidth;
@@ -62,9 +73,9 @@ public class BarChart extends JPanel implements MouseListener, MouseMotionListen
     private int rowEnd;
 
     // list of row label draw objects (only the ones on the screen)
-    private ArrayList rowLabelDrawObjects = new ArrayList();
+    private ArrayList<DrawObject> rowLabelDrawObjects = new ArrayList<DrawObject>();
     // list of value label draw objects (only the ones on the screen)
-    private ArrayList valueDrawObjects = new ArrayList();
+    private ArrayList<ArrayList<DrawObject>> valueDrawObjects = new ArrayList<ArrayList<DrawObject>>();
 
     private BarChartPanel panel;
     private Searcher searcher;
@@ -82,6 +93,8 @@ public class BarChart extends JPanel implements MouseListener, MouseMotionListen
 
     // normalized or not
     private boolean normalized = true;
+    
+    
 
     // single line means that the bars go along one line
     // the comparison window is the only one not using singleLine
@@ -172,7 +185,7 @@ public class BarChart extends JPanel implements MouseListener, MouseMotionListen
         // search the row labels
         int size = rowLabelDrawObjects.size();
         for (int i = 0; i < size; i++) {
-            DrawObject drawObject = (DrawObject) rowLabelDrawObjects.get(i);
+            DrawObject drawObject = rowLabelDrawObjects.get(i);
             if (x >= drawObject.getXBeg() && x <= drawObject.getXEnd() && y >= drawObject.getYBeg() && y <= drawObject.getYEnd()) {
                 return model.getRowLabelToolTipText(i + rowStart);
             }
@@ -181,11 +194,11 @@ public class BarChart extends JPanel implements MouseListener, MouseMotionListen
         // search the values
         size = valueDrawObjects.size();
         for (int i = 0; i < size; i++) {
-            ArrayList subList = (ArrayList) valueDrawObjects.get(i);
+            ArrayList<DrawObject> subList = valueDrawObjects.get(i);
 
             int size2 = subList.size();
             for (int j = 0; j < size2; j++) {
-                DrawObject drawObject = (DrawObject) subList.get(j);
+                DrawObject drawObject = subList.get(j);
                 if (drawObject != null) {
                     if (x >= drawObject.getXBeg() && x <= drawObject.getXEnd() && y >= drawObject.getYBeg()
                             && y <= drawObject.getYEnd()) {
@@ -224,7 +237,7 @@ public class BarChart extends JPanel implements MouseListener, MouseMotionListen
         // search the row labels
         int size = rowLabelDrawObjects.size();
         for (int i = 0; i < size; i++) {
-            DrawObject drawObject = (DrawObject) rowLabelDrawObjects.get(i);
+            DrawObject drawObject = rowLabelDrawObjects.get(i);
             if (x >= drawObject.getXBeg() && x <= drawObject.getXEnd() && y >= drawObject.getYBeg() && y <= drawObject.getYEnd()) {
                 model.fireRowLabelClick(i + rowStart, e, this);
                 return;
@@ -234,11 +247,11 @@ public class BarChart extends JPanel implements MouseListener, MouseMotionListen
         // search the values
         size = valueDrawObjects.size();
         for (int i = 0; i < size; i++) {
-            ArrayList subList = (ArrayList) valueDrawObjects.get(i);
+            ArrayList<DrawObject> subList = valueDrawObjects.get(i);
 
             int size2 = subList.size();
             for (int j = 0; j < size2; j++) {
-                DrawObject drawObject = (DrawObject) subList.get(j);
+                DrawObject drawObject = subList.get(j);
                 if (drawObject != null) {
                     if (x >= drawObject.getXBeg() && x <= drawObject.getXEnd() && y >= drawObject.getYBeg()
                             && y <= drawObject.getYEnd()) {
@@ -342,7 +355,7 @@ public class BarChart extends JPanel implements MouseListener, MouseMotionListen
                     maxWidth = leftMargin + getMaxRowLabelStringWidth() + horizSpacing + barLengthMultiple + rightMargin;
                 } else {
                     maxWidth = leftMargin + getMaxRowLabelStringWidth() + horizSpacing + rightMargin;
-                    double otherValues = 0;
+                    //double otherValues = 0;
                     for (int i = 0; i < model.getSubSize(); i++) {
                         int subIndexMaxWidth = (int) (maxSubValues[i] / maxRowSum * barLengthMultiple);
                         if (subIndexMaxWidth >= threshold) {
@@ -475,7 +488,7 @@ public class BarChart extends JPanel implements MouseListener, MouseMotionListen
             String rowLabel = model.getRowLabel(row);
             int rowLabelStringWidth = fontMetrics.stringWidth(rowLabel);
 
-            ArrayList subDrawObjects = new ArrayList();
+            ArrayList<DrawObject> subDrawObjects = new ArrayList<DrawObject>();
             valueDrawObjects.add(subDrawObjects);
 
             String valueLabel = model.getValueLabel(row, 0);
@@ -526,7 +539,7 @@ public class BarChart extends JPanel implements MouseListener, MouseMotionListen
             String rowLabel = model.getRowLabel(row);
             int rowLabelStringWidth = fontMetrics.stringWidth(rowLabel);
 
-            ArrayList subDrawObjects = new ArrayList();
+            ArrayList<DrawObject> subDrawObjects = new ArrayList<DrawObject>();
             valueDrawObjects.add(subDrawObjects);
 
             int barStartX;
@@ -593,10 +606,14 @@ public class BarChart extends JPanel implements MouseListener, MouseMotionListen
                         } else {
                             if (value < 0) { // negative means no value
                                 subDrawObjects.add(null);
-                            } else if (length < threshold) {
-                                subDrawObjects.add(null);
-                                otherValue += value;
-                            } else {
+                            } 
+                            //Disabling this shows a distinct line for every event that exists and gets a column of its own, rather than dividing an event between its own column and 'other'.
+//                            else if (length < threshold) {
+//                                subDrawObjects.add(null);
+//                                otherValue += value;
+//                            } 
+                            
+                            else {
 
                                 if (i == mouseCol) {
                                     color = lighter(color);
@@ -644,7 +661,7 @@ public class BarChart extends JPanel implements MouseListener, MouseMotionListen
             String rowLabel = model.getRowLabel(row);
             int rowLabelStringWidth = fontMetrics.stringWidth(rowLabel);
 
-            ArrayList subDrawObjects = new ArrayList();
+            ArrayList<DrawObject> subDrawObjects = new ArrayList<DrawObject>();
             valueDrawObjects.add(subDrawObjects);
             int barStartX;
             int rowLabelPosition;
@@ -840,7 +857,7 @@ public class BarChart extends JPanel implements MouseListener, MouseMotionListen
     }
 
     private void setSearchLines() {
-        ArrayList searchLines = new ArrayList();
+        ArrayList<String> searchLines = new ArrayList<String>();
         for (int i = 0; i < model.getNumRows(); i++) {
             searchLines.add(model.getRowLabel(i));
         }
@@ -910,6 +927,8 @@ public class BarChart extends JPanel implements MouseListener, MouseMotionListen
         this.normalized = normalized;
         this.preferredSizeSet = false;
     }
+    
+
 
     public boolean getStacked() {
         return stacked;
@@ -953,11 +972,11 @@ public class BarChart extends JPanel implements MouseListener, MouseMotionListen
         // search the values
         size = valueDrawObjects.size();
         for (int i = 0; i < size; i++) {
-            ArrayList subList = (ArrayList) valueDrawObjects.get(i);
+            ArrayList<DrawObject> subList = valueDrawObjects.get(i);
 
             int size2 = subList.size();
             for (int j = 0; j < size2; j++) {
-                DrawObject drawObject = (DrawObject) subList.get(j);
+                DrawObject drawObject = subList.get(j);
                 if (drawObject != null) {
                     int minx = drawObject.getXBeg();
                     int maxx = drawObject.getXEnd();
