@@ -3,12 +3,26 @@ package edu.uoregon.tau.paraprof.barchart;
 import java.awt.Color;
 import java.awt.event.MouseEvent;
 import java.io.File;
-import java.util.*;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.HashMap;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
+import java.util.Vector;
 
 import javax.swing.JComponent;
 import javax.swing.JPopupMenu;
 
-import edu.uoregon.tau.paraprof.*;
+import edu.uoregon.tau.paraprof.DataSorter;
+import edu.uoregon.tau.paraprof.DataSorterWrapper;
+import edu.uoregon.tau.paraprof.FunctionBarChartWindow;
+import edu.uoregon.tau.paraprof.PPFunctionProfile;
+import edu.uoregon.tau.paraprof.ParaProf;
+import edu.uoregon.tau.paraprof.ParaProfApplication;
+import edu.uoregon.tau.paraprof.ParaProfExperiment;
+import edu.uoregon.tau.paraprof.ParaProfTrial;
+import edu.uoregon.tau.paraprof.ParaProfUtils;
 import edu.uoregon.tau.paraprof.enums.SortType;
 import edu.uoregon.tau.paraprof.enums.ValueType;
 import edu.uoregon.tau.perfdmf.Thread;
@@ -23,11 +37,11 @@ import edu.uoregon.tau.perfdmf.UtilFncs;
  */
 public class ComparisonBarChartModel extends AbstractBarChartModel {
 
-    private List ppTrials = new ArrayList();
-    private List threads = new ArrayList();
+    private List<ParaProfTrial> ppTrials = new ArrayList<ParaProfTrial>();
+    private List<Thread> threads = new ArrayList<Thread>();
 
-    private Map rowMap = new HashMap(); // maps function names (Strings) to RowBlobs
-    private List rows = new ArrayList();
+    private Map<String, RowBlob> rowMap = new HashMap<String, RowBlob>(); // maps function names (Strings) to RowBlobs
+    private List<RowBlob> rows = new ArrayList<RowBlob>();
 
     private DataSorter dataSorter;
     private FunctionBarChartWindow window;
@@ -36,8 +50,12 @@ public class ComparisonBarChartModel extends AbstractBarChartModel {
 
     // A RowBlob is the data needed for one row.  If we're comparing trial A to trial B, then
     // a single RowBlob will contain two PPFunctionProfiles, one for each trial.
-    private class RowBlob extends ArrayList implements Comparable {
-        String functionName;
+    private class RowBlob extends ArrayList<PPFunctionProfile> implements Comparable<RowBlob> {
+        /**
+		 * 
+		 */
+		private static final long serialVersionUID = 8555913184400646137L;
+		String functionName;
 
         public RowBlob(String functionName) {
             this.functionName = functionName;
@@ -47,7 +65,7 @@ public class ComparisonBarChartModel extends AbstractBarChartModel {
             return functionName;
         }
 
-        public void add(int index, Object element) {
+        public void add(int index, PPFunctionProfile element) {
 
             while (index >= this.size()) {
                 this.add(null);
@@ -55,7 +73,7 @@ public class ComparisonBarChartModel extends AbstractBarChartModel {
             super.set(index, element);
         }
 
-        public Object get(int index) {
+        public PPFunctionProfile get(int index) {
             if (index >= size()) {
                 return null;
             } else {
@@ -81,7 +99,7 @@ public class ComparisonBarChartModel extends AbstractBarChartModel {
             return (int) (other.getSortMax() - getSortMax());
         }
 
-        public int compareTo(Object arg0) {
+        public int compareTo(RowBlob arg0) {
             if (dataSorter.getDescendingOrder()) {
                 return privateCompare((RowBlob) arg0);
             } else {
@@ -106,8 +124,8 @@ public class ComparisonBarChartModel extends AbstractBarChartModel {
                 }
 
                 public String getLabel(int index) {
-                    ParaProfTrial ppTrial = (ParaProfTrial) ppTrials.get(index);
-                    Thread thread = (Thread) threads.get(index);
+                    ParaProfTrial ppTrial = ppTrials.get(index);
+                    Thread thread = threads.get(index);
                     return ppTrial.getName() + " - " + ParaProfUtils.getThreadLabel(thread);
                 }
 
@@ -128,15 +146,29 @@ public class ComparisonBarChartModel extends AbstractBarChartModel {
 
         rows.clear();
         rowMap.clear();
+        
+        
+        if(threads.get(0).getDataSource().isDerivedProvided())
+        {
+        	for(int i =0; i<threads.size();i++){
+        		Thread t = threads.get(i);
+        		if(t.getThreadID()==-1){
+        			threads.set(i, t.getDataSource().getMeanData());
+        		}
+        		else if(t.getThreadID()==-3){
+        			threads.set(i, t.getDataSource().getStdDevData());
+        		}
+        	}
+        }
 
-        ParaProfTrial selectedTrial = (ParaProfTrial) ppTrials.get(0);
-        Thread selectedThread = (Thread) threads.get(0);
+        ParaProfTrial selectedTrial = ppTrials.get(0);
+        Thread selectedThread = threads.get(0);
 
         dataSorter.setPpTrial(selectedTrial);
         DataSorter newDataSorter = new DataSorterWrapper(dataSorter, selectedTrial);
-        List list = newDataSorter.getFunctionProfiles(selectedThread);
-        for (Iterator it = list.iterator(); it.hasNext();) {
-            PPFunctionProfile ppFunctionProfile = (PPFunctionProfile) it.next();
+        List<PPFunctionProfile> list = newDataSorter.getFunctionProfiles(selectedThread);
+        for (Iterator<PPFunctionProfile> it = list.iterator(); it.hasNext();) {
+            PPFunctionProfile ppFunctionProfile = it.next();
             RowBlob blob = new RowBlob(ppFunctionProfile.getDisplayName());
             rows.add(blob);
             blob.add(ppFunctionProfile);
@@ -145,18 +177,18 @@ public class ComparisonBarChartModel extends AbstractBarChartModel {
 
         // add all the others
         for (int i = 1; i < ppTrials.size(); i++) {
-            ParaProfTrial ppTrial = (ParaProfTrial) ppTrials.get(i);
-            Thread thread = (Thread) threads.get(i);
+            ParaProfTrial ppTrial = ppTrials.get(i);
+            Thread thread = threads.get(i);
 
             // We now use the kludge wrapper so that the metric ids between trials get mapped
             // dataSorter.setPpTrial(ppTrial);
             newDataSorter = new DataSorterWrapper(dataSorter, ppTrial);
             list = newDataSorter.getFunctionProfiles(thread);
 
-            for (Iterator it = list.iterator(); it.hasNext();) {
-                PPFunctionProfile fp = (PPFunctionProfile) it.next();
+            for (Iterator<PPFunctionProfile> it = list.iterator(); it.hasNext();) {
+                PPFunctionProfile fp = it.next();
                 if (ppTrial.displayFunction(fp.getFunction())) {
-                    RowBlob blob = (RowBlob) rowMap.get(fp.getDisplayName());
+                    RowBlob blob = rowMap.get(fp.getDisplayName());
                     if (blob != null) {
                         blob.add(i, fp);
                     } else {
@@ -189,7 +221,7 @@ public class ComparisonBarChartModel extends AbstractBarChartModel {
     }
 
     public double getValue(int row, int subIndex) {
-        RowBlob blob = (RowBlob) rows.get(row);
+        RowBlob blob = rows.get(row);
         PPFunctionProfile ppFp = (PPFunctionProfile) blob.get(subIndex);
         if (ppFp == null) {
             return -1;
@@ -223,14 +255,14 @@ public class ComparisonBarChartModel extends AbstractBarChartModel {
     }
 
     public String getRowLabel(int row) {
-        RowBlob blob = (RowBlob) rows.get(row);
+        RowBlob blob = rows.get(row);
         return blob.getFunctionName();
     }
 
     public Color getValueColor(int row, int subIndex) {
         // we use the "default" colors for our legend and bars
-        List colorList = ParaProf.colorChooser.getColors();
-        return (Color) colorList.get(subIndex % colorList.size());
+        List<Color> colorList = ParaProf.colorChooser.getColors();
+        return colorList.get(subIndex % colorList.size());
     }
 
     public Color getValueHighlightColor(int row, int subIndex) {
@@ -244,9 +276,9 @@ public class ComparisonBarChartModel extends AbstractBarChartModel {
 
     public void fireRowLabelClick(int row, MouseEvent e, JComponent owner) {
         if (ParaProfUtils.rightClick(e)) {
-            RowBlob blob = (RowBlob) rows.get(row);
-            for (Iterator it = blob.iterator(); it.hasNext();) {
-                PPFunctionProfile ppFunctionProfile = (PPFunctionProfile) it.next();
+            RowBlob blob = rows.get(row);
+            for (Iterator<PPFunctionProfile> it = blob.iterator(); it.hasNext();) {
+                PPFunctionProfile ppFunctionProfile = it.next();
                 if (ppFunctionProfile != null) {
                     JPopupMenu popup = ParaProfUtils.createFunctionClickPopUp(ppFunctionProfile.getPPTrial(),
                             ppFunctionProfile.getFunction(), ppFunctionProfile.getThread(), owner);
@@ -301,9 +333,9 @@ public class ComparisonBarChartModel extends AbstractBarChartModel {
 
         ParaProf.paraProfManagerWindow.addTrial(application, experiment, files, type, false, false);
 
-        Vector trials = experiment.getTrials();
+        Vector<ParaProfTrial> trials = experiment.getTrials();
 
-        ParaProfTrial ppTrial = (ParaProfTrial) trials.get(0);
+        ParaProfTrial ppTrial = trials.get(0);
 
         while (ppTrial.loading()) {
             sleep(500);
@@ -320,15 +352,15 @@ public class ComparisonBarChartModel extends AbstractBarChartModel {
         }
     }
 
-    public List getThreads() {
+    public List<Thread> getThreads() {
         return threads;
     }
 
-    public List getPpTrials() {
+    public List<ParaProfTrial> getPpTrials() {
         return ppTrials;
     }
 
-    public void setThreads(List threads) {
+    public void setThreads(List<Thread> threads) {
         this.threads = threads;
     }
 
