@@ -1,13 +1,30 @@
 package edu.uoregon.tau.paraprof.sourceview;
 
-import java.awt.*;
+import java.awt.Component;
+import java.awt.Container;
+import java.awt.Dimension;
+import java.awt.Font;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.io.File;
-import java.util.*;
+import java.io.IOException;
+import java.util.ArrayList;
 import java.util.List;
+import java.util.Map;
+import java.util.TreeMap;
 
-import javax.swing.*;
+import javax.swing.DefaultListModel;
+import javax.swing.JButton;
+import javax.swing.JFileChooser;
+import javax.swing.JFrame;
+import javax.swing.JLabel;
+import javax.swing.JList;
+import javax.swing.JOptionPane;
+import javax.swing.JScrollPane;
+import javax.swing.ListSelectionModel;
 
 import edu.uoregon.tau.paraprof.ParaProfUtils;
 import edu.uoregon.tau.paraprof.WindowPlacer;
@@ -15,40 +32,75 @@ import edu.uoregon.tau.perfdmf.SourceRegion;
 
 public class SourceManager extends JFrame {
 
-    private DefaultListModel listModel;
+    /**
+	 * 
+	 */
+	private static final long serialVersionUID = -2806416317097108083L;
+	private DefaultListModel listModel;
     private JList dirList;
     private SourceRegion toFind;
 
-    private Map sourceViewers = new TreeMap();
+    private Map<File, SourceViewer> sourceViewers = new TreeMap<File, SourceViewer>();
 
-    public ArrayList getCurrentElements() {
-        ArrayList list = new ArrayList();
+    public ArrayList<Object> getCurrentElements() {
+        ArrayList<Object> list = new ArrayList<Object>();
         for (int i = 0; i < listModel.getSize(); i++) {
             list.add(listModel.getElementAt(i));
         }
         return list;
     }
 
-    private boolean match(String s1, String s2) {
+//    private boolean match(String s1, String s2) {
+//        //System.out.println("comparing " + s1 + " to " + s2);
+//        if (s1.equals(s2)) {
+//            return true;
+//        }
+//
+//        return false;
+//    }
+    
+    private boolean matchFiles(String s1, String s2) {
         //System.out.println("comparing " + s1 + " to " + s2);
-        if (s1.equals(s2)) {
-            return true;
-        }
-
+    	
+    	if(s1==null || s2==null)
+    		return false;
+    	
+    	if(s1.equals(s2))
+    		return true;
+    	
+    	File f1=new File(s1);
+    	File f2=new File(s2);
+    	
+    	if(f1.exists()&&f2.exists())
+    	{
+        try {
+			if (f1.getCanonicalFile().equals(f2.getCanonicalFile())) {
+			    return true;
+			}
+		} catch (IOException e) {
+			e.printStackTrace();
+		}
+    	}
         return false;
     }
 
+    private void launchSourceViewer(File sourceFile,SourceRegion region){
+        SourceViewer sourceViewer = sourceViewers.get(sourceFile);
+        if (sourceViewer == null) {
+            sourceViewer = new SourceViewer(sourceFile);
+            sourceViewers.put(sourceFile, sourceViewer);
+        }
+        sourceViewer.highlightRegion(region);
+        sourceViewer.setVisible(true);
+    }
+    
     private boolean searchLocations(SourceRegion region, File[] list, boolean recurse) {
+    	if(list==null)
+    		return false;
         for (int j = 0; j < list.length; j++) {
-            if (match(region.getFilename(), list[j].getName())) {
+            if (matchFiles(region.getFilename(), list[j].getName())) {
                 //System.out.println("found it");
-                SourceViewer sourceViewer = (SourceViewer) sourceViewers.get(list[j]);
-                if (sourceViewer == null) {
-                    sourceViewer = new SourceViewer(list[j]);
-                    sourceViewers.put(list[j], sourceViewer);
-                }
-                sourceViewer.highlightRegion(region);
-                sourceViewer.setVisible(true);
+            	launchSourceViewer(list[j],region);
                 return true;
             }
         }
@@ -70,6 +122,14 @@ public class SourceManager extends JFrame {
 
         String filename = region.getFilename();
 
+        
+        File rfile = new File(filename);
+        if(rfile.exists())
+        {
+        	this.launchSourceViewer(rfile, region);
+        	return;
+        }
+        
         File cwd = new File(".");
 
         if (searchLocations(region, cwd.listFiles(), false)) {
@@ -100,7 +160,7 @@ public class SourceManager extends JFrame {
         }
     }
 
-    public SourceManager(List initialElements) {
+    public SourceManager(List<Object> initialElements) {
 
         Container contentPane = getContentPane();
         contentPane.setLayout(new GridBagLayout());
@@ -113,7 +173,7 @@ public class SourceManager extends JFrame {
         gbc.weighty = 0;
 
         // First add the label.
-        JLabel titleLabel = new JLabel("Current Source Directories (directories are search recursively)");
+        JLabel titleLabel = new JLabel("Current Source Directories (directories are searched recursively)");
         titleLabel.setFont(new Font("SansSerif", Font.PLAIN, 14));
         addCompItem(titleLabel, gbc, 0, 0, 1, 1);
 
@@ -188,11 +248,10 @@ public class SourceManager extends JFrame {
         button.addActionListener(new ActionListener() {
 
             public void actionPerformed(ActionEvent e) {
-                SourceManager.this.setVisible(false);
                 if (toFind != null) {
                     showSourceCode(toFind);
                 }
-
+                SourceManager.this.setVisible(false);
             }
         });
         addCompItem(button, gbc, 1, 3, 1, 1);
