@@ -1,6 +1,14 @@
 package edu.uoregon.tau.paraprof.treetable;
 
-import java.awt.*;
+import java.awt.Color;
+import java.awt.Component;
+import java.awt.Dimension;
+import java.awt.Font;
+import java.awt.FontMetrics;
+import java.awt.Graphics;
+import java.awt.Graphics2D;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
 import java.awt.event.MouseAdapter;
 import java.awt.event.MouseEvent;
 import java.awt.event.MouseListener;
@@ -10,25 +18,35 @@ import java.awt.print.PrinterException;
 import java.util.Observable;
 import java.util.Observer;
 
-import javax.swing.*;
-import javax.swing.event.TreeExpansionEvent;
-import javax.swing.event.TreeExpansionListener;
+import javax.swing.JFrame;
+import javax.swing.JMenuBar;
+import javax.swing.JPopupMenu;
+import javax.swing.JScrollPane;
+import javax.swing.JTable;
+import javax.swing.JTree;
 import javax.swing.table.TableColumn;
 import javax.swing.tree.DefaultTreeCellRenderer;
+import javax.swing.tree.TreePath;
 
 import edu.uoregon.tau.common.ImageExport;
 import edu.uoregon.tau.common.Utility;
 import edu.uoregon.tau.common.treetable.AbstractTreeTableModel;
 import edu.uoregon.tau.common.treetable.JTreeTable;
-import edu.uoregon.tau.paraprof.*;
-import edu.uoregon.tau.paraprof.barchart.BarChart;
+import edu.uoregon.tau.paraprof.ParaProf;
+import edu.uoregon.tau.paraprof.ParaProfTrial;
+import edu.uoregon.tau.paraprof.ParaProfUtils;
+import edu.uoregon.tau.paraprof.WindowPlacer;
 import edu.uoregon.tau.paraprof.interfaces.ParaProfWindow;
-import edu.uoregon.tau.paraprof.interfaces.UnitListener;
 import edu.uoregon.tau.perfdmf.Thread;
+import edu.uoregon.tau.perfdmf.UserEvent;
 
 public class ContextEventWindow extends JFrame implements Observer, ParaProfWindow, Printable, ImageExport {
 
-    private ParaProfTrial ppTrial;
+    /**
+	 * 
+	 */
+	private static final long serialVersionUID = 1234017079628001497L;
+	private ParaProfTrial ppTrial;
     private Thread thread;
 
     private ContextEventModel model;
@@ -63,9 +81,8 @@ public class ContextEventWindow extends JFrame implements Observer, ParaProfWind
             this.setTitle("TAU: ParaProf: Std. Dev. Context Events - "
                     + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()));
         } else {
-            this.setTitle("TAU: ParaProf: Context Events for thread: " + "n,c,t, " + thread.getNodeID() + ","
-                    + thread.getContextID() + "," + thread.getThreadID() + " - "
-                    + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()));
+            this.setTitle("TAU: ParaProf: Context Events for: " + ParaProfUtils.getThreadLabel(thread)+ " - "
+                    + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()));//+ "n,c,t, " +thread.getNodeID() + ","+ thread.getContextID() + "," + thread.getThreadID() +
         }
         ParaProfUtils.setFrameIcon(this);
 
@@ -99,12 +116,39 @@ public class ContextEventWindow extends JFrame implements Observer, ParaProfWind
 
     private void createTreeTable(AbstractTreeTableModel model) {
         treeTable = new JTreeTable(model, true, true);
-
-        final JTree tree = treeTable.getTree();
+        //final JComponent localThis = this;
+       final JTree tree = 
+        	treeTable.getTree();
 
         // Add a mouse listener for this tree.
         MouseListener ml = new MouseAdapter() {
             public void mousePressed(MouseEvent evt) {
+                try {
+                    //int selRow = tree.getRowForLocation(evt.getX(), evt.getY());
+                    TreePath path = tree.getPathForLocation(evt.getX(), evt.getY());
+                    if (path != null) {
+                    	//Object o = path.getLastPathComponent();
+                        ContextEventTreeNode node =  (ContextEventTreeNode) path.getLastPathComponent();
+                        if (ParaProfUtils.rightClick(evt)) {
+                            //JPopupMenu popup;
+                            if (node.getUserEventProfile() != null) {
+                                //popup = 
+                                		ParaProfUtils.handleUserEventClick(ppTrial, node.getUserEventProfile().getUserEvent(), treeTable, evt);
+                                		//.createFunctionClickPopUp(node.getModel().getPPTrial(),node.getFunctionProfile().getFunction(), getThread(), treeTable);
+                               // popup.show(treeTable, evt.getX(), evt.getY());
+                            } else {
+                                //popup = new JPopupMenu();
+                            }
+                        }
+                    }
+                } catch (Exception e) {
+                    ParaProfUtils.handleException(e);
+                }
+            	
+            	
+            	
+            	
+            	
             //                try {
             //                    int selRow = tree.getRowForLocation(evt.getX(), evt.getY());
             //                    TreePath path = tree.getPathForLocation(evt.getX(), evt.getY());
@@ -131,7 +175,12 @@ public class ContextEventWindow extends JFrame implements Observer, ParaProfWind
 
         DefaultTreeCellRenderer renderer = new DefaultTreeCellRenderer() {
 
-            public Component getTreeCellRendererComponent(JTree tree, Object value, boolean selected, boolean expanded,
+            /**
+			 * 
+			 */
+			private static final long serialVersionUID = 2780103869814842355L;
+
+			public Component getTreeCellRendererComponent(JTree tree, Object value, boolean selected, boolean expanded,
                     boolean leaf, int row, boolean hasFocus) {
                 super.getTreeCellRendererComponent(tree, value, selected, expanded, leaf, row, hasFocus);
 
@@ -162,7 +211,7 @@ public class ContextEventWindow extends JFrame implements Observer, ParaProfWind
 
         TableColumn col = treeTable.getColumnModel().getColumn(0);
 
-        int nameWidth = 500;
+        int nameWidth = 450;
 
         col.setPreferredWidth(nameWidth);
 
@@ -240,6 +289,12 @@ public class ContextEventWindow extends JFrame implements Observer, ParaProfWind
     }
 
     public void update(Observable o, Object arg) {
+    	
+    	if(thread.getNodeID()>=0){
+    		this.setTitle("TAU: ParaProf: Context Events for: " + ParaProfUtils.getThreadLabel(thread)+ " - "
+                    + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()));
+    	}
+    	
         treeTable.repaint();
         //setupData();
     }
