@@ -1,14 +1,39 @@
 package edu.uoregon.tau.paraprof.treetable;
 
-import java.awt.*;
-import java.awt.event.*;
+import java.awt.Component;
+import java.awt.Dimension;
+import java.awt.Font;
+import java.awt.FontMetrics;
+import java.awt.Graphics;
+import java.awt.Graphics2D;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.event.ActionEvent;
+import java.awt.event.ActionListener;
+import java.awt.event.MouseAdapter;
+import java.awt.event.MouseEvent;
+import java.awt.event.MouseListener;
 import java.awt.print.PageFormat;
 import java.awt.print.Printable;
 import java.awt.print.PrinterException;
-import java.util.*;
+import java.util.ArrayList;
 import java.util.List;
+import java.util.Observable;
+import java.util.Observer;
 
-import javax.swing.*;
+import javax.swing.ButtonGroup;
+import javax.swing.JCheckBoxMenuItem;
+import javax.swing.JComboBox;
+import javax.swing.JFrame;
+import javax.swing.JMenu;
+import javax.swing.JMenuBar;
+import javax.swing.JMenuItem;
+import javax.swing.JPopupMenu;
+import javax.swing.JRadioButtonMenuItem;
+import javax.swing.JScrollPane;
+import javax.swing.JTable;
+import javax.swing.JTree;
+import javax.swing.ListModel;
 import javax.swing.event.TableModelEvent;
 import javax.swing.event.TreeExpansionEvent;
 import javax.swing.event.TreeExpansionListener;
@@ -19,11 +44,25 @@ import javax.swing.tree.TreePath;
 import edu.uoregon.tau.common.ImageExport;
 import edu.uoregon.tau.common.treetable.AbstractTreeTableModel;
 import edu.uoregon.tau.common.treetable.JTreeTable;
-import edu.uoregon.tau.paraprof.*;
+import edu.uoregon.tau.paraprof.ColorBar;
+import edu.uoregon.tau.paraprof.ParaProf;
+import edu.uoregon.tau.paraprof.ParaProfTrial;
+import edu.uoregon.tau.paraprof.ParaProfUtils;
+import edu.uoregon.tau.paraprof.WindowPlacer;
 import edu.uoregon.tau.paraprof.interfaces.ParaProfWindow;
 import edu.uoregon.tau.paraprof.interfaces.UnitListener;
 import edu.uoregon.tau.paraprof.treetable.ColumnChooser.CheckBoxListItem;
-import edu.uoregon.tau.paraprof.treetable.TreeTableColumn.*;
+import edu.uoregon.tau.paraprof.treetable.TreeTableColumn.ExclusiveColumn;
+import edu.uoregon.tau.paraprof.treetable.TreeTableColumn.ExclusivePerCallColumn;
+import edu.uoregon.tau.paraprof.treetable.TreeTableColumn.ExclusivePercentColumn;
+import edu.uoregon.tau.paraprof.treetable.TreeTableColumn.InclusiveColumn;
+import edu.uoregon.tau.paraprof.treetable.TreeTableColumn.InclusivePerCallColumn;
+import edu.uoregon.tau.paraprof.treetable.TreeTableColumn.InclusivePercentColumn;
+import edu.uoregon.tau.paraprof.treetable.TreeTableColumn.NumCallsColumn;
+import edu.uoregon.tau.paraprof.treetable.TreeTableColumn.NumSubrColumn;
+import edu.uoregon.tau.paraprof.treetable.TreeTableColumn.RegularMetricColumn;
+import edu.uoregon.tau.paraprof.treetable.TreeTableColumn.RegularPerCallMetricColumn;
+import edu.uoregon.tau.paraprof.treetable.TreeTableColumn.RegularPercentMetricColumn;
 import edu.uoregon.tau.perfdmf.Thread;
 
 /**
@@ -33,22 +72,28 @@ import edu.uoregon.tau.perfdmf.Thread;
  *    
  * TODO : ...
  *
- * <P>CVS $Id: TreeTableWindow.java,v 1.17 2009/10/26 20:17:23 amorris Exp $</P>
+ * <P>CVS $Id: TreeTableWindow.java,v 1.18 2010/03/16 02:16:28 amorris Exp $</P>
  * @author  Alan Morris
- * @version $Revision: 1.17 $
+ * @version $Revision: 1.18 $
  */
 public class TreeTableWindow extends JFrame implements TreeExpansionListener, Observer, ParaProfWindow, Printable, UnitListener,
         ImageExport {
 
-    private ParaProfTrial ppTrial;
+    /**
+	 * 
+	 */
+	private static final long serialVersionUID = 4726597182083786681L;
+	private ParaProfTrial ppTrial;
     private Thread thread;
 
     private CallPathModel model;
     private JTreeTable treeTable;
     private int colorMetricID;
     private int units = ParaProf.preferences.getUnits();
+    private int decimals = -1; // -1 = auto, -2 = full
 
-    private List columns;
+
+    private List<TreeTableColumn> columns;
     private ColumnChooser columnChooser;
 
     private final JMenuItem showAsTreeMenuItem = new JCheckBoxMenuItem("Show as Call Tree");
@@ -87,9 +132,8 @@ public class TreeTableWindow extends JFrame implements TreeExpansionListener, Ob
             this.setTitle("TAU: ParaProf: Std. Dev. Statistics - "
                     + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()));
         } else {
-            this.setTitle("TAU: ParaProf: Thread Statistics: " + "n,c,t, " + thread.getNodeID() + "," + thread.getContextID()
-                    + "," + thread.getThreadID() + " - "
-                    + ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()));
+            this.setTitle("TAU: ParaProf: Statistics for: " + ParaProfUtils.getThreadLabel(thread) //"n,c,t, " + thread.getNodeID() + "," + thread.getContextID()  + "," + thread.getThreadID() 
+            		+ " - "+ ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()));
         }
         ParaProfUtils.setFrameIcon(this);
 
@@ -112,13 +156,13 @@ public class TreeTableWindow extends JFrame implements TreeExpansionListener, Ob
 
         // reset the cell rendereres
         for (int i = 0; i < columns.size(); i++) {
-            treeTable.setDefaultRenderer(columns.get(i).getClass(), ((TreeTableColumn) columns.get(i)).getCellRenderer());
+            treeTable.setDefaultRenderer(columns.get(i).getClass(), columns.get(i).getCellRenderer());
         }
     }
 
     // get the chosen columns from the columnChooser and setup the 'columns' List
     private void setColumns() {
-        columns = new ArrayList();
+        columns = new ArrayList<TreeTableColumn>();
 
         ListModel metricModel = columnChooser.getMetricModel();
         ListModel valueModel = columnChooser.getValueModel();
@@ -237,7 +281,7 @@ public class TreeTableWindow extends JFrame implements TreeExpansionListener, Ob
         scrollPane = new JScrollPane(treeTable);
 
         for (int i = 0; i < columns.size(); i++) {
-            treeTable.setDefaultRenderer(columns.get(i).getClass(), ((TreeTableColumn) columns.get(i)).getCellRenderer());
+            treeTable.setDefaultRenderer(columns.get(i).getClass(), columns.get(i).getCellRenderer());
         }
 
         gbc.fill = GridBagConstraints.BOTH;
@@ -268,6 +312,58 @@ public class TreeTableWindow extends JFrame implements TreeExpansionListener, Ob
         getContentPane().add(c, gbc);
     }
 
+    private void helperAddButton(JMenu menu, ActionListener actionListener, ButtonGroup group, String value, boolean selected) {
+        JRadioButtonMenuItem button = new JRadioButtonMenuItem(value, selected);
+        button.addActionListener(actionListener);
+        group.add(button);
+        menu.add(button);
+    }
+
+    private JMenu createDecimalMenu() {
+
+        ActionListener actionListener = new ActionListener() {
+
+            public void actionPerformed(ActionEvent evt) {
+                try {
+
+                    String arg = evt.getActionCommand();
+                    if (arg.equals("auto")) {
+                        decimals = -1;
+                    } else if (arg.equals("display full numbers")) {
+                        decimals = -2;
+                    } else if (arg.equals("0 decimal places")) {
+                        decimals = 0;
+                    } else if (arg.equals("1 decimal places")) {
+                        decimals = 1;
+                    } else if (arg.equals("2 decimal places")) {
+                        decimals = 2;
+                    } else if (arg.equals("3 decimal places")) {
+                        decimals = 3;
+                    } else if (arg.equals("4 decimal places")) {
+                        decimals = 4;
+                    }
+                    treeTable.forceRedraw();
+
+                } catch (Exception e) {
+                    ParaProfUtils.handleException(e);
+                }
+            }
+        };
+
+        JMenu decimalSubMenu = new JMenu("Select Precision...");
+        ButtonGroup group = new ButtonGroup();
+
+        helperAddButton(decimalSubMenu, actionListener, group, "auto", true);
+        helperAddButton(decimalSubMenu, actionListener, group, "0 decimal places", false);
+        helperAddButton(decimalSubMenu, actionListener, group, "1 decimal places", false);
+        helperAddButton(decimalSubMenu, actionListener, group, "2 decimal places", false);
+        helperAddButton(decimalSubMenu, actionListener, group, "3 decimal places", false);
+        helperAddButton(decimalSubMenu, actionListener, group, "4 decimal places", false);
+        helperAddButton(decimalSubMenu, actionListener, group, "display full numbers", false);
+
+        return decimalSubMenu;
+    }
+
     private void setupMenus() {
 
         JMenuBar mainMenu = new JMenuBar();
@@ -310,6 +406,8 @@ public class TreeTableWindow extends JFrame implements TreeExpansionListener, Ob
         JMenu unitsSubMenu = ParaProfUtils.createUnitsMenu(this, units, false);
         optionsMenu.add(unitsSubMenu);
 
+        optionsMenu.add(createDecimalMenu());
+
         JMenuItem menuItem = new JMenuItem("Choose Columns...");
         menuItem.addActionListener(new ActionListener() {
 
@@ -346,7 +444,7 @@ public class TreeTableWindow extends JFrame implements TreeExpansionListener, Ob
         MouseListener ml = new MouseAdapter() {
             public void mousePressed(MouseEvent evt) {
                 try {
-                    int selRow = tree.getRowForLocation(evt.getX(), evt.getY());
+                    //int selRow = tree.getRowForLocation(evt.getX(), evt.getY());
                     TreePath path = tree.getPathForLocation(evt.getX(), evt.getY());
                     if (path != null) {
                         TreeTableNode node = (TreeTableNode) path.getLastPathComponent();
@@ -415,6 +513,9 @@ public class TreeTableWindow extends JFrame implements TreeExpansionListener, Ob
     }
 
     public void update(Observable o, Object arg) {
+    	if(thread.getNodeID()>=0){
+    		this.setTitle("TAU: ParaProf: Statistics for: " + ParaProfUtils.getThreadLabel(thread) + " - "+ ppTrial.getTrialIdentifier(ParaProf.preferences.getShowPathTitleInReverse()));
+    	}
         setupData();
     }
 
@@ -475,7 +576,7 @@ public class TreeTableWindow extends JFrame implements TreeExpansionListener, Ob
         return units;
     }
 
-    public List getColumns() {
+    public List<TreeTableColumn> getColumns() {
         return columns;
     }
 
@@ -514,4 +615,13 @@ public class TreeTableWindow extends JFrame implements TreeExpansionListener, Ob
     public JFrame getFrame() {
         return this;
     }
+    
+
+    public int getDecimals() {
+        return decimals;
+    }
+
+    public void setDecimals(int decimals) {
+        this.decimals = decimals;
+    }
 }
