@@ -20,12 +20,16 @@ import java.util.List;
  *
  * TODO ...
  */
-public class Function implements Serializable, Comparable {
+public class Function implements Serializable, Comparable<Function> {
 
-    private String name = null;
-    private String reversedName = null;
+    /**
+	 * 
+	 */
+	private static final long serialVersionUID = 362090098221172924L;
+	private String name;
+    private String reversedName;
     private int id = -1;
-    private List groups = new ArrayList();
+    private List<Group> groups = new ArrayList<Group>();
     private boolean phase = false;
     private Function actualPhase;
     private Function parentPhase;
@@ -38,6 +42,8 @@ public class Function implements Serializable, Comparable {
     private FunctionProfile meanProfile;
     private FunctionProfile stddevProfile;
     private FunctionProfile totalProfile;
+    private FunctionProfile minProfile;
+    private FunctionProfile maxProfile;
 
     // color settings
     private boolean colorFlag = false;
@@ -62,6 +68,7 @@ public class Function implements Serializable, Comparable {
 
     public void setName(String name) {
         this.name = name;
+        this.reversedName = null;
     }
 
     /**
@@ -105,7 +112,7 @@ public class Function implements Serializable, Comparable {
 
     public SourceRegion getSourceLink() {
         if (this.sourceLink == null) {
-            if (isGroupMember("TAU_CALLPATH_DERIVED")) {
+            if (isCallPathFunction(name)){//(isGroupMember("TAU_CALLPATH_DERIVED")) {
                 this.sourceLink = getSourceLink(UtilFncs.getLeftSide(name));
             } else {
                 this.sourceLink = getSourceLink(this.name);
@@ -248,14 +255,14 @@ public class Function implements Serializable, Comparable {
         return groups.contains(group);
     }
 
-    public List getGroups() {
+    public List<Group> getGroups() {
         return groups;
     }
 
     public String getGroupString() {
         String groupString = "";
         for (int i = 0; i < groups.size(); i++) {
-            Group group = (Group) groups.get(i);
+            Group group = groups.get(i);
             if (i == 0) {
                 groupString = group.getName();
             } else {
@@ -290,8 +297,8 @@ public class Function implements Serializable, Comparable {
     }
 
     public boolean isGroupMember(String groupName) {
-        for (Iterator it = this.groups.iterator(); it.hasNext();) {
-            Group group = (Group) it.next();
+        for (Iterator<Group> it = this.groups.iterator(); it.hasNext();) {
+            Group group = it.next();
             if (group.getName().equals(groupName)) {
                 return true;
             }
@@ -456,8 +463,23 @@ public class Function implements Serializable, Comparable {
         return totalProfile;
     }
 
-    public int compareTo(Object o) {
-        return this.id - ((Function) o).getID();
+    
+    public FunctionProfile getMinProfile(){
+    	return minProfile;
+    }
+    public void setMinProfile(FunctionProfile fp) {
+        this.minProfile = fp;
+    }
+    
+    public FunctionProfile getMaxProfile(){
+    	return maxProfile;
+    }
+    public void setMaxProfile(FunctionProfile fp) {
+        this.maxProfile = fp;
+    }
+    
+    public int compareTo(Function o) {
+        return this.id -  o.getID();
     }
 
     public boolean isPhase() {
