@@ -1,6 +1,10 @@
 package edu.uoregon.tau.perfdmf;
 
-import java.util.*;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.Iterator;
+import java.util.Map;
+import java.util.Set;
 
 /**
  * This class represents a single function profile on a single thread.
@@ -15,10 +19,10 @@ public class FunctionProfile {
     // this is a private static class to save memory when callpath data is not needed
     // we need only one empty pointer instead of four
     private static class CallPathData {
-        public Set childProfiles;
-        public Set parentProfiles;
-        public Map childProfileCallPathSets;
-        public Map parentProfileCallPathSets;
+        public Set<FunctionProfile> childProfiles;
+        public Set<FunctionProfile> parentProfiles;
+        public Map<FunctionProfile, Set<FunctionProfile>> childProfileCallPathSets;
+        public Map<FunctionProfile, Set<FunctionProfile>> parentProfileCallPathSets;
     }
 
     private static final int METRIC_SIZE = 2;
@@ -100,7 +104,7 @@ public class FunctionProfile {
                 return 0;
             }
             return getInclusive(snapshot, metric) / dividend;
-        } else if (thread.getNodeID() == Thread.TOTAL || thread.getNodeID() == Thread.MEAN) {
+        } else if (thread.getNodeID() == Thread.TOTAL || thread.getNodeID() == Thread.MEAN|| thread.getNodeID() == Thread.MIN|| thread.getNodeID() == Thread.MAX) {
             double dividend = thread.getPercentDivider(metric, snapshot);
             if (dividend == 0) {
                 return 0;
@@ -128,14 +132,21 @@ public class FunctionProfile {
                 return 0;
             }
             return getExclusive(snapshot, metric) / dividend;
-        } else if (thread.getNodeID() == Thread.TOTAL || thread.getNodeID() == Thread.MEAN) {
+        } else if (thread.getNodeID() == Thread.TOTAL || thread.getNodeID() == Thread.MEAN || thread.getNodeID() == Thread.MIN || thread.getNodeID() == Thread.MAX) {
             double dividend = thread.getPercentDivider(metric, snapshot);
             if (dividend == 0) {
                 return 0;
             }
             if (thread.getNodeID() == Thread.TOTAL) {
                 return function.getTotalProfile().getExclusive(snapshot, metric) / dividend;
-            } else {
+            } 
+            else if(thread.getNodeID()==Thread.MIN){
+            	 return function.getMinProfile().getExclusive(snapshot, metric) / dividend;
+            }
+            else if(thread.getNodeID()==Thread.MAX){
+            	 return function.getMaxProfile().getExclusive(snapshot, metric) / dividend;
+            }
+            else {
                 dividend /= thread.getDataSource().getAllThreads().size();
                 return function.getMeanProfile().getExclusive(snapshot, metric) / dividend;
             }
@@ -262,17 +273,17 @@ public class FunctionProfile {
         CallPathData callPathData = getCallPathData();
 
         if (callPathData.childProfiles == null)
-            callPathData.childProfiles = new HashSet();
+            callPathData.childProfiles = new HashSet<FunctionProfile>();
         callPathData.childProfiles.add(child);
 
         if (callPathData.childProfileCallPathSets == null)
-            callPathData.childProfileCallPathSets = new HashMap();
+            callPathData.childProfileCallPathSets = new HashMap<FunctionProfile, Set<FunctionProfile>>();
 
         // we maintain a set of callpaths for each child, retrieve the set for this child
-        Set callPathSet = (Set) callPathData.childProfileCallPathSets.get(child);
+        Set<FunctionProfile> callPathSet = callPathData.childProfileCallPathSets.get(child);
 
         if (callPathSet == null) {
-            callPathSet = new HashSet();
+            callPathSet = new HashSet<FunctionProfile>();
             callPathData.childProfileCallPathSets.put(child, callPathSet);
         }
 
@@ -288,49 +299,49 @@ public class FunctionProfile {
         CallPathData callPathData = getCallPathData();
 
         if (callPathData.parentProfiles == null)
-            callPathData.parentProfiles = new HashSet();
+            callPathData.parentProfiles = new HashSet<FunctionProfile>();
         callPathData.parentProfiles.add(parent);
 
         if (callPathData.parentProfileCallPathSets == null)
-            callPathData.parentProfileCallPathSets = new HashMap();
+            callPathData.parentProfileCallPathSets = new HashMap<FunctionProfile, Set<FunctionProfile>>();
 
         // we maintain a set of callpaths for each child, retrieve the set for this child
-        Set callPathSet = (Set) callPathData.parentProfileCallPathSets.get(parent);
+        Set<FunctionProfile> callPathSet = callPathData.parentProfileCallPathSets.get(parent);
 
         if (callPathSet == null) {
-            callPathSet = new HashSet();
+            callPathSet = new HashSet<FunctionProfile>();
             callPathData.parentProfileCallPathSets.put(parent, callPathSet);
         }
 
         callPathSet.add(callpath);
     }
 
-    public Iterator getChildProfiles() {
+    public Iterator<FunctionProfile> getChildProfiles() {
         CallPathData callPathData = getCallPathData();
         if (callPathData.childProfiles != null)
             return callPathData.childProfiles.iterator();
         return new UtilFncs.EmptyIterator();
     }
 
-    public Iterator getParentProfiles() {
+    public Iterator<FunctionProfile> getParentProfiles() {
         CallPathData callPathData = getCallPathData();
         if (callPathData.parentProfiles != null)
             return callPathData.parentProfiles.iterator();
         return new UtilFncs.EmptyIterator();
     }
 
-    public Iterator getParentProfileCallPathIterator(FunctionProfile parent) {
+    public Iterator<FunctionProfile> getParentProfileCallPathIterator(FunctionProfile parent) {
         CallPathData callPathData = getCallPathData();
         if (callPathData.parentProfileCallPathSets == null)
             return new UtilFncs.EmptyIterator();
-        return ((Set) callPathData.parentProfileCallPathSets.get(parent)).iterator();
+        return callPathData.parentProfileCallPathSets.get(parent).iterator();
     }
 
-    public Iterator getChildProfileCallPathIterator(FunctionProfile child) {
+    public Iterator<FunctionProfile> getChildProfileCallPathIterator(FunctionProfile child) {
         CallPathData callPathData = getCallPathData();
         if (callPathData.childProfileCallPathSets == null)
             return new UtilFncs.EmptyIterator();
-        return ((Set) callPathData.childProfileCallPathSets.get(child)).iterator();
+        return callPathData.childProfileCallPathSets.get(child).iterator();
     }
 
     /**
