@@ -16,11 +16,18 @@
 
 package edu.uoregon.tau.perfdmf;
 
-import java.io.*;
-import java.lang.reflect.Method;
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.FileNotFoundException;
+import java.io.IOException;
+import java.io.InputStreamReader;
 import java.nio.channels.FileChannel;
 import java.nio.channels.FileLock;
-import java.util.*;
+import java.util.ArrayList;
+import java.util.Iterator;
+import java.util.List;
+import java.util.NoSuchElementException;
+import java.util.StringTokenizer;
 
 import edu.uoregon.tau.common.LineCountBufferedReader;
 import edu.uoregon.tau.common.Utility;
@@ -28,7 +35,11 @@ import edu.uoregon.tau.common.Utility;
 public class TauDataSource extends DataSource {
 
     public class CorruptFileException extends RuntimeException {
-        private String message;
+        /**
+		 * 
+		 */
+		private static final long serialVersionUID = 3505483745617386975L;
+		private String message;
 
         public CorruptFileException(String message) {
             this.message = message;
@@ -44,28 +55,29 @@ public class TauDataSource extends DataSource {
     private volatile int filesRead = 0;
     private boolean profileStatsPresent = false;
     private boolean groupCheck = false;
-    private List dirs; // list of directories (e.g. MULTI__PAPI_FP_INS, MULTI__PAPI_L1_DCM)
-    private int currFunction = 0;
+    private List<File[]> dirs; // list of directories (e.g. MULTI__PAPI_FP_INS, MULTI__PAPI_L1_DCM)
+    //private int currFunction = 0;
 
     private File fileToMonitor;
 
     private File currentFile;
-    private int currentLine;
+    //private int currentLine;
 
     private LineCountBufferedReader br;
 
-    public TauDataSource(List dirs) {
+    @SuppressWarnings("unchecked")
+	public TauDataSource(List<?> dirs) {
         super();
-        this.dirs = dirs;
 
         if (dirs.size() > 0) {
             if (dirs.get(0) instanceof File[]) {
-                File[] files = (File[]) dirs.get(0);
+            	this.dirs=(List<File[]>)dirs;
+                File[] files = (File[])dirs.get(0);
                 if (files.length > 0) {
                     fileToMonitor = files[0];
                 }
             } else {
-                this.dirs = new ArrayList();
+                this.dirs = new ArrayList<File[]>();
                 File[] files = new File[1];
                 files[0] = (File) dirs.get(0);
                 this.dirs.add(files);
@@ -86,8 +98,8 @@ public class TauDataSource extends DataSource {
         return 0;
     }
 
-    public List getFiles() {
-        List list = new ArrayList();
+    public List<File> getFiles() {
+        List<File> list = new ArrayList<File>();
         list.add(fileToMonitor);
         return list;
     }
@@ -97,15 +109,16 @@ public class TauDataSource extends DataSource {
 
         boolean modernJava = false;
         try {
-            Method m = FileInputStream.class.getMethod("getChannel", (Class[]) null);
+            //Method m = 
+            	FileInputStream.class.getMethod("getChannel", (Class[]) null);
             modernJava = true;
         } catch (NoSuchMethodException nsme) {
             // way to go java 1.3
         }
 
         // first count the files (for progressbar)
-        for (Iterator e = dirs.iterator(); e.hasNext();) {
-            File[] files = (File[]) e.next();
+        for (Iterator<File[]> e = dirs.iterator(); e.hasNext();) {
+            File[] files = e.next();
             for (int i = 0; i < files.length; i++) {
                 totalFiles++;
             }
@@ -131,8 +144,8 @@ public class TauDataSource extends DataSource {
         StringTokenizer genericTokenizer;
 
         // iterate through the vector of File arrays (each directory)
-        for (Iterator e = dirs.iterator(); e.hasNext();) {
-            File[] files = (File[]) e.next();
+        for (Iterator<File[]> e = dirs.iterator(); e.hasNext();) {
+            File[] files = e.next();
 
             //Reset metricNameProcessed flag.
             metricNameProcessed = false;
@@ -179,7 +192,7 @@ public class TauDataSource extends DataSource {
 
                         FileInputStream fileIn = new FileInputStream(files[i]);
                         currentFile = files[i];
-                        currentLine = 0;
+                        //currentLine = 0;
                         FileChannel channel;
                         FileLock lock = null;
 
@@ -261,7 +274,7 @@ public class TauDataSource extends DataSource {
                             }
 
                             for (int j = 0; j < numFunctions; j++) {
-                                this.currFunction = j;
+                                //this.currFunction = j;
 
                                 inputString = br.readLine();
                                 if (inputString == null) {
@@ -337,7 +350,8 @@ public class TauDataSource extends DataSource {
                             fileIn.close();
 
                         } catch (Exception e2) {
-                            throw new CorruptFileException("Error parsing file (" + e2.getMessage() + ")");
+                            e2.printStackTrace();
+                            throw new CorruptFileException("Error parsing file (" + e2 + ")");
                         }
 
                         finished = true;
@@ -371,8 +385,8 @@ public class TauDataSource extends DataSource {
                             finished = true;
                         } else {
                             if (thread != null) {
-                                for (Iterator it2 = thread.getFunctionProfileIterator(); it2.hasNext();) {
-                                    FunctionProfile fp = (FunctionProfile) it2.next();
+                                for (Iterator<FunctionProfile> it2 = thread.getFunctionProfileIterator(); it2.hasNext();) {
+                                    FunctionProfile fp = it2.next();
                                     if (fp != null) {
                                         for (int m = 0; m < this.getNumberOfMetrics(); m++) {
                                             fp.setExclusive(m, 0);
@@ -398,7 +412,7 @@ public class TauDataSource extends DataSource {
                     "Didn't find any valid files.\nAre you sure these are TAU profiles? (e.g. profile.*.*.*)");
         }
 
-        long thistime = (System.currentTimeMillis()) - time;
+        //long thistime = (System.currentTimeMillis()) - time;
         //System.out.println("Time to process (in milliseconds): " + thistime);
         //System.out.print(thistime + ", ");
 
@@ -470,8 +484,8 @@ public class TauDataSource extends DataSource {
         double numsubr;
         double exclusive;
         double inclusive;
-        double profileCalls;
-        double sumExclSqr;
+        //double profileCalls;
+        //double sumExclSqr;
 
         String groupNames = this.getGroupNames(string);
 
@@ -518,10 +532,10 @@ public class TauDataSource extends DataSource {
         exclusive = Double.parseDouble(st2.nextToken()); //Exclusive
         inclusive = Double.parseDouble(st2.nextToken()); //Inclusive
         if (this.getProfileStatsPresent()) {
-            sumExclSqr = Double.parseDouble(st2.nextToken()); //SumExclSqr
+            //sumExclSqr = Double.parseDouble(st2.nextToken()); //SumExclSqr
         }
 
-        profileCalls = Integer.parseInt(st2.nextToken()); //ProfileCalls
+        //profileCalls = Integer.parseInt(st2.nextToken()); //ProfileCalls
 
         if (inclusive < 0) {
             System.err.println("File '" + currentFile + "' is corrupt (at line " + br.getCurrentLine()
@@ -534,7 +548,7 @@ public class TauDataSource extends DataSource {
             exclusive = 0;
         }
 
-        if (numcalls != 0) {
+        //if (numcalls != 0) {
             Function func = this.addFunction(name, 1);
 
             FunctionProfile functionProfile = thread.getFunctionProfile(func);
@@ -556,7 +570,7 @@ public class TauDataSource extends DataSource {
             if (metric == 0) {
                 addGroups(groupNames, func);
             }
-        }
+        //}
     }
 
     private String getGroupNames(String string) {
@@ -650,7 +664,7 @@ public class TauDataSource extends DataSource {
         sampleMean = Double.parseDouble(st2.nextToken()); //Mean
         sampleSumSquared = Double.parseDouble(st2.nextToken()); //Standard Deviation
 
-        if (numSamples != 0) {
+        //if (numSamples != 0) {
             UserEvent userEvent = this.addUserEvent(name);
             UserEventProfile userEventProfile = thread.getUserEventProfile(userEvent);
 
@@ -680,7 +694,7 @@ public class TauDataSource extends DataSource {
                 userEventProfile.setSumSquared(sampleSumSquared + userEventProfile.getSumSquared());
                 userEventProfile.updateMax();
             }
-        }
+        //}
     }
 
     protected void setProfileStatsPresent(boolean profileStatsPresent) {
