@@ -9,31 +9,33 @@ import edu.uoregon.tau.common.TauRuntimeException;
  * UserEventProfiles as well as maximum data (e.g. max exclusive value for all functions on 
  * this thread). 
  *  
- * <P>CVS $Id: Thread.java,v 1.17 2009/04/10 21:10:26 amorris Exp $</P>
+ * <P>CVS $Id: Thread.java,v 1.19 2010/05/14 19:42:18 amorris Exp $</P>
  * @author	Robert Bell, Alan Morris
- * @version	$Revision: 1.17 $
+ * @version	$Revision: 1.19 $
  * @see		Node
  * @see		Context
  * @see		FunctionProfile
  * @see		UserEventProfile
  */
-public class Thread implements Comparable {
+public class Thread implements Comparable<Thread> {
 
     private int nodeID, contextID, threadID;
-    private List functionProfiles = new ArrayList();
-    private Map userEventProfiles = new HashMap();
+    private List<FunctionProfile> functionProfiles = new ArrayList<FunctionProfile>();
+    private Map<Integer, UserEventProfile> userEventProfiles = new HashMap<Integer, UserEventProfile>();
     private boolean trimmed;
     private boolean relationsBuilt;
     private int numMetrics;
 
-    private Hashtable foo = new Hashtable();
+    //private Hashtable foo = new Hashtable();
     
     public static final int MEAN = -1;
     public static final int TOTAL = -2;
     public static final int STDDEV = -3;
+    public static final int MIN = -4;
+    public static final int MAX = -5;
 
-    private List snapshots = new ArrayList();
-    private Map metaData = new TreeMap();
+    private List<Snapshot> snapshots = new ArrayList<Snapshot>();
+    private Map<String,String> metaData = new TreeMap<String,String>();
 
     private boolean firstSnapshotFound;
 
@@ -87,6 +89,12 @@ public class Thread implements Comparable {
         if (nodeID == -3) {
             return "Standard Deviation";
         }
+        if (nodeID == -4) {
+            return "Min";
+        }
+        if (nodeID == -5) {
+            return "Max";
+        }
         return "n,c,t " + nodeID + "," + contextID + "," + threadID;
     }
 
@@ -111,8 +119,8 @@ public class Thread implements Comparable {
 
         recreateData();
 
-        for (Iterator it = getFunctionProfiles().iterator(); it.hasNext();) {
-            FunctionProfile fp = (FunctionProfile) it.next();
+        for (Iterator<FunctionProfile> it = getFunctionProfiles().iterator(); it.hasNext();) {
+            FunctionProfile fp = it.next();
             if (fp != null) { // fp == null would mean this thread didn't call this function
                 fp.addMetric();
             }
@@ -122,7 +130,7 @@ public class Thread implements Comparable {
     public Snapshot addSnapshot(String name) {
         if (!firstSnapshotFound) {
             firstSnapshotFound = true;
-            Snapshot snapshot = (Snapshot) snapshots.get(0);
+            Snapshot snapshot = snapshots.get(0);
             snapshot.setName(name);
             return snapshot;
         }
@@ -130,14 +138,14 @@ public class Thread implements Comparable {
         snapshots.add(snapshot);
 
         if (snapshots.size() > 1) {
-            for (Iterator e6 = functionProfiles.iterator(); e6.hasNext();) {
-                FunctionProfile fp = (FunctionProfile) e6.next();
+            for (Iterator<FunctionProfile> e6 = functionProfiles.iterator(); e6.hasNext();) {
+                FunctionProfile fp = e6.next();
                 if (fp != null) { // fp == null would mean this thread didn't call this function
                     fp.addSnapshot();
                 }
             }
-            for (Iterator it = userEventProfiles.values().iterator(); it.hasNext();) {
-                UserEventProfile uep = (UserEventProfile) it.next();
+            for (Iterator<UserEventProfile> it = userEventProfiles.values().iterator(); it.hasNext();) {
+                UserEventProfile uep = it.next();
                 if (uep != null) {
                     uep.addSnapshot();
                 }
@@ -164,7 +172,7 @@ public class Thread implements Comparable {
         }
     }
 
-    public List getSnapshots() {
+    public List<Snapshot> getSnapshots() {
         return snapshots;
     }
 
@@ -192,8 +200,9 @@ public class Thread implements Comparable {
     }
 
     public FunctionProfile getFunctionProfile(Function function) {
-        if ((functionProfiles != null) && (function.getID() < functionProfiles.size()))
-            return (FunctionProfile) functionProfiles.get(function.getID());
+        if ((functionProfiles != null) && (function.getID() < functionProfiles.size())) {
+            return functionProfiles.get(function.getID());
+        }
         return null;
     }
 
@@ -208,19 +217,19 @@ public class Thread implements Comparable {
         }
     }
 
-    public List getFunctionProfiles() {
+    public List<FunctionProfile> getFunctionProfiles() {
         return functionProfiles;
     }
 
-    public Iterator getFunctionProfileIterator() {
+    public Iterator<FunctionProfile> getFunctionProfileIterator() {
         return functionProfiles.iterator();
     }
 
     public UserEventProfile getUserEventProfile(UserEvent userEvent) {
-        return (UserEventProfile) userEventProfiles.get(new Integer(userEvent.getID()));
+        return userEventProfiles.get(new Integer(userEvent.getID()));
     }
 
-    public Iterator getUserEventProfiles() {
+    public Iterator<UserEventProfile> getUserEventProfiles() {
         return userEventProfiles.values().iterator();
     }
 
@@ -242,8 +251,8 @@ public class Thread implements Comparable {
         return relationsBuilt;
     }
 
-    public int compareTo(Object obj) {
-        return threadID - ((Thread) obj).getThreadID();
+    public int compareTo(Thread obj) {
+        return threadID -  obj.getThreadID();
     }
 
     public void setThreadData(int metric) {
@@ -276,8 +285,8 @@ public class Thread implements Comparable {
                 double maxNumCalls = 0;
                 double maxNumSubr = 0;
 
-                for (Iterator it = this.getFunctionProfileIterator(); it.hasNext();) {
-                    FunctionProfile fp = (FunctionProfile) it.next();
+                for (Iterator<FunctionProfile> it = this.getFunctionProfileIterator(); it.hasNext();) {
+                    FunctionProfile fp = it.next();
                     if (fp == null) {
                         continue;
                     }
@@ -313,8 +322,8 @@ public class Thread implements Comparable {
 
                 double maxInclusivePercent = 0;
                 double maxExclusivePercent = 0;
-                for (Iterator it = this.getFunctionProfileIterator(); it.hasNext();) {
-                    FunctionProfile fp = (FunctionProfile) it.next();
+                for (Iterator<FunctionProfile> it = this.getFunctionProfileIterator(); it.hasNext();) {
+                    FunctionProfile fp = it.next();
                     if (fp == null) {
                         continue;
                     }
@@ -328,7 +337,7 @@ public class Thread implements Comparable {
         }
     }
 
-    public Map getMetaData() {
+    public Map<String,String> getMetaData() {
         return metaData;
     }
 
@@ -364,7 +373,7 @@ public class Thread implements Comparable {
     }
 
     public double getPercentDivider(int metric, int snapshot) {
-        double val = threadData[snapshot][metric].percentDivider;
+        //double val = threadData[snapshot][metric].percentDivider;
         return threadData[snapshot][metric].percentDivider;
     }
 
