@@ -1,16 +1,19 @@
-
 package edu.uoregon.tau.perfdmf;
 
-import java.awt.*;
-import java.io.*;
+import java.awt.Color;
+import java.io.Serializable;
 
-public class UserEvent implements Serializable, Comparable {
-    private String name;
+public class UserEvent implements Serializable, Comparable<UserEvent> {
+    /**
+	 * 
+	 */
+	private static final long serialVersionUID = 2315924747862094461L;
+	private String name;
     private int id;
     private Color color;
     private Color specificColor;
     private boolean colorFlag = false;
-    
+
     private double maxUserEventNumberValue = 0;
     private double maxUserEventMinValue = 0;
     private double maxUserEventMaxValue = 0;
@@ -18,20 +21,26 @@ public class UserEvent implements Serializable, Comparable {
     private double maxUserEventSumSquared = 0;
     private double maxUserEventStdDev = 0;
 
-    
+    private boolean contextEventSet;
+    private boolean contextEvent;
+
     public UserEvent(String name, int id) {
         this.name = name;
         this.id = id;
     }
-    
+
     public String getName() {
         return name;
     }
 
+    public String toString() {
+        return name;
+    }
+    
     public void setName(String name) {
         this.name = name;
     }
-    
+
     public int getID() {
         return id;
     }
@@ -84,12 +93,10 @@ public class UserEvent implements Serializable, Comparable {
         return maxUserEventStdDev;
     }
 
-
-    public int compareTo(Object inObject) {
-        return name.compareTo(((UserEvent) inObject).getName());
+    public int compareTo(UserEvent inObject) {
+        return name.compareTo(( inObject).getName());
     }
 
-    
     // Color Stuff
     public Color getColor() {
         if (colorFlag)
@@ -97,7 +104,7 @@ public class UserEvent implements Serializable, Comparable {
         else
             return color;
     }
-    
+
     public void setColorFlag(boolean colorFlag) {
         this.colorFlag = colorFlag;
     }
@@ -109,10 +116,19 @@ public class UserEvent implements Serializable, Comparable {
     public void setSpecificColor(Color specificColor) {
         this.specificColor = specificColor;
     }
-    
+
     public void setColor(Color color) {
         this.color = color;
     }
 
+    public boolean isContextEvent() {
+        if (!contextEventSet) {
+            if (name.indexOf(":") > 0) {
+                contextEvent = true;
+            }
+            contextEventSet = true;
+        }
+        return contextEvent;
+    }
 
 }
\ No newline at end of file
