@@ -6,15 +6,25 @@
 
 package edu.uoregon.tau.perfdmf;
 
-import java.io.*;
+import java.io.BufferedReader;
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.FileOutputStream;
+import java.io.IOException;
+import java.io.InputStream;
+import java.io.InputStreamReader;
 import java.text.DecimalFormat;
-import java.util.*;
+import java.util.ArrayList;
+import java.util.Iterator;
+import java.util.List;
+import java.util.ListIterator;
+import java.util.Vector;
 import java.util.zip.GZIPInputStream;
 import java.util.zip.GZIPOutputStream;
 
 public class UtilFncs {
 
-    public static class EmptyIterator implements ListIterator, Iterator {
+    public static class EmptyIterator implements ListIterator<FunctionProfile>, Iterator<FunctionProfile> {
 
         public int nextIndex() {
             return 0;
@@ -34,17 +44,17 @@ public class UtilFncs {
             return false;
         }
 
-        public Object next() {
+        public FunctionProfile next() {
             return null;
         }
 
-        public Object previous() {
+        public FunctionProfile previous() {
             return null;
         }
 
-        public void add(Object o) {}
+        public void add(FunctionProfile o) {}
 
-        public void set(Object o) {}
+        public void set(FunctionProfile o) {}
     }
 
     // left pad : pad string 's' up to length plen, but put the whitespace on
@@ -106,7 +116,17 @@ public class UtilFncs {
 
         // first check if the regular toString is in exponential form
         boolean exp = false;
-        String str = Double.toString(d);
+        String str;
+        
+        if(d<0){
+        	str="-";
+        	 if (pad) {
+                 return lpad(str, width);
+             } else {
+                 return str;
+             }
+        }
+        	str= Double.toString(d);
         for (int i = 0; i < str.length(); i++) {
             if (str.charAt(i) == 'E') {
                 exp = true;
@@ -336,14 +356,14 @@ public class UtilFncs {
     //        return -1;
     //    }
 
-    public static int exists(Vector ref, int i) {
+    public static int exists(Vector<Integer> ref, int i) {
         //Assuming a vector of Integers.
         if (ref == null)
             return -1;
         Integer current = null;
         int test = ref.size();
         for (int j = 0; j < test; j++) {
-            current = (Integer) ref.elementAt(j);
+            current = ref.elementAt(j);
             if ((current.intValue()) == i)
                 return j;
         }
@@ -398,8 +418,12 @@ public class UtilFncs {
     public static String getContextEventRoot(String str) {
         int colon = str.indexOf(":");
         int location = str.indexOf("=>");
-        if (colon < 0 || location < 0) {
-            return str;
+        if (location < 0) {
+            if (colon < 0) {
+                return str;
+            } else {
+                return str.substring(colon + 1);
+            }
         }
         return str.substring(colon + 1, location).trim();
     }
@@ -417,6 +441,9 @@ public class UtilFncs {
         if (filename.toLowerCase().endsWith(".ppk")) {
             return DataSource.PPK;
         }
+        if (filename.toLowerCase().endsWith(".cubex")) {
+            return DataSource.CUBE;
+        }
         if (filename.toLowerCase().endsWith(".cube")) {
             return DataSource.CUBE;
         }
@@ -464,15 +491,36 @@ public class UtilFncs {
         return DataSource.TAUPROFILE; // default
     }
 
-    public static DataSource initializeDataSource(File[] sourceFiles, int fileType, boolean fixGprofNames)
+    public static DataSource initializeDataSource(File[] sourceFiles, int fileType, boolean fixGprofNames){
+    	return initializeDataSource(sourceFiles,fileType,fixGprofNames,null);
+    }
+    
+    public static DataSource initializeDataSource(File[] sourceFiles, int fileType, boolean fixGprofNames, String range)
             throws DataSourceException {
         DataSource dataSource = null;
+        List<File[]> v = new ArrayList<File[]>();
+        /**
+         * This is ugly and inefficient. Need to avoid multiple reads of the file system here.
+         */
+        
+        if(fileType==DataSource.TAUPROFILE&&range==null&&sourceFiles.length < 1){
+        	 FileList fl=new FileList();
+        	 File[] list = fl.helperFindSnapshots(System.getProperty("user.dir"));
+        	 if(list.length>0){
+             		fileType=DataSource.SNAP;
+             		sourceFiles=list;
 
-        List v = new ArrayList();
-        File filelist[];
+             	}
+        }
+        //File filelist[];
         switch (fileType) {
         case DataSource.TAUPROFILE: // TAU Profiles
-            FileList fl = new FileList();
+            FileList fl;
+          
+            if(range!=null)
+            	fl= new FileList(range);
+            else
+            	fl = new FileList();
 
             if (sourceFiles.length < 1) {
                 v = fl.helperFindProfiles(System.getProperty("user.dir"));
@@ -494,9 +542,11 @@ public class UtilFncs {
                 }
 
             }
+            
 
             dataSource = new TauDataSource(v);
             break;
+            
         case DataSource.PPROF:
             if (sourceFiles.length != 1) {
                 throw new DataSourceException("pprof type: you must specify exactly one file");
@@ -527,6 +577,9 @@ public class UtilFncs {
         case DataSource.GPROF:
             dataSource = new GprofDataSource(sourceFiles, fixGprofNames);
             break;
+        case DataSource.GOOGLE:
+            dataSource = new GoogleDataSource(sourceFiles);
+            break;
         case DataSource.PSRUN:
             v.add(sourceFiles);
             dataSource = new PSRunDataSource(v);
@@ -549,13 +602,31 @@ public class UtilFncs {
             }
 
             try {
-                Class c = Class.forName("org.xml.sax.SAXException");
+                //Class c = 
+                	Class.forName("org.xml.sax.SAXException");
             } catch (ClassNotFoundException cnfe) {
                 throw new DataSourceException("Sorry, cube format requires Java 1.4");
             }
 
             dataSource = new CubeDataSource(sourceFiles[0]);
             break;
+        case DataSource.CUBE3:
+            if (sourceFiles.length != 1) {
+                throw new DataSourceException("Cube type : you must specify exactly one file");
+            }
+            if (sourceFiles[0].isDirectory()) {
+                throw new DataSourceException("Cube type: you must specify a file, not a directory");
+            }
+
+            try {
+                //Class c = 
+                	Class.forName("org.xml.sax.SAXException");
+            } catch (ClassNotFoundException cnfe) {
+                throw new DataSourceException("Sorry, cube format requires Java >=1.4");
+            }
+
+            dataSource = new Cube3DataSource(sourceFiles[0]);
+            break;
         case DataSource.HPCTOOLKIT:
             if (sourceFiles.length != 1) {
                 throw new DataSourceException("HPCToolkit type: you must specify exactly one file");
@@ -565,7 +636,8 @@ public class UtilFncs {
             }
 
             try {
-                Class c = Class.forName("org.xml.sax.SAXException");
+                //Class c = 
+                	Class.forName("org.xml.sax.SAXException");
             } catch (ClassNotFoundException cnfe) {
                 throw new DataSourceException("Sorry, HPCToolkit format requires Java 1.4");
             }
@@ -626,7 +698,7 @@ public class UtilFncs {
     public static void mergeSnapshots(File[] sourceFiles, String outfile) throws Exception {
         FileOutputStream fos = new FileOutputStream(outfile);
         GZIPOutputStream gzipout = new GZIPOutputStream(fos);
-        
+
         for (int i = 0; i < sourceFiles.length; i++) {
             FileInputStream fis = new FileInputStream(sourceFiles[i]);
 
@@ -641,7 +713,7 @@ public class UtilFncs {
                 input = new FileInputStream(sourceFiles[i]);
             }
 
-            int count=0;
+            int count = 0;
             byte[] buffer = new byte[4096];
             while ((count = input.read(buffer)) >= 0) {
                 gzipout.write(buffer, 0, count);
