@@ -54,7 +54,7 @@ public class LoadTrial {
                 + "  -f, --filetype <filetype>       Specify type of performance data, options are:\n"
                 + "                                    profiles (default), pprof, dynaprof, mpip,\n"
                 + "                                    gprof, psrun, hpm, packed, cube, hpc, ompp,\n"
-                + "                                    snap, perixml, gptl, paraver, ipm\n"
+                + "                                    snap, perixml, gptl, paraver, ipm, google\n"
                 + "  -t, --trialid <number>          Specify trial ID\n"
                 + "  -i, --fixnames                  Use the fixnames option for gprof\n"
                 + "  -m, --metadata <filename>       XML metadata for the trial\n\n" + "Notes:\n"
@@ -109,7 +109,7 @@ public class LoadTrial {
     }
 
     public boolean checkForTrialName(String trialName) {
-        Trial tmpTrial = databaseAPI.setTrial(trialName,false);
+        Trial tmpTrial = databaseAPI.setTrial(trialName, false);
         if (tmpTrial == null)
             return false;
         else
@@ -117,7 +117,7 @@ public class LoadTrial {
     }
 
     public boolean checkForTrial(String trialid) {
-        Trial tmpTrial = databaseAPI.setTrial(Integer.parseInt(trialid),false);
+        Trial tmpTrial = databaseAPI.setTrial(Integer.parseInt(trialid), false);
         if (tmpTrial == null)
             return false;
         else
@@ -163,8 +163,8 @@ public class LoadTrial {
         }
 
         // set the meta data from the datasource
-	trial.setMetaData(dataSource.getMetaData());
-	trial.setUncommonMetaData(dataSource.getUncommonMetaData());
+        trial.setMetaData(dataSource.getMetaData());
+        trial.setUncommonMetaData(dataSource.getUncommonMetaData());
 
         if (trialID == 0) {
             saveTrial();
@@ -300,10 +300,26 @@ public class LoadTrial {
                 configFile = System.getProperty("user.home") + "/.ParaProf/perfdmf.cfg." + configName;
         }
 
+        
+        String sourceFiles[] = parser.getRemainingArgs();
+        
+        boolean multippk=false;
         if (trialName == null) {
+        	
+        	if(sourceFiles!=null&&sourceFiles.length>0){
+        		
+        		String s = sourceFiles[0];
+        		File f=new File(s);
+        		int tid = UtilFncs.identifyData(f);
+        		if((fileTypeString!=null&&fileTypeString.equals("packed"))||tid==DataSource.PPK){
+        			multippk=true;
+        		}
+        	}
+        	if(!multippk){
             System.err.println("Error: Missing trial name\n");
             LoadTrial.usage();
             System.exit(-1);
+        	}
         } else if (experimentID == null && expName == null) {
             System.err.println("Error: Missing experiment id or name\n");
             LoadTrial.usage();
@@ -314,7 +330,7 @@ public class LoadTrial {
             System.exit(-1);
         }
 
-        String sourceFiles[] = parser.getRemainingArgs();
+        //String sourceFiles[] = parser.getRemainingArgs();
 
         int fileType = DataSource.TAUPROFILE;
         if (fileTypeString != null) {
@@ -354,6 +370,8 @@ public class LoadTrial {
                 fileType = DataSource.PARAVER;
             } else if (fileTypeString.equals("perixml")) {
                 fileType = DataSource.PERIXML;
+            } else if (fileTypeString.equals("google")) {
+                fileType = DataSource.GOOGLE;
             } else {
                 System.err.println("Please enter a valid file type.");
                 LoadTrial.usage();
@@ -365,7 +383,6 @@ public class LoadTrial {
             }
         }
 
-
         if (trialName == null) {
             trialName = "";
         }
@@ -376,6 +393,32 @@ public class LoadTrial {
         if (summaryOnly == null) {
             summaryOnly = new Boolean(false);
         }
+        
+        
+        if(multippk){
+        	
+        	for(int i=0;i<sourceFiles.length;i++)
+        	{
+        		
+        		trialName=sourceFiles[i].substring(0,sourceFiles[i].lastIndexOf('.'));
+        		
+        	LoadTrial trans = new LoadTrial(configFile, new String []{sourceFiles[i]});
+            trans.checkForExp(experimentID, appName, expName);
+            if (trialID != null) {
+                trans.checkForTrial(trialID);
+                trans.trialID = Integer.parseInt(trialID);
+            }
+
+            trans.trialName = trialName;
+            //trans.problemFile = problemFile;
+            trans.fixNames = fixNames.booleanValue();
+            trans.metadataFile = metadataFile;
+            trans.summaryOnly = summaryOnly.booleanValue();
+            trans.loadTrial(fileType);
+        	}
+        }
+        else
+        {
         LoadTrial trans = new LoadTrial(configFile, sourceFiles);
         trans.checkForExp(experimentID, appName, expName);
         if (trialID != null) {
@@ -390,6 +433,7 @@ public class LoadTrial {
         trans.summaryOnly = summaryOnly.booleanValue();
         trans.loadTrial(fileType);
         // the trial will be saved when the load is finished (update is called)
+        }
     }
 
     public void setMetadataFile(String metadataFile) {
