@@ -1,14 +1,45 @@
 package edu.uoregon.tau.perfexplorer.client;
 
-import java.awt.*;
-import java.awt.event.*;
-import java.io.*;
+import java.awt.Component;
+import java.awt.Container;
+import java.awt.Dimension;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
+import java.awt.Point;
+import java.awt.Toolkit;
+import java.awt.event.ActionEvent;
+import java.awt.event.ActionListener;
+import java.awt.event.ItemEvent;
+import java.awt.event.ItemListener;
+import java.io.BufferedReader;
+import java.io.File;
+import java.io.FileInputStream;
+import java.io.IOException;
+import java.io.InputStreamReader;
 import java.util.Observable;
 import java.util.Observer;
 import java.util.Vector;
 
-import javax.swing.*;
-import javax.swing.event.*;
+import javax.swing.BorderFactory;
+import javax.swing.DefaultListSelectionModel;
+import javax.swing.JButton;
+import javax.swing.JCheckBox;
+import javax.swing.JComboBox;
+import javax.swing.JFileChooser;
+import javax.swing.JFrame;
+import javax.swing.JLabel;
+import javax.swing.JList;
+import javax.swing.JOptionPane;
+import javax.swing.JPanel;
+import javax.swing.JPasswordField;
+import javax.swing.JProgressBar;
+import javax.swing.JTextField;
+import javax.swing.ListSelectionModel;
+import javax.swing.event.ChangeEvent;
+import javax.swing.event.ChangeListener;
+import javax.swing.event.ListSelectionEvent;
+import javax.swing.event.ListSelectionListener;
 
 import edu.uoregon.tau.common.Common;
 import edu.uoregon.tau.common.Wget;
@@ -29,13 +60,13 @@ public class DatabaseManagerWindow extends JFrame implements ActionListener, Obs
 	private static final String fileLoc = ""; //Was http://spaceghost.cs.uoregon.edu/PerfExplorer/
     private static final long serialVersionUID = 1L;
     private String lastDirectory = "";
-    private JList configList = new JList((Vector) ConfigureFiles.getConfigurationNames());
+    private JList configList = new JList((Vector<String>) ConfigureFiles.getConfigurationNames());
     private JButton saveConfig = new JButton("Save Configuration");
     private JButton removeConfig = new JButton("Remove Configuration");
     private JTextField name = new JTextField(15);
     private JPanel configurations = new JPanel();
     private JPanel editConfiguration = new JPanel();
-    private String[] adapters = { "mysql", "postgresql", "oracle", "derby", "db2" };
+    private String[] adapters = { "mysql", "postgresql", "oracle", "derby", "db2", "h2" };
     private JComboBox adapter = new JComboBox(adapters);
     private JTextField driver = new JTextField(15);
     private JTextField host = new JTextField(15);
@@ -258,9 +289,10 @@ public class DatabaseManagerWindow extends JFrame implements ActionListener, Obs
                 yPosition = yPosition - 50;
 
             this.setLocation(xPosition, yPosition);
-        } else {
-            this.setLocation(savedPosition);
-        }
+        } 
+//        else {  //TODO: Make sure we don't want to save positions
+//            this.setLocation(savedPosition);
+//        }
 
         //configurations.setLayout(new GridBagLayout());
         addCompItem(this, configurations, gbc, 0, 0, 1, 1);
@@ -345,7 +377,7 @@ public class DatabaseManagerWindow extends JFrame implements ActionListener, Obs
             } else if (arg.equals("Save Configuration")) {
                 String filename = writeConfig(name.getText());
                 configList.clearSelection();
-                configList.setListData((Vector) ConfigureFiles.getConfigurationNames());
+                configList.setListData((Vector<String>) ConfigureFiles.getConfigurationNames());
                 ConfigureTest config = new ConfigureTest();
                 config.initialize(filename);
                 //config.setDBSchemaFile("dbschema." + adapter.getSelectedItem().toString() + ".txt");
@@ -366,12 +398,12 @@ public class DatabaseManagerWindow extends JFrame implements ActionListener, Obs
                 mainWindow.refreshDatabases();
             } else if (arg.equals("Remove Configuration")) {
                 String path = selectedConfig.getPath();
-                System.out.println("deleating config, path: " + path);
+                System.out.println("deleting config, path: " + path);
                 File removeFile = new File(path); 
                 //System.out.println(removeFile.exists() + "File path: " + removeFile.getAbsolutePath());
                 removeFile.delete();
                 configList.clearSelection();
-                configList.setListData((Vector) ConfigureFiles.getConfigurationNames());
+                configList.setListData((Vector<String>) ConfigureFiles.getConfigurationNames());
                 mainWindow.refreshDatabases();
             } else if (arg.equals("Download")) {
                 JFileChooser jFileChooser = new JFileChooser(lastDirectory);
@@ -401,7 +433,7 @@ public class DatabaseManagerWindow extends JFrame implements ActionListener, Obs
                 driver.setText("");
                 jarfile.setText("");
                 schema.setText("");
-                adapter.setSelectedItem("derby");
+                adapter.setSelectedItem("h2");
                 host.setEnabled(false);
                 host.setText("");
                 databasePassword.setEditable(false);
@@ -670,6 +702,36 @@ public class DatabaseManagerWindow extends JFrame implements ActionListener, Obs
             {
             	this.jarfile.setText(fileLoc+"derby.jar");
             }
+         } else if (newAdapter.compareTo("h2") == 0) {
+            host.setEnabled(false);
+            host.setText("");
+            databasePassword.setEditable(false);
+            databasePassword.setEnabled(false);
+            databasePassword.setText("");
+            savePassword.setEnabled(false);
+            port.setEnabled(false);
+            port.setText("");
+        	download.setEnabled(false);
+        	labelDatabaseName.setText("Path to Database:");
+            this.driver.setText("org.h2.Driver");
+            String jarlocation;
+            if (System.getProperty("os.name").startsWith("Windows"))
+            {
+            	jarlocation = home + File.separator + "bin" + File.separator + "h2.jar";
+            }
+            else
+            {
+            	jarlocation = home + File.separator + "tools" + File.separator + "src" + File.separator + "contrib" + File.separator + "h2.jar";
+            }
+            File jar = new File(jarlocation);
+            if (jar.exists() && home != null && arch != null)
+            {
+            	this.jarfile.setText(jarlocation);
+            }
+            else
+            {
+            	this.jarfile.setText(fileLoc+"h2.jar");
+            }
         } else if (newAdapter.compareTo("db2") == 0) {
             download.setEnabled(false);
             host.setEnabled(true);
@@ -731,4 +793,4 @@ public class DatabaseManagerWindow extends JFrame implements ActionListener, Obs
     	
     }
 
-}
\ No newline at end of file
+}
