@@ -14,7 +14,6 @@ import java.util.ListIterator;
 import javax.swing.ImageIcon;
 import javax.swing.JComponent;
 import javax.swing.JFileChooser;
-import javax.swing.JFrame;
 import javax.swing.JMenuItem;
 import javax.swing.JOptionPane;
 import javax.swing.JTree;
@@ -43,7 +42,6 @@ import edu.uoregon.tau.perfexplorer.server.PerfExplorerServer;
 
 public class PerfExplorerActionListener implements ActionListener {
 
-	public static final String DERIVE_METRIC = "Open Expression Window";
 	public static final String PARSE_EXPRESSION = "Parse Expression File";
 	public static final String REPARSE_EXPRESSION = "Re-Parse Expression File";
 	public final static String DATABASE_CONFIGURATION = "Database Configuration";
@@ -147,8 +145,6 @@ public class PerfExplorerActionListener implements ActionListener {
 					}
 				} else if (arg.equals(DATABASE_CONFIGURATION)) {
 					databaseConfiguration();
-				} else if (arg.equals(DERIVE_METRIC)) {
-					deriveMetric();
 				} else if (arg.equals(PARSE_EXPRESSION)) {
 					parseExpression();
 				} else if (arg.equals(REPARSE_EXPRESSION)) {
@@ -351,7 +347,8 @@ public class PerfExplorerActionListener implements ActionListener {
 
 	private void createChartDialogBox() {
 		System.out.println("Opening Dialog Box to create charts");
-		JFrame dialogBox = ChartGUI.getInstance(true);
+		//JFrame dialogBox = 
+			ChartGUI.getInstance(true);
 	}
 
 	private void updateAll (Container container) {
@@ -527,7 +524,6 @@ public class PerfExplorerActionListener implements ActionListener {
 			PerfExplorerModel.getModel().setNumberOfClusters(reply);
 	}
 
-	@SuppressWarnings("unchecked") // for trial.getMetricS() call
 	public void createDoClusteringWindow() {
 		PerfExplorerModel theModel = PerfExplorerModel.getModel();
 		Object selection = theModel.getCurrentSelection();
@@ -840,8 +836,14 @@ public class PerfExplorerActionListener implements ActionListener {
 		String event = theModel.getEventName();
 		if (forceIt || event == null) {
 			PerfExplorerConnection server = PerfExplorerConnection.getConnection();
-			List<String> metrics = server.getPotentialEvents(theModel);
-			Object[] options = metrics.toArray();
+			List<String> events = server.getPotentialEvents(theModel);
+			List<String> callpath = server.getPotentialCallPathEvents(theModel);
+			for(String cp: callpath){
+				events.add(cp);
+			}
+			
+			
+			Object[] options = events.toArray();
 			if (options.length > 0) {
 				if (options.length == 1) {
 					event = (String)options[0];
@@ -1000,7 +1002,8 @@ public class PerfExplorerActionListener implements ActionListener {
 			String script;
 			try {
 				script = new PerfExplorerExpression().getScriptFromFile(app,exp,trial,expressionFilename);
-				ScriptThread runner = new ScriptThread(script,true);
+				//ScriptThread runner = 
+					new ScriptThread(script,true);
 			} catch (FileNotFoundException e) {
 				JOptionPane.showMessageDialog(mainFrame, 
 						"",
@@ -1029,7 +1032,8 @@ public class PerfExplorerActionListener implements ActionListener {
 		} else {
 			// run the script
 			//PythonInterpreterFactory.defaultfactory.getPythonInterpreter().execfile(scriptName);
-			ScriptThread runner = new ScriptThread(scriptName);
+			//ScriptThread runner = 
+				new ScriptThread(scriptName);
 			return true;
 		}
 	}
