@@ -3,13 +3,23 @@ package edu.uoregon.tau.perfexplorer.client;
 
 import jargs.gnu.CmdLineParser;
 
-import java.util.*;
+import java.util.ArrayList;
+import java.util.Iterator;
+import java.util.List;
+import java.util.ListIterator;
 
 import javax.swing.JFrame;
 import javax.swing.ToolTipManager;
 
-import edu.uoregon.tau.perfdmf.*;
-import edu.uoregon.tau.perfexplorer.common.*;
+import edu.uoregon.tau.perfdmf.Application;
+import edu.uoregon.tau.perfdmf.Experiment;
+import edu.uoregon.tau.perfdmf.Metric;
+import edu.uoregon.tau.perfdmf.Trial;
+import edu.uoregon.tau.perfexplorer.common.AnalysisType;
+import edu.uoregon.tau.perfexplorer.common.PerfExplorerOutput;
+import edu.uoregon.tau.perfexplorer.common.RMIPerfExplorerModel;
+import edu.uoregon.tau.perfexplorer.common.RMIView;
+import edu.uoregon.tau.perfexplorer.common.TransformationType;
 
 public class TestHarness {
 	private static String USAGE = "Usage: TestHarness [{-h,--help}] {-c,--configfile}=<config_file> [{-s,--standalone}] [{-t,--test}=<test_type>]\n  where test_type = charts, cluster, correlation, viz, script or all ";
@@ -213,7 +223,6 @@ public class TestHarness {
 	private Metric setMetric(Trial trial, String name) {
 		Metric metric = null;
 		System.out.println("******** Metrics *********");
-		@SuppressWarnings("unchecked")
 		List<Metric> metrics = trial.getMetrics();
 		for (int i = 0 ; i < metrics.size() ; i++) {
 			metric = metrics.get(i);
@@ -480,7 +489,8 @@ public RMICubeData getCubeData(RMIPerfExplorerModel model) throws RemoteExceptio
 		} catch (Exception e) { }
 	*/
 
-		TestHarness harness = new TestHarness(standalone.booleanValue(),
+		//TestHarness harness = 
+			new TestHarness(standalone.booleanValue(),
 			configFile, quiet.booleanValue(), testType);
 	}
 
