@@ -1,4 +1,4 @@
-package clustering;
+package edu.uoregon.tau.perfexplorer.clustering;
 
 import java.util.ArrayList;
 import java.util.List;
@@ -8,7 +8,7 @@ import java.util.List;
  * This class specifies the nodes in a dendrogram representing the results
  * of a hierarchical clustering.  This dendrogram is a simple binary tree.
  *
- * <P>CVS $Id: DendrogramTree.java,v 1.2 2007/01/04 21:20:01 khuck Exp $</P>
+ * <P>CVS $Id: DendrogramTree.java,v 1.8 2009/11/18 10:17:31 khuck Exp $</P>
  * @author khuck
  * @version 0.1
  * @since   0.1
@@ -19,7 +19,7 @@ public class DendrogramTree {
     private DendrogramTree left = null;
     private DendrogramTree right = null;
     private int id = 0;
-    private double height = 0.0;
+	private double height = 0.0;
     private int maxDepth = 0;
 
     /**
@@ -129,14 +129,14 @@ public class DendrogramTree {
                 centers[0] = left.getRepresentative();
                 centers[1] = right.getRepresentative();
         }else {
-            List clusters = new ArrayList(count);
+            List<DendrogramTree> clusters = new ArrayList<DendrogramTree>(count);
             clusters.add(left);
             clusters.add(right);
             DendrogramTree current = null;
             while (clusters.size() < count) {
-                DendrogramTree winner = (DendrogramTree)clusters.get(0);
+                DendrogramTree winner = clusters.get(0);
                 for (int i = 0 ; i < clusters.size() ; i++) {
-                    current = (DendrogramTree)clusters.get(i);
+                    current = clusters.get(i);
                     if (current.getHeight() > winner.getHeight())
                         winner = current;
                 }
@@ -145,7 +145,7 @@ public class DendrogramTree {
                 clusters.add(winner.getRight());
             }
             for (int i = 0 ; i < clusters.size() ; i++) {
-                current = (DendrogramTree)clusters.get(i);
+                current = clusters.get(i);
                 centers[i] = current.getRepresentative();
             }
         }
@@ -187,14 +187,44 @@ public class DendrogramTree {
      * @return
      */
     public String toString() {
-        StringBuffer buf = new StringBuffer();
+        StringBuilder buf = new StringBuilder();
         if (!isLeaf()) {
             buf.append(left.toString());
             buf.append(right.toString());
-            buf.append("[" + id + "]: " );
-            buf.append(left.id + ", " + right.id + ": " + height + "\n");
+            buf.append("node [" + id + "] " + left.id + ", " + right.id + ": " + height + "\n");
+        } else {
+            buf.append("leaf [" + id + "] \n" );     	
         }
         return buf.toString();
     }
+
+    /**
+     * Returns the instance index (ID) of the data at this node in the tree
+     * 
+     * @return
+     */
+    public int getID() {
+    	// could be negative...
+		return Math.abs(id);
+	}
+
+    /**
+     * Returns a list of indexes for the instances in this tree
+     * 
+     * @return List<Integer>
+     */
+    public List<Integer> getIndexes() {
+    	List<Integer> list = new ArrayList<Integer>();
+    	if (left != null) {
+        	list.addAll(left.getIndexes());
+    	}
+    	if (right != null) {
+        	list.addAll(right.getIndexes());
+    	}
+        if (isLeaf())
+            list.add(new Integer(Math.abs(id)-1));
+    	return list;
+    }
+
 }
 
