@@ -1,11 +1,5 @@
 package edu.uoregon.tau.perfexplorer.common;
 
-import edu.uoregon.tau.perfdmf.Database;
-import edu.uoregon.tau.perfdmf.database.ConnectionManager;
-import edu.uoregon.tau.perfdmf.Database;
-import edu.uoregon.tau.perfdmf.database.DB;
-import edu.uoregon.tau.perfdmf.database.ParseConfig;
-
 import jargs.gnu.CmdLineParser;
 
 import java.io.BufferedReader;
@@ -13,10 +7,14 @@ import java.io.File;
 import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InputStreamReader;
-
 import java.sql.ResultSet;
 import java.sql.SQLException;
 
+import edu.uoregon.tau.perfdmf.Database;
+import edu.uoregon.tau.perfdmf.database.ConnectionManager;
+import edu.uoregon.tau.perfdmf.database.DB;
+import edu.uoregon.tau.perfdmf.database.ParseConfig;
+
 /**
  * This class is used as a main class for configuring PerfExplorer.
  *
@@ -158,6 +156,8 @@ public class Configure {
                         filename = tau_root + File.separator + "dbschema.oracle";
                     } else if (db.getDBType().compareTo("derby") == 0) {
                         filename = tau_root + File.separator + "dbschema.derby";
+                    } else if (db.getDBType().compareTo("h2") == 0) {
+                        filename = tau_root + File.separator + "dbschema.h2";
                     } else if (db.getDBType().compareTo("mysql") == 0) {
                         filename = tau_root + File.separator + "dbschema.mysql";
                     } else if (db.getDBType().compareTo("postgresql") == 0) {
