@@ -1,15 +1,16 @@
 package edu.uoregon.tau.perfexplorer.common;
 
+import java.io.Serializable;
+import java.util.ArrayList;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
+
 import edu.uoregon.tau.perfdmf.Application;
 import edu.uoregon.tau.perfdmf.Experiment;
-import edu.uoregon.tau.perfdmf.Trial;
-import edu.uoregon.tau.perfdmf.Metric;
 import edu.uoregon.tau.perfdmf.IntervalEvent;
-import java.io.Serializable;
-import java.util.Map;
-import java.util.HashMap;
-import java.util.List;
-import java.util.ArrayList;
+import edu.uoregon.tau.perfdmf.Metric;
+import edu.uoregon.tau.perfdmf.Trial;
 
 /**
  * This RMI object defines the state of the client model when an analysis
@@ -22,6 +23,10 @@ import java.util.ArrayList;
  *
  */
 public class RMIPerfExplorerModel implements Serializable {
+	/**
+	 * 
+	 */
+	private static final long serialVersionUID = 544071368610204750L;
 	public final static int MAX_CLUSTERS = 10;
 	public final static double X_PERCENT = 1.0;
 
@@ -47,6 +52,7 @@ public class RMIPerfExplorerModel implements Serializable {
 	protected String chartYAxisLabel = null;
 	protected String chartTitle = null;
 	protected boolean chartLogYAxis = false;
+	protected boolean chartLogXAxis = false;
 	protected boolean chartScalability = false;
 	protected boolean chartEfficiency = false;
 	protected boolean chartHorizontal = false;
@@ -118,6 +124,7 @@ public class RMIPerfExplorerModel implements Serializable {
 		this.chartYAxisLabel = source.chartYAxisLabel;
 		this.chartTitle = source.chartTitle;
 		this.chartLogYAxis = source.chartLogYAxis;
+		this.chartLogXAxis = source.chartLogXAxis;
 		this.chartScalability = source.chartScalability;
 		this.chartEfficiency = source.chartEfficiency;
 		this.chartHorizontal = source.chartHorizontal;
@@ -1077,6 +1084,15 @@ public class RMIPerfExplorerModel implements Serializable {
 	public boolean getChartLogYAxis() {
 		return this.chartLogYAxis;
 	}
+	
+    /**
+     * Get the log axis
+     *
+     * @return
+     */
+	public boolean getChartLogXAxis() {
+		return this.chartLogXAxis;
+	}
 
     /**
      * Get the log axis
@@ -1104,6 +1120,14 @@ public class RMIPerfExplorerModel implements Serializable {
 	public void setChartLogYAxis(boolean logAxis) {
 		this.chartLogYAxis = logAxis;
 	}
+    /**
+     * Set the log axis
+     *
+     * @param seriesName
+     */
+	public void setChartLogXAxis(boolean logAxis) {
+		this.chartLogXAxis = logAxis;
+	}
 
     /**
      * Set the log axis
