@@ -28,6 +28,10 @@ import edu.uoregon.tau.perfexplorer.common.RMIView;
  */
 public class ChartData extends RMIChartData {
 
+	/**
+	 * 
+	 */
+	private static final long serialVersionUID = -4066428857538615268L;
 	private RMIPerfExplorerModel model;
 	private String metricName = null;
 	private String groupName = null;
@@ -81,7 +85,7 @@ public class ChartData extends RMIChartData {
 		PreparedStatement statement = null;
 		try {
 			String groupingName = null;
-			String threadName = null;
+			//String threadName = null;
 			double value = 0.0;
 			double numThreads = 0;
 			String currentExperiment = "";
@@ -124,12 +128,12 @@ public class ChartData extends RMIChartData {
 				groupingName = results.getString(1);
 				if (dataType == ChartDataType.IQR_DATA || dataType == ChartDataType.DISTRIBUTION_DATA) {
 					numThreads = results.getDouble(2);
-					threadName = Double.toString(numThreads);
+					//threadName = Double.toString(numThreads);
 					value = results.getDouble(3);
 				} else {
 					numThreads = results.getDouble(2) * results.getDouble(3) *
 						results.getDouble(4);
-					threadName = Double.toString(numThreads);
+					//threadName = Double.toString(numThreads);
 					value = results.getDouble(5);
 				}
 				if ((metricName.toLowerCase().indexOf("time") != -1) 
@@ -172,7 +176,7 @@ public class ChartData extends RMIChartData {
 					groupingName = "other";
 					numThreads = results.getDouble(1) * results.getDouble(2) *
 						results.getDouble(3);
-					threadName = Double.toString(numThreads);
+					//threadName = Double.toString(numThreads);
 					value = results.getDouble(4);
 					if ((metricName.toLowerCase().indexOf("time") != -1) 
 						&& (dataType != ChartDataType.FRACTION_OF_TOTAL))
@@ -220,6 +224,7 @@ public class ChartData extends RMIChartData {
 		}
 	}
 
+ 
 	/**
 	 * The buildStatment method will construct the query to get the chart
 	 * data, customizing it to the type of data desired.
@@ -254,8 +259,22 @@ public class ChartData extends RMIChartData {
 			if (object instanceof RMIView) {
 				buf.append(model.getViewSelectionPath(true, true, db.getDBType()));
 			} else {
-				buf.append("where t.experiment = ");
-				buf.append(model.getExperiment().getID() + " ");
+				buf.append("where t.experiment in (");
+				
+    List<Object> selections = model.getMultiSelection();
+				if (selections == null) {
+					// just one selection
+					buf.append (model.getExperiment().getID());
+				} else {
+					for (int i = 0 ; i < selections.size() ; i++) {
+						Experiment exp = (Experiment)selections.get(i);
+						if (i > 0)
+							buf.append(",");
+						buf.append(exp.getID());
+					}
+				}
+				buf.append(")"); 
+				
 			}
 			if (db.getDBType().compareTo("db2") == 0) {
 				buf.append(" and m.name like ? ");
@@ -279,7 +298,7 @@ public class ChartData extends RMIChartData {
 			// The user wants to know the relative efficiency or speedup
 			// of one or more experiments, as the number of threads of 
 			// execution increases.
-			List selections = model.getMultiSelection();
+			List<Object> selections = model.getMultiSelection();
 			buf.append("select ");
 			StringBuilder tmpBuf = new StringBuilder();
 			if (object instanceof RMIView) {
@@ -306,6 +325,7 @@ public class ChartData extends RMIChartData {
 			} else {
 				buf.append("inner join experiment e on t.experiment = e.id ");
 				buf.append("where t.experiment in (");
+     selections = model.getMultiSelection();
 				if (selections == null) {
 					// just one selection
 					buf.append (model.getExperiment().getID());
@@ -372,7 +392,7 @@ public class ChartData extends RMIChartData {
 				buf.append(model.getViewSelectionPath(true, false, db.getDBType()));
 			} else {
 				buf.append("where t.experiment in (");
-				List selections = model.getMultiSelection();
+				List<Object> selections = model.getMultiSelection();
 				if (selections == null) {
 					// just one selection
 					buf.append (model.getExperiment().getID());
@@ -457,8 +477,21 @@ public class ChartData extends RMIChartData {
 			if (object instanceof RMIView) {
 				buf.append(model.getViewSelectionPath(true, true, db.getDBType()));
 			} else {
-				buf.append("where t.experiment = ");
-				buf.append(model.getExperiment().getID() + " ");
+			
+			buf.append("where t.experiment in (");
+    List<Object> selections = model.getMultiSelection();
+				if (selections == null) {
+					// just one selection
+					buf.append (model.getExperiment().getID());
+				} else {
+					for (int i = 0 ; i < selections.size() ; i++) {
+						Experiment exp = (Experiment)selections.get(i);
+						if (i > 0)
+							buf.append(",");
+						buf.append(exp.getID());
+					}
+				}
+				buf.append(")");
 			}
 			if (db.getDBType().compareTo("db2") == 0) {
 				buf.append(" and m.name like ? ");
@@ -528,8 +561,20 @@ public class ChartData extends RMIChartData {
 			if (object instanceof RMIView) {
 				buf.append(model.getViewSelectionPath(true, true, db.getDBType()));
 			} else {
-				buf.append("where t.experiment = ");
-				buf.append(model.getExperiment().getID() + " ");
+buf.append("where t.experiment in (");
+    List<Object> selections = model.getMultiSelection();
+				if (selections == null) {
+					// just one selection
+					buf.append (model.getExperiment().getID());
+				} else {
+					for (int i = 0 ; i < selections.size() ; i++) {
+						Experiment exp = (Experiment)selections.get(i);
+						if (i > 0)
+							buf.append(",");
+						buf.append(exp.getID());
+					}
+				}
+				buf.append(")");
 			}
 
 			if (db.getDBType().compareTo("db2") == 0) {
@@ -580,7 +625,7 @@ public class ChartData extends RMIChartData {
 			} else {
 				buf.append("inner join experiment e on t.experiment = e.id ");
 				buf.append("where t.experiment in (");
-				List selections = model.getMultiSelection();
+    List<Object> selections = model.getMultiSelection();
 				if (selections == null) {
 					// just one selection
 					buf.append (model.getExperiment().getID());
@@ -705,8 +750,20 @@ public class ChartData extends RMIChartData {
 			if (object instanceof RMIView) {
 				buf.append(model.getViewSelectionPath(true, true, db.getDBType()));
 			} else {
-				buf.append("where t.experiment = ");
-				buf.append(model.getExperiment().getID() + " ");
+				buf.append("where t.experiment in (");
+				List<Object> selections = model.getMultiSelection();
+				if (selections == null) {
+					// just one selection
+					buf.append (model.getExperiment().getID());
+				} else {
+					for (int i = 0 ; i < selections.size() ; i++) {
+						Experiment exp = (Experiment)selections.get(i);
+						if (i > 0)
+							buf.append(",");
+						buf.append(exp.getID());
+					}
+				}
+				buf.append(")");
 			}
 
 			if (db.getDBType().compareTo("db2") == 0) {
@@ -789,7 +846,7 @@ public class ChartData extends RMIChartData {
 			buf.append("where ie.trial = ? ");
 			buf.append("and p.metric = ? ");
 			buf.append("and ie.id in (");
-			List selections = model.getMultiSelection();
+			List<Object> selections = model.getMultiSelection();
 			if (selections == null) {
 				// just one selection
 				buf.append (model.getEvent().getID());
@@ -805,8 +862,9 @@ public class ChartData extends RMIChartData {
 			statement = db.prepareStatement(buf.toString());
 			statement.setInt(1, model.getTrial().getID());
 			statement.setInt(2, model.getMetric().getID());
-			System.out.println(statement.toString());
+			//System.out.println(statement.toString());
 		}
+			//System.out.println(statement.toString());
 		return statement;
 	}
 
@@ -829,8 +887,21 @@ public class ChartData extends RMIChartData {
 			if (object instanceof RMIView) {
 				buf.append(model.getViewSelectionPath(true, true, db.getDBType()));
 			} else {
-				buf.append("where t.experiment = ");
-				buf.append(model.getExperiment().getID() + " ");
+		buf.append("where t.experiment in (");
+    List<Object> selections = model.getMultiSelection();
+
+				if (selections == null) {
+					// just one selection
+					buf.append (model.getExperiment().getID());
+				} else {
+					for (int i = 0 ; i < selections.size() ; i++) {
+						Experiment exp = (Experiment)selections.get(i);
+						if (i > 0)
+							buf.append(",");
+						buf.append(exp.getID());
+					}
+				}
+				buf.append(")");
 			}
 			if (db.getDBType().compareTo("db2") == 0) {
 				buf.append(" and m.name like ? ");
@@ -897,8 +968,20 @@ public class ChartData extends RMIChartData {
 			if (object instanceof RMIView) {
 				buf.append(model.getViewSelectionPath(true, true, db.getDBType()));
 			} else {
-				buf.append("where t.experiment = ");
-				buf.append(model.getExperiment().getID() + " ");
+    List<Object> selections = model.getMultiSelection();
+	buf.append("where t.experiment in (");
+				if (selections == null) {
+					// just one selection
+					buf.append (model.getExperiment().getID());
+				} else {
+					for (int i = 0 ; i < selections.size() ; i++) {
+						Experiment exp = (Experiment)selections.get(i);
+						if (i > 0)
+							buf.append(",");
+						buf.append(exp.getID());
+					}
+				}
+				buf.append(")");
 			}
 			
 			if (db.getDBType().compareTo("db2") == 0) {
@@ -937,8 +1020,20 @@ public class ChartData extends RMIChartData {
 			if (object instanceof RMIView) {
 				buf.append(model.getViewSelectionPath(true, true, db.getDBType()));
 			} else {
-				buf.append("where t.experiment = ");
-				buf.append(model.getExperiment().getID() + " ");
+	buf.append("where t.experiment in (");
+    List<Object> selections = model.getMultiSelection();
+				if (selections == null) {
+					// just one selection
+					buf.append (model.getExperiment().getID());
+				} else {
+					for (int i = 0 ; i < selections.size() ; i++) {
+						Experiment exp = (Experiment)selections.get(i);
+						if (i > 0)
+							buf.append(",");
+						buf.append(exp.getID());
+					}
+				}
+				buf.append(")");
 			}
 			if (db.getDBType().compareTo("db2") == 0) {
 				buf.append(" and m.name like ? ");
