@@ -6,9 +6,10 @@
  */
 package edu.uoregon.tau.perfexplorer.server;
 
-import org.jfree.chart.ChartColor;
 import java.awt.Color;
 
+import org.jfree.chart.ChartColor;
+
 /**
  * Description
  *
@@ -20,6 +21,11 @@ import java.awt.Color;
  */
 public class PEChartColor extends ChartColor {
     /**
+	 * 
+	 */
+	private static final long serialVersionUID = 381728458851268718L;
+
+	/**
      * Creates a Color with an opaque sRGB with red, green and blue values in range 0-255.
      *
      * @param r  the red component in range 0x00-0xFF.
@@ -35,7 +41,7 @@ public class PEChartColor extends ChartColor {
 			Color.red,
 			Color.blue,
 			Color.green,
-			Color.yellow,
+			//Color.yellow,
 			Color.orange,
 			Color.magenta,
 			Color.cyan,
@@ -51,7 +57,7 @@ public class PEChartColor extends ChartColor {
 			ChartColor.LIGHT_RED,
 			ChartColor.LIGHT_BLUE,
 			ChartColor.LIGHT_GREEN,
-			ChartColor.LIGHT_YELLOW,
+			//ChartColor.LIGHT_YELLOW,
 			ChartColor.LIGHT_MAGENTA,
 			ChartColor.LIGHT_CYAN,
 			Color.lightGray,
@@ -64,7 +70,7 @@ public class PEChartColor extends ChartColor {
 			ChartColor.VERY_LIGHT_RED,
 			ChartColor.VERY_LIGHT_BLUE,
 			ChartColor.VERY_LIGHT_GREEN,
-			ChartColor.VERY_LIGHT_YELLOW,
+			//ChartColor.VERY_LIGHT_YELLOW,
 			ChartColor.VERY_LIGHT_MAGENTA,
 			ChartColor.VERY_LIGHT_CYAN
 	    	};
