@@ -24,9 +24,7 @@ import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
-import java.util.NoSuchElementException;
 import java.util.Queue;
-import java.util.StringTokenizer;
 
 import edu.uoregon.tau.perfdmf.Application;
 import edu.uoregon.tau.perfdmf.DatabaseAPI;
@@ -36,7 +34,6 @@ import edu.uoregon.tau.perfdmf.IntervalEvent;
 import edu.uoregon.tau.perfdmf.Metric;
 import edu.uoregon.tau.perfdmf.Trial;
 import edu.uoregon.tau.perfdmf.database.DB;
-import edu.uoregon.tau.perfdmf.loader.*;
 import edu.uoregon.tau.perfexplorer.common.AnalysisType;
 import edu.uoregon.tau.perfexplorer.common.ChartDataType;
 import edu.uoregon.tau.perfexplorer.common.ChartType;
@@ -52,7 +49,6 @@ import edu.uoregon.tau.perfexplorer.common.RMIPerformanceResults;
 import edu.uoregon.tau.perfexplorer.common.RMISortableIntervalEvent;
 import edu.uoregon.tau.perfexplorer.common.RMIVarianceData;
 import edu.uoregon.tau.perfexplorer.common.RMIView;
-import edu.uoregon.tau.perfexplorer.common.Configure;
 import edu.uoregon.tau.perfexplorer.constants.Constants;
 
 /**
@@ -171,10 +167,13 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 		// this is how you replace 1 backslash with 2 backslashes for use later 
 		// as a regular expression...
 		prefix = prefix.replaceAll("\\\\", "\\\\\\\\");
-		System.out.println(prefix);
+		//System.out.println(prefix);
 		for (Iterator<String> iter = configFiles.iterator() ; iter.hasNext() ; ) {
 			DatabaseAPI api = null;
 			String tmpFile = iter.next();
+			if (tmpFile.contains("NO_DATABASE")) {
+				break;
+			}
 			PerfExplorerOutput.print("Connecting...");
 			try {
 				api = new DatabaseAPI();
@@ -275,7 +274,6 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 	 * 
 	 * @return List of PerfDMF Application objects.
 	 */
-	@SuppressWarnings("unchecked")  // for getApplicationList() call
 	public List<Application> getApplicationList() {
 		//PerfExplorerOutput.println("getApplicationList()...");
 		List<Application> applications = this.session.getApplicationList();
@@ -289,7 +287,6 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 	 * @param applicationID
 	 * @return List of PerfDMF Experiment objects.
 	 */
-	@SuppressWarnings("unchecked")  // for getExperimentList() call
 	public List<Experiment> getExperimentList(int applicationID) {
 		//PerfExplorerOutput.println("getExperimentList(" + applicationID + ")...");
 		this.session.setApplication(applicationID);
@@ -308,7 +305,6 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 	 * @param experimentID
 	 * @return List of PerfDMF Trial objects.
 	 */
-	@SuppressWarnings("unchecked")  // for getTrialList() call
 	public List<Trial> getTrialList(int experimentID, boolean getXMLMetadata) {
 		//PerfExplorerOutput.println("getTrialList(" + experimentID + ")...");
 		try {
@@ -411,7 +407,8 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 					"thumbnail, image_size, image, result_type from analysis_result where " + 
 					"analysis_settings = ? and result_type = ? order by id asc");
 			statement.setInt(1, analysisID);
-			statement.setString(2, ChartType.CORRELATION_SCATTERPLOT.toString());
+			statement.setInt(2,Integer.valueOf(ChartType.CORRELATION_SCATTERPLOT.toString()));
+			//statement.setString(2, ChartType.CORRELATION_SCATTERPLOT.toString());
 			//PerfExplorerOutput.println(statement.toString());
 			results = statement.executeQuery();
 			while (results.next() != false) {
@@ -420,11 +417,13 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 				int thumbSize = results.getInt(3);
 				InputStream thumbStream = results.getBinaryStream(4);
 				byte[] thumbData = new byte[thumbSize];
-				int bytesRead = thumbStream.read(thumbData);
+				//int bytesRead = 
+				thumbStream.read(thumbData);
 				int imageSize = results.getInt(5);
 				InputStream imageStream = results.getBinaryStream(6);
 				byte[] imageData = new byte[imageSize];
-				bytesRead = imageStream.read(imageData);
+				//bytesRead = 
+				imageStream.read(imageData);
 				//String k = results.getString(8);
 				analysisResults.getDescriptions().add(description);
 				analysisResults.getIDs().add(id);
@@ -432,7 +431,7 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 				analysisResults.getThumbnails().add(thumbData);
 				analysisResults.getImages().add(imageData);
 			}
-			statement.close();
+
 
 			/* The following code was commented out for performance reasons.
 			 * If the raw performance results are desired, then uncomment
@@ -551,11 +550,13 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 				int thumbSize = results.getInt(3);
 				InputStream thumbStream = results.getBinaryStream(4);
 				byte[] thumbData = new byte[thumbSize];
-				int bytesRead = thumbStream.read(thumbData);
+				//int bytesRead = 
+					thumbStream.read(thumbData);
 				int imageSize = results.getInt(5);
 				InputStream imageStream = results.getBinaryStream(6);
 				byte[] imageData = new byte[imageSize];
-				bytesRead = imageStream.read(imageData);
+				//bytesRead = 
+					imageStream.read(imageData);
 				//String k = results.getString(8);
 				analysisResults.getDescriptions().add(description);
 				analysisResults.getIDs().add(id);
@@ -621,7 +622,8 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 	 */
 	public void taskFinished (int connectionIndex) {
 		Queue<RMIPerfExplorerModel> requestQueue = requestQueues.get(connectionIndex);
-		RMIPerfExplorerModel model = requestQueue.poll();
+		//RMIPerfExplorerModel model = 
+		requestQueue.poll();
 		//PerfExplorerOutput.println(model.toString() + " finished!");
 		// endRSession();
 	}
@@ -717,6 +719,8 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 		   	tmpStr = "select IDENTITY_VAL_LOCAL() FROM analysis_settings";
 			} else if (db.getDBType().compareTo("derby") == 0) {
 		   	tmpStr = "select IDENTITY_VAL_LOCAL() FROM analysis_settings";
+			} else if (db.getDBType().compareTo("h2") == 0) {
+		   	tmpStr = "select IDENTITY_VAL_LOCAL() FROM analysis_settings";
 			} else if (db.getDBType().compareTo("oracle") == 0) {
 		   	tmpStr = "SELECT as_id_seq.currval FROM DUAL";
 			} else { // postgresql 
@@ -953,7 +957,92 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 		}
 		return metrics;
 	}
-
+	/**
+	 * Get the events defined in these profiles.  The client passes in a model
+	 * with one or more experiments selected, and the code will get all the
+	 * events which are common among all trials for those experiemnts.
+	 * 
+	 * @param modelData
+	 * @return List
+	 */
+	public List<String> getPotentialCallPathEvents(RMIPerfExplorerModel modelData) {
+		//PerfExplorerOutput.println("getPotentialEvents()...");
+		List<String> events = new ArrayList<String>();
+		try {
+			DB db = this.getDB();
+			StringBuilder buf = new StringBuilder();
+			if (db.getDBType().compareTo("db2") == 0) {
+				buf.append("select distinct cast (m.name as VARCHAR(256))");
+			} else {
+				buf.append("select distinct ie.name ");
+			}
+			buf.append(" from interval_event ie inner join trial t on ie.trial = t.id ");
+			Object object = modelData.getCurrentSelection();
+			if (object instanceof RMIView) {
+				buf.append(modelData.getViewSelectionPath(true, true, db.getDBType()));
+			} else {
+				buf.append(" inner join experiment e on t.experiment = e.id ");
+				List<Object> selections = modelData.getMultiSelection();
+				if (selections == null) {
+					// just one selection
+					Object selection = modelData.getCurrentSelection();
+					if (selection instanceof Application) {
+						buf.append(" where e.application = ");
+						buf.append(modelData.getApplication().getID());
+					} else if (selection instanceof Experiment) {
+						buf.append(" where t.experiment = ");
+						buf.append(modelData.getExperiment().getID());
+					} else if (selection instanceof Trial) {
+						buf.append(" where t.id = ");
+						buf.append(modelData.getTrial().getID());
+					}
+				} else {
+					Object selection = modelData.getCurrentSelection();
+					if (selection instanceof Application) {
+						buf.append(" where e.application in (");
+						for (int i = 0 ; i < selections.size() ; i++) {
+							Application app = (Application)selections.get(i);
+							if (i > 0)
+								buf.append(",");
+							buf.append(app.getID());
+						}
+						buf.append(")");
+					} else if (selection instanceof Experiment) {
+						buf.append(" where t.experiment in (");
+						for (int i = 0 ; i < selections.size() ; i++) {
+							Experiment exp = (Experiment)selections.get(i);
+							if (i > 0)
+								buf.append(",");
+							buf.append(exp.getID());
+						}
+						buf.append(")");
+					} else if (selection instanceof Trial) {
+						buf.append(" where t.id in (");
+						for (int i = 0 ; i < selections.size() ; i++) {
+							Trial trial = (Trial)selections.get(i);
+							if (i > 0)
+								buf.append(",");
+							buf.append(trial.getID());
+						}
+						buf.append(")");
+					}
+				}
+			}
+			buf.append(" and (group_name is null or group_name like '%TAU_CALLPATH%') ");
+			PreparedStatement statement = db.prepareStatement(buf.toString());
+			//PerfExplorerOutput.println(statement.toString());
+			ResultSet results = statement.executeQuery();
+			while (results.next() != false) {
+				events.add(results.getString(1));
+			}
+			statement.close();
+		} catch (Exception e) {
+			String error = "ERROR: Couldn't select the events from the database!";
+			System.err.println(error);
+			e.printStackTrace();
+		}
+		return events;
+	}
 	/**
 	 * Get the events defined in these profiles.  The client passes in a model
 	 * with one or more experiments selected, and the code will get all the
@@ -1127,19 +1216,19 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 		return events;
 	}
 
-	private static String shortName(String longName) {
-		StringTokenizer st = new StringTokenizer(longName, "(");
-		String shorter = null;
-		try {
-			shorter = st.nextToken();
-			if (shorter.length() < longName.length()) {
-				shorter = shorter + "()";
-			}
-		} catch (NoSuchElementException e) {
-			shorter = longName;
-		}
-		return shorter;
-	}
+//	private static String shortName(String longName) {
+//		StringTokenizer st = new StringTokenizer(longName, "(");
+//		String shorter = null;
+//		try {
+//			shorter = st.nextToken();
+//			if (shorter.length() < longName.length()) {
+//				shorter = shorter + "()";
+//			}
+//		} catch (NoSuchElementException e) {
+//			shorter = longName;
+//		}
+//		return shorter;
+//	}
 
 	/**
 	 * This method will request the column names for the application, 
@@ -1246,6 +1335,8 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 				tmpStr = "select IDENTITY_VAL_LOCAL() FROM trial_view";
 			} else if (db.getDBType().compareTo("derby") == 0) {
 				tmpStr = "select IDENTITY_VAL_LOCAL() FROM trial_view";
+			} else if (db.getDBType().compareTo("h2") == 0) {
+				tmpStr = "select IDENTITY_VAL_LOCAL() FROM trial_view";
 			} else if (db.getDBType().compareTo("oracle") == 0) {
 				tmpStr = "SELECT " + db.getSchemaPrefix() + "tv_id_seq.currval FROM DUAL";
 			} else { // postgresql 
@@ -1341,10 +1432,6 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 	 * @param views
 	 * @return List
 	 */
-	/* (non-Javadoc)
-	 * @see common.RMIPerfExplorer#getTrialsForView(java.util.List)
-	 */
-	@SuppressWarnings("unchecked")  // for Trial.getTrialList() call
 	public List<Trial> getTrialsForView (List<RMIView> views, boolean getXMLMetadata) {
 		//PerfExplorerOutput.println("getTrialsForView()...");
 		List<Trial> trials = new ArrayList<Trial>();
@@ -1707,7 +1794,6 @@ public class PerfExplorerServer extends UnicastRemoteObject implements RMIPerfEx
 	 * @param trialID
 	 * @return List of PerfDMF IntervalEvent objects.
 	 */
-	@SuppressWarnings("unchecked")
 	public List<RMISortableIntervalEvent> getEventList(int trialID, int metricIndex) {
 		try {
 			this.session.setTrial(trialID, false);
