@@ -9,9 +9,13 @@
 
 package edu.uoregon.tau;
 
-import java.util.*;
+//import java.util.;
 
 
+import java.util.Date;
+import java.util.HashMap;
+import java.util.Map;
+
 import base.drawable.*;
 //import logformat.trace.*;
 import logformat.slog2.*;
@@ -29,14 +33,15 @@ public class Tau2Slog2
     private static boolean  enable_endtime_check;
     private static boolean  continue_when_violation;
 
-    public static void main( String[] args )
+    @SuppressWarnings("unchecked")
+	public static void main( String[] args )
     {
         InputLog							dobj_ins;
         logformat.slog2.output.OutputLog    slog_outs;
         Kind                                next_kind;
         Topology                            topo;
         CategoryMap                         objdefs;   // Drawable def'n
-        Map                                 shadefs;   // Shadow   def'n
+        Map<Topology,Category>                                 shadefs;   // Shadow   def'n
         Category                            objdef;
         LineIDMapList                       lineIDmaps;
         LineIDMap                           lineIDmap;
@@ -59,11 +64,17 @@ public class Tau2Slog2
 
         out_filename = null;
         parseCmdLineArgs( args );
-        if ( out_filename == null )
-            out_filename  = TraceName.getDefaultSLOG2Name( tautrc );
+        if ( out_filename == null ){
+        	int lastP=tautrc.lastIndexOf('.');
+        	String outF =tautrc.substring(0, lastP);
+        	outF+=".slog2";
+        	out_filename=outF;
+        	 //out_filename  = TraceName.getDefaultSLOG2Name( tautrc );
+        }
+           
 
         objdefs       = new CategoryMap();
-        shadefs       = new HashMap();
+        shadefs       = new HashMap<Topology,Category>();
         lineIDmaps    = new LineIDMapList();
         Nobjs         = 0;
 
@@ -133,7 +144,16 @@ public class Tau2Slog2
                     offended_dobj     = prime_obj;
                     prev_dobj_endtime = curr_dobj_endtime;
                 }
+                
+//                treetrunk.addDrawable( prime_obj );
+                
+                try{
                 treetrunk.addDrawable( prime_obj );
+                }catch(Exception e){
+                	e.printStackTrace();
+                	
+                	System.out.println(prime_obj.toString());
+                }
             }
             else if ( next_kind == Kind.COMPOSITE ) {
                 cmplx_obj = dobj_ins.getNextComposite();
@@ -175,7 +195,14 @@ public class Tau2Slog2
                                   + "from peekNextKind() = " + next_kind );
             }
         }   // Endof while ( dobj_ins.peekNextKind() )
-        treetrunk.flushToFile();
+        //treetrunk.flushToFile();
+        try{
+        	treetrunk.flushToFile();
+            }catch(Exception e){
+            	e.printStackTrace();
+            	
+            
+            }
 
         objdefs.removeUnusedCategories();
         slog_outs.writeCategoryMap( objdefs );
@@ -215,8 +242,8 @@ public class Tau2Slog2
             return Integer.parseInt( size_str );
     }
 
-    private static String help_msg = "Usage: java Tau2Slog2 "
-                                   + "[options] tau_trc_file tau_edf_file.\n"
+    private static String help_msg = "\nUsage: tau2slog "
+                                   + "[options] <tau_trc_file> <tau_edf_file> -o <output.slog2>\n"
                                    + " options: \n"
                                    + "\t [-h|--h|-help|--help]             "
                                    + "\t Display HELP message.\n"
@@ -241,7 +268,10 @@ public class Tau2Slog2
                                    + "k, K, m or M,\n"
                                    + "       where k or K stands for kilobyte,"
                                    + " m or M stands for megabyte.\n"
-                                   + "       e.g. 64k means 65536 bytes.\n";
+                                   + "       e.g. 64k means 65536 bytes.\n"
+    + "\n"
+    + "Example:\n"
+    + "  tau2slog2 tau.trc tau.edf -o tau.slog2\n\n";
 
     private static void parseCmdLineArgs( String argv[] )
     {
