@@ -15,7 +15,8 @@ invoke_with_tau=yes
 
 DEFAULT_MAKEFILE=
 
-if [ $# = 0 ] ; then
+usage()
+{
     cmd=`basename $0`
     echo ""
     echo " $cmd - C++ compiler wrapper for TAU"
@@ -32,6 +33,14 @@ if [ $# = 0 ] ; then
     echo " % setenv TAU_MAKEFILE /usr/local/tau-2.x/include/Makefile"
     echo " % setenv TAU_OPTIONS -optVerbose -optTauSelectFile=select.tau"
     echo " % $cmd -c foo.cpp"
+    echo ""
+    echo " Options:"
+    echo "   -tau:help            Show this help message"
+    echo "   -tau:show            Do not invoke, just show what would be done"
+    echo "   -tau:showcompiler    Show underlying compiler"
+    echo "   -tau:showincludes    Show header file options used by the compiler"
+    echo "   -tau:showlibs        Show libraries used by the compiler"
+
     echo ""
     echo "TAU_OPTIONS:"
     echo ""
@@ -47,6 +56,10 @@ if [ $# = 0 ] ; then
     echo -e "  -optPDTInst\t\t\tUse PDT-based instrumentation."
     echo ""
     exit 1
+}
+
+if [ $# = 0 ] ; then
+    usage
 fi
 
 TAUARGS=
@@ -67,7 +80,7 @@ for arg in "$@" ; do
 	      makefile_specified=yes
 	      ;;
 	  -tau_options=*)
-	      TAUCOMPILER_OPTIONS=`echo $arg | sed -e 's/-tau_options=//'`
+	      TAUCOMPILER_OPTIONS=`echo $arg | sed -e 's/\^/ /g' | sed -e 's/-tau_options=//'`
 	      options_specified=yes
 	      ;;
 	  -show)
@@ -76,6 +89,33 @@ for arg in "$@" ; do
 	      NON_TAUARGS="$NON_TAUARGS $modarg"
               SHOW=show
 	      ;;
+	  -tau:show)
+	      invoke_without_tau=yes
+	      invoke_with_tau=no
+	      NON_TAUARGS="$NON_TAUARGS $modarg"
+              SHOW=show
+	      ;;
+	  -tau:showincludes)
+	      invoke_without_tau=yes
+	      invoke_with_tau=no
+	      NON_TAUARGS="$NON_TAUARGS $modarg"
+              SHOW=showincludes
+	      ;;
+	  -tau:showlibs)
+	      invoke_without_tau=yes
+	      invoke_with_tau=no
+	      NON_TAUARGS="$NON_TAUARGS $modarg"
+              SHOW=showlibs
+	      ;;
+	  -tau:showcompiler)
+	      invoke_without_tau=yes
+	      invoke_with_tau=no
+	      NON_TAUARGS="$NON_TAUARGS $modarg"
+              SHOW=showcompiler
+	      ;;
+	  -tau:help)
+              usage
+              ;;
 	  -E)
 	      invoke_without_tau=yes
 	      invoke_with_tau=no
@@ -97,12 +137,22 @@ for arg in "$@" ; do
               # these arguments should only go to the non-tau invocation
 	      NON_TAUARGS="$NON_TAUARGS $modarg"
 	      ;;
-	  -M | -MM | -V | -v | --version | -print-prog-name=ld | -print-search-dirs | -dumpversion)
+	  -M | -MM | -V | --version | -print-prog-name=ld | -print-search-dirs | -dumpversion)
               # if any of these are specified, we invoke the regular compiler only
 	      invoke_without_tau=yes
 	      invoke_with_tau=no
 	      NON_TAUARGS="$NON_TAUARGS $modarg"
 	      ;;
+	  -v)
+	      if [ "$#" -eq 1 ] ; then
+	      	invoke_without_tau=yes
+	      	invoke_with_tau=no
+	      	NON_TAUARGS="$NON_TAUARGS $modarg"
+	      else
+	         TAUARGS="$TAUARGS $modarg"
+	         NON_TAUARGS="$NON_TAUARGS $modarg"
+	      fi
+	      ;;
 	  *)
 	      TAUARGS="$TAUARGS $modarg"
 	      NON_TAUARGS="$NON_TAUARGS $modarg"
@@ -135,15 +185,24 @@ fi
 
 TAUCOMPILER_OPTIONS="$TAUCOMPILER_OPTIONS -optDefaultParser=cxxparse"
 
+retval=0
+
 if [ $invoke_without_tau = yes ] ; then
 cat <<EOF > /tmp/makefile.tau.$USER.$$
 include $MAKEFILE
 all:
 	@\$(TAU_RUN_CXX) \$(TAU_MPI_INCLUDE) $NON_TAUARGS
 show:
-	@echo \$(TAU_RUN_CXX) \$(TAU_MPI_FLIBS) \$(TAU_LIBS) \$(TAU_LDFLAGS) \$(TAU_CXXLIBS)
+	@echo \$(TAU_RUN_CXX) \$(TAU_INCLUDE) \$(TAU_MPI_INCLUDE) \$(TAU_DEFS) \$(TAU_MPI_FLIBS) \$(TAU_LIBS) \$(TAU_LDFLAGS) \$(TAU_CXXLIBS)
+showcompiler:
+	@echo \$(TAU_RUN_CXX)
+showincludes:
+	@echo \$(TAU_INCLUDE) \$(TAU_MPI_INCLUDE)
+showlibs:
+	@echo \$(TAU_MPI_FLIBS) \$(TAU_LIBS) 
 EOF
 make -s -f /tmp/makefile.tau.$USER.$$  $SHOW
+retval=$?
 /bin/rm -f /tmp/makefile.tau.$USER.$$
 fi
 
@@ -156,6 +215,10 @@ all:
 
 EOF
 make -s -f /tmp/makefile.tau.$USER.$$
+retval=$?
 /bin/rm -f /tmp/makefile.tau.$USER.$$
 fi
 
+if [ $retval != 0 ] ; then
+    exit 1
+fi
