@@ -1,6 +1,7 @@
 package edu.uoregon.tau.multimerge;
 
-import java.awt.Point;
+
+
 import java.io.File;
 import java.io.FilenameFilter;
 import java.util.ArrayList;
@@ -24,14 +25,14 @@ class TotID{
 	 * The name of the trace file
 	 */
 	public String filename;
-	/**
-	 * The id of the thread as contained in the trace file
-	 */
-	public int thread;
-	/**
-	 * The id of the node as contained in the trace file
-	 */
-	public int node;
+//	/**
+//	 * The id of the thread as contained in the trace file
+//	 */
+//	public int thread;
+//	/**
+//	 * The id of the node as contained in the trace file
+//	 */
+//	public int node;
 
 	/**
 	 * The map from the local state id (the id in this trace file) to the global state id (the id used in the merged trace)
@@ -46,8 +47,14 @@ class TotID{
 	/**
 	 * The number of CUDA communication use events seen on this thread.  Used to detect communication triplets used by CUDA traces
 	 */
-	public boolean cSeen=false;
-	public boolean send=true;
+	//public boolean cSeen=false;
+	//public boolean send=true;
+	public int oneSideType=-1;
+	//public static final int ONESIDE_SEND=0;
+	//public static final int ONESIDE_RECV=1;
+	public int size=0;
+	
+	public long offset=0;
 
 	//	/**
 	//	 * Most recent valid CUDA mem-copy size, set in the second of 3 communication triplets.
@@ -71,15 +78,15 @@ class TotID{
 	 */
 	StringBuilder mpi=new StringBuilder();//null;
 
-	public int cudaSendID=-1;
-	public int cudaRecvID=-1;
-	public int cudaSizeID=-1;
+	//public int cudaSendID=-1;
+	//public int cudaRecvID=-1;
+	//public int cudaSizeID=-1;
 
 	TotID(String fname){
 		filename=fname;
 		locToGlobStates=new HashMap<Integer, Integer>();
-		thread=-1;
-		node=-1;
+//		thread=-1;
+//		node=-1;
 	}
 }
 
@@ -150,7 +157,7 @@ class TraceNameComparitor implements Comparator<String>{
 class TraceFilter implements FilenameFilter{
 
 	public boolean accept(File arg0, String arg1) {
-		if((arg1.startsWith("tautrace.")||arg1.startsWith("taucudatrace."))&&arg1.endsWith(".trc"))
+		if(arg1.startsWith("tautrace.")&&arg1.endsWith(".trc"))
 			return true;
 		return false;
 	}
@@ -183,8 +190,30 @@ class DoublePair{
 	}
 }
 
+
+class ToFrom{
+	public int toNode,toThread,fromNode,fromThread;
+
+	public ToFrom(int toNode, int toThread, int fromNode, int fromThread) {
+		super();
+		this.toNode = toNode;
+		this.toThread = toThread;
+		this.fromNode = fromNode;
+		this.fromThread = fromThread;
+	}
+	
+	
+	
+}
+
 public class MultiMerge {
 
+	private static final int ONESIDED_MESSAGE_SEND=70000;
+	private static final int ONESIDED_MESSAGE_RECV=70001;
+	private static final int ONESIDED_MESSAGE_ID_TriggerValueT1=70002;
+	private static final int ONESIDED_MESSAGE_ID_TriggerValueT2=70003;
+	
+	
 	/**
 	 * The map between state ids provided by different threads, and the global id used in the merged trace
 	 */
@@ -201,19 +230,19 @@ public class MultiMerge {
 	 * Keeps track of the number of state and user-events seen so far.  The global ids are set by the current value (ids are sequential in the order seen)
 	 */
 	static int numStates=0;
+//	/**
+//	 * Keeps track of the last global node id recorded.  This allows the global node ids to be generated sequentially.
+//	 */
+//	static int lastNode=-1;
 	/**
-	 * Keeps track of the last global node id recorded.  This allows the global node ids to be generated sequentially.
-	 */
-	static int lastNode=-1;
-	/**
-	 * The map from the node id associated with the old trace file to the new global node id that will be used in the merged trace
-	 */
-	static Map<Integer,Integer> oldNewDest;
+//	 * The map from the node id associated with the old trace file to the new global node id that will be used in the merged trace
+//	 */
+//	static Map<Integer,Integer> oldNewDest;
 
 	/**
 	 * The map from the unique cuda communication id string to the point (node/thread id pair) that is associated with that unique id
 	 */
-	static Map<String,Point> idNodes;
+	static Map<String,ToFrom> idNodes;
 
 	//	/**
 	//	 * This set contains all filename/timestamp combinations that are associated with mpi communication events.  If the string is not in here then it is cuda communication.
@@ -230,6 +259,8 @@ public class MultiMerge {
 	 */
 	static TraceWriter tw;
 
+	private static boolean synch = false;
+	
 	/**
 	 * Given an array of timestamps returns the index of the smallest timestamp greater than or equal to 0;
 	 * @param times an array of timestamps
@@ -314,58 +345,58 @@ public class MultiMerge {
 		return newname;
 	}
 
-	/**
-	 * Does extra initialization on the given TotID object
-	 * @param tot
-	 * @return
-	 */
-	private static TotID initTotLoc(TotID tot){
-
-		boolean isCuda=tot.filename.contains("cuda");
-
-		int[]fn=getNCT(tot.filename);
-		int threadToken=-1;
-		if(isCuda)
-		{
-			threadToken=0;
-		}else{
-			threadToken=fn[2];
-		}
-
-		/*
-		 * If this is a threaded trace file we are on the same node as before, just update the thread
-		 */
-		if(threadToken>0){
-			tot.node=lastNode;
-			tot.thread=threadToken;
-		}
-		/*
-		 * If this is not a threaded entry we're on a new node so increment and set thread to 0.  If this is not a cuda tracefile we need to map the local node ID to the global nodeID.
-		 */
-		else{
-			lastNode++;
-			tot.node=lastNode;
-			tot.thread=0;
-			if(!isCuda){
-				oldNewDest.put(new Integer(fn[0]), new Integer(lastNode));
-			}	
-		}
-
-
-		/*
-		 * Identify the threads based on the n/c/t in the file names.
-		 */
-		if(!tot.filename.startsWith("tautrace")){
-
-			String threadName="Node"+fn[0]+" CUDA Stream "+fn[1]+" Device "+fn[2];
-			tw.defThread(tot.node, tot.thread, threadName);
-		}else{
-			String threadName="Node"+fn[0]+" Thread "+fn[2];
-			tw.defThread(tot.node, tot.thread, threadName);
-		}
-
-		return tot;
-	}
+//	/**
+//	 * Does extra initialization on the given TotID object
+//	 * @param tot
+//	 * @return
+//	 */
+//	private static TotID initTotLoc(TotID tot){
+//
+//		//boolean isCuda=tot.filename.contains("cuda");
+//
+//		int[]fn=getNCT(tot.filename);
+//		int threadToken=-1;
+////		if(isCuda)
+////		{
+////			threadToken=0;
+////		}else{
+//			threadToken=fn[2];
+//		//}
+//
+//		/*
+//		 * If this is a threaded trace file we are on the same node as before, just update the thread
+//		 */
+//		/*if(threadToken>0){
+//			tot.node=lastNode;
+//			tot.thread=threadToken;
+//		}*/
+//		/*
+//		 * If this is not a threaded entry we're on a new node so increment and set thread to 0.  If this is not a cuda tracefile we need to map the local node ID to the global nodeID.
+//		 */
+//		//else{
+////			lastNode++;
+////			tot.node=lastNode;
+////			tot.thread=0;
+////			if(threadToken==0){
+////				oldNewDest.put(new Integer(fn[0]), new Integer(lastNode));
+//			//}	
+////		}
+//
+//
+//		/*
+//		 * Identify the threads based on the n/c/t in the file names.
+//		 */
+//		if(threadToken==1){//!tot.filename.startsWith("tautrace")){
+//
+//			String threadName="Node"+fn[0]+" CUDA Stream "+fn[1]+" Device "+fn[2];
+//			tw.defThread(tot.node, tot.thread, threadName);
+//		}else{
+//			String threadName="Node"+fn[0]+" Thread "+fn[2];
+//			tw.defThread(tot.node, tot.thread, threadName);
+//		}
+//
+//		return tot;
+//	}
 
 	/**
 	 * Returns a sorted list of all trace files in the current directory
@@ -400,7 +431,7 @@ public class MultiMerge {
 			initReaders[rs].setDefsOnly(false);
 			initReaders[rs].setSubtractFirstTimestamp(false);
 			TotID t = new TotID(initReaders[rs].getTraceFile());
-			t=initTotLoc(t);
+//			t=initTotLoc(t);
 			totIDs[rs]=t;
 			recs_read=0;
 			do{
@@ -412,6 +443,18 @@ public class MultiMerge {
 			}else System.out.println("Warning: Tried to close null trace");
 			initReaders[rs]=null;
 		}
+		if(synch){
+		long base=0;
+		for(int i=0;i<totIDs.length;i++){
+			if(i==0){
+				base=totIDs[i].offset;
+				totIDs[i].offset=0;
+			}
+			else{
+				totIDs[i].offset=base-totIDs[i].offset;
+			}
+		}
+		}
 	}
 
 	/**
@@ -434,6 +477,7 @@ public class MultiMerge {
 			readers[rs].setSubtractFirstTimestamp(false);//TODO: Why is this needed only for cuda output?
 			totalRecords+=readers[rs].getNumRecords();
 			sorter[rs]=readers[rs].peekTime();
+			if(synch){sorter[rs]+=totIDs[rs].offset;}
 		}
 
 		System.out.println(totalRecords+" records to merge.");
@@ -461,6 +505,7 @@ public class MultiMerge {
 				}
 
 				sorter[minDex]=readers[minDex].peekTime();
+				if(synch){sorter[minDex]+=totIDs[minDex].offset;}
 				if(sorter[minDex]==-1)
 				{
 					readers[minDex].closeTrace();
@@ -483,8 +528,8 @@ public class MultiMerge {
 	public static void main(String[] args) {
 
 		//mpiCom=new HashSet<String>();
-		oldNewDest=new HashMap<Integer,Integer>();
-		idNodes=new HashMap<String,Point>();
+		//oldNewDest=new HashMap<Integer,Integer>();
+		idNodes=new HashMap<String,ToFrom>();
 		stateMap=new HashMap<String,Integer>();
 		ueMap=new HashMap<String,Integer>();
 		tw = new TraceWriter("tau.trc", "tau.edf");
@@ -550,7 +595,7 @@ public class MultiMerge {
 
 			TotID tot = (TotID)userData;
 
-			if(userEventName.equals("TAUCUDA_MEM_SEND")){
+			/*if(userEventName.equals("TAUCUDA_MEM_SEND")){
 				tot.cudaSendID=userEventToken;
 				return 0;
 			} 
@@ -561,7 +606,10 @@ public class MultiMerge {
 			if(userEventName.equals("TAUCUDA_COPY_MEM_SIZE")){
 				tot.cudaSizeID=userEventToken;
 				return 0;
-			} 
+			} */
+			
+			if(userEventToken>=70000)
+				return 0;
 
 
 			/*
@@ -590,6 +638,8 @@ public class MultiMerge {
 			return 0;
 		}
 		public int leaveState(Object userData, long time, int nodeToken, int threadToken, int stateToken){
+			TotID tot = (TotID)userData;
+			tot.offset=time;
 			return 0;
 		}
 
@@ -606,7 +656,25 @@ public class MultiMerge {
 		public int eventTrigger(Object userData, long time, int nodeToken, int threadToken, int userEventToken, double userEventValue) {
 			TotID tot = (TotID)userData;
 
-			if(userEventToken==tot.cudaRecvID||userEventToken==tot.cudaSendID)
+			if(userEventToken==ONESIDED_MESSAGE_ID_TriggerValueT1){
+				tot.dp.l1=userEventValue;
+			}
+			
+			if(userEventToken==ONESIDED_MESSAGE_ID_TriggerValueT2){
+				tot.dp.l2=userEventValue;
+				
+				ToFrom p =idNodes.get(tot.dp.toString());
+				if(p==null){
+					p=new ToFrom(nodeToken,threadToken,-1,-1);
+					idNodes.put(tot.dp.toString(), p);
+				}else if(p.toNode!=nodeToken||p.toThread!=threadToken){
+					p.fromNode=nodeToken;
+					p.fromThread=threadToken;
+				}
+			}
+			
+			/*
+			if(userEventToken==ONESIDED_MESSAGE_SEND||userEventToken==ONESIDED_MESSAGE_RECV)
 			{
 
 				if(!tot.cSeen){
@@ -644,7 +712,7 @@ public class MultiMerge {
 					//tot.uniC.setLength(0);
 
 				}
-			}
+			}*/
 
 			return 0;
 		}
@@ -684,16 +752,20 @@ public class MultiMerge {
 
 		public int enterState(Object userData, long time, int nodeToken, int threadToken, int stateToken){
 			TotID tot = (TotID)userData;
-
+			if(synch){
+				time+=tot.offset;
+			}
 			int actualID=tot.locToGlobStates.get(new Integer(stateToken)).intValue();
 
-			tw.enterState(time, tot.node, tot.thread, actualID);
+			tw.enterState(time, nodeToken, threadToken, actualID);
 			return 0;
 		}
 		public int leaveState(Object userData, long time, int nodeToken, int threadToken, int stateToken){
 			TotID tot = (TotID)userData;
-
-			tw.leaveState(time, tot.node, tot.thread, tot.locToGlobStates.get(new Integer(stateToken)).intValue());
+			if(synch){
+				time+=tot.offset;
+			}
+			tw.leaveState(time, nodeToken, threadToken, tot.locToGlobStates.get(new Integer(stateToken)).intValue());
 			return 0;
 		}
 
@@ -702,16 +774,18 @@ public class MultiMerge {
 				int destinationNodeToken, int destinationThreadToken, int messageSize, int messageTag, int messageComm){
 
 			TotID tot = (TotID)userData;
-
-
-			Integer transNode=oldNewDest.get(new Integer(destinationNodeToken));
-			if(transNode==null)
-			{
-				System.out.println("Bad Dest Node ID: "+destinationNodeToken);
-				return 0;
+			if(synch){
+				time+=tot.offset;
 			}
 
-			tw.sendMessage(time, tot.node, tot.thread, transNode.intValue(), destinationThreadToken, messageSize, messageTag, messageComm);
+//			Integer transNode=oldNewDest.get(new Integer(destinationNodeToken));
+//			if(transNode==null)
+//			{
+//				System.out.println("Bad Dest Node ID: "+destinationNodeToken);
+//				return 0;
+//			}
+
+			tw.sendMessage(time, sourceNodeToken, sourceThreadToken, destinationNodeToken, destinationThreadToken, messageSize, messageTag, messageComm);
 
 			return 0;
 		}
@@ -720,80 +794,84 @@ public class MultiMerge {
 
 		public int recvMessage(Object userData, long time, int sourceNodeToken, int sourceThreadToken, int destinationNodeToken, int destinationThreadToken, int messageSize, int messageTag, int messageCom) {
 			TotID tot = (TotID)userData;
-
-
-
-			Integer transNode=oldNewDest.get(new Integer(sourceNodeToken));
-			if(transNode==null)
-			{
-				System.out.println("Bad Source Node ID: "+sourceNodeToken);
-				return 0;
+			if(synch){
+				time+=tot.offset;
 			}
-			tw.recvMessage(time, transNode.intValue(), sourceThreadToken, tot.node, tot.thread, messageSize, messageTag, messageCom);
+
+
+			//Integer transNode=oldNewDest.get(new Integer(sourceNodeToken));
+//			if(transNode==null)
+//			{
+//				System.out.println("Bad Source Node ID: "+sourceNodeToken);
+//				return 0;
+//			}
+			tw.recvMessage(time, sourceNodeToken, sourceThreadToken, destinationNodeToken, destinationThreadToken, messageSize, messageTag, messageCom);
 
 			return 0;
 		}
 
-
+		boolean defRemThread=true;
+		
 		public int eventTrigger(Object userData, long time, int nodeToken, int threadToken, int userEventToken, double userEventValue) {
 			TotID tot = (TotID)userData;
-
-			if(userEventToken==tot.cudaRecvID||userEventToken==tot.cudaSendID)
-			{
-				if(!tot.cSeen){
-					tot.cSeen=true;
-					tot.dp.l1=userEventValue;
-				}
-				else{
-					tot.cSeen=false;
-					tot.dp.l2=userEventValue;
-					if(userEventToken==tot.cudaSendID)
-					{
-						tot.send=true;
-					}
-					else{
-						tot.send=false;
-					}
-				}
+			if(synch){
+				time+=tot.offset;
+			}
+			if(userEventToken==ONESIDED_MESSAGE_SEND||userEventToken==ONESIDED_MESSAGE_RECV){
+				tot.oneSideType=userEventToken;
+				tot.size=(int)userEventValue;
 				return 0;
 			}
-			else if(userEventToken==tot.cudaSizeID)
+			if(userEventToken==ONESIDED_MESSAGE_ID_TriggerValueT1)
 			{
-				Point p = idNodes.get(tot.dp.toString());
+				tot.dp.l1=userEventValue;
+				return 0;
+			}
+			if(userEventToken==ONESIDED_MESSAGE_ID_TriggerValueT2)
+			{
+				tot.dp.l2=userEventValue;
+				ToFrom p = idNodes.get(tot.dp.toString());
 				if(p==null){
 					System.out.println("Bad Recv: "+tot.dp);
 					return 0;
 				}
-
-				if(p.x!=tot.node&&p.y!=tot.node){
-					System.out.println(tot.dp+" not for "+tot.node);
+				int remoteNode,remoteThread;
+				if(p.toNode==nodeToken&&p.toThread==threadToken){
+					remoteNode=p.fromNode;
+					remoteThread=p.fromThread;
+				}
+				else if(p.fromNode==nodeToken&&p.fromThread==threadToken){
+					remoteNode=p.toNode;
+					remoteThread=p.toThread;
+				}	
+				else{
+					System.out.println(tot.dp+" not for node: "+nodeToken+" thread: "+threadToken);
+					return 0;
 				}
 				//tot.uniR.setLength(0);
-				int remote;
-				if(p.x==tot.node)
+				if(defRemThread)
 				{
-					remote=p.y;
-				}else{
-					remote=p.x;
+					tw.defUserEvent(7004, "RemoteMessageThreadID", 1);
+					defRemThread=false;
 				}
-				if(tot.send)
+				tw.eventTrigger(time, nodeToken, threadToken, 7004, remoteThread);
+				if(tot.oneSideType==ONESIDED_MESSAGE_SEND)
 				{
-					tw.sendMessage(time,  tot.node, tot.thread, remote, 0, (int)userEventValue, 0, 0);
+					tw.sendMessage(time,  nodeToken, threadToken, remoteNode, remoteThread, (int)userEventValue, 0, 0);
 				}
 				else{
-					tw.recvMessage(time,  remote, 0, tot.node, tot.thread, (int)userEventValue, 0, 0);
+					tw.recvMessage(time,  remoteNode, remoteThread, nodeToken, threadToken, (int)userEventValue, 0, 0);
 				}
 
 				return 0;
 			}
 
+//			if(tot.thread>0)
+//			{
+//				System.out.println("Event from node!");
+//			}
 
-			if(tot.thread>0)
-			{
-				System.out.println("Event from node!");
-			}
-
-			tw.eventTrigger(time, tot.node, tot.thread, tot.locToGlobStates.get(new Integer(userEventToken)).intValue(), (long)userEventValue);
+			tw.eventTrigger(time, nodeToken, threadToken, tot.locToGlobStates.get(new Integer(userEventToken)).intValue(), (long)userEventValue);
 			return 0;}
 
 		public int endTrace(Object userData, int nodeToken, int threadToken){
