@@ -19,7 +19,6 @@ import java.util.Observable;
 
 import javax.media.opengl.GL;
 import javax.media.opengl.GLAutoDrawable;
-import javax.media.opengl.GLAutoDrawable;
 import javax.swing.BorderFactory;
 import javax.swing.JCheckBox;
 import javax.swing.JLabel;
@@ -28,8 +27,6 @@ import javax.swing.JSlider;
 import javax.swing.event.ChangeEvent;
 import javax.swing.event.ChangeListener;
 
-import com.sun.opengl.util.GLUT;
-
 /**
  * Draws a 3d bar plot.
  *
@@ -39,7 +36,7 @@ import com.sun.opengl.util.GLUT;
  */
 public class BarPlot implements Plot {
 
-    private final GLUT glut = new GLUT();
+    //private final GLUT glut = new GLUT();
 
     // settings that the user can tweak
     private float xSize, ySize, zSize;
@@ -54,13 +51,16 @@ public class BarPlot implements Plot {
     // if a value is less than this threshold, no box will be drawn 
     // (this is essential to drawing huge datasets (64k+)
     private static float threshold = 0.05f; // 5 percent
+    private static final float defThreshold=0.05f;
+    private static final float noThreshold=0f;
+    private boolean useThreshold=true;
 
     // implementation details
     private int nrows;
     private int ncols;
     private float[][] heightValues, colorValues;
     private boolean dirty = true;
-    private List displayLists = new ArrayList();
+    private List<Integer> displayLists = new ArrayList<Integer>();
 
     private int translucentDisplayListsXplus;
     private int translucentDisplayListsXminus;
@@ -409,7 +409,7 @@ public class BarPlot implements Plot {
         // delete displaylists
         if (displayLists != null) {
             for (int i = 0; i < displayLists.size(); i++) {
-                gl.glDeleteLists(((Integer) displayLists.get(i)).intValue(), 1);
+                gl.glDeleteLists(displayLists.get(i).intValue(), 1);
             }
             displayLists.clear();
             displayLists = null;
@@ -425,11 +425,11 @@ public class BarPlot implements Plot {
             if (displayLists != null) {
                 // delete old displaylists
                 for (int i = 0; i < displayLists.size(); i++) {
-                    gl.glDeleteLists(((Integer) displayLists.get(i)).intValue(), 1);
+                    gl.glDeleteLists(displayLists.get(i).intValue(), 1);
                 }
-                displayLists = new ArrayList();
+                displayLists = new ArrayList<Integer>();
             } else {
-                displayLists = new ArrayList();
+                displayLists = new ArrayList<Integer>();
             }
 
             Integer displayList = new Integer(gl.glGenLists(1));
@@ -564,7 +564,7 @@ public class BarPlot implements Plot {
         }
 
         for (int i = 0; i < displayLists.size(); i++) {
-            gl.glCallList(((Integer) displayLists.get(i)).intValue());
+            gl.glCallList(displayLists.get(i).intValue());
         }
 
         renderSelection(gl);
@@ -891,6 +891,22 @@ public class BarPlot implements Plot {
             }
         });
 
+        
+        final JCheckBox thresholdBox = new JCheckBox("Use Height Threshold",useThreshold);
+        thresholdBox.addActionListener(new ActionListener() {
+            public void actionPerformed(ActionEvent evt) {
+                try {
+                   setUseThreshold(thresholdBox.isSelected());
+                    
+                    
+                    visRenderer.redraw();
+
+                } catch (Exception e) {
+                    VisTools.handleException(e);
+                }
+            }
+        });
+        
         gbc.anchor = GridBagConstraints.WEST;
         gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
@@ -909,6 +925,9 @@ public class BarPlot implements Plot {
         addCompItem(sizePanel, plotHeightSlider, gbc, 1, 2, 1, 1);
         addCompItem(sizePanel, barSizeSlider, gbc, 1, 3, 1, 1);
         addCompItem(sizePanel, translucencySlider, gbc, 1, 4, 1, 1);
+        addCompItem(sizePanel, thresholdBox, gbc, 0, 5, 1, 1);
+        
+        
         return sizePanel;
 
     }
@@ -998,6 +1017,18 @@ public class BarPlot implements Plot {
         this.dirty = true;
     }
 
+    public void setUseThreshold(boolean thresh){
+        if(thresh){
+        	threshold = defThreshold;
+        
+        }
+        else
+        {
+        	threshold = noThreshold;
+        }
+        this.dirty = true;
+    }
+    
     /**
      * Returns current translucency ratio.
      * @return the current translucency value (0..1).
