@@ -13,9 +13,12 @@ import java.util.EmptyStackException;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.LinkedList;
+import java.util.List;
 import java.util.Random;
 import java.util.Set;
 
+import logformat.trace.DobjDef;
+
 import base.drawable.Category;
 import base.drawable.Composite;
 import base.drawable.Kind;
@@ -54,7 +57,7 @@ class PrimEvent
 	int stateToken;
 }
 
-class EZStack extends ArrayList{
+class EZStack extends ArrayList<PrimEvent>{
 	/**
 	 * 
 	 */
@@ -62,11 +65,11 @@ class EZStack extends ArrayList{
 
 	public EZStack() {
     }
-	public void push(Object o){
+	public void push(PrimEvent o){
 		add(o);
 	}
 	
-	public Object peek(){
+	public PrimEvent peek(){
 		int	len = size();
 
 		if (len == 0)
@@ -74,8 +77,8 @@ class EZStack extends ArrayList{
 		return get(len - 1);
 	}
 	
-	public Object pop(){
-		Object obj;
+	public PrimEvent pop(){
+		PrimEvent obj;
 		
 		int	len = size();
 
@@ -90,6 +93,54 @@ class EZStack extends ArrayList{
 	    }
 }
 
+
+class ComSource {
+	int source;
+	int dest;
+	int tag;
+	
+	
+
+	public ComSource(int source, int dest, int tag) {
+		super();
+		this.source = source;
+		this.dest = dest;
+		this.tag = tag;
+	}
+
+
+
+	@Override
+	public int hashCode() {
+		final int prime = 31;
+		int result = 1;
+		result = prime * result + dest;
+		result = prime * result + source;
+		result = prime * result + tag;
+		return result;
+	}
+
+
+
+	@Override
+	public boolean equals(Object obj) {
+		if (this == obj)
+			return true;
+		if (obj == null)
+			return false;
+		if (getClass() != obj.getClass())
+			return false;
+		ComSource other = (ComSource) obj;
+		if (dest != other.dest)
+			return false;
+		if (source != other.source)
+			return false;
+		if (tag != other.tag)
+			return false;
+		return true;
+	}
+}
+
 /*
    This class provides the Java version of TRACE-API.
 */
@@ -110,11 +161,12 @@ public class InputLog implements base.drawable.InputAPI
 	private static boolean eventReady;
 	private static boolean doneReading;
 	
-	private static ArrayList categories;
+	private static ArrayList<DobjDef> categories;
 	//private static int numcats;
 	//private static int maxcats;
 	//private static base.drawable.YCoordMap ymap;
 	private static base.drawable.Primitive prime;
+	private static base.drawable.Primitive lastPrime;
 	private base.drawable.Category statedef;
 	
 	//private static Map global;
@@ -122,19 +174,19 @@ public class InputLog implements base.drawable.InputAPI
 	//private static int numthreads;
 	private static int maxnode;
 	private static int maxthread;
-	private static HashMap eventstack;
-	private static HashMap msgRecStack;
-	private static HashMap msgSenStack;
+	private static HashMap<Integer, EZStack> eventstack;
+	private static HashMap<ComSource, List<MessageEvent>> msgRecStack;
+	private static HashMap<ComSource, List<MessageEvent>> msgSenStack;
 	//private static int[] offset;
 	
 	private static Random getcolors;
-	private static Set msgtags;
+	private static Set<Integer> msgtags;
 	/**
 	 * Associates each thread with a state of 0,1 or 2 with 1 indicating an actual event containing data, 
 	 * and 0 or 2 indicating leading and trailing 'empty' events.
 	 */
-	private static HashMap noMonEventCycle;
-	private static Set noMonEvents;
+	private static HashMap<Integer, Integer> noMonEventCycle;
+	private static Set<Integer> noMonEvents;
 	
 	private static int maxEvtId;
 	
@@ -147,10 +199,10 @@ public class InputLog implements base.drawable.InputAPI
 		return (nid << 16)+tid;
 	}
 	
-	private static long SourceDest(int source,int dest)
-	{
-		return ((long)source << 32)+dest;
-	}
+//	private static long SourceDest(int source,int dest, int tag)
+//	{
+//		return ((long)source << 32)+dest;
+//	}
 	
 	/*private static int GlobalID(int localnodeid, int localthreadid)
 	{
@@ -201,7 +253,7 @@ public class InputLog implements base.drawable.InputAPI
 	{
 		//private 
 		
-		categories = new ArrayList();//TreeMap();//base.drawable.Category[128];
+		categories = new ArrayList<DobjDef>();//TreeMap();//base.drawable.Category[128];
 		//logformat.trace.DobjDef newobj= new logformat.trace.DobjDef(1, "message", Topology.ARROW_ID, 
 			//	255,255,255, 255, 3, "msg_tag=%d, msg_size=%d", null);
 
@@ -209,6 +261,7 @@ public class InputLog implements base.drawable.InputAPI
 		//numcats=0;
 		//maxcats=0;
 		prime=null;
+		lastPrime=null;
 		clockP=1;
 		eventReady=false;
 		doneReading=false;
@@ -217,9 +270,9 @@ public class InputLog implements base.drawable.InputAPI
 		maxnode=0;
 		maxthread=0;
 		maxEvtId=0;
-		msgtags=new HashSet();
+		msgtags=new HashSet<Integer>();
 		getcolors = new Random(0);
-		noMonEvents=new HashSet();
+		noMonEvents=new HashSet<Integer>();
 		
 		TraceReaderCallbacks def_cb = new TAUReaderInit();
 		TraceReader tFileDefRead=new TraceReader(tautrc,tauedf);
@@ -251,10 +304,10 @@ public class InputLog implements base.drawable.InputAPI
 					offset[i+1]=offset[i]+maxthread+1;
 			}
 		}*/
-		eventstack = new HashMap();// Stack[maxnode+1][maxthread+1];
-		msgRecStack = new HashMap();// Stack[maxnode+1][maxthread+1];
-		msgSenStack = new HashMap();
-		noMonEventCycle = new HashMap();//[maxnode+1][maxthread+1];
+		eventstack = new HashMap<Integer, EZStack>();// Stack[maxnode+1][maxthread+1];
+		msgRecStack = new HashMap<ComSource, List<MessageEvent>>();// Stack[maxnode+1][maxthread+1];
+		msgSenStack = new HashMap<ComSource, List<MessageEvent>>();
+		noMonEventCycle = new HashMap<Integer, Integer>();//[maxnode+1][maxthread+1];
 		
 		ev_cb = new TAUReader();
 		tFileEvRead=new TraceReader(tautrc,tauedf);
@@ -268,20 +321,31 @@ public class InputLog implements base.drawable.InputAPI
 		tFileEvRead.closeTrace();
 		return true;
 	}
+	
+	private int popCategory(){
+		statedef = categories.remove(categories.size()-1);// .get(new Integer(maxcats));//[maxcats];
+		//maxcats++;
+		return Kind.CATEGORY_ID;
+	}
 
 	public int peekNextKindIndex()
 	{
+		
 		if(categories.size()>0)//maxcats<categories.size())//numcats)
 		{
-			statedef = (Category)categories.remove(categories.size()-1);// .get(new Integer(maxcats));//[maxcats];
-			//maxcats++;
-			return Kind.CATEGORY_ID;
+			return popCategory();
 		}
 
 		if(!doneReading)
 		{
 			while(!eventReady)
 			{
+				
+				if(categories.size()>0)//maxcats<categories.size())//numcats)
+				{
+					return popCategory();
+				}
+				
 				if(tFileEvRead.readNumEvents(ev_cb, 1, null)==0)
 				{
 					doneReading=true;
@@ -401,6 +465,22 @@ public class InputLog implements base.drawable.InputAPI
 		return bary_outs.getByteArrayBuf();
 	}	
 	
+	protected static byte[] getInfoVals(double[] vals)
+	{
+		BufArrayOutputStream bary_outs  = new BufArrayOutputStream( vals.length*8 );//8
+		DataOutputStream     data_outs  = new DataOutputStream( bary_outs);
+		try {
+			for(int i=0; i< vals.length;i++)
+			{
+				data_outs.writeDouble(vals[i]);
+			}
+		} catch ( java.io.IOException ioerr ) {
+			ioerr.printStackTrace();
+			System.exit( 1 );
+		}
+		return bary_outs.getByteArrayBuf();
+	}	
+	
 	private static class TAUReaderInit implements TraceReaderCallbacks{
 		
 		public int defClkPeriod(Object userData, double clkPeriod) {
@@ -434,6 +514,10 @@ public class InputLog implements base.drawable.InputAPI
 		
 		public int defUserEvent(Object userData, int userEventToken, String userEventName, int monotonicallyIncreasing){
 			
+			if(userEventToken==7004){
+				return 0;
+			}
+			
 			if(monotonicallyIncreasing==0)
 			{
 				noMonEvents.add(new Integer(userEventToken));
@@ -444,7 +528,7 @@ public class InputLog implements base.drawable.InputAPI
 				name = name.substring(1,name.length()-1);
 			
 			logformat.trace.DobjDef newobj= new logformat.trace.DobjDef(userEventToken, name, Topology.EVENT_ID, 
-					getcolors.nextInt(256),getcolors.nextInt(256),getcolors.nextInt(256), 255, 20, "Count=%d", null);
+					getcolors.nextInt(256),getcolors.nextInt(256),getcolors.nextInt(256), 255, 20, "Count=%E", null);
 			categories.add(newobj);//put(new Integer(numcats), newobj);
 			//numcats++;
 			if(userEventToken>maxEvtId)
@@ -477,19 +561,19 @@ public class InputLog implements base.drawable.InputAPI
 			Integer glob = new Integer(GlobalID(nodeToken,threadToken));
 			if(!eventstack.containsKey(glob))//  eventstack[nodeToken][threadToken]==null
 				eventstack.put(glob, new EZStack());  //[nodeToken][threadToken]=new Stack();
-			((EZStack)eventstack.get(glob)).push(new PrimEvent(time,stateToken));//eventstack[nodeToken][threadToken].push(new PrimEvent(time,stateToken));
+			eventstack.get(glob).push(new PrimEvent(time,stateToken));//eventstack[nodeToken][threadToken].push(new PrimEvent(time,stateToken));
 			return 0;
 		}
 		
 		public int leaveState(Object userData, long time, int nodeToken, int threadToken, int stateToken){
 			//System.out.println("Leaving state "+stateToken+" time "+time+" nid "+nodeToken+" tid "+threadToken);
 			Integer glob = new Integer(GlobalID(nodeToken,threadToken));
-			if(!eventstack.containsKey(glob)||((EZStack)eventstack.get(glob)).size()==0)//if(eventstack[nodeToken][threadToken]==null||eventstack[nodeToken][threadToken].size()==0)
+			if(!eventstack.containsKey(glob)||eventstack.get(glob).size()==0)//if(eventstack[nodeToken][threadToken]==null||eventstack[nodeToken][threadToken].size()==0)
 			{
 				System.err.println("Fault: Exit from empty or uninitialized thread");
 				System.exit(1);
 			}
-			PrimEvent leave = (PrimEvent) (((EZStack)eventstack.get(glob)).pop());
+			PrimEvent leave = (PrimEvent) (eventstack.get(glob).pop());
 			if(leave.stateToken!=stateToken)
 			{
 				System.err.println("Fault: Event order failure.");
@@ -497,7 +581,17 @@ public class InputLog implements base.drawable.InputAPI
 			}
 			prime = new base.drawable.Primitive(stateToken,leave.time*clockP,time*clockP,
 					new double[]{leave.time*clockP,time*clockP} ,new int[]{GlobalID(nodeToken,threadToken),GlobalID(nodeToken,threadToken)},null);//((Integer)global.get(new Point(nodeToken,threadToken))).intValue(),((Integer)global.get(new Point(nodeToken,threadToken))).intValue()
-			eventReady=true;
+			
+			
+			if(lastPrime==null||(
+					comparePrimatives(prime,lastPrime)
+					))
+			{	
+				eventReady=true;
+				lastPrime=prime;
+			}
+			
+			
 			//System.out.println(nodeToken+" "+threadToken+" vs. "+((Integer)global.get(new Point(nodeToken,threadToken))).intValue()+" "+((Integer)global.get(new Point(nodeToken,threadToken))).intValue());
 			return 0;
 		}
@@ -511,10 +605,28 @@ public class InputLog implements base.drawable.InputAPI
 //			return false;
 //		}
 		
+		/**
+		 * Returns true if the argument primitives are not too similar to both be printed.  False if they should not both be printed (they are the same category in the same location)
+		 * @param prim1
+		 * @param prim2
+		 * @return
+		 */
+		private static boolean comparePrimatives(Primitive prim1,Primitive prim2){
+			if(prim1.getCategoryIndex()!=prim2.getCategoryIndex()||!prim1.equals(prim2)||(prim1.getStartVertex().lineID!=prim2.getStartVertex().lineID&&prim1.getFinalVertex().lineID!=prim2.getFinalVertex().lineID))
+				return true;
+			return false;
+		}
+		
 		public int sendMessage(Object userData, long time, int sourceNodeToken, int sourceThreadToken, 
 				int destinationNodeToken, int destinationThreadToken, int messageSize, int messageTag, int messageComm){
 
-			destinationThreadToken=0;
+			if(remoteThread>-1)
+			{
+				destinationThreadToken=remoteThread;
+				remoteThread=-1;
+			}
+			else
+				destinationThreadToken=0;
 			/*
 			 * The 'tag space' and 'eventId space' may overlap and overwrite each other
 			 * So add the highest tag ID+1, to be sure all IDs sent to jumpshot are unique.
@@ -538,7 +650,8 @@ public class InputLog implements base.drawable.InputAPI
 			 */
 			int destGlob = GlobalID(destinationNodeToken,destinationThreadToken);
 			int sourceGlob = GlobalID(sourceNodeToken,sourceThreadToken);
-			Long srcDst=new Long(SourceDest(sourceGlob,destGlob));
+			//Long srcDst=new Long(SourceDest(sourceGlob,destGlob,messageTag));
+			ComSource cs = new ComSource(sourceGlob,destGlob,messageTag);
 			
 			MessageEvent sndE=new MessageEvent(time,messageTag,sourceGlob,destGlob,messageSize,messageComm);
 			
@@ -547,7 +660,7 @@ public class InputLog implements base.drawable.InputAPI
 			 * If we have a message event in the recieved list then there has been a recieve sent before its send.
 			 * Match this send with the advanced recieve and submit the event.  (Is this always correct?)
 			 */
-			if(msgRecStack.containsKey(srcDst) && ((LinkedList)msgRecStack.get(srcDst)).size()>0 &&(leave=(MessageEvent)((LinkedList)msgRecStack.get(srcDst)).removeFirst())!=null)
+			if(msgRecStack.containsKey(cs) && msgRecStack.get(cs).size()>0 &&(leave=(MessageEvent)msgRecStack.get(cs).remove(0))!=null)
 			{
 					System.out.println("Reversed Message: time "+time+", source nid "+ sourceNodeToken +
 							" tid "+sourceThreadToken+", destination nid "+destinationNodeToken+" tid "+
@@ -556,7 +669,17 @@ public class InputLog implements base.drawable.InputAPI
 							new double[]{time*clockP,leave.time*clockP,} ,
 							new int[]{sourceGlob,destGlob},
 							getInfoVals(new int[]{messageTag,messageSize,messageComm}));
-					eventReady=true;
+					
+					
+					if(lastPrime==null||(
+							comparePrimatives(prime,lastPrime)
+							))
+					{	
+						eventReady=true;
+						lastPrime=prime;
+					}
+					
+					//eventReady=true;
 					return 0;
 			}
 			
@@ -564,25 +687,32 @@ public class InputLog implements base.drawable.InputAPI
 			 * If we do not yet have an event source-list list for this transaction ID, create one
 			 * Put this event in the source list
 			 */
-			if(!msgSenStack.containsKey(srcDst))
-				msgSenStack.put(srcDst, new LinkedList());
-			((LinkedList)msgSenStack.get(srcDst)).add(sndE);
+			if(!msgSenStack.containsKey(cs))
+				msgSenStack.put(cs, new LinkedList<MessageEvent>());
+			msgSenStack.get(cs).add(sndE);
 			return 0;
-		}
+		}//sendMessage
 		
 		public int recvMessage(Object userData, long time, int sourceNodeToken, int sourceThreadToken, 
 				int destinationNodeToken, int destinationThreadToken, int messageSize, int messageTag, int messageComm){
 			
 			int messageTagShift=messageTag+maxEvtId+1;
-			sourceThreadToken=0;
+			
+			if(remoteThread>-1)
+			{
+				sourceThreadToken=remoteThread;
+				remoteThread=-1;
+			}
+			else
+				sourceThreadToken=0;
 			int sourceGlob = GlobalID(sourceNodeToken,sourceThreadToken);
 			int destGlob = GlobalID(destinationNodeToken,destinationThreadToken);
-			Long srcDst=new Long(SourceDest(sourceGlob,destGlob));
-			
+			//Long srcDst=new Long(SourceDest(sourceGlob,destGlob,messageTag));
+			ComSource cs = new ComSource(sourceGlob,destGlob,messageTag);
 			MessageEvent recE=new MessageEvent(time,messageTag, sourceGlob,destGlob,messageSize,messageComm);
 			
 			MessageEvent leave;
-			if(msgSenStack.containsKey(srcDst) && ((LinkedList)msgSenStack.get(srcDst)).size()>0 && (leave=(MessageEvent)((LinkedList)msgSenStack.get(srcDst)).removeFirst())!=null)
+			if(msgSenStack.containsKey(cs) && msgSenStack.get(cs).size()>0 && (leave=(MessageEvent)msgSenStack.get(cs).remove(0))!=null)
 			{
 					prime = new base.drawable.Primitive(messageTagShift,leave.time*clockP,time*clockP,
 							new double[]{leave.time*clockP,time*clockP},
@@ -590,18 +720,38 @@ public class InputLog implements base.drawable.InputAPI
 							sourceGlob,destGlob
 							},
 							getInfoVals(new int[]{messageTag,messageSize,messageComm}));
-					eventReady=true;
+					
+					if(lastPrime==null||(
+							comparePrimatives(prime,lastPrime)
+							))
+					{	
+						eventReady=true;
+						lastPrime=prime;
+					}
+					
+					//eventReady=true;
 					return 0;
 			}
 			
-			if(!msgRecStack.containsKey(srcDst))
-				msgRecStack.put(srcDst, new LinkedList());
-			((LinkedList)msgRecStack.get(srcDst)).add(recE);
+			if(!msgRecStack.containsKey(cs))
+				msgRecStack.put(cs, new LinkedList<MessageEvent>());
+			msgRecStack.get(cs).add(recE);
 			return 0;
-		}
+		}//recvMessage
+		
+		/*
+		 * If a message is sent from a thread (7004) we need to get its value from the send since we don't get thread values in messages naturally.
+		 */
+		int remoteThread=-1;
 		
 		public int eventTrigger(Object userData, long time, int nodeToken, int threadToken, int userEventToken,
 				double userEventValue){
+			
+			if(userEventToken==7004){
+				remoteThread=(int) userEventValue;
+				return 0;
+			}
+			
 			//System.out.println("EventTrigger: time "+time+", nid "+nodeToken+" tid "+threadToken+" event id "+userEventToken+" triggered value "+userEventValue);
 			if(noMonEvents.contains(new Integer(userEventToken)))
 			{
@@ -628,13 +778,21 @@ public class InputLog implements base.drawable.InputAPI
 					return 0;
 				}
 			}
+			//System.out.println("Test Evt Double: "+userEventValue+" vs: "+(long)userEventValue);
 			prime = new base.drawable.Primitive(userEventToken,time*clockP,time*clockP,
 					new double[]{time*clockP} ,new int[]{
 					GlobalID(nodeToken,threadToken)
 					//((Integer)global.get(new Point(nodeToken,threadToken))).intValue()
 					},
-					getInfoVals(new int[]{(int)userEventValue}));
-			eventReady=true;
+					getInfoVals(new double[]{userEventValue}));
+			if(lastPrime==null||(
+					comparePrimatives(prime,lastPrime)
+					))
+			{	
+				eventReady=true;
+				lastPrime=prime;
+			}
+			//eventReady=true;
 			return 0;
 		}
 
