@@ -69,17 +69,12 @@ int getdtablesize(void);
 int dynamic = TRUE ; /* by default events.<node>.edf files exist */
 int dontblock = FALSE; /* by default, block waiting for records, online merge*/
 char *mergededffile = NULL; /* default merged EDF file name */
-#if !(defined(TAU_XLC) || defined (TAU_NEC))
-extern "C" {
-#endif /* TAU_XLC || TAU_NEC */
-  int open_edf_file(char *prefix, int nodeid, int prefix_is_filename);
-  int parse_edf_file(int node);
-  int store_merged_edffile(char *filename);
-  const char *get_event_name(int gid);
-  int GID(int node, long localEventId); 
-#if!(defined(TAU_XLC) || defined (TAU_NEC)) 
-} 
-#endif /* TAU_XLC || TAU_NEC */
+
+int open_edf_file(char *prefix, int nodeid, int prefix_is_filename);
+int parse_edf_file(int node);
+int store_merged_edffile(char *filename);
+const char *get_event_name(int gid);
+int GID(int node, long localEventId); 
 
 
 struct trcdescr
@@ -719,7 +714,7 @@ static void output(int fd, char *data, size_t l)
 int cannot_get_enough_fd(int need)
 {
 #ifdef TAU_WINDOWS
-  return false; /* no getdtablesize() in windows*/
+  return FALSE; /* no getdtablesize() in windows*/
 #else	
 # if defined(__hpux) || defined(sun)
   /* -- system supports get/setrlimit (RLIMIT_NOFILE) -- */
@@ -1219,7 +1214,7 @@ int main(int argc, char *argv[])
     nativeEvent.tid = event_GetTid(trcdes+source,trcdes[source].erec,0);
     nativeEvent.par = event_GetPar(trcdes+source,trcdes[source].erec,0);
     nativeEvent.ti = event_GetTi(trcdes+source,trcdes[source].erec,0);
-/*     printf ("writing out record with ev = %d\n", nativeEvent.ev); */
+    /* printf ("writing out record with ev = %d, nid = %d\n", nativeEvent.ev, nativeEvent.nid);  */
     output (outfd, (char *) &nativeEvent, sizeof(TAU_EV));
 
     numrec++;
@@ -1247,8 +1242,11 @@ int main(int argc, char *argv[])
           /* -- correct nid event field (only the first time) --------------- */
           if ( trcdes[source].nid != -1 ) {
 	    /*erec->nid = trcdes[source].nid;*/
-
-	    event_SetNid(trcdes+source,erec,0,trcdes[source].nid);
+	    /* Removed code to explicitly set the node id to the node id of 
+	the trace. This hinders merging traces that have remote one-sided events
+	where a given trace has events that take place on a remote node as in 
+	send or receive in one-sided put operations. */
+	    /*event_SetNid(trcdes+source,erec,0,trcdes[source].nid); */
 	  }
 
           /* -- correct clock ----------------------------------------------- */
