@@ -22,6 +22,9 @@
 #include <string>
 #include <vector> 
 #include "tau_instrument.h"
+#include <string.h>
+#include <stdlib.h>
+
 
 using namespace std;
 
@@ -52,25 +55,34 @@ void printInstrumentList(void);
 int processInstrumentationRequests(char *fname)
 {
   ifstream input(fname); 
-  char inbuf[INBUF_SIZE];
+  char line[INBUF_SIZE];
+  char* inbuf;
   int lineno = 0; 
 
   if (!input)
   {
-    cout << "ERROR: Cannot open file" << fname<<endl;
+    cout << "ERROR: Cannot open file: " << fname<<endl;
     return 0; 
   }
 #ifdef DEBUG
   printf("Inside processInstrumentationRequests\n");
 #endif /* DEBUG */
-  while (input.getline(inbuf, INBUF_SIZE) || input.gcount()) {  
+  while (input.getline(line, INBUF_SIZE) || input.gcount()) {
     lineno++;
+    /* Skip whitespaces at the beginning of line */
+    inbuf = line;
+    while (isspace(*inbuf))
+      ++inbuf;
     if ((inbuf[0] == '#') || (inbuf[0] == '\0')) continue;
     if (strcmp(inbuf,BEGIN_EXCLUDE_TOKEN) == 0) 
     {
-      while(input.getline(inbuf,INBUF_SIZE) || input.gcount())
+      while(input.getline(line,INBUF_SIZE) || input.gcount())
       {
         lineno++;
+        /* Skip whitespaces at the beginning of line */
+        inbuf = line;
+        while (isspace(*inbuf))
+          ++inbuf;
 	if (strcmp(inbuf, END_EXCLUDE_TOKEN) == 0)
 	  break; /* Found the end of exclude list. */  
         if ((inbuf[0] == '#') || (inbuf[0] == '\0')) continue;
@@ -100,9 +112,13 @@ int processInstrumentationRequests(char *fname)
     }
     if (strcmp(inbuf,BEGIN_INCLUDE_TOKEN) == 0) 
     {
-      while(input.getline(inbuf,INBUF_SIZE) || input.gcount())
+      while(input.getline(line,INBUF_SIZE) || input.gcount())
       {
         lineno++;
+        /* Skip whitespaces at the beginning of line */
+        inbuf = line;
+        while (isspace(*inbuf))
+          ++inbuf;
 	if (strcmp(inbuf, END_INCLUDE_TOKEN) == 0)
 	  break; /* Found the end of exclude list. */  
         if ((inbuf[0] == '#') || (inbuf[0] == '\0')) continue;
@@ -133,9 +149,13 @@ int processInstrumentationRequests(char *fname)
     }
     if (strcmp(inbuf,BEGIN_FILE_INCLUDE_TOKEN) == 0) 
     {
-      while(input.getline(inbuf,INBUF_SIZE) || input.gcount())
+      while(input.getline(line,INBUF_SIZE) || input.gcount())
       {
         lineno++;
+        /* Skip whitespaces at the beginning of line */
+        inbuf = line;
+        while (isspace(*inbuf))
+          ++inbuf;
 	if (strcmp(inbuf, END_FILE_INCLUDE_TOKEN) == 0)
 	  break; /* Found the end of file include list. */  
         if ((inbuf[0] == '#') || (inbuf[0] == '\0')) continue;
@@ -147,9 +167,13 @@ int processInstrumentationRequests(char *fname)
     }
     if (strcmp(inbuf,BEGIN_FILE_EXCLUDE_TOKEN) == 0) 
     {
-      while(input.getline(inbuf,INBUF_SIZE) || input.gcount())
+      while(input.getline(line,INBUF_SIZE) || input.gcount())
       {
         lineno++;
+        /* Skip whitespaces at the beginning of line */
+        inbuf = line;
+        while (isspace(*inbuf))
+          ++inbuf;
 	if (strcmp(inbuf, END_FILE_EXCLUDE_TOKEN) == 0)
 	  break; /* Found the end of file exclude list. */  
         if ((inbuf[0] == '#') || (inbuf[0] == '\0')) continue;
@@ -158,9 +182,13 @@ int processInstrumentationRequests(char *fname)
     }
     if (strcmp(inbuf,BEGIN_INSTRUMENT_SECTION) == 0) 
     {
-      while(input.getline(inbuf,INBUF_SIZE) || input.gcount())
+      while(input.getline(line,INBUF_SIZE) || input.gcount())
       {
         lineno++;
+        /* Skip whitespaces at the beginning of line */
+        inbuf = line;
+        while (isspace(*inbuf))
+          ++inbuf;
 	if (strcmp(inbuf, END_INSTRUMENT_SECTION) == 0)
 	  break; /* Found the end of file exclude list. */  
         if ((inbuf[0] == '#') || (inbuf[0] == '\0')) continue;
@@ -263,18 +291,16 @@ bool matchName(const string& str1, const string& str2)
 /* -------------------------------------------------------------------------- */
 /* -- should the routine be instrumented? Returns true or false ------------- */
 /* -------------------------------------------------------------------------- */
-bool instrumentEntity(const string& function_name)
-{
+bool instrumentEntity(const string& function_name) {
   list<string>::iterator it;
 #ifdef DEBUG
   cout <<"instrument "<<function_name<<" ?"<<endl;
 #endif /* DEBUG */
-  if (!excludelist.empty())
-  { /* if exclude list has entries */
-    for (it = excludelist.begin(); it != excludelist.end(); it++)
-    { /* iterate through the entries and see if the names match */
-      if (matchName(*it, function_name)) 
-      {
+  if (!excludelist.empty()) { 
+    /* if exclude list has entries */
+    for (it = excludelist.begin(); it != excludelist.end(); it++) { 
+      /* iterate through the entries and see if the names match */
+      if (matchName(*it, function_name)) {
         /* names match! This routine should not be instrumented */
 #ifdef DEBUG
 	cout <<"Don't instrument: "<<function_name<<" it is in exclude list"<<endl;
@@ -283,34 +309,27 @@ bool instrumentEntity(const string& function_name)
       }
     }
   }  
-
+  
   /* There is no entry in the exclude list that matches function_name. */ 
-  if (includelist.empty())
-  {
+  if (includelist.empty()) {
 #ifdef DEBUG
-    cout <<"Instrumenting ... "<< function_name
-	 << " INCLUDE list is empty" <<endl;
+    cout <<"Instrumenting ... "<< function_name << " INCLUDE list is empty" <<endl;
 #endif /* DEBUG */
     /* There are no entries in the include list */
     return true; /* instrument the given routine */
-  }
-  else
-  {
+  } else {
     /* wait! The include list is not empty. We must see if the given name
        appears in the list of routines that should be instrumented 
        For this, we need to iterate through the include list.  */
-    for (it = includelist.begin(); it != includelist.end(); it++)
-    { /* iterate through the entries and see if the names match */
-      if (matchName(*it, function_name)) 
-      {
+    for (it = includelist.begin(); it != includelist.end(); it++) { 
+      /* iterate through the entries and see if the names match */
+      if (matchName(*it, function_name)) {
         /* names match! This routine should be instrumented */
 #ifdef DEBUG
 	cout <<"Instrument "<< function_name<<" matchName is true "<<endl;
 #endif /* DEBUG */
         return true;
-      }
-      else 
-      {
+      } else {
 #ifdef DEBUG
 	cout <<"Iterate over include_list: "
 	     << function_name<<" matchName is false "<<endl;
@@ -443,7 +462,7 @@ bool processFileForInstrumentation(const string& file_name)
 
 
 /***************************************************************************
- * $RCSfile: tau_selective.cpp,v $   $Author: sameer $
- * $Revision: 1.15 $   $Date: 2007/11/02 02:23:21 $
- * VERSION_ID: $Id: tau_selective.cpp,v 1.15 2007/11/02 02:23:21 sameer Exp $
+ * $RCSfile: tau_selective.cpp,v $   $Author: amorris $
+ * $Revision: 1.19 $   $Date: 2009/07/24 22:19:27 $
+ * VERSION_ID: $Id: tau_selective.cpp,v 1.19 2009/07/24 22:19:27 amorris Exp $
  ***************************************************************************/
